@@ -1,4 +1,4 @@
-# -*- coding: utf-8 -*-
+# sage.doctest: needs sage.combinat sage.modules
 """
 Free algebras
 
@@ -17,16 +17,17 @@ AUTHORS:
 
 EXAMPLES::
 
-    sage: F = FreeAlgebra(ZZ,3,'x,y,z')
+    sage: F = FreeAlgebra(ZZ, 3, 'x,y,z')
     sage: F.base_ring()
     Integer Ring
     sage: G = FreeAlgebra(F, 2, 'm,n'); G
-    Free Algebra on 2 generators (m, n) over Free Algebra on 3 generators (x, y, z) over Integer Ring
+    Free Algebra on 2 generators (m, n) over
+     Free Algebra on 3 generators (x, y, z) over Integer Ring
     sage: G.base_ring()
     Free Algebra on 3 generators (x, y, z) over Integer Ring
 
 The above free algebra is based on a generic implementation. By
-:trac:`7797`, there is a different implementation
+:issue:`7797`, there is a different implementation
 :class:`~sage.algebras.letterplace.free_algebra_letterplace.FreeAlgebra_letterplace`
 based on Singular's letterplace rings. It is currently restricted to
 weighted homogeneous elements and is therefore not the default. But the
@@ -34,8 +35,8 @@ arithmetic is much faster than in the generic implementation.
 Moreover, we can compute Groebner bases with degree bound for its
 two-sided ideals, and thus provide ideal containment tests::
 
-    sage: F.<x,y,z> = FreeAlgebra(QQ, implementation='letterplace')
-    sage: F
+    sage: # needs sage.libs.singular
+    sage: F.<x,y,z> = FreeAlgebra(QQ, implementation='letterplace'); F
     Free Associative Unital Algebra on 3 generators (x, y, z) over Rational Field
     sage: I = F*[x*y+y*z,x^2+x*y-y*x-y^2]*F
     sage: I.groebner_basis(degbound=4)
@@ -52,8 +53,9 @@ two-sided ideals, and thus provide ideal containment tests::
     True
 
 Positive integral degree weights for the letterplace implementation
-was introduced in :trac:`7797`::
+was introduced in :issue:`7797`::
 
+    sage: # needs sage.libs.singular
     sage: F.<x,y,z> = FreeAlgebra(QQ, implementation='letterplace', degrees=[2,1,3])
     sage: x.degree()
     2
@@ -73,6 +75,8 @@ TESTS::
     sage: TestSuite(F).run()
     sage: F is loads(dumps(F))
     True
+
+    sage: # needs sage.libs.singular
     sage: F = FreeAlgebra(GF(5),3,'x', implementation='letterplace')
     sage: TestSuite(F).run()
     sage: F is loads(dumps(F))
@@ -84,6 +88,8 @@ TESTS::
     sage: TestSuite(F).run()
     sage: F is loads(dumps(F))
     True
+
+    sage: # needs sage.libs.singular
     sage: F.<x,y,z> = FreeAlgebra(GF(5),3, implementation='letterplace')
     sage: TestSuite(F).run()
     sage: F is loads(dumps(F))
@@ -95,6 +101,8 @@ TESTS::
     sage: TestSuite(F).run()
     sage: F is loads(dumps(F))
     True
+
+    sage: # needs sage.libs.singular
     sage: F = FreeAlgebra(GF(5),3, ['xx', 'zba', 'Y'], implementation='letterplace')
     sage: TestSuite(F).run()
     sage: F is loads(dumps(F))
@@ -106,6 +114,8 @@ TESTS::
     sage: TestSuite(F).run()
     sage: F is loads(dumps(F))
     True
+
+    sage: # needs sage.libs.singular
     sage: F = FreeAlgebra(GF(5),3, 'abc', implementation='letterplace')
     sage: TestSuite(F).run()
     sage: F is loads(dumps(F))
@@ -121,13 +131,23 @@ TESTS::
 Note that the letterplace implementation can only be used if the corresponding
 (multivariate) polynomial ring has an implementation in Singular::
 
-    sage: FreeAlgebra(FreeAlgebra(ZZ,2,'ab'), 2, 'x', implementation='letterplace')
+    sage: FreeAlgebra(FreeAlgebra(ZZ,2,'ab'), 2, 'x', implementation='letterplace')     # needs sage.libs.singular
     Traceback (most recent call last):
     ...
-    NotImplementedError: polynomials over Free Algebra on 2 generators (a, b) over Integer Ring are not supported in Singular
+    NotImplementedError: polynomials over Free Algebra on 2 generators (a, b)
+    over Integer Ring are not supported in Singular
+
+Some tests for the category::
+
+    sage: R.<x> = FreeAlgebra(QQ,1)
+    sage: R.is_commutative()
+    True
+    sage: R.<x,y> = FreeAlgebra(QQ,2)
+    sage: R.is_commutative()
+    False
 """
 
-#*****************************************************************************
+# ***************************************************************************
 #       Copyright (C) 2005 David Kohel <kohel@maths.usyd.edu>
 #       Copyright (C) 2005,2006 William Stein <wstein@gmail.com>
 #       Copyright (C) 2011 Simon King <simon.king@uni-jena.de>
@@ -136,8 +156,8 @@ Note that the letterplace implementation can only be used if the corresponding
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 2 of the License, or
 # (at your option) any later version.
-#                  http://www.gnu.org/licenses/
-#*****************************************************************************
+#                  https://www.gnu.org/licenses/
+# ***************************************************************************
 
 
 from sage.categories.rings import Rings
@@ -149,14 +169,18 @@ from sage.algebras.free_algebra_element import FreeAlgebraElement
 
 from sage.structure.factory import UniqueFactory
 from sage.misc.cachefunc import cached_method
+from sage.misc.lazy_import import lazy_import
 from sage.rings.polynomial.polynomial_ring_constructor import PolynomialRing
-from sage.rings.ring import Algebra
+from sage.rings.integer_ring import ZZ
 from sage.categories.algebras_with_basis import AlgebrasWithBasis
 from sage.combinat.free_module import CombinatorialFreeModule
 from sage.combinat.words.word import Word
 from sage.structure.category_object import normalize_names
 
 
+lazy_import('sage.algebras.letterplace.free_algebra_letterplace', 'FreeAlgebra_letterplace')
+
+
 class FreeAlgebraFactory(UniqueFactory):
     """
     A constructor of free algebras.
@@ -179,7 +203,8 @@ class FreeAlgebraFactory(UniqueFactory):
         sage: FreeAlgebra(GF(5),1, ['alpha'])
         Free Algebra on 1 generators (alpha,) over Finite Field of size 5
         sage: FreeAlgebra(FreeAlgebra(ZZ,1,'a'), 2, 'x')
-        Free Algebra on 2 generators (x0, x1) over Free Algebra on 1 generators (a,) over Integer Ring
+        Free Algebra on 2 generators (x0, x1) over
+         Free Algebra on 1 generators (a,) over Integer Ring
 
     Free algebras are globally unique::
 
@@ -196,13 +221,14 @@ class FreeAlgebraFactory(UniqueFactory):
         True
         sage: TestSuite(F).run()
 
-    By :trac:`7797`, we provide a different implementation of free
+    By :issue:`7797`, we provide a different implementation of free
     algebras, based on Singular's "letterplace rings". Our letterplace
     wrapper allows for choosing positive integral degree weights for the
     generators of the free algebra. However, only (weighted) homogeneous
     elements are supported. Of course, isomorphic algebras in different
     implementations are not identical::
 
+        sage: # needs sage.libs.singular
         sage: G = FreeAlgebra(GF(5),['x','y','z'], implementation='letterplace')
         sage: F == G
         False
@@ -214,10 +240,13 @@ class FreeAlgebraFactory(UniqueFactory):
 
     ::
 
-        sage: H = FreeAlgebra(GF(5),['x','y','z'], implementation='letterplace', degrees=[1,2,3])
+        sage: # needs sage.libs.singular
+        sage: H = FreeAlgebra(GF(5), ['x','y','z'], implementation='letterplace',
+        ....:                 degrees=[1,2,3])
         sage: F != H != G
         True
-        sage: H is FreeAlgebra(GF(5),['x','y','z'], implementation='letterplace', degrees=[1,2,3])
+        sage: H is FreeAlgebra(GF(5),['x','y','z'], implementation='letterplace',
+        ....:                  degrees=[1,2,3])
         True
         sage: copy(H) is H is loads(dumps(H))
         True
@@ -235,14 +264,15 @@ class FreeAlgebraFactory(UniqueFactory):
         sage: s = a*b^2 * c^3; s
         a*b^2*c^3
         sage: parent(s)
-        Free Algebra on 1 generators (c,) over Free Algebra on 2 generators (a, b) over Rational Field
+        Free Algebra on 1 generators (c,) over
+         Free Algebra on 2 generators (a, b) over Rational Field
         sage: c^3 * a * b^2
         a*b^2*c^3
     """
     def create_key(self, base_ring, arg1=None, arg2=None,
-            sparse=None, order=None,
-            names=None, name=None,
-            implementation=None, degrees=None):
+                   sparse=None, order=None,
+                   names=None, name=None,
+                   implementation=None, degrees=None):
         """
         Create the key under which a free algebra is stored.
 
@@ -254,13 +284,19 @@ class FreeAlgebraFactory(UniqueFactory):
             (Finite Field of size 5, ('x', 'y', 'z'))
             sage: FreeAlgebra.create_key(GF(5),3,'xyz')
             (Finite Field of size 5, ('x', 'y', 'z'))
-            sage: FreeAlgebra.create_key(GF(5),['x','y','z'], implementation='letterplace')
+
+            sage: # needs sage.libs.singular
+            sage: FreeAlgebra.create_key(GF(5),['x','y','z'],
+            ....:                        implementation='letterplace')
             (Multivariate Polynomial Ring in x, y, z over Finite Field of size 5,)
-            sage: FreeAlgebra.create_key(GF(5),['x','y','z'],3, implementation='letterplace')
+            sage: FreeAlgebra.create_key(GF(5),['x','y','z'],3,
+            ....:                        implementation='letterplace')
             (Multivariate Polynomial Ring in x, y, z over Finite Field of size 5,)
-            sage: FreeAlgebra.create_key(GF(5),3,'xyz', implementation='letterplace')
+            sage: FreeAlgebra.create_key(GF(5),3,'xyz',
+            ....:                        implementation='letterplace')
             (Multivariate Polynomial Ring in x, y, z over Finite Field of size 5,)
-            sage: FreeAlgebra.create_key(GF(5),3,'xyz', implementation='letterplace', degrees=[1,2,3])
+            sage: FreeAlgebra.create_key(GF(5),3,'xyz',
+            ....:                        implementation='letterplace', degrees=[1,2,3])
             ((1, 2, 3), Multivariate Polynomial Ring in x, y, z, x_ over Finite Field of size 5)
 
         """
@@ -268,13 +304,13 @@ class FreeAlgebraFactory(UniqueFactory):
             # this is used for pickling
             if degrees is None:
                 return (base_ring,)
-            return tuple(degrees),base_ring
+            return tuple(degrees), base_ring
         # test if we can use libSingular/letterplace
         if implementation == "letterplace":
             if order is None:
                 order = 'degrevlex' if degrees is None else 'deglex'
             args = [arg for arg in (arg1, arg2) if arg is not None]
-            kwds = dict(sparse=sparse, order=order, implementation="singular")
+            kwds = {'sparse': sparse, 'order': order, 'implementation': "singular"}
             if name is not None:
                 kwds["name"] = name
             if names is not None:
@@ -304,7 +340,11 @@ class FreeAlgebraFactory(UniqueFactory):
         if arg2 is None:
             arg2 = len(arg1)
         names = normalize_names(arg2, arg1)
-        return base_ring, names
+        if degrees is None:
+            return base_ring, names
+        if degrees in ZZ:
+            return base_ring, names, (degrees,) * len(names)
+        return base_ring, names, tuple(degrees)
 
     def create_object(self, version, key):
         """
@@ -321,7 +361,6 @@ class FreeAlgebraFactory(UniqueFactory):
             Free Associative Unital Algebra on 2 generators (x, y) over Rational Field
             sage: FreeAlgebra.create_object('4.7.1', (QQ['x','y'],)) is FreeAlgebra(QQ,['x','y'])
             False
-
         """
         if len(key) == 1:
             from sage.algebras.letterplace.free_algebra_letterplace import FreeAlgebra_letterplace
@@ -329,19 +368,26 @@ class FreeAlgebraFactory(UniqueFactory):
         if isinstance(key[0], tuple):
             from sage.algebras.letterplace.free_algebra_letterplace import FreeAlgebra_letterplace
             return FreeAlgebra_letterplace(key[1], degrees=key[0])
-        return FreeAlgebra_generic(key[0], len(key[1]), key[1])
+        if len(key) == 2:
+            return FreeAlgebra_generic(key[0], len(key[1]), key[1])
+        return FreeAlgebra_generic(key[0], len(key[1]), key[1], key[2])
+
 
 FreeAlgebra = FreeAlgebraFactory('FreeAlgebra')
 
 
-def is_FreeAlgebra(x):
+def is_FreeAlgebra(x) -> bool:
     """
-    Return True if x is a free algebra; otherwise, return False.
+    Return ``True`` if x is a free algebra; otherwise, return ``False``.
 
     EXAMPLES::
 
         sage: from sage.algebras.free_algebra import is_FreeAlgebra
         sage: is_FreeAlgebra(5)
+        doctest:warning...
+        DeprecationWarning: the function is_FreeAlgebra is deprecated;
+        use 'isinstance(..., (FreeAlgebra_generic, FreeAlgebra_letterplace))' instead
+        See https://github.com/sagemath/sage/issues/37896 for details.
         False
         sage: is_FreeAlgebra(ZZ)
         False
@@ -349,15 +395,16 @@ def is_FreeAlgebra(x):
         True
         sage: is_FreeAlgebra(FreeAlgebra(ZZ,10,'x',implementation='letterplace'))
         True
-        sage: is_FreeAlgebra(FreeAlgebra(ZZ,10,'x',implementation='letterplace', degrees=list(range(1,11))))
+        sage: is_FreeAlgebra(FreeAlgebra(ZZ,10,'x',implementation='letterplace',
+        ....:                            degrees=list(range(1,11))))
         True
-
     """
-    from sage.algebras.letterplace.free_algebra_letterplace import FreeAlgebra_letterplace
-    return isinstance(x, (FreeAlgebra_generic,FreeAlgebra_letterplace))
+    from sage.misc.superseded import deprecation
+    deprecation(37896, "the function is_FreeAlgebra is deprecated; use 'isinstance(..., (FreeAlgebra_generic, FreeAlgebra_letterplace))' instead")
+    return isinstance(x, (FreeAlgebra_generic, FreeAlgebra_letterplace))
 
 
-class FreeAlgebra_generic(CombinatorialFreeModule, Algebra):
+class FreeAlgebra_generic(CombinatorialFreeModule):
     """
     The free algebra on `n` generators over a base ring.
 
@@ -366,6 +413,9 @@ class FreeAlgebra_generic(CombinatorialFreeModule, Algebra):
     - ``R`` -- a ring
     - ``n`` -- an integer
     - ``names`` -- the generator names
+    - ``degrees`` -- (optional) a tuple or list specifying the
+      degrees of all the generators, if omitted, the algebra is not
+      graded
 
     EXAMPLES::
 
@@ -382,8 +432,7 @@ class FreeAlgebra_generic(CombinatorialFreeModule, Algebra):
 
     TESTS:
 
-    Free algebras commute with their base ring.
-    ::
+    Free algebras commute with their base ring::
 
         sage: K.<a,b> = FreeAlgebra(QQ)
         sage: K.is_commutative()
@@ -414,14 +463,14 @@ class FreeAlgebra_generic(CombinatorialFreeModule, Algebra):
         sage: F == FreeAlgebra(QQ,3,'y')
         False
 
-    Note that since :trac:`7797` there is a different
+    Note that since :issue:`7797` there is a different
     implementation of free algebras. Two corresponding free
     algebras in different implementations are not equal, but there
     is a coercion.
     """
     Element = FreeAlgebraElement
 
-    def __init__(self, R, n, names):
+    def __init__(self, R, n, names, degrees=None):
         """
         The free algebra on `n` generators over a base ring.
 
@@ -444,9 +493,20 @@ class FreeAlgebra_generic(CombinatorialFreeModule, Algebra):
         self.__ngens = n
         indices = FreeMonoid(n, names=names)
         cat = AlgebrasWithBasis(R)
+        if self.__ngens <= 1 and R.is_commutative():
+            cat = cat.Commutative()
+        if degrees is not None:
+            if len(degrees) != len(names) or not all(d in ZZ for d in degrees):
+                raise ValueError("argument degrees must specify an integer for each generator")
+            cat = cat.Graded()
+
         CombinatorialFreeModule.__init__(self, R, indices, prefix='F',
                                          category=cat)
         self._assign_names(indices.variable_names())
+        if degrees is None:
+            self._degrees = None
+        else:
+            self._degrees = {g: ZZ(d) for g, d in zip(self.monoid().gens(), degrees)}
 
     def one_basis(self):
         """
@@ -462,9 +522,11 @@ class FreeAlgebra_generic(CombinatorialFreeModule, Algebra):
         """
         return self._indices.one()
 
-    def is_field(self, proof=True):
+    def is_field(self, proof=True) -> bool:
         """
-        Return True if this Free Algebra is a field, which is only if the
+        Return ``True`` if this Free Algebra is a field.
+
+        This happens only if the
         base ring is a field and there are no generators
 
         EXAMPLES::
@@ -480,40 +542,31 @@ class FreeAlgebra_generic(CombinatorialFreeModule, Algebra):
             return self.base_ring().is_field(proof)
         return False
 
-    def is_commutative(self):
-        """
-        Return True if this free algebra is commutative.
-
-        EXAMPLES::
-
-            sage: R.<x> = FreeAlgebra(QQ,1)
-            sage: R.is_commutative()
-            True
-            sage: R.<x,y> = FreeAlgebra(QQ,2)
-            sage: R.is_commutative()
-            False
-        """
-        return self.__ngens <= 1 and self.base_ring().is_commutative()
-
-    def _repr_(self):
+    def _repr_(self) -> str:
         """
         Text representation of this free algebra.
 
         EXAMPLES::
 
-            sage: F = FreeAlgebra(QQ,3,'x')
-            sage: F  # indirect doctest
+            sage: F = FreeAlgebra(QQ, 3, 'x')
+            sage: F                                                             # indirect doctest
             Free Algebra on 3 generators (x0, x1, x2) over Rational Field
             sage: F.rename('QQ<<x0,x1,x2>>')
-            sage: F #indirect doctest
+            sage: F                                                             # indirect doctest
             QQ<<x0,x1,x2>>
-            sage: FreeAlgebra(ZZ,1,['a'])
+            sage: FreeAlgebra(ZZ, 1, ['a'])
             Free Algebra on 1 generators (a,) over Integer Ring
-        """
-        return "Free Algebra on {} generators {} over {}".format(
-            self.__ngens, self.gens(), self.base_ring())
 
-    def _latex_(self):
+            sage: FreeAlgebra(QQ, 2, ['x', 'y'], degrees=(2,1))
+            Free Algebra on 2 generators (x, y) with degrees (2, 1) over Rational Field
+        """
+        if self._degrees is None:
+            return "Free Algebra on {} generators {} over {}".format(
+                self.__ngens, self.gens(), self.base_ring())
+        return "Free Algebra on {} generators {} with degrees {} over {}".format(
+            self.__ngens, self.gens(), tuple(self._degrees.values()), self.base_ring())
+
+    def _latex_(self) -> str:
         r"""
         Return a latex representation of ``self``.
 
@@ -542,6 +595,7 @@ class FreeAlgebra_generic(CombinatorialFreeModule, Algebra):
 
         TESTS::
 
+            sage: # needs sage.libs.singular
             sage: F.<x,y,z> = FreeAlgebra(GF(5),3)
             sage: L.<x,y,z> = FreeAlgebra(ZZ,3,implementation='letterplace')
             sage: F(x)     # indirect doctest
@@ -551,15 +605,16 @@ class FreeAlgebra_generic(CombinatorialFreeModule, Algebra):
             sage: (F.1*L.2).parent() is F
             True
 
-       ::
+        ::
 
+            sage: # needs sage.libs.singular sage.rings.finite_rings
             sage: K.<z> = GF(25)
             sage: F.<a,b,c> = FreeAlgebra(K,3)
             sage: L.<a,b,c> = FreeAlgebra(K,3, implementation='letterplace')
-            sage: F.1+(z+1)*L.2
+            sage: F.1 + (z+1)*L.2
             b + (z+1)*c
 
-        Check that :trac:`15169` is fixed::
+        Check that :issue:`15169` is fixed::
 
             sage: A.<x> = FreeAlgebra(CC)
             sage: A(2)
@@ -587,24 +642,22 @@ class FreeAlgebra_generic(CombinatorialFreeModule, Algebra):
                 return x
             if P is not self.base_ring():
                 return self.element_class(self, x)
-        elif hasattr(x,'letterplace_polynomial'):
+        elif hasattr(x, 'letterplace_polynomial'):
             P = x.parent()
-            if self.has_coerce_map_from(P): # letterplace versus generic
+            if self.has_coerce_map_from(P):  # letterplace versus generic
                 ngens = P.ngens()
                 M = self._indices
 
                 def exp_to_monomial(T):
-                    out = []
-                    for i in range(len(T)):
-                        if T[i]:
-                            out.append((i%ngens,T[i]))
-                    return M(out)
-                return self.element_class(self, {exp_to_monomial(T):c for T,c in x.letterplace_polynomial().dict().items()})
+                    return M([(i % ngens, Ti) for i, Ti in enumerate(T) if Ti])
+
+                return self.element_class(self, {exp_to_monomial(T): c
+                                                 for T, c in x.letterplace_polynomial().dict().items()})
         # ok, not a free algebra element (or should not be viewed as one).
         if isinstance(x, str):
             from sage.misc.sage_eval import sage_eval
             G = self.gens()
-            d = {str(v): G[i] for i,v in enumerate(self.variable_names())}
+            d = {str(v): G[i] for i, v in enumerate(self.variable_names())}
             return self(sage_eval(x, locals=d))
         R = self.base_ring()
         # coercion from free monoid
@@ -618,7 +671,7 @@ class FreeAlgebra_generic(CombinatorialFreeModule, Algebra):
         # Check if it's a factorization
         from sage.structure.factorization import Factorization
         if isinstance(x, Factorization):
-            return self.prod(f**i for f,i in x)
+            return self.prod(f**i for f, i in x)
 
         # coercion via base ring
         x = R(x)
@@ -666,6 +719,7 @@ class FreeAlgebra_generic(CombinatorialFreeModule, Algebra):
             sage: F.has_coerce_map_from(PolynomialRing(ZZ, 3, 'x,y,z'))
             False
 
+            sage: # needs sage.rings.finite_rings
             sage: K.<z> = GF(25)
             sage: F.<a,b,c> = FreeAlgebra(K,3)
             sage: F._coerce_map_from_(ZZ)
@@ -681,15 +735,15 @@ class FreeAlgebra_generic(CombinatorialFreeModule, Algebra):
             True
             sage: G._coerce_map_from_(F)
             False
-            sage: L.<a,b,c> = FreeAlgebra(K,3, implementation='letterplace')
-            sage: F.1 + (z+1) * L.2
+            sage: L.<a,b,c> = FreeAlgebra(K,3, implementation='letterplace')            # needs sage.libs.singular
+            sage: F.1 + (z+1) * L.2                                                     # needs sage.libs.singular
             b + (z+1)*c
         """
         if self._indices.has_coerce_map_from(R):
             return True
 
         # free algebras in the same variable over any base that coerces in:
-        if is_FreeAlgebra(R):
+        if isinstance(R, (FreeAlgebra_generic, FreeAlgebra_letterplace)):
             if R.variable_names() == self.variable_names():
                 return self.base_ring().has_coerce_map_from(R.base_ring())
         if isinstance(R, PBWBasisOfFreeAlgebra):
@@ -744,6 +798,23 @@ class FreeAlgebra_generic(CombinatorialFreeModule, Algebra):
         """
         return tuple(self.gen(i) for i in range(self.__ngens))
 
+    def degree_on_basis(self, m):
+        r"""
+        Return the degree of the basis element indexed by ``m``.
+
+        EXAMPLES::
+
+            sage: A.<a, b> = FreeAlgebra(QQ, degrees=(1, -1))
+            sage: m = A.basis().keys()[42]
+            sage: m
+            a*b*a*b^2
+            sage: A.degree_on_basis(m)
+            -1
+            sage: (a*b*a*b^2).degree()
+            -1
+        """
+        return ZZ.sum(self._degrees[g] * e for g, e in m)
+
     def product_on_basis(self, x, y):
         """
         Return the product of the basis elements indexed by ``x`` and ``y``.
@@ -779,9 +850,12 @@ class FreeAlgebra_generic(CombinatorialFreeModule, Algebra):
             sage: i, j, k = F.gens()
             sage: mons = [ F(1), i, j, k ]
             sage: M = MatrixSpace(QQ,4)
-            sage: mats = [M([0,1,0,0, -1,0,0,0, 0,0,0,-1, 0,0,1,0]),  M([0,0,1,0, 0,0,0,1, -1,0,0,0, 0,-1,0,0]),  M([0,0,0,1, 0,0,-1,0, 0,1,0,0, -1,0,0,0]) ]
+            sage: mats = [M([0,1,0,0, -1,0,0,0, 0,0,0,-1, 0,0,1,0]),
+            ....:         M([0,0,1,0, 0,0,0,1, -1,0,0,0, 0,-1,0,0]),
+            ....:         M([0,0,0,1, 0,0,-1,0, 0,1,0,0, -1,0,0,0]) ]
             sage: H.<i,j,k> = A.quotient(mons, mats); H
-            Free algebra quotient on 3 generators ('i', 'j', 'k') and dimension 4 over Rational Field
+            Free algebra quotient on 3 generators ('i', 'j', 'k') and dimension 4
+             over Rational Field
         """
         if mats is None:
             return super().quotient(mons, names)
@@ -829,6 +903,7 @@ class FreeAlgebra_generic(CombinatorialFreeModule, Algebra):
 
         EXAMPLES::
 
+            sage: # needs sage.libs.singular
             sage: A.<x,y,z> = FreeAlgebra(QQ,3)
             sage: G = A.g_algebra({y*x: -x*y})
             sage: (x,y,z) = G.gens()
@@ -839,47 +914,59 @@ class FreeAlgebra_generic(CombinatorialFreeModule, Algebra):
             sage: z*x
             x*z
             sage: (x,y,z) = A.gens()
-            sage: G = A.g_algebra({y*x: -x*y+1})
+            sage: G = A.g_algebra({y*x: -x*y + 1})
             sage: (x,y,z) = G.gens()
             sage: y*x
             -x*y + 1
             sage: (x,y,z) = A.gens()
-            sage: G = A.g_algebra({y*x: -x*y+z})
+            sage: G = A.g_algebra({y*x: -x*y + z})
             sage: (x,y,z) = G.gens()
             sage: y*x
             -x*y + z
+
+        TESTS::
+
+            sage: S = FractionField(QQ['t'])
+            sage: t = S.gen()
+            sage: F.<x,y> = FreeAlgebra(S)
+            sage: K = F.g_algebra({y*x:-x*y+1+y})
+            sage: x,y = K.gens()
+            sage: 1+t*y*x
+            (-t)*x*y + t*y + (t + 1)
         """
         from sage.matrix.constructor import Matrix
 
         base_ring = self.base_ring()
+        polynomial_ring = PolynomialRing(base_ring, self.gens())
         n = self.__ngens
         cmat = Matrix(base_ring, n)
-        dmat = Matrix(self, n)
+        dmat = Matrix(polynomial_ring, n)
         for i in range(n):
             for j in range(i + 1, n):
-                cmat[i,j] = 1
-        for (to_commute,commuted) in relations.items():
-            #This is dirty, coercion is broken
-            assert isinstance(to_commute, FreeAlgebraElement), to_commute.__class__
+                cmat[i, j] = 1
+        for to_commute, commuted in relations.items():
+            # This is dirty, coercion is broken
+            assert isinstance(to_commute, FreeAlgebraElement), to_commute
             assert isinstance(commuted, FreeAlgebraElement), commuted
-            ((v1,e1),(v2,e2)) = list(list(to_commute)[0][0])
+            (v1, e1), (v2, e2) = next(iter(to_commute))[0]
             assert e1 == 1
             assert e2 == 1
             assert v1 > v2
             c_coef = None
             d_poly = None
+            reverse_monomial = v2 * v1
             for m, c in commuted:
-                if list(m) == [(v2,1),(v1,1)]:
+                if m == reverse_monomial:
                     c_coef = c
                     # buggy coercion workaround
-                    d_poly = commuted - self(c) * self(m)
+                    d_poly = commuted - c * self.monomial(m)
                     break
-            assert c_coef is not None, list(m)
+            assert c_coef is not None, m
             v2_ind = self.gens().index(v2)
             v1_ind = self.gens().index(v1)
-            cmat[v2_ind,v1_ind] = c_coef
+            cmat[v2_ind, v1_ind] = c_coef
             if d_poly:
-                dmat[v2_ind,v1_ind] = d_poly
+                dmat[v2_ind, v1_ind] = polynomial_ring(d_poly)
         from sage.rings.polynomial.plural import g_Algebra
         return g_Algebra(base_ring, cmat, dmat,
                          names=names or self.variable_names(),
@@ -919,18 +1006,18 @@ class FreeAlgebra_generic(CombinatorialFreeModule, Algebra):
             return PBW.zero()
 
         l = {}
-        while elt: # != 0
+        while elt:  # != 0
             lst = list(elt)
             support = [i[0].to_word() for i in lst]
             min_elt = support[0]
-            for word in support[1:len(support)-1]:
+            for word in support[1:len(support) - 1]:
                 if min_elt.lex_less(word):
                     min_elt = word
             coeff = lst[support.index(min_elt)][1]
             min_elt = min_elt.to_monoid_element()
             l[min_elt] = l.get(min_elt, 0) + coeff
             elt = elt - coeff * self.lie_polynomial(min_elt)
-        return PBW.sum_of_terms([(k, v) for k,v in l.items() if v != 0], distinct=True)
+        return PBW.sum_of_terms([(k, v) for k, v in l.items() if v != 0], distinct=True)
 
     def lie_polynomial(self, w):
         """
@@ -979,7 +1066,7 @@ class FreeAlgebra_generic(CombinatorialFreeModule, Algebra):
             sage: F.lie_polynomial('')
             1
 
-        We check that :trac:`22251` is fixed::
+        We check that :issue:`22251` is fixed::
 
             sage: F.lie_polynomial(x*y*z)
             x*y*z - x*z*y - y*z*x + z*y*x
@@ -999,10 +1086,10 @@ class FreeAlgebra_generic(CombinatorialFreeModule, Algebra):
             if len(factor) == 1:
                 ret = ret * self(M(factor))
                 continue
-            x,y = factor.standard_factorization()
+            x, y = factor.standard_factorization()
             x = self.lie_polynomial(M(x))
             y = self.lie_polynomial(M(y))
-            ret = ret * (x*y - y*x)
+            ret = ret * (x * y - y * x)
         return ret
 
 
