@@ -4,7 +4,7 @@ all.py -- much of sage is imported into this module, so you don't
 
 TESTS:
 
-This is to test :trac:`10570`. If the number of stackframes at startup
+This is to test :issue:`10570`. If the number of stackframes at startup
 changes due to a patch you made, please check that this was an
 intended effect of your patch.
 
@@ -39,7 +39,7 @@ Check lazy import of ``interacts``::
     sage: interacts
     <module 'sage.interacts.all' from '...'>
 
-Check that :trac:`34506` is resolved::
+Check that :issue:`34506` is resolved::
 
     sage: x = int('1'*4301)
 """
@@ -59,7 +59,7 @@ import math
 
 ################ end setup warnings ###############################
 
-from .all__sagemath_repl import *  # includes .all__sagemath_objects, .all__sagemath_environment
+from sage.all__sagemath_repl import *  # includes .all__sagemath_objects, .all__sagemath_environment
 
 ###################################################################
 
@@ -104,7 +104,6 @@ from sage.interfaces.all import *
 from sage.functions.all  import *
 from sage.calculus.all   import *
 
-lazy_import('sage.tests', 'all', as_='tests', deprecation=27337)
 from sage.cpython.all    import *
 
 from sage.crypto.all     import *
@@ -132,8 +131,6 @@ from sage.quadratic_forms.all import *
 
 from sage.games.all      import *
 
-lazy_import('sage.media.wav', 'Wave', as_='wave', deprecation=12673)
-
 from sage.logic.all      import *
 
 from sage.numerical.all  import *
@@ -141,8 +138,6 @@ from sage.numerical.all  import *
 from sage.stats.all      import *
 import sage.stats.all as stats
 
-lazy_import("sage.finance", "all", as_="finance", deprecation=32427)
-
 from sage.parallel.all   import *
 
 from sage.ext.fast_callable  import fast_callable
@@ -194,15 +189,6 @@ from sage.misc.copying import license
 copying = license
 copyright = license
 
-def quit_sage(verbose=True):
-    """
-    Does nothing. Code that needs cleanup should register its own
-    handler using the atexit module.
-    """
-    from sage.misc.superseded import deprecation
-    deprecation(8784, 'quit_sage is deprecated and now does nothing; please simply delete it')
-
-
 from sage.misc.persist import register_unpickle_override
 register_unpickle_override('sage.categories.category', 'Sets', Sets)
 register_unpickle_override('sage.categories.category_types', 'HeckeModules', HeckeModules)
@@ -223,11 +209,6 @@ sage.misc.lazy_import.save_cache_file()
 # sys.settrace(poison_currRing)
 
 
-# Deprecated leftover of monkey-patching inspect.isfunction() to support Cython functions.
-lazy_import('sage.misc.sageinspect', 'is_function_or_cython_function',
-            as_='isfunction', namespace=sage.__dict__, deprecation=32479)
-
-
 # Set a new random number seed as the very last thing
 # (so that printing initial_seed() and using that seed
 # in set_random_seed() will result in the same sequence you got at
