@@ -1,3 +1,4 @@
+# sage_setup: distribution = sagemath-categories
 r"""
 Additive magmas
 """
@@ -241,16 +242,16 @@ class AdditiveMagmas(Category_singleton):
 
             - ``names`` -- the type of names used:
 
-              * ``'letters'`` - lowercase ASCII letters are used
+              * ``'letters'`` -- lowercase ASCII letters are used
                 for a base 26 representation of the elements'
                 positions in the list given by
                 :meth:`~sage.matrix.operation_table.OperationTable.column_keys`,
                 padded to a common width with leading 'a's.
-              * ``'digits'`` - base 10 representation of the
+              * ``'digits'`` -- base 10 representation of the
                 elements' positions in the list given by
                 :meth:`~sage.matrix.operation_table.OperationTable.column_keys`,
                 padded to a common width with leading zeros.
-              * ``'elements'`` - the string representations
+              * ``'elements'`` -- the string representations
                 of the elements themselves.
               * a list - a list of strings, where the length
                 of the list equals the number of elements.
@@ -283,7 +284,7 @@ class AdditiveMagmas(Category_singleton):
             elements as lowercase ASCII letters.  ::
 
                 sage: R = IntegerModRing(5)
-                sage: R.addition_table()                                                # optional - sage.modules
+                sage: R.addition_table()                                                # needs sage.modules
                 +  a b c d e
                  +----------
                 a| a b c d e
@@ -298,7 +299,7 @@ class AdditiveMagmas(Category_singleton):
             ``digits`` will include leading zeros as padding.  ::
 
                 sage: R = IntegerModRing(11)
-                sage: P = R.addition_table(names='elements'); P                         # optional - sage.modules
+                sage: P = R.addition_table(names='elements'); P                         # needs sage.modules
                  +   0  1  2  3  4  5  6  7  8  9 10
                   +---------------------------------
                  0|  0  1  2  3  4  5  6  7  8  9 10
@@ -313,7 +314,7 @@ class AdditiveMagmas(Category_singleton):
                  9|  9 10  0  1  2  3  4  5  6  7  8
                 10| 10  0  1  2  3  4  5  6  7  8  9
 
-                sage: T = R.addition_table(names='digits'); T                           # optional - sage.modules
+                sage: T = R.addition_table(names='digits'); T                           # needs sage.modules
                 +  00 01 02 03 04 05 06 07 08 09 10
                   +---------------------------------
                 00| 00 01 02 03 04 05 06 07 08 09 10
@@ -333,7 +334,7 @@ class AdditiveMagmas(Category_singleton):
 
                 sage: S = IntegerModRing(7)
                 sage: elts = [0, 3, 6, 2, 5, 1, 4]
-                sage: S.addition_table(elements=elts)                                   # optional - sage.modules
+                sage: S.addition_table(elements=elts)                                   # needs sage.modules
                 +  a b c d e f g
                  +--------------
                 a| a b c d e f g
@@ -354,7 +355,7 @@ class AdditiveMagmas(Category_singleton):
 
                 sage: T = IntegerModRing(12)
                 sage: elts = [0, 3, 6, 9]
-                sage: T.addition_table(names='elements', elements=elts)                 # optional - sage.modules
+                sage: T.addition_table(names='elements', elements=elts)                 # needs sage.modules
                 +  0 3 6 9
                  +--------
                 0| 0 3 6 9
@@ -367,16 +368,17 @@ class AdditiveMagmas(Category_singleton):
             :class:`~sage.matrix.operation_table.OperationTable` for more
             comprehensive documentation. ::
 
+                sage: # needs sage.modules
                 sage: R = IntegerModRing(3)
-                sage: T = R.addition_table()                                            # optional - sage.modules
-                sage: T.column_keys()                                                   # optional - sage.modules
+                sage: T = R.addition_table()
+                sage: T.column_keys()
                 (0, 1, 2)
-                sage: sorted(T.translation().items())                                   # optional - sage.modules
+                sage: sorted(T.translation().items())
                 [('a', 0), ('b', 1), ('c', 2)]
-                sage: T.change_names(['x', 'y', 'z'])                                   # optional - sage.modules
-                sage: sorted(T.translation().items())                                   # optional - sage.modules
+                sage: T.change_names(['x', 'y', 'z'])
+                sage: sorted(T.translation().items())
                 [('x', 0), ('y', 1), ('z', 2)]
-                sage: T                                                                 # optional - sage.modules
+                sage: T
                 +  x y z
                  +------
                 x| x y z
@@ -473,16 +475,17 @@ class AdditiveMagmas(Category_singleton):
                 r"""
                 EXAMPLES::
 
-                    sage: G5 = GF(5); G8 = GF(4, 'x'); GG = G5.cartesian_product(G8)    # optional - sage.rings.finite_rings
-                    sage: e = GG((G5(1), G8.primitive_element())); e                    # optional - sage.rings.finite_rings
+                    sage: # needs sage.rings.finite_rings
+                    sage: G5 = GF(5); G8 = GF(4, 'x'); GG = G5.cartesian_product(G8)
+                    sage: e = GG((G5(1), G8.primitive_element())); e
                     (1, x)
-                    sage: e + e                                                         # optional - sage.rings.finite_rings
+                    sage: e + e
                     (2, 0)
-                    sage: e = groups.misc.AdditiveCyclic(8)                             # optional - sage.rings.finite_rings
-                    sage: x = e.cartesian_product(e)((e(1), e(2)))                      # optional - sage.rings.finite_rings
-                    sage: x                                                             # optional - sage.rings.finite_rings
+                    sage: e = groups.misc.AdditiveCyclic(8)                             # needs sage.groups
+                    sage: x = e.cartesian_product(e)((e(1), e(2)))
+                    sage: x
                     (1, 2)
-                    sage: 4 * x                                                         # optional - sage.rings.finite_rings
+                    sage: 4 * x
                     (4, 0)
                 """
                 return self.parent()._cartesian_product_of_elements(
@@ -521,8 +524,8 @@ class AdditiveMagmas(Category_singleton):
                     sage: S = CommutativeAdditiveSemigroups().example(); S
                     An example of a commutative semigroup:
                      the free commutative semigroup generated by ('a', 'b', 'c', 'd')
-                    sage: A = S.algebra(QQ)                                             # optional - sage.modules
-                    sage: A.algebra_generators()                                        # optional - sage.modules
+                    sage: A = S.algebra(QQ)                                             # needs sage.modules
+                    sage: A.algebra_generators()                                        # needs sage.modules
                     Family (B[a], B[b], B[c], B[d])
 
                 .. TODO::
@@ -547,9 +550,9 @@ class AdditiveMagmas(Category_singleton):
                     sage: S = CommutativeAdditiveSemigroups().example(); S
                     An example of a commutative semigroup:
                      the free commutative semigroup generated by ('a', 'b', 'c', 'd')
-                    sage: A = S.algebra(QQ)                                             # optional - sage.modules
-                    sage: a, b, c, d = A.algebra_generators()                           # optional - sage.modules
-                    sage: a * d * b                                                     # optional - sage.modules
+                    sage: A = S.algebra(QQ)                                             # needs sage.modules
+                    sage: a, b, c, d = A.algebra_generators()                           # needs sage.modules
+                    sage: a * d * b                                                     # needs sage.modules
                     B[a + b + d]
 
                 .. TODO::
@@ -724,10 +727,11 @@ class AdditiveMagmas(Category_singleton):
 
                 EXAMPLES::
 
-                    sage: A = AdditiveAbelianGroup([3, 3])                              # optional - sage.groups
-                    sage: A in AdditiveMagmas()                                         # optional - sage.groups
+                    sage: # needs sage.modules
+                    sage: A = AdditiveAbelianGroup([3, 3])
+                    sage: A in AdditiveMagmas()
                     True
-                    sage: A.is_empty()                                                  # optional - sage.groups
+                    sage: A.is_empty()
                     False
 
                     sage: B = CommutativeAdditiveMonoids().example()
@@ -739,7 +743,7 @@ class AdditiveMagmas(Category_singleton):
                 We check that the method ``is_empty`` is inherited from this
                 category in both examples above::
 
-                    sage: A.is_empty.__module__                                         # optional - sage.groups
+                    sage: A.is_empty.__module__                                         # needs sage.modules
                     'sage.categories.additive_magmas'
                     sage: B.is_empty.__module__
                     'sage.categories.additive_magmas'
@@ -784,7 +788,7 @@ class AdditiveMagmas(Category_singleton):
                     False
                     sage: bool(S.an_element())
                     True
-                 """
+                """
 
             def _test_nonzero_equal(self, **options):
                 r"""
@@ -807,17 +811,17 @@ class AdditiveMagmas(Category_singleton):
 
                 EXAMPLES::
 
-                    sage: F = CombinatorialFreeModule(QQ, ['a', 'b'])                   # optional - sage.modules
-                    sage: a, b = F.basis()                                              # optional - sage.modules
-                    sage: a - b                                                         # optional - sage.modules
+                    sage: F = CombinatorialFreeModule(QQ, ['a', 'b'])                   # needs sage.modules
+                    sage: a, b = F.basis()                                              # needs sage.modules
+                    sage: a - b                                                         # needs sage.modules
                     B['a'] - B['b']
 
                 TESTS:
 
-                Check that :trac:`18275` is fixed::
+                Check that :issue:`18275` is fixed::
 
-                    sage: C = GF(5).cartesian_product(GF(5))                            # optional - sage.rings.finite_rings
-                    sage: C.one() - C.one()                                             # optional - sage.rings.finite_rings
+                    sage: C = GF(5).cartesian_product(GF(5))
+                    sage: C.one() - C.one()
                     (0, 0)
                 """
                 return left + (-right)
@@ -833,21 +837,22 @@ class AdditiveMagmas(Category_singleton):
 
                 EXAMPLES::
 
-                    sage: F = CombinatorialFreeModule(QQ, ['a', 'b'])                   # optional - sage.modules
-                    sage: a, b = F.basis()                                              # optional - sage.modules
-                    sage: -b                                                            # optional - sage.modules
+                    sage: F = CombinatorialFreeModule(QQ, ['a', 'b'])                   # needs sage.modules
+                    sage: a, b = F.basis()                                              # needs sage.modules
+                    sage: -b                                                            # needs sage.modules
                     -B['b']
 
                 TESTS::
 
-                    sage: F = CombinatorialFreeModule(ZZ, ['a', 'b'])                   # optional - sage.modules
-                    sage: a, b = F.gens()                                               # optional - sage.modules
-                    sage: FF = cartesian_product((F, F))                                # optional - sage.modules
-                    sage: x = cartesian_product([a, 2*a-3*b]); x                        # optional - sage.modules
+                    sage: # needs sage.modules
+                    sage: F = CombinatorialFreeModule(ZZ, ['a', 'b'])
+                    sage: a, b = F.gens()
+                    sage: FF = cartesian_product((F, F))
+                    sage: x = cartesian_product([a, 2*a-3*b]); x
                     B[(0, 'a')] + 2*B[(1, 'a')] - 3*B[(1, 'b')]
-                    sage: x.parent() is FF                                              # optional - sage.modules
+                    sage: x.parent() is FF
                     True
-                    sage: -x                                                            # optional - sage.modules
+                    sage: -x
                     -B[(0, 'a')] - 2*B[(1, 'a')] + 3*B[(1, 'b')]
                 """
                 return self._neg_()
@@ -917,15 +922,15 @@ class AdditiveMagmas(Category_singleton):
 
                         EXAMPLES::
 
-                           sage: x = cartesian_product((GF(7)(2), 17)); x               # optional - sage.rings.finite_rings
+                           sage: x = cartesian_product((GF(7)(2), 17)); x
                            (2, 17)
-                           sage: -x                                                     # optional - sage.rings.finite_rings
+                           sage: -x
                            (5, -17)
 
                         TESTS::
 
                            sage: C = AdditiveMagmas().AdditiveUnital().AdditiveInverse().CartesianProducts()
-                           sage: x.parent() in C                                        # optional - sage.rings.finite_rings
+                           sage: x.parent() in C
                            True
                         """
                         return self.parent()._cartesian_product_of_elements(
@@ -954,7 +959,7 @@ class AdditiveMagmas(Category_singleton):
 
                     EXAMPLES::
 
-                        sage: GF(8, 'x').cartesian_product(GF(5)).zero()                # optional - sage.rings.finite_rings
+                        sage: GF(8, 'x').cartesian_product(GF(5)).zero()                # needs sage.rings.finite_rings
                         (0, 0)
                     """
                     return self._cartesian_product_of_elements(
@@ -989,15 +994,16 @@ class AdditiveMagmas(Category_singleton):
 
                     EXAMPLES::
 
+                        sage: # needs sage.modules
                         sage: S = CommutativeAdditiveMonoids().example(); S
                         An example of a commutative monoid:
                          the free commutative monoid generated by ('a', 'b', 'c', 'd')
-                        sage: A = S.algebra(ZZ)                                         # optional - sage.modules
-                        sage: A.one_basis()                                             # optional - sage.modules
+                        sage: A = S.algebra(ZZ)
+                        sage: A.one_basis()
                         0
-                        sage: A.one()                                                   # optional - sage.modules
+                        sage: A.one()
                         B[0]
-                        sage: A(3)                                                      # optional - sage.modules
+                        sage: A(3)
                         3*B[0]
                     """
                     return self.basis().keys().zero()
@@ -1016,17 +1022,17 @@ class AdditiveMagmas(Category_singleton):
 
                     EXAMPLES::
 
-                        sage: A = Sets().WithRealizations().example(); A                # optional - sage.combinat
+                        sage: A = Sets().WithRealizations().example(); A                # needs sage.modules
                         The subset algebra of {1, 2, 3} over Rational Field
-                        sage: A.zero.__module__                                         # optional - sage.combinat
+                        sage: A.zero.__module__                                         # needs sage.modules
                         'sage.categories.additive_magmas'
-                        sage: A.zero()                                                  # optional - sage.combinat
+                        sage: A.zero()                                                  # needs sage.modules
                         0
 
                     TESTS::
 
-                        sage: A.zero() is A.a_realization().zero()                      # optional - sage.combinat
+                        sage: A.zero() is A.a_realization().zero()                      # needs sage.modules
                         True
-                        sage: A._test_zero()                                            # optional - sage.combinat
+                        sage: A._test_zero()                                            # needs sage.modules
                     """
                     return self.a_realization().zero()
