@@ -1,4 +1,5 @@
-# sage.doctest: optional - sage.groups
+# sage_setup: distribution = sagemath-categories
+# sage.doctest: needs sage.groups
 r"""
 Finite Permutation Groups
 """
@@ -110,7 +111,7 @@ class FinitePermutationGroups(CategoryWithAxiom):
 
             INPUT:
 
-             - ``self`` - a permutation group `G`
+             - ``self`` -- a permutation group `G`
              - ``parent`` -- a free module with basis indexed by partitions,
                or behave as such, with a ``term`` and ``sum`` method
                (default: the symmetric functions over the rational field in the `p` basis)
@@ -130,14 +131,14 @@ class FinitePermutationGroups(CategoryWithAxiom):
             of length 2, 8 cycles of length 3, and 6 cycles of length 4::
 
                 sage: S4 = SymmetricGroup(4)
-                sage: P = S4.cycle_index()
-                sage: 24 * P
+                sage: P = S4.cycle_index()                                              # needs sage.combinat
+                sage: 24 * P                                                            # needs sage.combinat
                 p[1, 1, 1, 1] + 6*p[2, 1, 1] + 3*p[2, 2] + 8*p[3, 1] + 6*p[4]
 
             If `l = (l_1,\dots,l_k)` is a partition, ``|G| P[l]`` is the number
             of elements of `G` with cycles of length `(p_1,\dots,p_k)`::
 
-                sage: 24 * P[ Partition([3,1]) ]
+                sage: 24 * P[ Partition([3,1]) ]                                        # needs sage.combinat
                 8
 
             The cycle index plays an important role in the enumeration of
@@ -146,7 +147,7 @@ class FinitePermutationGroups(CategoryWithAxiom):
             encoded as a symmetric function, expressed in the powersum
             basis::
 
-                sage: P.parent()
+                sage: P.parent()                                                        # needs sage.combinat
                 Symmetric Functions over Rational Field in the powersum basis
 
             This symmetric function can have some nice properties; for
@@ -154,7 +155,7 @@ class FinitePermutationGroups(CategoryWithAxiom):
             symmetric function `h_n`::
 
                 sage: S = SymmetricFunctions(QQ); h = S.h()
-                sage: h( P )
+                sage: h( P )                                                            # needs sage.combinat
                 h[4]
 
             .. TODO::
@@ -165,10 +166,10 @@ class FinitePermutationGroups(CategoryWithAxiom):
 
             Here are the cycle indices of some permutation groups::
 
-                sage: 6 * CyclicPermutationGroup(6).cycle_index()
+                sage: 6 * CyclicPermutationGroup(6).cycle_index()                       # needs sage.combinat
                 p[1, 1, 1, 1, 1, 1] + p[2, 2, 2] + 2*p[3, 3] + 2*p[6]
 
-                sage: 60 * AlternatingGroup(5).cycle_index()
+                sage: 60 * AlternatingGroup(5).cycle_index()                            # needs sage.combinat
                 p[1, 1, 1, 1, 1] + 15*p[2, 2, 1] + 20*p[3, 1, 1] + 24*p[5]
 
                 sage: for G in TransitiveGroups(5):               # long time
@@ -180,16 +181,17 @@ class FinitePermutationGroups(CategoryWithAxiom):
                 p[1, 1, 1, 1, 1] + 10*p[2, 1, 1, 1] + 15*p[2, 2, 1] + 20*p[3, 1, 1] + 20*p[3, 2] + 30*p[4, 1] + 24*p[5]
 
             Permutation groups with arbitrary domains are supported
-            (see :trac:`22765`)::
+            (see :issue:`22765`)::
 
                 sage: G = PermutationGroup([['b','c','a']], domain=['a','b','c'])
-                sage: G.cycle_index()
+                sage: G.cycle_index()                                                   # needs sage.combinat
                 1/3*p[1, 1, 1] + 2/3*p[3]
 
             One may specify another parent for the result::
 
+                sage: # needs sage.combinat
                 sage: F = CombinatorialFreeModule(QQ, Partitions())
-                sage: P = CyclicPermutationGroup(6).cycle_index(parent = F)
+                sage: P = CyclicPermutationGroup(6).cycle_index(parent=F)
                 sage: 6 * P
                 B[[1, 1, 1, 1, 1, 1]] + B[[2, 2, 2]] + 2*B[[3, 3]] + 2*B[[6]]
                 sage: P.parent() is F
@@ -214,11 +216,11 @@ class FinitePermutationGroups(CategoryWithAxiom):
 
                 sage: P = PermutationGroup([]); P
                 Permutation Group with generators [()]
-                sage: P.cycle_index()
+                sage: P.cycle_index()                                                   # needs sage.combinat
                 p[1]
                 sage: P = PermutationGroup([[(1)]]); P
                 Permutation Group with generators [()]
-                sage: P.cycle_index()
+                sage: P.cycle_index()                                                   # needs sage.combinat
                 p[1]
             """
             from sage.categories.modules import Modules
@@ -259,6 +261,7 @@ class FinitePermutationGroups(CategoryWithAxiom):
 
             EXAMPLES::
 
+                sage: # needs sage.combinat
                 sage: C8 = CyclicPermutationGroup(8)
                 sage: C8.profile_series()
                 z^8 + z^7 + 4*z^6 + 7*z^5 + 10*z^4 + 7*z^3 + 4*z^2 + z + 1
@@ -270,8 +273,8 @@ class FinitePermutationGroups(CategoryWithAxiom):
                 Univariate Polynomial Ring in z over Rational Field
                 sage: D8.profile_series(variable='y')
                 y^8 + y^7 + 4*y^6 + 5*y^5 + 8*y^4 + 5*y^3 + 4*y^2 + y + 1
-                sage: u = var('u')                                              # optional - sage.symbolic
-                sage: D8.profile_series(u).parent()                             # optional - sage.symbolic
+                sage: u = var('u')
+                sage: D8.profile_series(u).parent()
                 Symbolic Ring
             """
             from sage.rings.integer_ring import ZZ
@@ -311,9 +314,9 @@ class FinitePermutationGroups(CategoryWithAxiom):
             EXAMPLES::
 
                 sage: C6 = CyclicPermutationGroup(6)
-                sage: C6.profile(2)
+                sage: C6.profile(2)                                                     # needs sage.combinat
                 3
-                sage: C6.profile(3)
+                sage: C6.profile(3)                                                     # needs sage.combinat
                 4
                 sage: D8 = DihedralGroup(8)
                 sage: D8.profile(4, using_polya=False)
