@@ -1,4 +1,4 @@
-# -*- coding: utf-8 -*-
+# sage_setup: distribution = sagemath-categories
 r"""
 Group Algebras
 
@@ -10,13 +10,13 @@ AUTHOR:
 
 - David Loeffler (2008-08-24): initial version
 - Martin Raum (2009-08): update to use new coercion model -- see
-  :trac:`6670`.
+  :issue:`6670`.
 - John Palmieri (2011-07): more updates to coercion, categories, etc.,
   group algebras constructed using CombinatorialFreeModule -- see
-  :trac:`6670`.
+  :issue:`6670`.
 - Nicolas M. Thiéry (2010-2017), Travis Scrimshaw (2017):
   generalization to a covariant functorial construction for
-  monoid algebras, and beyond -- see e.g. :trac:`18700`.
+  monoid algebras, and beyond -- see e.g. :issue:`18700`.
 """
 
 #*****************************************************************************
@@ -31,6 +31,7 @@ AUTHOR:
 from sage.misc.cachefunc import cached_method
 from sage.categories.algebra_functor import AlgebrasCategory
 
+
 class GroupAlgebras(AlgebrasCategory):
     r"""
     The category of group algebras over a given base ring.
@@ -40,7 +41,7 @@ class GroupAlgebras(AlgebrasCategory):
         sage: C = Groups().Algebras(ZZ); C
         Category of group algebras over Integer Ring
         sage: C.super_categories()
-        [Category of hopf algebras with basis over Integer Ring,
+        [Category of Hopf algebras with basis over Integer Ring,
          Category of monoid algebras over Integer Ring]
 
     We can also construct this category with::
@@ -50,16 +51,16 @@ class GroupAlgebras(AlgebrasCategory):
 
     Here is how to create the group algebra of a group `G`::
 
-        sage: G = DihedralGroup(5)                                                      # optional - sage.groups
-        sage: QG = G.algebra(QQ); QG                                                    # optional - sage.groups sage.modules
+        sage: G = DihedralGroup(5)                                                      # needs sage.groups
+        sage: QG = G.algebra(QQ); QG                                                    # needs sage.groups sage.modules
         Algebra of
          Dihedral group of order 10 as a permutation group over Rational Field
 
     and an example of computation::
 
-        sage: g = G.an_element(); g                                                     # optional - sage.groups sage.modules
+        sage: g = G.an_element(); g                                                     # needs sage.groups sage.modules
         (1,4)(2,3)
-        sage: (QG.term(g) + 1)**3                                                       # optional - sage.groups sage.modules
+        sage: (QG.term(g) + 1)**3                                                       # needs sage.groups sage.modules
         4*() + 4*(1,4)(2,3)
 
     .. TODO::
@@ -69,14 +70,15 @@ class GroupAlgebras(AlgebrasCategory):
 
     TESTS::
 
-        sage: A = GroupAlgebras(QQ).example(GL(3, GF(11)))                              # optional - sage.groups sage.modules sage.rings.finite_rings
-        sage: A.one_basis()                                                             # optional - sage.groups sage.modules sage.rings.finite_rings
+        sage: # needs sage.groups sage.modules
+        sage: A = GroupAlgebras(QQ).example(GL(3, GF(11)))
+        sage: A.one_basis()
         [1 0 0]
         [0 1 0]
         [0 0 1]
-        sage: A = SymmetricGroupAlgebra(QQ, 4)                                          # optional - sage.groups sage.modules sage.combinat
-        sage: x = Permutation([4,3,2,1])                                                # optional - sage.groups sage.modules sage.combinat
-        sage: A.product_on_basis(x, x)                                                  # optional - sage.groups sage.modules sage.combinat
+        sage: A = SymmetricGroupAlgebra(QQ, 4)                                          # needs sage.combinat
+        sage: x = Permutation([4,3,2,1])
+        sage: A.product_on_basis(x, x)                                                  # needs sage.combinat
         [1, 2, 3, 4]
 
         sage: C = GroupAlgebras(ZZ)
@@ -91,9 +93,9 @@ class GroupAlgebras(AlgebrasCategory):
 
             sage: C = Groups().Algebras(QQ)
             sage: C.extra_super_categories()
-            [Category of hopf algebras over Rational Field]
+            [Category of Hopf algebras over Rational Field]
             sage: sorted(C.super_categories(), key=str)
-            [Category of hopf algebras with basis over Rational Field,
+            [Category of Hopf algebras with basis over Rational Field,
              Category of monoid algebras over Rational Field]
         """
         from sage.categories.hopf_algebras import HopfAlgebras
@@ -105,13 +107,13 @@ class GroupAlgebras(AlgebrasCategory):
 
         EXAMPLES::
 
-            sage: GroupAlgebras(QQ['x']).example()                                      # optional - sage.groups sage.modules
+            sage: GroupAlgebras(QQ['x']).example()                                      # needs sage.groups sage.modules
             Algebra of Dihedral group of order 8 as a permutation group
              over Univariate Polynomial Ring in x over Rational Field
 
         An other group can be specified as optional argument::
 
-            sage: GroupAlgebras(QQ).example(AlternatingGroup(4))                        # optional - sage.groups sage.modules
+            sage: GroupAlgebras(QQ).example(AlternatingGroup(4))                        # needs sage.groups sage.modules
             Algebra of
              Alternating group of order 4!/2 as a permutation group over Rational Field
         """
@@ -127,19 +129,20 @@ class GroupAlgebras(AlgebrasCategory):
 
             EXAMPLES::
 
-                sage: A = GroupAlgebra(SymmetricGroup(4), QQ)                           # optional - sage.groups sage.modules
-                sage: B = GroupAlgebra(SymmetricGroup(3), ZZ)                           # optional - sage.groups sage.modules
-                sage: A.has_coerce_map_from(B)                                          # optional - sage.groups sage.modules
+                sage: # needs sage.combinat sage.groups sage.modules
+                sage: A = GroupAlgebra(SymmetricGroup(4), QQ)
+                sage: B = GroupAlgebra(SymmetricGroup(3), ZZ)
+                sage: A.has_coerce_map_from(B)
                 True
-                sage: B.has_coerce_map_from(A)                                          # optional - sage.groups sage.modules
+                sage: B.has_coerce_map_from(A)
                 False
-                sage: A.has_coerce_map_from(ZZ)                                         # optional - sage.groups sage.modules
+                sage: A.has_coerce_map_from(ZZ)
                 True
-                sage: A.has_coerce_map_from(CC)                                         # optional - sage.groups sage.modules
+                sage: A.has_coerce_map_from(CC)
                 False
-                sage: A.has_coerce_map_from(SymmetricGroup(5))                          # optional - sage.groups sage.modules
+                sage: A.has_coerce_map_from(SymmetricGroup(5))
                 False
-                sage: A.has_coerce_map_from(SymmetricGroup(2))                          # optional - sage.groups sage.modules
+                sage: A.has_coerce_map_from(SymmetricGroup(2))
                 True
             """
             if not self.base_ring().has_coerce_map_from(self.group()):
@@ -155,8 +158,8 @@ class GroupAlgebras(AlgebrasCategory):
 
             EXAMPLES::
 
-                sage: A = GroupAlgebra(KleinFourGroup(), ZZ)                            # optional - sage.groups sage.modules
-                sage: latex(A)  # indirect doctest                                      # optional - sage.groups sage.modules
+                sage: A = GroupAlgebra(KleinFourGroup(), ZZ)                            # needs sage.groups sage.modules
+                sage: latex(A)  # indirect doctest                                      # needs sage.groups sage.modules
                 \Bold{Z}[\langle (3,4), (1,2) \rangle]
             """
             from sage.misc.latex import latex
@@ -168,9 +171,9 @@ class GroupAlgebras(AlgebrasCategory):
 
             EXAMPLES::
 
-                sage: GroupAlgebras(QQ).example(GL(3, GF(11))).group()                  # optional - sage.groups sage.modules sage.rings.finite_rings
+                sage: GroupAlgebras(QQ).example(GL(3, GF(11))).group()                  # needs sage.groups sage.modules
                 General Linear Group of degree 3 over Finite Field of size 11
-                sage: SymmetricGroup(10).algebra(QQ).group()                            # optional - sage.groups sage.modules
+                sage: SymmetricGroup(10).algebra(QQ).group()                            # needs sage.combinat sage.groups sage.modules
                 Symmetric group of order 10! as a permutation group
             """
             return self.basis().keys()
@@ -198,7 +201,7 @@ class GroupAlgebras(AlgebrasCategory):
 
             EXAMPLES::
 
-                sage: SymmetricGroup(3).algebra(QQ).center_basis()                      # optional - sage.groups sage.modules
+                sage: SymmetricGroup(3).algebra(QQ).center_basis()                      # needs sage.combinat sage.groups sage.modules
                 ((), (2,3) + (1,2) + (1,3), (1,2,3) + (1,3,2))
 
             .. SEEALSO::
@@ -220,16 +223,17 @@ class GroupAlgebras(AlgebrasCategory):
 
             EXAMPLES::
 
-                sage: A = CyclicPermutationGroup(6).algebra(ZZ); A                      # optional - sage.groups sage.modules
+                sage: # needs sage.groups sage.modules
+                sage: A = CyclicPermutationGroup(6).algebra(ZZ); A
                 Algebra of
                  Cyclic group of order 6 as a permutation group over Integer Ring
-                sage: g = CyclicPermutationGroup(6).an_element(); g                     # optional - sage.groups sage.modules
+                sage: g = CyclicPermutationGroup(6).an_element(); g
                 (1,2,3,4,5,6)
-                sage: A.coproduct_on_basis(g)                                           # optional - sage.groups sage.modules
+                sage: A.coproduct_on_basis(g)
                 (1,2,3,4,5,6) # (1,2,3,4,5,6)
-                sage: a = A.an_element(); a                                             # optional - sage.groups sage.modules
+                sage: a = A.an_element(); a
                 () + 3*(1,2,3,4,5,6) + 3*(1,3,5)(2,4,6)
-                sage: a.coproduct()                                                     # optional - sage.groups sage.modules
+                sage: a.coproduct()
                 () # () + 3*(1,2,3,4,5,6) # (1,2,3,4,5,6) + 3*(1,3,5)(2,4,6) # (1,3,5)(2,4,6)
             """
             from sage.categories.tensor import tensor
@@ -246,16 +250,17 @@ class GroupAlgebras(AlgebrasCategory):
 
             EXAMPLES::
 
-                sage: A = CyclicPermutationGroup(6).algebra(ZZ); A                      # optional - sage.groups sage.modules
+                sage: # needs sage.groups sage.modules
+                sage: A = CyclicPermutationGroup(6).algebra(ZZ); A
                 Algebra of
                  Cyclic group of order 6 as a permutation group over Integer Ring
-                sage: g = CyclicPermutationGroup(6).an_element(); g                     # optional - sage.groups sage.modules
+                sage: g = CyclicPermutationGroup(6).an_element(); g
                 (1,2,3,4,5,6)
-                sage: A.antipode_on_basis(g)                                            # optional - sage.groups sage.modules
+                sage: A.antipode_on_basis(g)
                 (1,6,5,4,3,2)
-                sage: a = A.an_element(); a                                             # optional - sage.groups sage.modules
+                sage: a = A.an_element(); a
                 () + 3*(1,2,3,4,5,6) + 3*(1,3,5)(2,4,6)
-                sage: a.antipode()                                                      # optional - sage.groups sage.modules
+                sage: a.antipode()
                 () + 3*(1,5,3)(2,6,4) + 3*(1,6,5,4,3,2)
             """
             return self.term(~g)
@@ -270,12 +275,12 @@ class GroupAlgebras(AlgebrasCategory):
 
             EXAMPLES::
 
-                sage: A = CyclicPermutationGroup(6).algebra(ZZ); A                      # optional - sage.groups sage.modules
+                sage: A = CyclicPermutationGroup(6).algebra(ZZ); A                      # needs sage.groups sage.modules
                 Algebra of
                  Cyclic group of order 6 as a permutation group over Integer Ring
-                sage: g = CyclicPermutationGroup(6).an_element(); g                     # optional - sage.groups sage.modules
+                sage: g = CyclicPermutationGroup(6).an_element(); g                     # needs sage.groups sage.modules
                 (1,2,3,4,5,6)
-                sage: A.counit_on_basis(g)                                              # optional - sage.groups sage.modules
+                sage: A.counit_on_basis(g)                                              # needs sage.groups sage.modules
                 1
             """
             return self.base_ring().one()
@@ -290,12 +295,12 @@ class GroupAlgebras(AlgebrasCategory):
 
             EXAMPLES::
 
-                sage: A = CyclicPermutationGroup(6).algebra(ZZ); A                      # optional - sage.groups sage.modules
+                sage: A = CyclicPermutationGroup(6).algebra(ZZ); A                      # needs sage.groups sage.modules
                 Algebra of
                  Cyclic group of order 6 as a permutation group over Integer Ring
-                sage: a = A.an_element(); a                                             # optional - sage.groups sage.modules
+                sage: a = A.an_element(); a                                             # needs sage.groups sage.modules
                 () + 3*(1,2,3,4,5,6) + 3*(1,3,5)(2,4,6)
-                sage: a.counit()                                                        # optional - sage.groups sage.modules
+                sage: a.counit()                                                        # needs sage.groups sage.modules
                 7
             """
             return self.base_ring().sum(x.coefficients())
@@ -312,19 +317,20 @@ class GroupAlgebras(AlgebrasCategory):
 
             EXAMPLES::
 
-                sage: S2 = SymmetricGroup(2)                                            # optional - sage.groups
-                sage: GroupAlgebra(S2).is_integral_domain()                             # optional - sage.groups sage.modules
+                sage: # needs sage.groups sage.modules
+                sage: S2 = SymmetricGroup(2)
+                sage: GroupAlgebra(S2).is_integral_domain()                             # needs sage.combinat
                 False
-                sage: S1 = SymmetricGroup(1)                                            # optional - sage.groups
-                sage: GroupAlgebra(S1).is_integral_domain()                             # optional - sage.groups sage.modules
+                sage: S1 = SymmetricGroup(1)
+                sage: GroupAlgebra(S1).is_integral_domain()                             # needs sage.combinat
                 True
-                sage: GroupAlgebra(S1, IntegerModRing(4)).is_integral_domain()          # optional - sage.groups sage.modules
+                sage: GroupAlgebra(S1, IntegerModRing(4)).is_integral_domain()          # needs sage.combinat
                 False
-                sage: GroupAlgebra(AbelianGroup(1)).is_integral_domain()                # optional - sage.groups sage.modules
+                sage: GroupAlgebra(AbelianGroup(1)).is_integral_domain()
                 True
-                sage: GroupAlgebra(AbelianGroup(2, [0,2])).is_integral_domain()         # optional - sage.groups sage.modules
+                sage: GroupAlgebra(AbelianGroup(2, [0,2])).is_integral_domain()
                 False
-                sage: GroupAlgebra(GL(2, ZZ)).is_integral_domain()  # not implemented   # optional - sage.groups sage.modules
+                sage: GroupAlgebra(GL(2, ZZ)).is_integral_domain()      # not implemented
                 False
             """
             from sage.sets.set import Set
@@ -354,7 +360,7 @@ class GroupAlgebras(AlgebrasCategory):
             return ans
 
         # I haven't written is_noetherian(), because I don't know when group
-        # algebras are noetherian, and I haven't written is_prime_field(), because
+        # algebras are Noetherian, and I haven't written is_prime_field(), because
         # I don't know if that means "is canonically isomorphic to a prime field"
         # or "is identical to a prime field".
 
@@ -394,22 +400,24 @@ class GroupAlgebras(AlgebrasCategory):
 
             EXAMPLES::
 
-                sage: QS3 = SymmetricGroup(3).algebra(QQ)                               # optional - sage.groups sage.modules
-                sage: A = QS3([2,3,1]) + QS3([3,1,2])                                   # optional - sage.groups sage.modules
-                sage: A.central_form()                                                  # optional - sage.groups sage.modules
+                sage: # needs sage.combinat sage.groups sage.modules
+                sage: QS3 = SymmetricGroup(3).algebra(QQ)
+                sage: A = QS3([2,3,1]) + QS3([3,1,2])
+                sage: A.central_form()
                 B[(1,2,3)]
-                sage: QS4 = SymmetricGroup(4).algebra(QQ)                               # optional - sage.groups sage.modules
-                sage: B = sum(len(s.cycle_type()) * QS4(s) for s in Permutations(4))    # optional - sage.groups sage.modules
-                sage: B.central_form()                                                  # optional - sage.groups sage.modules
+                sage: QS4 = SymmetricGroup(4).algebra(QQ)
+                sage: B = sum(len(s.cycle_type()) * QS4(s) for s in Permutations(4))
+                sage: B.central_form()
                 4*B[()] + 3*B[(1,2)] + 2*B[(1,2)(3,4)] + 2*B[(1,2,3)] + B[(1,2,3,4)]
 
             The following test fails due to a bug involving combinatorial free modules and
-            the coercion system (see :trac:`28544`)::
+            the coercion system (see :issue:`28544`)::
 
-                sage: G = PermutationGroup([[(1,2,3),(4,5)], [(3,4)]])                  # optional - sage.groups sage.modules
-                sage: QG = GroupAlgebras(QQ).example(G)                                 # optional - sage.groups sage.modules
-                sage: s = sum(QG.basis())                                               # optional - sage.groups sage.modules
-                sage: s.central_form()   # not tested                                   # optional - sage.groups sage.modules
+                sage: # needs sage.groups sage.modules
+                sage: G = PermutationGroup([[(1,2,3),(4,5)], [(3,4)]])
+                sage: QG = GroupAlgebras(QQ).example(G)
+                sage: s = sum(QG.basis())
+                sage: s.central_form()          # not tested
                 B[()] + B[(4,5)] + B[(3,4,5)] + B[(2,3)(4,5)]
                 + B[(2,3,4,5)] + B[(1,2)(3,4,5)] + B[(1,2,3,4,5)]
 
