@@ -1,3 +1,4 @@
+# sage_setup: distribution = sagemath-categories
 r"""
 Semigroups
 """
@@ -26,6 +27,7 @@ from sage.arith.power import generic_power
 
 all_axioms += ("HTrivial", "Aperiodic", "LTrivial", "RTrivial", "JTrivial")
 
+
 class Semigroups(CategoryWithAxiom):
     """
     The category of (multiplicative) semigroups.
@@ -180,7 +182,7 @@ class Semigroups(CategoryWithAxiom):
 
             - ``side`` -- "left", "right", or "twosided":
               the side on which the generators act (default:"right")
-            - ``simple`` -- boolean (default:False):
+            - ``simple`` -- boolean (default: ``False``):
               if True, returns a simple graph (no loops, no labels,
               no multiple edges)
             - ``generators`` -- a list, tuple, or family of elements
@@ -196,37 +198,40 @@ class Semigroups(CategoryWithAxiom):
 
             We start with the (right) Cayley graphs of some classical groups::
 
-                sage: D4 = DihedralGroup(4); D4                                         # optional - sage.groups
+                sage: # needs sage.graphs sage.groups
+                sage: D4 = DihedralGroup(4); D4
                 Dihedral group of order 8 as a permutation group
-                sage: G = D4.cayley_graph()                                             # optional - sage.groups sage.graphs
-                sage: show(G, color_by_label=True, edge_labels=True)                    # optional - sage.groups sage.graphs sage.plot
-                sage: A5 = AlternatingGroup(5); A5                                      # optional - sage.groups
+                sage: G = D4.cayley_graph()
+                sage: show(G, color_by_label=True, edge_labels=True)                    # needs sage.plot
+                sage: A5 = AlternatingGroup(5); A5
                 Alternating group of order 5!/2 as a permutation group
-                sage: G = A5.cayley_graph()                                             # optional - sage.groups sage.graphs
-                sage: G.show3d(color_by_label=True, edge_size=0.01,                     # optional - sage.groups sage.graphs sage.plot
+                sage: G = A5.cayley_graph()
+                sage: G.show3d(color_by_label=True, edge_size=0.01,                     # needs sage.plot
                 ....:          edge_size2=0.02, vertex_size=0.03)
-                sage: G.show3d(vertex_size=0.03,  # long time (less than a minute)      # optional - sage.groups sage.graphs sage.plot
+                sage: G.show3d(vertex_size=0.03,        # long time (less than a minute), needs sage.plot
                 ....:          edge_size=0.01, edge_size2=0.02,
                 ....:          vertex_colors={(1,1,1): G.vertices(sort=True)},
                 ....:          bgcolor=(0,0,0), color_by_label=True,
                 ....:          xres=700, yres=700, iterations=200)
-                sage: G.num_edges()                                                     # optional - sage.groups sage.graphs
+                sage: G.num_edges()
                 120
 
-                sage: w = WeylGroup(['A', 3])                                           # optional - sage.combinat sage.groups
-                sage: d = w.cayley_graph(); d                                           # optional - sage.combinat sage.groups sage.graphs
+                sage: # needs sage.combinat sage.graphs sage.groups
+                sage: w = WeylGroup(['A', 3])
+                sage: d = w.cayley_graph(); d
                 Digraph on 24 vertices
-                sage: d.show3d(color_by_label=True, edge_size=0.01, vertex_size=0.03)   # optional - sage.combinat sage.groups sage.graphs sage.plot
+                sage: d.show3d(color_by_label=True, edge_size=0.01, vertex_size=0.03)   # needs sage.plot
 
             Alternative generators may be specified::
 
-                sage: G = A5.cayley_graph(generators=[A5.gens()[0]])                    # optional - sage.groups sage.graphs
-                sage: G.num_edges()                                                     # optional - sage.groups sage.graphs
+                sage: # needs sage.graphs sage.groups
+                sage: G = A5.cayley_graph(generators=[A5.gens()[0]])
+                sage: G.num_edges()
                 60
-                sage: g = PermutationGroup([(i + 1, j + 1)                              # optional - sage.groups sage.graphs
+                sage: g = PermutationGroup([(i + 1, j + 1)
                 ....:                       for i in range(5)
                 ....:                       for j in range(5) if j != i])
-                sage: g.cayley_graph(generators=[(1,2), (2,3)])                         # optional - sage.groups sage.graphs
+                sage: g.cayley_graph(generators=[(1,2), (2,3)])
                 Digraph on 120 vertices
 
             If ``elements`` is specified, then only the subgraph
@@ -234,62 +239,63 @@ class Semigroups(CategoryWithAxiom):
             display the Cayley graph of the free monoid truncated on
             the elements of length at most 3::
 
+                sage: # needs sage.combinat sage.graphs
                 sage: M = Monoids().example(); M
                 An example of a monoid:
                  the free monoid generated by ('a', 'b', 'c', 'd')
-                sage: elements = [M.prod(w)                                             # optional - sage.combinat
+                sage: elements = [M.prod(w)
                 ....:             for w in sum((list(Words(M.semigroup_generators(), k))
                 ....:                           for k in range(4)), [])]
-                sage: G = M.cayley_graph(elements=elements)                             # optional - sage.combinat sage.graphs
-                sage: G.num_verts(), G.num_edges()                                      # optional - sage.combinat sage.graphs
+                sage: G = M.cayley_graph(elements=elements)
+                sage: G.num_verts(), G.num_edges()
                 (85, 84)
-                sage: G.show3d(color_by_label=True, edge_size=0.001, vertex_size=0.01)  # optional - sage.combinat sage.graphs sage.plot
+                sage: G.show3d(color_by_label=True, edge_size=0.001, vertex_size=0.01)  # needs sage.plot
 
             We now illustrate the ``side`` and ``simple`` options on
             a semigroup::
 
                 sage: S = FiniteSemigroups().example(alphabet=('a', 'b'))
-                sage: g = S.cayley_graph(simple=True)                                   # optional - sage.graphs
-                sage: g.vertices(sort=True)                                             # optional - sage.graphs
+                sage: g = S.cayley_graph(simple=True)                                   # needs sage.graphs
+                sage: g.vertices(sort=True)                                             # needs sage.graphs
                 ['a', 'ab', 'b', 'ba']
-                sage: g.edges(sort=True)                                                # optional - sage.graphs
+                sage: g.edges(sort=True)                                                # needs sage.graphs
                 [('a', 'ab', None), ('b', 'ba', None)]
 
             ::
 
-                sage: g = S.cayley_graph(side="left", simple=True)                      # optional - sage.graphs
-                sage: g.vertices(sort=True)                                             # optional - sage.graphs
+                sage: g = S.cayley_graph(side="left", simple=True)                      # needs sage.graphs
+                sage: g.vertices(sort=True)                                             # needs sage.graphs
                 ['a', 'ab', 'b', 'ba']
-                sage: g.edges(sort=True)                                                # optional - sage.graphs
+                sage: g.edges(sort=True)                                                # needs sage.graphs
                 [('a', 'ba', None), ('ab', 'ba', None), ('b', 'ab', None),
                 ('ba', 'ab', None)]
 
             ::
 
-                sage: g = S.cayley_graph(side="twosided", simple=True)                  # optional - sage.graphs
-                sage: g.vertices(sort=True)                                             # optional - sage.graphs
+                sage: g = S.cayley_graph(side="twosided", simple=True)                  # needs sage.graphs
+                sage: g.vertices(sort=True)                                             # needs sage.graphs
                 ['a', 'ab', 'b', 'ba']
-                sage: g.edges(sort=True)                                                # optional - sage.graphs
+                sage: g.edges(sort=True)                                                # needs sage.graphs
                 [('a', 'ab', None), ('a', 'ba', None), ('ab', 'ba', None),
                 ('b', 'ab', None), ('b', 'ba', None), ('ba', 'ab', None)]
 
             ::
 
-                sage: g = S.cayley_graph(side="twosided")                               # optional - sage.graphs
-                sage: g.vertices(sort=True)                                             # optional - sage.graphs
+                sage: g = S.cayley_graph(side="twosided")                               # needs sage.graphs
+                sage: g.vertices(sort=True)                                             # needs sage.graphs
                 ['a', 'ab', 'b', 'ba']
-                sage: g.edges(sort=True)                                                # optional - sage.graphs
+                sage: g.edges(sort=True)                                                # needs sage.graphs
                 [('a', 'a', (0, 'left')), ('a', 'a', (0, 'right')), ('a', 'ab', (1, 'right')), ('a', 'ba', (1, 'left')), ('ab', 'ab', (0, 'left')), ('ab', 'ab', (0, 'right')), ('ab', 'ab', (1, 'right')), ('ab', 'ba', (1, 'left')), ('b', 'ab', (0, 'left')), ('b', 'b', (1, 'left')), ('b', 'b', (1, 'right')), ('b', 'ba', (0, 'right')), ('ba', 'ab', (0, 'left')), ('ba', 'ba', (0, 'right')), ('ba', 'ba', (1, 'left')), ('ba', 'ba', (1, 'right'))]
 
             ::
 
-                sage: s1 = SymmetricGroup(1); s = s1.cayley_graph()                     # optional - sage.groups sage.graphs
-                sage: s.vertices(sort=False)                                            # optional - sage.groups sage.graphs
+                sage: s1 = SymmetricGroup(1); s = s1.cayley_graph()                     # needs sage.graphs sage.groups
+                sage: s.vertices(sort=False)                                            # needs sage.graphs sage.groups
                 [()]
 
             TESTS::
 
-                sage: SymmetricGroup(2).cayley_graph(side="both")                       # optional - sage.groups sage.graphs
+                sage: SymmetricGroup(2).cayley_graph(side="both")                       # needs sage.graphs sage.groups
                 Traceback (most recent call last):
                 ...
                 ValueError: option 'side' must be 'left', 'right' or 'twosided'
@@ -337,7 +343,7 @@ class Semigroups(CategoryWithAxiom):
                 else:
                     generators = self.semigroup_generators()
             if isinstance(generators, (list, tuple)):
-                generators = dict((self(g), self(g)) for g in generators)
+                generators = {self(g): self(g) for g in generators}
             left = (side == "left"  or side == "twosided")
             right = (side == "right" or side == "twosided")
 
@@ -386,52 +392,53 @@ class Semigroups(CategoryWithAxiom):
             EXAMPLES::
 
                 sage: R = IntegerModRing(15)
-                sage: M = R.subsemigroup([R(3), R(5)]); M                               # optional - sage.groups
+                sage: M = R.subsemigroup([R(3), R(5)]); M                               # needs sage.combinat
                 A subsemigroup of (Ring of integers modulo 15) with 2 generators
-                sage: M.list()                                                          # optional - sage.groups
+                sage: M.list()                                                          # needs sage.combinat
                 [3, 5, 9, 0, 10, 12, 6]
 
             By default, `M` is just in the category of subsemigroups::
 
-                sage: M in Semigroups().Subobjects()                                    # optional - sage.groups
+                sage: M in Semigroups().Subobjects()                                    # needs sage.combinat
                 True
 
             In the following example, we specify that `M` is a
             submonoid of the finite monoid `R` (it shares the same
             unit), and a group by itself::
 
-                sage: M = R.subsemigroup([R(-1)],                                       # optional - sage.groups
+                sage: M = R.subsemigroup([R(-1)],                                       # needs sage.combinat
                 ....:     category=Monoids().Finite().Subobjects() & Groups()); M
                 A submonoid of (Ring of integers modulo 15) with 1 generators
-                sage: M.list()                                                          # optional - sage.groups
+                sage: M.list()                                                          # needs sage.combinat
                 [1, 14]
-                sage: M.one()                                                           # optional - sage.groups
+                sage: M.one()                                                           # needs sage.combinat
                 1
 
             In the following example, `M` is a group; however, its unit
             does not coincide with that of `R`, so `M` is only a
             subsemigroup, and we need to specify its unit explicitly::
 
-                sage: M = R.subsemigroup([R(5)],                                        # optional - sage.groups
+                sage: M = R.subsemigroup([R(5)],                                        # needs sage.combinat
                 ....:     category=Semigroups().Finite().Subobjects() & Groups()); M
                 Traceback (most recent call last):
                 ...
                 ValueError: For a monoid which is just a subsemigroup,
                 the unit should be specified
 
-                sage: M = R.subsemigroup([R(5)], one=R(10),                             # optional - sage.groups
+                sage: # needs sage.combinat sage.groups
+                sage: M = R.subsemigroup([R(5)], one=R(10),
                 ....:     category=Semigroups().Finite().Subobjects() & Groups()); M
                 A subsemigroup of (Ring of integers modulo 15) with 1 generators
-                sage: M in Groups()                                                     # optional - sage.groups
+                sage: M in Groups()
                 True
-                sage: M.list()                                                          # optional - sage.groups
+                sage: M.list()
                 [10, 5]
-                sage: M.one()                                                           # optional - sage.groups
+                sage: M.one()
                 10
 
             TESTS::
 
-                sage: TestSuite(M).run()                                                # optional - sage.groups
+                sage: TestSuite(M).run()                                                # needs sage.combinat
                 Failure in _test_inverse:
                 Traceback (most recent call last):
                 ...
@@ -461,8 +468,8 @@ class Semigroups(CategoryWithAxiom):
 
             EXAMPLES::
 
-                sage: G = groups.permutation.Dihedral(4)                                # optional - sage.groups
-                sage: G.trivial_representation()                                        # optional - sage.groups
+                sage: G = groups.permutation.Dihedral(4)                                # needs sage.groups
+                sage: G.trivial_representation()                                        # needs sage.groups
                 Trivial representation of Dihedral group of order 8
                  as a permutation group over Integer Ring
             """
@@ -481,8 +488,8 @@ class Semigroups(CategoryWithAxiom):
 
             EXAMPLES::
 
-                sage: G = groups.permutation.Dihedral(4)                                # optional - sage.groups
-                sage: G.regular_representation()                                        # optional - sage.groups
+                sage: G = groups.permutation.Dihedral(4)                                # needs sage.groups
+                sage: G.regular_representation()                                        # needs sage.groups
                 Left Regular Representation of Dihedral group of order 8
                  as a permutation group over Integer Ring
             """
@@ -492,6 +499,36 @@ class Semigroups(CategoryWithAxiom):
             from sage.modules.with_basis.representation import RegularRepresentation
             return RegularRepresentation(self, base_ring, side)
 
+        def representation(self, module, on_basis, side="left", *args, **kwargs):
+            r"""
+            Return a representation of ``self`` on ``module`` with
+            the action given by ``on_basis``.
+
+            INPUT:
+
+            - ``module`` -- a module with a basis
+            - ``on_basis`` -- function which takes as input ``g``, ``m``, where
+              ``g`` is an element of the semigroup and ``m`` is an element of the
+              indexing set for the basis, and returns the result of ``g`` acting
+              on ``m``
+            - ``side`` -- (default: ``"left"``) whether this is a
+              ``"left"`` or ``"right"`` representation
+
+            EXAMPLES::
+
+                sage: G = CyclicPermutationGroup(3)
+                sage: M = algebras.Exterior(QQ, 'x', 3)
+                sage: def on_basis(g, m):  # cyclically permute generators
+                ....:     return M.prod([M.monomial(FrozenBitset([g(j+1)-1])) for j in m])
+                sage: from sage.categories.algebras import Algebras
+                sage: R = G.representation(M, on_basis, category=Algebras(QQ).WithBasis().FiniteDimensional())
+                sage: R
+                Representation of Cyclic group of order 3 as a permutation group
+                 indexed by Subsets of {0,1,...,2} over Rational Field
+            """
+            from sage.modules.with_basis.representation import Representation
+            return Representation(self, module, on_basis, side, *args, **kwargs)
+
     class ElementMethods:
 
         def _pow_int(self, n):
@@ -892,7 +929,7 @@ class Semigroups(CategoryWithAxiom):
                     the left regular band generated by ('a', 'b', 'c', 'd')
                     sage: M.semigroup_generators()
                     Family ('a', 'b', 'c', 'd')
-                    sage: M.algebra(ZZ).algebra_generators()                            # optional - sage.modules
+                    sage: M.algebra(ZZ).algebra_generators()                            # needs sage.modules
                     Family (B['a'], B['b'], B['c'], B['d'])
                 """
                 return self.basis().keys().semigroup_generators().map(self.monomial)
@@ -901,18 +938,18 @@ class Semigroups(CategoryWithAxiom):
             # gens / monoid/group/*_generators, these methods could possibly
             # be removed in favor of aliases gens -> xxx_generators in
             # the Algebras.FinitelyGenerated hierarchy
-            def gens(self):
+            def gens(self) -> tuple:
                 r"""
                 Return the generators of ``self``.
 
                 EXAMPLES::
 
-                    sage: a, b = SL2Z.algebra(ZZ).gens(); a, b                          # optional - sage.groups sage.modules
+                    sage: a, b = SL2Z.algebra(ZZ).gens(); a, b                          # needs sage.groups sage.modular sage.modules
                     ([ 0 -1]
                      [ 1  0],
                      [1 1]
                      [0 1])
-                    sage: 2*a + b                                                       # optional - sage.groups sage.modules
+                    sage: 2*a + b                                                       # needs sage.groups sage.modular sage.modules
                     2*[ 0 -1]
                       [ 1  0]
                     +
@@ -927,9 +964,9 @@ class Semigroups(CategoryWithAxiom):
 
                 EXAMPLES::
 
-                    sage: SL2Z.algebra(ZZ).ngens()                                      # optional - sage.groups sage.modules
+                    sage: SL2Z.algebra(ZZ).ngens()                                      # needs sage.groups sage.modular sage.modules
                     2
-                    sage: DihedralGroup(4).algebra(RR).ngens()                          # optional - sage.groups sage.modules
+                    sage: DihedralGroup(4).algebra(RR).ngens()                          # needs sage.groups sage.modules
                     2
                 """
                 return self.basis().keys().ngens()
@@ -940,8 +977,8 @@ class Semigroups(CategoryWithAxiom):
 
                 EXAMPLES::
 
-                    sage: A = GL(3, GF(7)).algebra(ZZ)                                  # optional - sage.groups sage.libs.pari sage.modules
-                    sage: A.gen(0)                                                      # optional - sage.groups sage.libs.pari sage.modules
+                    sage: A = GL(3, GF(7)).algebra(ZZ)                                  # needs sage.modules
+                    sage: A.gen(0)                                                      # needs sage.groups sage.libs.pari sage.modules
                     [3 0 0]
                     [0 1 0]
                     [0 0 1]
@@ -962,9 +999,9 @@ class Semigroups(CategoryWithAxiom):
                     sage: S = FiniteSemigroups().example(); S
                     An example of a finite semigroup:
                      the left regular band generated by ('a', 'b', 'c', 'd')
-                    sage: A = S.algebra(QQ)                                             # optional - sage.modules
-                    sage: a, b, c, d = A.algebra_generators()                           # optional - sage.modules
-                    sage: a * b + b * d * c * d                                         # optional - sage.modules
+                    sage: A = S.algebra(QQ)                                             # needs sage.modules
+                    sage: a, b, c, d = A.algebra_generators()                           # needs sage.modules
+                    sage: a * b + b * d * c * d                                         # needs sage.modules
                     B['ab'] + B['bdc']
                 """
                 return self.monomial(g1 * g2)
@@ -979,10 +1016,11 @@ class Semigroups(CategoryWithAxiom):
 
                 EXAMPLES::
 
-                    sage: G = groups.permutation.Dihedral(4)                            # optional - sage.groups
-                    sage: A = G.algebra(QQ)                                             # optional - sage.groups sage.modules
-                    sage: V = A.trivial_representation()                                # optional - sage.groups sage.modules
-                    sage: V == G.trivial_representation(QQ)                             # optional - sage.groups sage.modules
+                    sage: # needs sage.groups
+                    sage: G = groups.permutation.Dihedral(4)
+                    sage: A = G.algebra(QQ)                                             # needs sage.modules
+                    sage: V = A.trivial_representation()                                # needs sage.modules
+                    sage: V == G.trivial_representation(QQ)                             # needs sage.modules
                     True
                 """
                 S = self.basis().keys()
@@ -999,11 +1037,40 @@ class Semigroups(CategoryWithAxiom):
 
                 EXAMPLES::
 
-                    sage: G = groups.permutation.Dihedral(4)                            # optional - sage.groups
-                    sage: A = G.algebra(QQ)                                             # optional - sage.groups sage.modules
-                    sage: V = A.regular_representation()                                # optional - sage.groups sage.modules
-                    sage: V == G.regular_representation(QQ)                             # optional - sage.groups sage.modules
+                    sage: # needs sage.groups
+                    sage: G = groups.permutation.Dihedral(4)
+                    sage: A = G.algebra(QQ)                                             # needs sage.modules
+                    sage: V = A.regular_representation()                                # needs sage.modules
+                    sage: V == G.regular_representation(QQ)                             # needs sage.modules
                     True
                 """
                 S = self.basis().keys()
                 return S.regular_representation(self.base_ring(), side)
+
+            def representation(self, module, on_basis, side="left", *args, **kwargs):
+                r"""
+                Return a representation of ``self`` on ``module`` with
+                the action of the semigroup given by ``on_basis``.
+
+                INPUT:
+
+                - ``module`` -- a module with a basis
+                - ``on_basis`` -- function which takes as input ``g``, ``m``, where
+                  ``g`` is an element of the semigroup and ``m`` is an element of the
+                  indexing set for the basis, and returns the result of ``g`` acting
+                  on ``m``
+                - ``side`` -- (default: ``"left"``) whether this is a
+                  ``"left"`` or ``"right"`` representation
+
+                EXAMPLES::
+
+                    sage: G = groups.permutation.Dihedral(5)
+                    sage: CFM = CombinatorialFreeModule(GF(2), [1, 2, 3, 4, 5])
+                    sage: A = G.algebra(GF(2))
+                    sage: R = A.representation(CFM, lambda g, i: CFM.basis()[g(i)], side='right')
+                    sage: R
+                    Representation of Dihedral group of order 10 as a permutation
+                     group indexed by {1, 2, 3, 4, 5} over Finite Field of size 2
+                """
+                from sage.modules.with_basis.representation import Representation
+                return Representation(self.group(), module, on_basis, side, *args, **kwargs)
