@@ -1,4 +1,4 @@
-# sage.doctest: optional - sage.modules sage.rings.finite_rings
+# sage.doctest: needs sage.modules sage.rings.finite_rings
 """
 Interpolation algorithms for the Guruswami-Sudan decoder
 
@@ -46,8 +46,7 @@ def _flatten_once(lstlst):
         [1, 2, 3, 4, 5, 6]
     """
     for lst in lstlst:
-        for e in lst:
-            yield e
+        yield from lst
 
 #*************************************************************
 #  Linear algebraic Interpolation algorithm, helper functions
@@ -131,7 +130,7 @@ def _interpolation_matrix_given_monomials(points, s, monomials):
         eqs = []
         for i in range(s):
             for j in range(s - i):
-                eq = dict()
+                eq = {}
                 for monomial in monomials:
                     ihat = monomial[0]
                     jhat = monomial[1]
