@@ -1,3 +1,4 @@
+# sage.doctest: needs sage.combinat sage.modules
 """
 Binary Recurrence Sequences
 
@@ -34,7 +35,7 @@ EXAMPLES::
     True
     sage: T.is_geometric()
     True
-    sage: T.pthpowers(7, 10**30)                                                        # optional - sage.symbolic
+    sage: T.pthpowers(7, 10**30)                                                        # needs sage.symbolic
     Traceback (most recent call last):
     ...
     ValueError: the degenerate binary recurrence sequence is geometric or quasigeometric
@@ -60,17 +61,19 @@ See [SV2013]_, [BMS2006]_, and [SS1983]_.
 
 
 from sage.structure.sage_object import SageObject
-from sage.matrix.constructor import matrix
-from sage.modules.free_module_element import vector
-from sage.rings.number_field.number_field import QuadraticField
 from sage.rings.finite_rings.integer_mod_ring import Integers
 from sage.rings.finite_rings.finite_field_constructor import GF
 from sage.rings.integer import Integer
 from sage.arith.functions import lcm
 from sage.arith.misc import is_prime, next_prime, next_prime_power, legendre_symbol
-from sage.functions.log import log
+from sage.misc.lazy_import import lazy_import
 from sage.misc.functional import sqrt
 
+lazy_import("sage.functions.log", "log")
+lazy_import("sage.rings.number_field.number_field", "QuadraticField")
+lazy_import("sage.matrix.constructor", "matrix")
+lazy_import("sage.modules.free_module_element", "vector")
+
 
 class BinaryRecurrenceSequence(SageObject):
 
@@ -126,9 +129,9 @@ class BinaryRecurrenceSequence(SageObject):
         self.c = c
         self.u0 = u0
         self.u1 = u1
-        self._period_dict = {}    #dictionary to cache the period of a sequence for future lookup
-        self._PGoodness = {} #dictionary to cache primes that are "good" by some prime power
-        self._ell = 1 #variable that keeps track of the last prime power to be used as a goodness
+        self._period_dict = {}  # dictionary to cache the period of a sequence for future lookup
+        self._PGoodness = {}  # dictionary to cache primes that are "good" by some prime power
+        self._ell = 1  # variable that keeps track of the last prime power to be used as a goodness
 
     def __repr__(self):
         """
@@ -468,7 +471,7 @@ class BinaryRecurrenceSequence(SageObject):
                     #expand the list of prime factors so every factor is with multiplicity 1
 
                     for i0, i1 in Mfac:
-                        for j in range(i1):
+                        for _ in range(i1):
                             C.append(i0)
 
                     Mfac = C
@@ -513,13 +516,15 @@ class BinaryRecurrenceSequence(SageObject):
 
         INPUT:
 
-        - ``p`` - a rational prime integer (the fixed p in `u_n = y^p`)
+        - ``p`` -- a rational prime integer (the fixed p in `u_n = y^p`)
 
-        - ``Bound`` - a natural number (the maximum index `n` in `u_n = y^p` that is checked).
+        - ``Bound`` -- a natural number (the maximum index `n` in `u_n = y^p` that is checked).
 
         OUTPUT:
 
-        - A list of the indices of all ``p`` th powers less bounded by ``Bound``.  If the sequence is degenerate and there are many ``p`` th powers, raises ``ValueError``.
+        - A list of the indices of all ``p`` th powers less bounded by
+          ``Bound``. If the sequence is degenerate and there are many
+          ``p`` th powers, raises :class:`ValueError`.
 
         EXAMPLES::
 
@@ -536,7 +541,7 @@ class BinaryRecurrenceSequence(SageObject):
             [1]
 
         If the sequence is degenerate, and there are no ``p`` th powers, returns `[]`.  Otherwise, if
-        there are many ``p`` th powers, raises ``ValueError``.
+        there are many ``p`` th powers, raises :class:`ValueError`.
 
         ::
 
@@ -545,7 +550,7 @@ class BinaryRecurrenceSequence(SageObject):
             True
             sage: T.is_geometric()
             True
-            sage: T.pthpowers(7, 10**30)                                                # optional - sage.symbolic
+            sage: T.pthpowers(7, 10**30)                                                # needs sage.symbolic
             Traceback (most recent call last):
             ...
             ValueError: the degenerate binary recurrence sequence is geometric or
@@ -556,7 +561,7 @@ class BinaryRecurrenceSequence(SageObject):
             [2, 2, 2^3, 2^5, 2^7, 2^9, 2^11, 2^13, 2^15, 2^17]
             sage: L.is_quasigeometric()
             True
-            sage: L.pthpowers(2, 10**30)                                                # optional - sage.symbolic
+            sage: L.pthpowers(2, 10**30)                                                # needs sage.symbolic
             []
 
         .. NOTE::
@@ -646,10 +651,10 @@ class BinaryRecurrenceSequence(SageObject):
 
                 F = GF(ell)
                 a0 = F(self.u0)
-                a1 = F(self.u1) #a0 and a1 are variables for terms in sequence
+                a1 = F(self.u1)  # a0 and a1 are variables for terms in sequence
                 bf, cf = F(self.b), F(self.c)
 
-                for n in range(Bound): # n is the index of the a0
+                for n in range(Bound):  # n is the index of the a0
 
                     #Check whether a0 is a perfect power mod ell
                     if _is_p_power_mod(a0, p, ell):
@@ -690,7 +695,7 @@ class BinaryRecurrenceSequence(SageObject):
                             #gather congruence data for the sequence mod ell, which will be mod period(ell) = modu
                             cong1, modu = _find_cong1(p, self, ell)
 
-                            CongNew = []        #makes a new list from cong that is now mod M = lcm(M1, modu) instead of M1
+                            CongNew = []        # makes a new list from cong that is now mod M = lcm(M1, modu) instead of M1
                             M = lcm(M1, modu)
                             for k in range(M // M1):
                                 for i in cong:
@@ -699,18 +704,18 @@ class BinaryRecurrenceSequence(SageObject):
 
                             M1 = M
 
-                            killed_something = False        #keeps track of when cong1 can rule out a congruence in cong
+                            killed_something = False        # keeps track of when cong1 can rule out a congruence in cong
 
-                            #CRT by hand to gain speed
+                            # CRT by hand to gain speed
                             for i in list(cong):
-                                if not (i % modu in cong1):        #congruence in cong is inconsistent with any in cong1
-                                    cong.remove(i)            #remove that congruence
+                                if i % modu not in cong1:     # congruence in cong is inconsistent with any in cong1
+                                    cong.remove(i)            # remove that congruence
                                     killed_something = True
 
                             if M1 == M2:
                                 if not killed_something:
                                     tries += 1
-                                    if tries == 2:            #try twice to rule out congruences
+                                    if tries == 2:            # try twice to rule out congruences
                                         cong = list(cong)
                                         qqold = qq
                                         qq = next_prime_power(qq)
@@ -1054,7 +1059,7 @@ def _estimated_time(M2, M1, length, p):
     EXAMPLES::
 
         sage: from sage.combinat.binary_recurrence_sequences import _estimated_time
-        sage: _estimated_time(2**4*3**2*5*7*11*13*17, 2**4*3**2*5*7*11*13, 20, 7)       # optional - sage.symbolic
+        sage: _estimated_time(2**4*3**2*5*7*11*13*17, 2**4*3**2*5*7*11*13, 20, 7)       # needs sage.symbolic
         106.211159309421
 
     """
@@ -1090,7 +1095,7 @@ def _find_cong1(p, R, ell):
     EXAMPLES::
 
         sage: R = BinaryRecurrenceSequence(1,1)
-        sage: sage.combinat.binary_recurrence_sequences._find_cong1(7, R, 29)           # optional - sage.rings.finite_rings
+        sage: sage.combinat.binary_recurrence_sequences._find_cong1(7, R, 29)           # needs sage.rings.finite_rings
         ([0, 1, 2, 12, 13], 14)
     """
     F = GF(ell)
@@ -1140,9 +1145,9 @@ def _is_p_power(a, p):
 
     EXAMPLES::
 
-        sage: sage.combinat.binary_recurrence_sequences._is_p_power(2**7, 7)            # optional - sage.symbolic
+        sage: sage.combinat.binary_recurrence_sequences._is_p_power(2**7, 7)            # needs sage.symbolic
         True
-        sage: sage.combinat.binary_recurrence_sequences._is_p_power(2**7*3**2, 7)       # optional - sage.symbolic
+        sage: sage.combinat.binary_recurrence_sequences._is_p_power(2**7*3**2, 7)       # needs sage.symbolic
         False
     """
     return int(a**(1/p))**p == a
