@@ -18,7 +18,6 @@ written by Peter Dobcsanyi [Do2009]_ peter@designtheory.org.
 
 Functions
 ---------
-
 """
 
 ###########################################################################
@@ -565,6 +564,7 @@ def open_extrep_url(url):
     else:
         return f.read()
 
+
 pattern_integer = re.compile(r'\d+$')
 pattern_decimal = re.compile(r'-?\d+\.\d+$')
 pattern_rational = re.compile(r'-?\d+/\d+$')
@@ -600,7 +600,7 @@ def _encode_attribute(string):
     else:
         return string
 
-class XTree():
+class XTree:
     '''
     A lazy class to wrap a rooted tree representing an XML document.
     The tree's nodes are tuples of the structure:
@@ -773,7 +773,7 @@ class XTree():
 
         return len(self.xt_children)
 
-class XTreeProcessor():
+class XTreeProcessor:
     '''
     An incremental event-driven parser for ext-rep documents.
     The processing stages:
@@ -921,7 +921,7 @@ class XTreeProcessor():
                     self.block_design_proc(self.current_node[2][0])
                 if self.save_designs:
                     init_bd = XTree(self.current_node[2][0])
-                    self.list_of_designs.append((init_bd.v, [b for b in init_bd.blocks]))
+                    self.list_of_designs.append((init_bd.v, list(init_bd.blocks)))
                 #print_subxt(self.current_node[2][0], level=2, outf=self.outf)
                 self._init()
             elif name == 'info':
