@@ -49,8 +49,8 @@ def construction_3_3(k,n,m,i,explain_construction=False):
 
     INPUT:
 
-    - ``k,n,m,i`` (integers) such that the following designs are available:
-      `OA(k,n)`, `OA(k,m)`, `OA(k,m+1)`, `OA(k,r)`.
+    - ``k``, ``n``, ``m``, ``i`` (integers) such that the following designs are
+      available: `OA(k,n)`, `OA(k,m)`, `OA(k,m+1)`, `OA(k,r)`.
 
     - ``explain_construction`` (boolean) -- return a string describing
       the construction.
@@ -64,8 +64,8 @@ def construction_3_3(k,n,m,i,explain_construction=False):
         sage: from sage.combinat.designs.orthogonal_arrays_find_recursive import find_construction_3_3
         sage: from sage.combinat.designs.orthogonal_arrays_build_recursive import construction_3_3
         sage: from sage.combinat.designs.orthogonal_arrays import is_orthogonal_array
-        sage: k=11;n=177
-        sage: is_orthogonal_array(construction_3_3(*find_construction_3_3(k,n)[1]),k,n,2)
+        sage: k = 11; n = 177
+        sage: is_orthogonal_array(construction_3_3(*find_construction_3_3(k,n)[1]),k,n,2)           # needs sage.schemes
         True
 
         sage: print(designs.orthogonal_arrays.explain_construction(9,91))
@@ -78,14 +78,14 @@ def construction_3_3(k,n,m,i,explain_construction=False):
     from .orthogonal_arrays import wilson_construction, OA_relabel, incomplete_orthogonal_array
     if explain_construction:
         return (("Construction 3.3 with n={},m={},i={} from:\n"
-                 "  Julian R. Abel, Nicholas Cavenagh\n"+
-                 "  Concerning eight mutually orthogonal latin squares,\n"+
-                 "  Vol. 15, n.3, pp. 255-261,\n"+
+                 "  Julian R. Abel, Nicholas Cavenagh\n" +
+                 "  Concerning eight mutually orthogonal latin squares,\n" +
+                 "  Vol. 15, n.3, pp. 255-261,\n" +
                  "  Journal of Combinatorial Designs, 2007").format(n,m,i))
 
     # Builds an OA(k+i,n) containing a block [0]*(k+i)
     OA = incomplete_orthogonal_array(k+i,n,(1,))
-    OA = [[(x+1)%n for x in B] for B in OA]
+    OA = [[(x+1) % n for x in B] for B in OA]
 
     # Truncated version
     OA = [B[:k]+[0 if x == 0 else None for x in B[k:]] for B in OA]
@@ -116,7 +116,8 @@ def construction_3_4(k,n,m,r,s,explain_construction=False):
 
     INPUT:
 
-    - ``k,n,m,r,s`` (integers) -- we assume that `s<n` and `1\leq r,s`
+    - ``k``, ``n``, ``m``, ``r``, ``s`` -- integers; we assume that `s<n` and
+      `1\leq r,s`
 
       The following designs must be available: `OA(k,n)`, `OA(k,m)`,
       `OA(k,m+1)`, `OA(k,m+2)`, `OA(k,s)`. Additionally, it requires either a
@@ -134,8 +135,8 @@ def construction_3_4(k,n,m,r,s,explain_construction=False):
         sage: from sage.combinat.designs.orthogonal_arrays_find_recursive import find_construction_3_4
         sage: from sage.combinat.designs.orthogonal_arrays_build_recursive import construction_3_4
         sage: from sage.combinat.designs.orthogonal_arrays import is_orthogonal_array
-        sage: k=8;n=196
-        sage: is_orthogonal_array(construction_3_4(*find_construction_3_4(k,n)[1]),k,n,2)
+        sage: k = 8; n = 196
+        sage: is_orthogonal_array(construction_3_4(*find_construction_3_4(k,n)[1]),k,n,2)           # needs sage.schemes
         True
 
         sage: print(designs.orthogonal_arrays.explain_construction(8,164))
@@ -146,14 +147,14 @@ def construction_3_4(k,n,m,r,s,explain_construction=False):
            Journal of Combinatorial Designs, 2007
     """
     if explain_construction:
-        return ("Construction 3.4 with n={},m={},r={},s={} from:\n"+
-                 "  Julian R. Abel, Nicholas Cavenagh\n"+
-                 "  Concerning eight mutually orthogonal latin squares,\n"+
-                 "  Vol. 15, n.3, pp. 255-261,\n"+
+        return ("Construction 3.4 with n={},m={},r={},s={} from:\n" +
+                 "  Julian R. Abel, Nicholas Cavenagh\n" +
+                 "  Concerning eight mutually orthogonal latin squares,\n" +
+                 "  Vol. 15, n.3, pp. 255-261,\n" +
                  "  Journal of Combinatorial Designs, 2007").format(n,m,r,s)
 
     from .orthogonal_arrays import wilson_construction, OA_relabel
-    assert s<n
+    assert s < n
     master_design = orthogonal_array(k+r+1,n)
 
     # Defines the first k+r columns of the matrix of labels
@@ -189,9 +190,9 @@ def construction_3_5(k,n,m,r,s,t,explain_construction=False):
 
     INPUT:
 
-    - ``k,n,m`` (integers)
+    - ``k``, ``n``, ``m`` (integers)
 
-    - ``r,s,t`` (integers) -- sizes of the three truncated groups,
+    - ``r``, ``s``, ``t`` (integers) -- sizes of the three truncated groups,
       such that `r\leq s` and `(q-r-1)(q-s) \geq (q-s-1)*(q-r)`.
 
     - ``explain_construction`` (boolean) -- return a string describing
@@ -210,7 +211,7 @@ def construction_3_5(k,n,m,r,s,t,explain_construction=False):
         sage: from sage.combinat.designs.orthogonal_arrays_build_recursive import construction_3_5
         sage: from sage.combinat.designs.orthogonal_arrays import is_orthogonal_array
         sage: k=8;n=111
-        sage: is_orthogonal_array(construction_3_5(*find_construction_3_5(k,n)[1]),k,n,2)
+        sage: is_orthogonal_array(construction_3_5(*find_construction_3_5(k,n)[1]),k,n,2)           # needs sage.schemes
         True
 
         sage: print(designs.orthogonal_arrays.explain_construction(8,90))
@@ -228,9 +229,9 @@ def construction_3_5(k,n,m,r,s,t,explain_construction=False):
 
     if explain_construction:
         return (("Construction 3.5 with n={},m={},r={},s={},t={} from:\n"
-                 "  Julian R. Abel, Nicholas Cavenagh\n"+
-                 "  Concerning eight mutually orthogonal latin squares,\n"+
-                 "  Vol. 15, n.3, pp. 255-261,\n"+
+                 "  Julian R. Abel, Nicholas Cavenagh\n" +
+                 "  Concerning eight mutually orthogonal latin squares,\n" +
+                 "  Vol. 15, n.3, pp. 255-261,\n" +
                  "  Journal of Combinatorial Designs, 2007").format(n,m,r,s,t))
 
     master_design = orthogonal_array(k+3,q)
@@ -282,8 +283,9 @@ def construction_3_6(k,n,m,i,explain_construction=False):
 
     INPUT:
 
-    - ``k,n,m,i`` (integers) -- `n` must be a prime power. The following designs
-      must be available: `OA(k+r,q)`, `OA(k,m)`, `OA(k,m+1)`, `OA(k,m+2)`.
+    - ``k``, ``n``, ``m``, ``i`` (integers) -- `n` must be a prime power. The
+      following designs must be available: `OA(k+r,q)`, `OA(k,m)`, `OA(k,m+1)`,
+      `OA(k,m+2)`.
 
     - ``explain_construction`` (boolean) -- return a string describing
       the construction.
@@ -302,7 +304,7 @@ def construction_3_6(k,n,m,i,explain_construction=False):
         sage: from sage.combinat.designs.orthogonal_arrays_build_recursive import construction_3_6
         sage: from sage.combinat.designs.orthogonal_arrays import is_orthogonal_array
         sage: k=8;n=95
-        sage: is_orthogonal_array(construction_3_6(*find_construction_3_6(k,n)[1]),k,n,2)
+        sage: is_orthogonal_array(construction_3_6(*find_construction_3_6(k,n)[1]),k,n,2)           # needs sage.schemes
         True
 
         sage: print(designs.orthogonal_arrays.explain_construction(10,756))
@@ -314,15 +316,15 @@ def construction_3_6(k,n,m,i,explain_construction=False):
     """
     if explain_construction:
         return (("Construction 3.6 with n={},m={},i={} from:\n"
-                 "  Julian R. Abel, Nicholas Cavenagh\n"+
-                 "  Concerning eight mutually orthogonal latin squares,\n"+
-                 "  Vol. 15, n.3, pp. 255-261,\n"+
+                 "  Julian R. Abel, Nicholas Cavenagh\n" +
+                 "  Concerning eight mutually orthogonal latin squares,\n" +
+                 "  Vol. 15, n.3, pp. 255-261,\n" +
                  "  Journal of Combinatorial Designs, 2007").format(n,m,i))
 
     from .orthogonal_arrays import wilson_construction
     OA = OA_and_oval(n)
     OA = [B[:k+i] for B in OA]
-    OA = [B[:k] + [x if x==0 else None for x in B[k:]] for B in OA]
+    OA = [B[:k] + [x if x == 0 else None for x in B[k:]] for B in OA]
     OA = wilson_construction(OA,k,n,m,[1]*i)
     assert is_orthogonal_array(OA,k,n*m+i)
     return OA
@@ -420,13 +422,13 @@ def OA_and_oval(q, *, solver=None, integrality_tolerance=1e-3):
     oval.sort()
 
     # Turning the TD into an OA
-    BB = [[xx%q for xx in b] for b in BB]
-    oval = [xx%q for xx in oval]
+    BB = [[xx % q for xx in b] for b in BB]
+    oval = [xx % q for xx in oval]
     assert len(oval) == q
 
     # We relabel the "oval" as relabelled as [0,...,0]
     OA = OA_relabel(BB+([[0]+oval]),q+1,q,blocks=[[0]+oval])
-    OA = [[(x+1)%q for x in B] for B in OA]
+    OA = [[(x+1) % q for x in B] for B in OA]
     OA.remove([0]*(q+1))
 
     assert all(sum([xx == 0 for xx in b[1:]]) <= 2 for b in OA)
@@ -471,7 +473,8 @@ def construction_q_x(k, q, x, check=True, explain_construction=False):
 
     INPUT:
 
-    - ``k,q,x`` -- integers such that `0<x<q` and such that Sage can build:
+    - ``k``, ``q``, ``x`` -- integers such that `0<x<q` and such that Sage can
+      build:
 
         - A projective plane of order `q`
         - `OA(k,q-x-1)-(q-x-1).OA(k,1)`
@@ -497,7 +500,7 @@ def construction_q_x(k, q, x, check=True, explain_construction=False):
     EXAMPLES::
 
         sage: from sage.combinat.designs.orthogonal_arrays_build_recursive import construction_q_x
-        sage: _ = construction_q_x(9,16,6)
+        sage: _ = construction_q_x(9,16,6)                                                          # needs sage.schemes
 
         sage: print(designs.orthogonal_arrays.explain_construction(9,158))
         (q-x)-construction with q=16,x=6 from:
@@ -518,10 +521,10 @@ def construction_q_x(k, q, x, check=True, explain_construction=False):
     from sage.combinat.designs.orthogonal_arrays import incomplete_orthogonal_array
 
     if explain_construction:
-        return ("(q-x)-construction with q={},x={} from:\n"+
-                "   Malcolm Greig,\n"+
-                "   Designs from projective planes and PBD bases,\n"+
-                "   vol. 7, num. 5, pp. 341--374,\n"+
+        return ("(q-x)-construction with q={},x={} from:\n" +
+                "   Malcolm Greig,\n" +
+                "   Designs from projective planes and PBD bases,\n" +
+                "   vol. 7, num. 5, pp. 341--374,\n" +
                 "   Journal of Combinatorial Designs, 1999").format(q, x)
 
     n = (q-1)*(q-x)+x+2
@@ -551,7 +554,7 @@ def construction_q_x(k, q, x, check=True, explain_construction=False):
     PBD = [[relabel[xx] for xx in B if xx not in points_to_delete] for B in TD]
 
     # Taking the unique block of size x+2
-    assert list(map(len,PBD)).count(x+2)==1
+    assert list(map(len,PBD)).count(x+2) == 1
     for B in PBD:
         if len(B) == x+2:
             break
@@ -633,8 +636,9 @@ def thwart_lemma_3_5(k,n,m,a,b,c,d=0,complement=False,explain_construction=False
 
     INPUT:
 
-    - ``k,n,m,a,b,c,d`` -- integers which must satisfy the constraints above. In
-      particular, `a+b+c\leq n+1` must hold. By default, `d=0`.
+    - ``k``, ``n``, ``m``, ``a``, ``b``, ``c``, ``d`` -- integers which must
+      satisfy the constraints above. In particular, `a+b+c\leq n+1` must hold.
+      By default, `d=0`.
 
     - ``complement`` (boolean) -- whether to complement the sets, i.e. follow
       the `n-a,n-b,n-c` variant described above.
@@ -650,11 +654,11 @@ def thwart_lemma_3_5(k,n,m,a,b,c,d=0,complement=False,explain_construction=False
 
         sage: from sage.combinat.designs.orthogonal_arrays_build_recursive import thwart_lemma_3_5
         sage: from sage.combinat.designs.designs_pyx import is_orthogonal_array
-        sage: OA = thwart_lemma_3_5(6,23,7,5,7,8)
-        sage: is_orthogonal_array(OA,6,23*7+5+7+8,2)
+        sage: OA = thwart_lemma_3_5(6,23,7,5,7,8)                                                   # needs sage.schemes
+        sage: is_orthogonal_array(OA,6,23*7+5+7+8,2)                                                # needs sage.schemes
         True
 
-        sage: print(designs.orthogonal_arrays.explain_construction(10,408))
+        sage: print(designs.orthogonal_arrays.explain_construction(10,408))                         # needs sage.schemes
         Lemma 4.1 with n=13,m=28 from:
            Charles J.Colbourn, Jeffrey H. Dinitz, Mieczyslaw Wojtas,
            Thwarts in transversal designs,
@@ -691,14 +695,14 @@ def thwart_lemma_3_5(k,n,m,a,b,c,d=0,complement=False,explain_construction=False
         a,b,c = n-a,n-b,n-c
 
     if explain_construction:
-        return ("Lemma 3.5 with n={},m={},a={},b={},c={},d={} from:\n"+
-                "   Charles J.Colbourn, Jeffrey H. Dinitz, Mieczyslaw Wojtas,\n"+
-                "   Thwarts in transversal designs,\n"+
+        return ("Lemma 3.5 with n={},m={},a={},b={},c={},d={} from:\n" +
+                "   Charles J.Colbourn, Jeffrey H. Dinitz, Mieczyslaw Wojtas,\n" +
+                "   Thwarts in transversal designs,\n" +
                 "   Designs, Codes and Cryptography 5, no. 3 (1995): 189-197.").format(n,m,a,b,c,d)
 
     assert is_prime_power(n), "n(={}) must be a prime power".format(n)
-    assert a<=n and b<=n and c<=n and d<=n, "a,b,c,d (={},{},{},{}) must be <=n(={})".format(a,b,c,d,n)
-    assert a+b+c<=n+1, "{}={}+{}+{}=a+b+c>n+1={}+1 violates the assumptions".format(a+b+c,a,b,c,n)
+    assert a <= n and b <= n and c <= n and d <= n, "a,b,c,d (={},{},{},{}) must be <=n(={})".format(a,b,c,d,n)
+    assert a+b+c <= n+1, "{}={}+{}+{}=a+b+c>n+1={}+1 violates the assumptions".format(a+b+c,a,b,c,n)
     assert k+3+bool(d) <= n+1, "There exists no OA({},{}).".format(k+3+bool(d),n)
     G = GF(n,prefix='x')
     G_set = sorted(G) # sorted by lexicographic order, G[1] = 1
@@ -773,7 +777,7 @@ def thwart_lemma_4_1(k,n,m,explain_construction=False):
 
     INPUT:
 
-    - ``k,n,m`` (integers)
+    - ``k``, ``n``, ``m`` (integers)
 
     - ``explain_construction`` (boolean) -- return a string describing
       the construction.
@@ -784,7 +788,7 @@ def thwart_lemma_4_1(k,n,m,explain_construction=False):
 
     EXAMPLES::
 
-        sage: print(designs.orthogonal_arrays.explain_construction(10,408))
+        sage: print(designs.orthogonal_arrays.explain_construction(10,408))                         # needs sage.schemes
         Lemma 4.1 with n=13,m=28 from:
            Charles J.Colbourn, Jeffrey H. Dinitz, Mieczyslaw Wojtas,
            Thwarts in transversal designs,
@@ -803,9 +807,9 @@ def thwart_lemma_4_1(k,n,m,explain_construction=False):
     from itertools import chain
 
     if explain_construction:
-        return ("Lemma 4.1 with n={},m={} from:\n"+
-                "   Charles J.Colbourn, Jeffrey H. Dinitz, Mieczyslaw Wojtas,\n"+
-                "   Thwarts in transversal designs,\n"+
+        return ("Lemma 4.1 with n={},m={} from:\n" +
+                "   Charles J.Colbourn, Jeffrey H. Dinitz, Mieczyslaw Wojtas,\n" +
+                "   Thwarts in transversal designs,\n" +
                 "   Designs, Codes and Cryptography 5, no. 3 (1995): 189-197.").format(n,m)
 
     assert is_prime_power(n), "n(={}) must be a prime power"
@@ -834,11 +838,11 @@ def thwart_lemma_4_1(k,n,m,explain_construction=False):
     points = [[K(_) for _ in t] for t in points] # triples of K^3
     AG_2_3 = []
     for x,y,z in points:
-        if z!=0:
+        if z != 0:
             x,y,z = x/z,y/z,z/z
             AG_2_3.append(relabel[x]+n*relabel[y])
-        elif y!=0:
-            x,y,z=x/y,y/y,z
+        elif y != 0:
+            x,y,z = x/y,y/y,z
             AG_2_3.append(q**2+relabel[x])
         else:
             AG_2_3.append(q**2+q)
@@ -871,7 +875,7 @@ def thwart_lemma_4_1(k,n,m,explain_construction=False):
     TD = [sorted(relabel[x] for x in B) for B in blocks]
 
     # We build the OA, removing unnecessary columns
-    OA = [[x%q for x in B[-k-4:]] for B in TD]
+    OA = [[x % q for x in B[-k-4:]] for B in TD]
     for B in OA:
         for i in range(4):
             if B[k+i] >= n-2:
@@ -945,7 +949,7 @@ def three_factor_product(k,n1,n2,n3,check=False,explain_construction=False):
 
     INPUT:
 
-    - ``k,n1,n2,n3`` (integers)
+    - ``k``, ``n1``, ``n2``, ``n3`` (integers)
 
     - ``check`` -- (boolean) Whether to check that everything is going smoothly
       while the design is being built. It is disabled by default, as the
@@ -960,25 +964,21 @@ def three_factor_product(k,n1,n2,n3,check=False,explain_construction=False):
 
     EXAMPLES::
 
+        sage: # needs sage.schemes
         sage: from sage.combinat.designs.designs_pyx import is_orthogonal_array
         sage: from sage.combinat.designs.orthogonal_arrays_build_recursive import three_factor_product
-
         sage: OA = three_factor_product(4,4,4,4)
         sage: is_orthogonal_array(OA,5,64)
         True
-
         sage: OA = three_factor_product(4,3,4,5)
         sage: is_orthogonal_array(OA,5,60)
         True
-
         sage: OA = three_factor_product(5,4,5,7)
         sage: is_orthogonal_array(OA,6,140)
         True
-
         sage: OA = three_factor_product(9,8,9,9) # long time
         sage: is_orthogonal_array(OA,10,8*9*9)   # long time
         True
-
         sage: print(designs.orthogonal_arrays.explain_construction(10,648))
         Three-factor product with n=8.9.9 from:
            Peter J. Dukes, Alan C.H. Ling,
@@ -1002,9 +1002,9 @@ def three_factor_product(k,n1,n2,n3,check=False,explain_construction=False):
     assert n1 <= n2 and n2 <= n3
 
     if explain_construction:
-        return ("Three-factor product with n={}.{}.{} from:\n"+
-                "   Peter J. Dukes, Alan C.H. Ling,\n"+
-                "   A three-factor product construction for mutually orthogonal latin squares,\n"+
+        return ("Three-factor product with n={}.{}.{} from:\n" +
+                "   Peter J. Dukes, Alan C.H. Ling,\n" +
+                "   A three-factor product construction for mutually orthogonal latin squares,\n" +
                 "   https://arxiv.org/abs/1401.1466").format(n1, n2, n3)
 
     def assert_c_partition(classs,k,n,c):
@@ -1013,10 +1013,10 @@ def three_factor_product(k,n1,n2,n3,check=False,explain_construction=False):
         ``B[i]`` covers `[n]` exactly `c` times for every index `i`.
         """
         c = int(c)
-        assert all(len(B)==k for B in classs), "A block has length {}!=k(={})".format(len(B),k)
+        assert all(len(B) == k for B in classs), "A block has length {}!=k(={})".format(len(B),k)
         assert len(classs) == n*c, "not the right number of blocks"
         for p in zip(*classs):
-            assert all(x==i//c for i,x in enumerate(sorted(p))), "A class is not c(={})-parallel".format(c)
+            assert all(x == i//c for i,x in enumerate(sorted(p))), "A class is not c(={})-parallel".format(c)
 
     def product_with_parallel_classes(OA1,k,g1,g2,g1_parall,parall,check=True):
         r"""
@@ -1026,7 +1026,7 @@ def three_factor_product(k,n1,n2,n3,check=False,explain_construction=False):
 
         - ``OA1`` (an `OA(k,g_1)`
 
-        - ``k,g1,g2`` integers
+        - ``k``, ``g1``, ``g2`` -- integers
 
         - ``g1_parall`` -- list of `g_1`-parallel classes
 
@@ -1065,7 +1065,7 @@ def three_factor_product(k,n1,n2,n3,check=False,explain_construction=False):
                 assert max(shift) < g1
 
                 for B1 in OA1:
-                    copy_of_OA1.append([x2*g1+(x1+sh)%g1 for sh,x1,x2 in zip(shift,B1,B2)])
+                    copy_of_OA1.append([x2*g1+(x1+sh) % g1 for sh,x1,x2 in zip(shift,B1,B2)])
 
                 copies_of_OA1.append(copy_of_OA1)
 
@@ -1190,8 +1190,8 @@ def _reorder_matrix(matrix):
         matching = g.matching(algorithm="LP")
         col = [0]*N
         for x,i,_ in matching:
-            if i<N:
-                x,i=i,x
+            if i < N:
+                x,i = i,x
             col[i-N] = x
         matrix.append(col)
         g.delete_edges(matching)
@@ -1323,7 +1323,7 @@ def brouwer_separable_design(k,t,q,x,check=False,verbose=False,explain_construct
 
     INPUT:
 
-    - ``k,t,q,x`` (integers)
+    - ``k``, ``t``, ``q``, ``x`` (integers)
 
     - ``check`` -- (boolean) Whether to check that output is correct before
       returning it. Set to ``False`` by default.
@@ -1391,31 +1391,31 @@ def brouwer_separable_design(k,t,q,x,check=False,verbose=False,explain_construct
     from sage.arith.misc import is_prime_power
 
     if explain_construction:
-        return ("Brouwer's separable design construction with t={},q={},x={} from:\n"+
-                "    Andries E. Brouwer,\n"+
-                "    A series of separable designs with application to pairwise orthogonal Latin squares\n"+
-                "    Vol. 1, n. 1, pp. 39-41,\n"+
+        return ("Brouwer's separable design construction with t={},q={},x={} from:\n" +
+                "    Andries E. Brouwer,\n" +
+                "    A series of separable designs with application to pairwise orthogonal Latin squares\n" +
+                "    Vol. 1, n. 1, pp. 39-41,\n" +
                 "    European Journal of Combinatorics, 1980").format(t,q,x)
 
     ###########################################################
     # Part 1: compute the separable PBD on t(q^2+q+1) points. #
     ###########################################################
 
-    assert t<q**2-q+1
-    assert x>=0
+    assert t < q**2-q+1
+    assert x >= 0
     assert is_prime_power(q)
     N2 = q**4+q**2+1
-    N1 = q**2+ q +1
+    N1 = q**2 + q + 1
 
     # A projective plane on (q^2-q+1)*(q^2+q+1)=q^4+q^2+1 points
     B = difference_family(N2,q**2+1,1)[1][0]
-    BIBD = [[(xx+i)%N2 for xx in B] for i in range(N2)]
+    BIBD = [[(xx+i) % N2 for xx in B] for i in range(N2)]
 
     # Each congruence class mod q^2-q+1 yields a Baer subplane. Let's check that:
     m = q**2-q+1
     for i in range(m):
         for B in BIBD:
-            assert sum((xx%m)==i for xx in B) in [1,q+1], sum((xx%m)==i for xx in B)
+            assert sum((xx % m) == i for xx in B) in [1,q+1], sum((xx % m) == i for xx in B)
 
     # We are only interested by the points of the first t Baer subplanes (each
     # has size q**2+q+1). Note that each block of the projective plane:
@@ -1439,14 +1439,14 @@ def brouwer_separable_design(k,t,q,x,check=False,verbose=False,explain_construct
 
     for B in BIBD:
         # Find the Baer subplane which B intersects on more than 1 point
-        B_mod = sorted(xx%m for xx in B)
+        B_mod = sorted(xx % m for xx in B)
         while B_mod.pop(0) != B_mod[0]:
             pass
         plane = B_mod[0]
         if plane < t:
-            blocks_of_size_q_plus_t.append([relabel[xx] for xx in B if xx%m<t])
+            blocks_of_size_q_plus_t.append([relabel[xx] for xx in B if xx % m < t])
         else:
-            partition_of_blocks_of_size_t[plane-t].append([relabel[xx] for xx in B if xx%m<t])
+            partition_of_blocks_of_size_t[plane-t].append([relabel[xx] for xx in B if xx % m < t])
 
     ###############################################################################
     # Separable design built !
@@ -1541,8 +1541,8 @@ def brouwer_separable_design(k,t,q,x,check=False,verbose=False,explain_construct
         # an OA(k,t) can be used instead of an OA(k+1,t)
 
         if x == q**2:
-            assert e3==0, "equivalent to x==q^2"
-            assert len(partition_of_blocks_of_size_t)==1, "also equivalent to exactly one partition into sets of size t"
+            assert e3 == 0, "equivalent to x==q^2"
+            assert len(partition_of_blocks_of_size_t) == 1, "also equivalent to exactly one partition into sets of size t"
             OA = [[B[xx] for xx in R] for R in orthogonal_array(k,t) for B in partition_of_blocks_of_size_t[0]]
         else:
             OA = OA_from_PBD(k,N,sum(partition_of_blocks_of_size_t,[]),check=False)[:-N]
@@ -1562,7 +1562,7 @@ def brouwer_separable_design(k,t,q,x,check=False,verbose=False,explain_construct
         blocks_of_size_q_plus_t = _reorder_matrix(blocks_of_size_q_plus_t)
 
         for i,classs in enumerate(OA_tq1_classes):
-            OA.extend([R[xx] if xx<t+q else N-i-1 for xx in B] for R in blocks_of_size_q_plus_t for B in classs)
+            OA.extend([R[xx] if xx < t+q else N-i-1 for xx in B] for R in blocks_of_size_q_plus_t for B in classs)
 
         # The set of size x
         OA.extend([N-1-xx for xx in R] for R in orthogonal_array(k,x))
@@ -1585,7 +1585,7 @@ def brouwer_separable_design(k,t,q,x,check=False,verbose=False,explain_construct
             # There is one partition into blocks of size t, which we extend with
             # the new vertex. The OA on t+1 points does not have to be resolvable.
 
-            OA.extend([B[xx] if xx<t else N-1 for xx in R]
+            OA.extend([B[xx] if xx < t else N-1 for xx in R]
                        for R in incomplete_orthogonal_array(k,t+1,[1])
                        for B in partition_of_blocks_of_size_t[0])
 
@@ -1606,13 +1606,13 @@ def brouwer_separable_design(k,t,q,x,check=False,verbose=False,explain_construct
         OA.extend([N-xx-1 for xx in B] for B in orthogonal_array(k,x))
 
     # iv)
-    elif (x == q**2+1 and
-          orthogonal_array( k  ,  x  ,existence=True) and # d0
-          orthogonal_array(k+e4, t+1 ,existence=True) and # d2-e4
-          orthogonal_array(k+ 1,t+q+1,existence=True)):   # d4-1
+    elif (x == q**2 + 1 and
+          orthogonal_array(k, x, existence=True) and            # d0
+          orthogonal_array(k + e4, t + 1, existence=True) and   # d2 - e4
+          orthogonal_array(k + 1, t + q + 1, existence=True)):  # d4 - 1
 
         if verbose:
-            print("Case iv) with k={},q={},t={},x={},e4={}".format(k,q,t,x,e4))
+            print(f"Case iv) with k={k},q={q},t={t},x={x},e4={e4}")
 
         # Sets of size t:
         #
@@ -1620,7 +1620,7 @@ def brouwer_separable_design(k,t,q,x,check=False,verbose=False,explain_construct
 
         if e4 == 0:
             # Only one partition into t-sets. The OA(k,t+1) needs not be resolvable
-            OA = [[B[xx] if xx<t else N-x for xx in R]
+            OA = [[B[xx] if xx < t else N-x for xx in R]
                   for R in incomplete_orthogonal_array(k,t+1,[1])
                   for B in partition_of_blocks_of_size_t[0]]
         else:
@@ -1643,14 +1643,14 @@ def brouwer_separable_design(k,t,q,x,check=False,verbose=False,explain_construct
         blocks_of_size_q_plus_t = _reorder_matrix(blocks_of_size_q_plus_t)
 
         for i,classs in enumerate(OA_tq1_classes):
-            OA.extend([R[xx] if xx<t+q else N-i-1 for xx in B] for R in blocks_of_size_q_plus_t for B in classs)
+            OA.extend([R[xx] if xx < t+q else N-i-1 for xx in B] for R in blocks_of_size_q_plus_t for B in classs)
 
         # Set of size x
         OA_k_x = orthogonal_array(k,x)
         OA.extend([N-i-1 for i in R] for R in OA_k_x)
 
     # v)
-    elif (0<x and x<q**2-q+1-t and (e1 or e2) and # The result is wrong when e1=e2=0
+    elif (0 < x and x < q**2-q+1-t and (e1 or e2) and # The result is wrong when e1=e2=0
           orthogonal_array(k   ,x  ,existence=True) and # d0
           orthogonal_array(k+e1,t  ,existence=True) and # d1-e1
           orthogonal_array(k+e2,t+1,existence=True) and # d2-e2
@@ -1664,14 +1664,14 @@ def brouwer_separable_design(k,t,q,x,check=False,verbose=False,explain_construct
         #
         # We extend x partitions into blocks of size t with the new x elements
         if e2:
-            assert x!=1, "equivalent to e2==1"
+            assert x != 1, "equivalent to e2==1"
             for i,classs in enumerate(partition_of_blocks_of_size_t[:x]):
                 for B in classs:
                     B.append(N-1-i)
             OA.extend(OA_from_PBD(k,N,sum(partition_of_blocks_of_size_t[:x],[]),check=False)[:-N])
 
         else:
-            assert x==1, "equivalent to e2==0"
+            assert x == 1, "equivalent to e2==0"
             # Only one class, the OA(k,t+1) need not be resolvable.
             OA.extend([B[xx] if xx < t else N-1 for xx in R]
                        for R in incomplete_orthogonal_array(k,t+1,[1])
@@ -1679,10 +1679,10 @@ def brouwer_separable_design(k,t,q,x,check=False,verbose=False,explain_construct
 
         # Sets of size t
         if e1:
-            assert x!=q**2-q-t, "equivalent to e1=1"
+            assert x != q**2-q-t, "equivalent to e1=1"
             OA.extend(OA_from_PBD(k,N,sum(partition_of_blocks_of_size_t[x:],[]),check=False)[:-N])
         else:
-            assert x==q**2-q-t, "equivalent to e1=0"
+            assert x == q**2-q-t, "equivalent to e1=0"
             # Only one class. The OA(k,t) needs not be resolvable
             OA.extend([B[xx] for xx in R] for R in orthogonal_array(k,t) for B in partition_of_blocks_of_size_t[-1])
 
@@ -1699,7 +1699,7 @@ def brouwer_separable_design(k,t,q,x,check=False,verbose=False,explain_construct
         OA.extend([N-i-1 for i in R] for R in orthogonal_array(k,x))
 
     # vi)
-    elif (t+q<x and x<q**2+1 and (e3 or e4) and # The result is wrong when e3=e4=0
+    elif (t+q < x and x < q**2+1 and (e3 or e4) and # The result is wrong when e3=e4=0
           orthogonal_array(k   ,x   ,existence=True) and # d0
           orthogonal_array(k+e3,t   ,existence=True) and # d1-e3
           orthogonal_array(k+e4,t+1 ,existence=True) and # d2-e4
@@ -1722,7 +1722,7 @@ def brouwer_separable_design(k,t,q,x,check=False,verbose=False,explain_construct
         else:
             assert x == q+t+1, "equivalent to e4=0"
             # Only one class. The OA(k,t+1) needs not be resolvable.
-            OA.extend([B[xx] if xx<t else N-x for xx in R]
+            OA.extend([B[xx] if xx < t else N-x for xx in R]
                        for R in incomplete_orthogonal_array(k,t+1,[1])
                        for B in partition_of_blocks_of_size_t[0])
 
@@ -1757,7 +1757,7 @@ def brouwer_separable_design(k,t,q,x,check=False,verbose=False,explain_construct
         blocks_of_size_q_plus_t = _reorder_matrix(blocks_of_size_q_plus_t)
 
         for i,classs in enumerate(OA_tq1_classes):
-            OA.extend([R[xx] if xx<t+q else N-i-1 for xx in B]
+            OA.extend([R[xx] if xx < t+q else N-i-1 for xx in B]
                        for R in blocks_of_size_q_plus_t
                        for B in classs)
 
