@@ -1,4 +1,4 @@
-# -*- coding: utf-8 -*-
+# sage.doctest: needs sage.combinat sage.modules
 r"""
 `\nu`-Dyck Words
 
@@ -12,7 +12,6 @@ This file is based off the class
 :func:`DyckWords<sage.combinat.dyck_word.DyckWord>` written by Mike Hansen, Dan
 Drake, Florent Hivert, Christian Stump, Mike Zabrocki, Jean--Baptiste Priez
 and Travis Scrimshaw
-
 """
 # ****************************************************************************
 #       Copyright (C) 2020 Aram Dermenjian <aram.dermenjian@gmail.com>,
@@ -84,7 +83,7 @@ def replace_dyck_char(x):
 
     INPUT:
 
-    - ``x`` -- str - A ``'1'``, ``'0'``, ``'N'``, ``'E'``, ``'('`` or ``')'``
+    - ``x`` -- string; a ``'1'``, ``'0'``, ``'N'``, ``'E'``, ``'('`` or ``')'``
 
     OUTPUT:
 
@@ -94,7 +93,7 @@ def replace_dyck_char(x):
     - If ``x`` is a closing character, replace ``x`` with the
       constant ``ndw_close_symbol``.
 
-    - Raise a ``ValueError`` if ``x`` is neither an opening nor a
+    - Raise a :class:`ValueError` if ``x`` is neither an opening nor a
       closing character.
 
     .. SEEALSO:: :func:`replace_dyck_symbol`
@@ -142,7 +141,7 @@ def replace_dyck_symbol(x, open_char='N', close_char='E') -> str:
     - If ``x`` is ``ndw_close_symbol``, replace ``x`` with ``close_char``.
 
     - If ``x`` is neither ``ndw_open_symbol`` nor ``ndw_close_symbol``, a
-      ``ValueError`` is raised.
+      :class:`ValueError` is raised.
 
     .. SEEALSO:: :func:`replace_dyck_char`
 
@@ -829,7 +828,7 @@ class NuDyckWord(CombinatorialElement):
         if latex_options['show_grid']:
             grid = [((0, 0), (self.width(), self.height()))]
             for v1, v2 in grid:
-                res += "  \\draw[dotted] %s grid %s;" % (str(v1), str(v2))
+                res += f"  \\draw[dotted] {v1} grid {v2};"
                 res += "\n"
 
         # Add points if wanted
@@ -838,8 +837,8 @@ class NuDyckWord(CombinatorialElement):
             radius = 0.15 + .03 * latex_options['line width']
             for v in self.points():
                 res += "  \\draw[line width=2,"
-                res += "color=%s,fill=%s]" % (pt_color, pt_color)
-                res += "%s circle (%s);" % (str(v), str(radius))
+                res += f"color={pt_color},fill={pt_color}]"
+                res += f"{v} circle ({radius});"
                 res += "\n"
 
         # Add nu if wanted
@@ -853,7 +852,7 @@ class NuDyckWord(CombinatorialElement):
             res += ";\n"
 
         # setup Path
-        res += "  \\draw[rounded corners=1, color=%s, line width=%s]" % (
+        res += "  \\draw[rounded corners=1, color={}, line width={}]".format(
             latex_options['color'],
             str(latex_options['line width'])
         )
@@ -873,7 +872,7 @@ class NuDyckWord(CombinatorialElement):
         EXAMPLES::
 
             sage: NDW = NuDyckWord('010','010')
-            sage: NDW.plot()                                                            # optional - sage.plot
+            sage: NDW.plot()                                                            # needs sage.plot
             Graphics object consisting of 1 graphics primitive
         """
         from sage.plot.plot import list_plot
@@ -1210,46 +1209,46 @@ class NuDyckWords(Parent):
         """
         NAME = 'NuDyckWords'
         module = 'sage.combinat.nu_dyck_path'
-        display = dict(default="list",
-                       description='Specifies how nu Dyck words should be printed',
-                       values=dict(list='displayed as a list',
-                                   lattice='displayed on the lattice defined by ``diagram_style``'),
-                       case_sensitive=False)
-        ascii_art = dict(default="pretty_output",
-                         description='Specifies how the ascii art of nu Dyck words should be printed',
-                         values=dict(pretty_output="Using pretty printing"),
-                         alias=dict(pretty_print="pretty_output",),
-                         case_sensitive=False)
-        diagram_style = dict(default="grid",
-                             values=dict(
-                                 grid='printing as paths on a grid using N and E steps',),
-                             alias={'N-E': 'grid'},
-                             case_sensitive=False)
-        latex_tikz_scale = dict(default=1,
-                                description='The default value for the tikz scale when latexed',
-                                checker=lambda x: True)  # More trouble than it's worth to check
-        latex_line_width_scalar = dict(default=2,
-                                       description='The default value for the line width as a '
-                                       'multiple of the tikz scale when latexed',
-                                       checker=lambda x: True)  # More trouble than it's worth to check
-        latex_color = dict(default="black",
-                           description='The default value for the color when latexed',
-                           checker=lambda x: isinstance(x, str))
-        latex_show_points = dict(default=False,
-                                 description='The default value for showing points',
-                                 checker=lambda x: isinstance(x, bool))
-        latex_points_color = dict(default='black',
-                                  description='The default value for path color.',
-                                  checker=lambda x: isinstance(x, str))
-        latex_show_grid = dict(default=True,
-                               description='The default value for showing grid',
-                               checker=lambda x: isinstance(x, bool))
-        latex_show_nu = dict(default=True,
-                             description='The default value for showing nu',
-                             checker=lambda x: isinstance(x, bool))
-        latex_nu_options = dict(default='rounded corners=1, color=red, line width=1',
-                                description='The default value for options for nu path',
-                                checker=lambda x: isinstance(x, str))
+        display = {'default': "list",
+                   'description': 'Specifies how nu Dyck words should be printed',
+                   'values': {'list': 'displayed as a list',
+                              'lattice': 'displayed on the lattice defined by ``diagram_style``'},
+                   'case_sensitive': False}
+        ascii_art = {'default': "pretty_output",
+                     'description': 'Specifies how the ascii art of nu Dyck words should be printed',
+                     'values': {'pretty_output': "Using pretty printing"},
+                     'alias': {'pretty_print': "pretty_output"},
+                     'case_sensitive': False}
+        diagram_style = {'default': "grid",
+                         'values': {
+                             'grid': 'printing as paths on a grid using N and E steps'},
+                         'alias': {'N-E': 'grid'},
+                         'case_sensitive': False}
+        latex_tikz_scale = {'default': 1,
+                            'description': 'The default value for the tikz scale when latexed',
+                            'checker': lambda x: True}  # More trouble than it's worth to check
+        latex_line_width_scalar = {'default': 2,
+                                   'description': 'The default value for the line width as a '
+                                   'multiple of the tikz scale when latexed',
+                                   'checker': lambda x: True}  # More trouble than it's worth to check
+        latex_color = {'default': "black",
+                       'description': 'The default value for the color when latexed',
+                       'checker': lambda x: isinstance(x, str)}
+        latex_show_points = {'default': False,
+                             'description': 'The default value for showing points',
+                             'checker': lambda x: isinstance(x, bool)}
+        latex_points_color = {'default': 'black',
+                              'description': 'The default value for path color.',
+                              'checker': lambda x: isinstance(x, str)}
+        latex_show_grid = {'default': True,
+                           'description': 'The default value for showing grid',
+                           'checker': lambda x: isinstance(x, bool)}
+        latex_show_nu = {'default': True,
+                         'description': 'The default value for showing nu',
+                         'checker': lambda x: isinstance(x, bool)}
+        latex_nu_options = {'default': 'rounded corners=1, color=red, line width=1',
+                            'description': 'The default value for options for nu path',
+                            'checker': lambda x: isinstance(x, str)}
 
     def _element_constructor_(self, word):
         """
