@@ -1,9 +1,10 @@
+# sage.doctest: needs sage.combinat sage.modules
 r"""
 Catalog of posets and lattices
 
 Some common posets can be accessed through the ``posets.<tab>`` object::
 
-    sage: posets.PentagonPoset()                                                        # optional - sage.modules
+    sage: posets.PentagonPoset()
     Finite lattice containing 5 elements
 
 Moreover, the set of all posets of order `n` is represented by ``Posets(n)``::
@@ -238,9 +239,9 @@ class Posets(metaclass=ClasscallMetaclass):
 
         Check the corner cases::
 
-            sage: list(posets.BooleanLattice(0, use_subsets=True))                      # optional - sage.modules
+            sage: list(posets.BooleanLattice(0, use_subsets=True))
             [{}]
-            sage: list(posets.BooleanLattice(1, use_subsets=True))                      # optional - sage.modules
+            sage: list(posets.BooleanLattice(1, use_subsets=True))
             [{}, {1}]
         """
         n = check_int(n)
@@ -304,7 +305,7 @@ class Posets(metaclass=ClasscallMetaclass):
             ....:         if C.covers(C(i),C(j)) and j != i+1:
             ....:             print("TEST FAILED")
 
-        Check that :trac:`8422` is solved::
+        Check that :issue:`8422` is solved::
 
             sage: posets.ChainPoset(0)
             Finite lattice containing 0 elements
@@ -352,7 +353,7 @@ class Posets(metaclass=ClasscallMetaclass):
 
         TESTS:
 
-        Check that :trac:`8422` is solved::
+        Check that :issue:`8422` is solved::
 
             sage: posets.AntichainPoset(0)
             Finite poset containing 0 elements
@@ -382,22 +383,22 @@ class Posets(metaclass=ClasscallMetaclass):
 
         EXAMPLES::
 
-            sage: P = posets.PentagonPoset(); P                                         # optional - sage.modules
+            sage: P = posets.PentagonPoset(); P
             Finite lattice containing 5 elements
-            sage: P.cover_relations()                                                   # optional - sage.modules
+            sage: P.cover_relations()
             [[0, 1], [0, 2], [1, 4], [2, 3], [3, 4]]
 
         TESTS:
 
         This is smallest lattice that is not modular::
 
-            sage: P.is_modular()                                                        # optional - sage.modules
+            sage: P.is_modular()
             False
 
         This poset and the :meth:`DiamondPoset` are the two smallest
         lattices which are not distributive::
 
-            sage: P.is_distributive()                                                   # optional - sage.modules
+            sage: P.is_distributive()
             False
             sage: posets.DiamondPoset(5).is_distributive()
             False
@@ -425,7 +426,7 @@ class Posets(metaclass=ClasscallMetaclass):
         """
         n = check_int(n, 3)
         c = [[n - 1] for x in range(n)]
-        c[0] = [x for x in range(1, n - 1)]
+        c[0] = list(range(1, n - 1))
         c[n - 1] = []
         D = DiGraph({v: c[v] for v in range(n)}, format='dict_of_lists')
         return FiniteLatticePoset(hasse_diagram=D,
@@ -535,9 +536,9 @@ class Posets(metaclass=ClasscallMetaclass):
 
         EXAMPLES::
 
-            sage: P = posets.IntegerPartitions(7); P                                    # optional - sage.combinat
+            sage: P = posets.IntegerPartitions(7); P
             Finite poset containing 15 elements
-            sage: len(P.cover_relations())                                              # optional - sage.combinat
+            sage: len(P.cover_relations())
             28
         """
         def lower_covers(partition):
@@ -573,9 +574,9 @@ class Posets(metaclass=ClasscallMetaclass):
 
         EXAMPLES::
 
-            sage: P = posets.RestrictedIntegerPartitions(7); P                          # optional - sage.combinat
+            sage: P = posets.RestrictedIntegerPartitions(7); P
             Finite poset containing 15 elements
-            sage: len(P.cover_relations())                                              # optional - sage.combinat
+            sage: len(P.cover_relations())
             17
 
         """
@@ -617,9 +618,9 @@ class Posets(metaclass=ClasscallMetaclass):
 
         EXAMPLES::
 
-            sage: P = posets.IntegerPartitionsDominanceOrder(6); P                      # optional - sage.combinat
+            sage: P = posets.IntegerPartitionsDominanceOrder(6); P
             Finite lattice containing 11 elements
-            sage: P.cover_relations()                                                   # optional - sage.combinat
+            sage: P.cover_relations()
             [[[1, 1, 1, 1, 1, 1], [2, 1, 1, 1, 1]],
              [[2, 1, 1, 1, 1], [2, 2, 1, 1]],
              [[2, 2, 1, 1], [2, 2, 2]],
@@ -652,22 +653,22 @@ class Posets(metaclass=ClasscallMetaclass):
 
         EXAMPLES::
 
-            sage: P3 = posets.PowerPoset(3); P3                                         # optional - sage.modules
+            sage: P3 = posets.PowerPoset(3); P3
             Finite meet-semilattice containing 19 elements
-            sage: all(P.is_chain() for P in P3.maximal_elements())                      # optional - sage.modules
+            sage: all(P.is_chain() for P in P3.maximal_elements())
             True
 
         TESTS::
 
-            sage: P0 = posets.PowerPoset(0); P0                                         # optional - sage.modules
+            sage: P0 = posets.PowerPoset(0); P0
             Finite meet-semilattice containing 1 elements
-            sage: P0[0]                                                                 # optional - sage.modules
+            sage: P0[0]
             Finite poset containing 0 elements
-            sage: P1 = posets.PowerPoset(1); P1                                         # optional - sage.modules
+            sage: P1 = posets.PowerPoset(1); P1
             Finite meet-semilattice containing 1 elements
-            sage: P1[0]                                                                 # optional - sage.modules
+            sage: P1[0]
             Finite poset containing 1 elements
-            sage: P1[0][0]                                                              # optional - sage.modules
+            sage: P1[0][0]
             0
         """
         # Todo: Make this faster.
@@ -697,30 +698,30 @@ class Posets(metaclass=ClasscallMetaclass):
 
         EXAMPLES::
 
-            sage: P = posets.ProductOfChains([2, 2]); P                                 # optional - sage.modules
+            sage: P = posets.ProductOfChains([2, 2]); P
             Finite lattice containing 4 elements
-            sage: P.linear_extension()                                                  # optional - sage.modules
+            sage: P.linear_extension()
             [(0, 0), (0, 1), (1, 0), (1, 1)]
-            sage: P.upper_covers((0,0))                                                 # optional - sage.modules
+            sage: P.upper_covers((0,0))
             [(0, 1), (1, 0)]
-            sage: P.lower_covers((1,1))                                                 # optional - sage.modules
+            sage: P.lower_covers((1,1))
             [(0, 1), (1, 0)]
 
         TESTS::
 
-            sage: P = posets.ProductOfChains([]); P                                     # optional - sage.modules
+            sage: P = posets.ProductOfChains([]); P
             Finite lattice containing 0 elements
-            sage: P = posets.ProductOfChains([3, 0, 1]); P                              # optional - sage.modules
+            sage: P = posets.ProductOfChains([3, 0, 1]); P
             Finite lattice containing 0 elements
-            sage: P = posets.ProductOfChains([1,1,1,1]); P                              # optional - sage.modules
+            sage: P = posets.ProductOfChains([1,1,1,1]); P
             Finite lattice containing 1 elements
         """
         try:
             l = [Integer(x) for x in chain_lengths]
         except TypeError:
-            raise TypeError("parameter chain_lengths must be a list of integers, not {0}".format(chain_lengths))
+            raise TypeError("parameter chain_lengths must be a list of integers, not {}".format(chain_lengths))
         if any(x < 0 for x in l):
-            raise TypeError("parameter chain_lengths must be a list of nonnegative integers, not {0}".format(l))
+            raise TypeError("parameter chain_lengths must be a list of nonnegative integers, not {}".format(l))
 
         # given the empty list, we expect the empty poset.
         if not chain_lengths:
@@ -740,9 +741,9 @@ class Posets(metaclass=ClasscallMetaclass):
 
         INPUT:
 
-        - ``n`` - number of elements, a non-negative integer
+        - ``n`` -- number of elements, a non-negative integer
 
-        - ``p`` - a probability, a real number between 0 and 1 (inclusive)
+        - ``p`` -- a probability, a real number between 0 and 1 (inclusive)
 
         OUTPUT:
 
@@ -780,9 +781,9 @@ class Posets(metaclass=ClasscallMetaclass):
         try:
             p = float(p)
         except (TypeError, ValueError):
-            raise TypeError("probability must be a real number, not {0}".format(p))
+            raise TypeError(f"probability must be a real number, not {p}")
         if p < 0 or p > 1:
-            raise ValueError("probability must be between 0 and 1, not {0}".format(p))
+            raise ValueError(f"probability must be between 0 and 1, not {p}")
 
         D = DiGraph(loops=False, multiedges=False)
         D.add_vertices(range(n))
@@ -831,12 +832,12 @@ class Posets(metaclass=ClasscallMetaclass):
         EXAMPLES::
 
             sage: set_random_seed(0)  # Results are reproducible
-            sage: L = posets.RandomLattice(8, 0.995); L                                 # optional - sage.modules
+            sage: L = posets.RandomLattice(8, 0.995); L
             Finite lattice containing 8 elements
-            sage: L.cover_relations()                                                   # optional - sage.modules
+            sage: L.cover_relations()
             [[7, 6], [7, 3], [7, 1], ..., [5, 4], [2, 4], [1, 4], [0, 4]]
-            sage: L = posets.RandomLattice(10, 0, properties=['dismantlable'])          # optional - sage.modules
-            sage: L.is_dismantlable()                                                   # optional - sage.modules
+            sage: L = posets.RandomLattice(10, 0, properties=['dismantlable'])
+            sage: L.is_dismantlable()
             True
 
         .. SEEALSO:: :meth:`RandomPoset`
@@ -858,7 +859,7 @@ class Posets(metaclass=ClasscallMetaclass):
             ...
             ValueError: unknown value junk for 'properties'
 
-            sage: posets.RandomLattice(0, 0.5)                                          # optional - sage.modules
+            sage: posets.RandomLattice(0, 0.5)
             Finite lattice containing 0 elements
         """
         from copy import copy
@@ -866,9 +867,9 @@ class Posets(metaclass=ClasscallMetaclass):
         try:
             p = float(p)
         except Exception:
-            raise TypeError("probability must be a real number, not {0}".format(p))
+            raise TypeError(f"probability must be a real number, not {p}")
         if p < 0 or p >= 1:
-            raise ValueError("probability must be a positive real number and below 1, not {0}".format(p))
+            raise ValueError("probability must be a positive real number and below 1, not {}".format(p))
 
         if properties is None:
             # Basic case, no special properties for lattice asked.
@@ -881,11 +882,11 @@ class Posets(metaclass=ClasscallMetaclass):
             return LatticePoset(D, cover_relations=True)
 
         if isinstance(properties, str):
-            properties = set([properties])
+            properties = {properties}
         else:
             properties = set(properties)
 
-        known_properties = set(['planar', 'dismantlable', 'distributive', 'stone'])
+        known_properties = {'planar', 'dismantlable', 'distributive', 'stone'}
         errors = properties.difference(known_properties)
         if errors:
             raise ValueError("unknown value %s for 'properties'" % errors.pop())
@@ -906,22 +907,22 @@ class Posets(metaclass=ClasscallMetaclass):
         if 'stone' in properties and len(properties) > 1:
             raise NotImplementedError("combining 'stone' with other properties is not implemented")
 
-        if properties == set(['planar']):
+        if properties == {'planar'}:
             D = _random_planar_lattice(n)
             D.relabel([i - 1 for i in Permutations(n).random_element()])
             return LatticePoset(D)
 
-        if properties == set(['dismantlable']):
+        if properties == {'dismantlable'}:
             D = _random_dismantlable_lattice(n)
             D.relabel([i - 1 for i in Permutations(n).random_element()])
             return LatticePoset(D)
 
-        if properties == set(['stone']):
+        if properties == {'stone'}:
             D = _random_stone_lattice(n)
             D.relabel([i - 1 for i in Permutations(n).random_element()])
             return LatticePoset(D)
 
-        if properties == set(['distributive']):
+        if properties == {'distributive'}:
             tmp = Poset(_random_distributive_lattice(n)).order_ideals_lattice(as_ideals=False)
             D = copy(tmp._hasse_diagram)
             D.relabel([i - 1 for i in Permutations(n).random_element()])
@@ -941,7 +942,7 @@ class Posets(metaclass=ClasscallMetaclass):
 
         EXAMPLES::
 
-            sage: posets.SetPartitions(4)                                               # optional - sage.combinat
+            sage: posets.SetPartitions(4)
             Finite lattice containing 15 elements
         """
         from sage.combinat.set_partition import SetPartitions
@@ -968,11 +969,10 @@ class Posets(metaclass=ClasscallMetaclass):
 
         INPUT:
 
-        - ``s`` - shape of the tableaux
+        - ``s`` -- shape of the tableaux
 
-        - ``f`` - maximum fill number.  This is an optional
-          argument.  If no maximal number is given, it will use
-          the number of cells in the shape.
+        - ``f`` -- integer (default: ``None``); the maximum fill number.
+          By default (``None``), the method uses the number of cells in the shape.
 
         .. NOTE::
 
@@ -981,19 +981,19 @@ class Posets(metaclass=ClasscallMetaclass):
 
         EXAMPLES::
 
-            sage: posets.SSTPoset([2,1])                                                # optional - sage.combinat
+            sage: posets.SSTPoset([2,1])
             Finite lattice containing 8 elements
 
-            sage: posets.SSTPoset([2,1],4)                                              # optional - sage.combinat
+            sage: posets.SSTPoset([2,1],4)
             Finite lattice containing 20 elements
 
-            sage: posets.SSTPoset([2,1],2).cover_relations()                            # optional - sage.combinat
+            sage: posets.SSTPoset([2,1],2).cover_relations()
             [[[[1, 1], [2]], [[1, 2], [2]]]]
 
-            sage: posets.SSTPoset([3,2]).bottom()  # long time (6s on sage.math, 2012)  # optional - sage.combinat
+            sage: posets.SSTPoset([3,2]).bottom()       # long time (6s on sage.math, 2012)
             [[1, 1, 1], [2, 2]]
 
-            sage: posets.SSTPoset([3,2],4).maximal_elements()                           # optional - sage.combinat
+            sage: posets.SSTPoset([3,2],4).maximal_elements()
             [[[3, 3, 4], [4, 4]]]
         """
         from sage.combinat.tableau import SemistandardTableaux
@@ -1009,8 +1009,8 @@ class Posets(metaclass=ClasscallMetaclass):
     @staticmethod
     def StandardExample(n, facade=None):
         r"""
-        Return the partially ordered set on ``2n`` elements with
-        dimension ``n``.
+        Return the partially ordered set on `2n` elements with
+        dimension `n`.
 
         Let `P` be the poset on `\{0, 1, 2, \ldots, 2n-1\}` whose defining
         relations are that `i < j` for every `0 \leq i < n \leq j < 2n`
@@ -1020,7 +1020,8 @@ class Posets(metaclass=ClasscallMetaclass):
         INPUT:
 
         - ``n`` -- an integer `\ge 2`, dimension of the constructed poset
-        - ``facade`` (boolean) -- whether to make the returned poset a
+
+        - ``facade`` -- boolean; whether to make the returned poset a
           facade poset (see :mod:`sage.categories.facade_sets`); the
           default behaviour is the same as the default behaviour of
           the :func:`~sage.combinat.posets.posets.Poset` constructor
@@ -1033,7 +1034,7 @@ class Posets(metaclass=ClasscallMetaclass):
 
             sage: A = posets.StandardExample(3); A
             Finite poset containing 6 elements
-            sage: A.dimension()
+            sage: A.dimension()                                                         # needs networkx
             3
 
         REFERENCES:
@@ -1080,9 +1081,9 @@ class Posets(metaclass=ClasscallMetaclass):
 
         INPUT:
 
-        - ``start`` - list permutation
+        - ``start`` -- list permutation
 
-        - ``end`` - list permutation (same n, of course)
+        - ``end`` -- list permutation (same n, of course)
 
         .. note::
 
@@ -1105,18 +1106,17 @@ class Posets(metaclass=ClasscallMetaclass):
         start = Permutation(start)
         end = Permutation(end)
         if len(start) != len(end):
-            raise TypeError("start (%s) and end (%s) must have same length" % (start, end))
+            raise TypeError(f"start ({start}) and end ({end}) must have same length")
         if not start.bruhat_lequal(end):
-            raise TypeError("must have start (%s) <= end (%s) in Bruhat order" % (start, end))
+            raise TypeError(f"must have start ({start}) <= end ({end}) in Bruhat order")
         unseen = [start]
         nodes = {}
         while unseen:
             perm = unseen.pop(0)
             nodes[perm] = [succ_perm for succ_perm in perm.bruhat_succ()
                            if succ_perm.bruhat_lequal(end)]
-            for succ_perm in nodes[perm]:
-                if succ_perm not in nodes:
-                    unseen.append(succ_perm)
+            unseen.extend(succ_perm for succ_perm in nodes[perm]
+                          if succ_perm not in nodes)
         return Poset(nodes)
 
     @staticmethod
@@ -1167,7 +1167,7 @@ class Posets(metaclass=ClasscallMetaclass):
         r"""
         Return the tetrahedral poset based on the input colors.
 
-        This method will return the tetrahedral poset with n-1 layers and
+        This method will return the tetrahedral poset with `n-1` layers and
         covering relations based on the input colors of 'green', 'red',
         'orange', 'silver', 'yellow' and 'blue' as defined in [Striker2011]_.
         For particular color choices, the order ideals of the resulting
@@ -1183,13 +1183,13 @@ class Posets(metaclass=ClasscallMetaclass):
 
         INPUT:
 
-        - ``n`` - Defines the number (n-1) of layers in the poset.
+        - ``n`` -- Defines the number (n-1) of layers in the poset.
 
-        - ``colors`` - The colors that define the covering relations of the
+        - ``colors`` -- The colors that define the covering relations of the
           poset. Colors used are 'green', 'red', 'yellow', 'orange', 'silver',
           and 'blue'.
 
-        - ``labels`` - Keyword variable used to determine whether the poset
+        - ``labels`` -- Keyword variable used to determine whether the poset
           is labeled with integers or tuples.  To label with integers, the
           method should be called with ``labels='integers'``.  Otherwise, the
           labeling will default to tuples.
@@ -1199,14 +1199,15 @@ class Posets(metaclass=ClasscallMetaclass):
             sage: posets.TetrahedralPoset(4,'green','red','yellow','silver','blue','orange')
             Finite poset containing 10 elements
 
-            sage: posets.TetrahedralPoset(4,'green','red','yellow','silver','blue','orange', labels='integers')
+            sage: posets.TetrahedralPoset(4,'green','red','yellow','silver','blue','orange',
+            ....:                         labels='integers')
             Finite poset containing 10 elements
 
-            sage: A = AlternatingSignMatrices(3)                                        # optional - sage.combinat sage.modules
-            sage: p = A.lattice()                                                       # optional - sage.combinat sage.modules
-            sage: ji = p.join_irreducibles_poset()                                      # optional - sage.combinat sage.modules
-            sage: tet = posets.TetrahedralPoset(3, 'green','yellow','blue','orange')    # optional - sage.combinat sage.modules
-            sage: ji.is_isomorphic(tet)                                                 # optional - sage.combinat sage.modules
+            sage: A = AlternatingSignMatrices(3)
+            sage: p = A.lattice()
+            sage: ji = p.join_irreducibles_poset()
+            sage: tet = posets.TetrahedralPoset(3, 'green','yellow','blue','orange')
+            sage: ji.is_isomorphic(tet)
             True
 
         TESTS::
@@ -1276,18 +1277,18 @@ class Posets(metaclass=ClasscallMetaclass):
 
         EXAMPLES::
 
-            sage: W = CoxeterGroup(['B', 3])                                            # optional - sage.combinat sage.groups
-            sage: posets.CoxeterGroupAbsoluteOrderPoset(W)                              # optional - sage.combinat sage.groups
+            sage: W = CoxeterGroup(['B', 3])                                            # needs sage.groups
+            sage: posets.CoxeterGroupAbsoluteOrderPoset(W)                              # needs sage.groups
             Finite poset containing 48 elements
 
-            sage: W = WeylGroup(['B', 2], prefix='s')                                   # optional - sage.combinat sage.groups
-            sage: posets.CoxeterGroupAbsoluteOrderPoset(W, False)                       # optional - sage.combinat sage.groups
+            sage: W = WeylGroup(['B', 2], prefix='s')                                   # needs sage.groups
+            sage: posets.CoxeterGroupAbsoluteOrderPoset(W, False)                       # needs sage.groups
             Finite poset containing 8 elements
         """
         if use_reduced_words:
             element_labels = {s: tuple(s.reduced_word()) for s in W}
-            return Poset({s: s.absolute_covers() for s in W}, element_labels)
-        return Poset({s: s.absolute_covers() for s in W})
+            return Poset({s: list(s.absolute_covers()) for s in W}, element_labels)
+        return Poset({s: list(s.absolute_covers()) for s in W})
 
     @staticmethod
     def NoncrossingPartitions(W):
@@ -1300,12 +1301,12 @@ class Posets(metaclass=ClasscallMetaclass):
 
         EXAMPLES::
 
-            sage: W = CoxeterGroup(['A', 3])                                            # optional - sage.combinat sage.groups
-            sage: posets.NoncrossingPartitions(W)                                       # optional - sage.combinat sage.groups
+            sage: W = CoxeterGroup(['A', 3])                                            # needs sage.groups
+            sage: posets.NoncrossingPartitions(W)                                       # needs sage.groups
             Finite lattice containing 14 elements
 
-            sage: W = WeylGroup(['B', 2], prefix='s')                                   # optional - sage.combinat sage.groups
-            sage: posets.NoncrossingPartitions(W)                                       # optional - sage.combinat sage.groups
+            sage: W = WeylGroup(['B', 2], prefix='s')                                   # needs sage.groups
+            sage: posets.NoncrossingPartitions(W)                                       # needs sage.groups
             Finite lattice containing 6 elements
         """
         return W.noncrossing_partition_lattice()
@@ -1322,20 +1323,20 @@ class Posets(metaclass=ClasscallMetaclass):
         - ``label`` -- (default: ``'permutations'``) a label for the elements
           of the poset returned by the function; the options are
 
-          * ``'permutations'`` - labels the elements are given by their
+          * ``'permutations'`` -- labels the elements by their
             one-line notation
-          * ``'reduced_words'`` - labels the elements by the
+          * ``'reduced_words'`` -- labels the elements by the
             lexicographically minimal reduced word
-          * ``'cycles'`` - labels the elements by their expression
+          * ``'cycles'`` -- labels the elements by their expression
             as a product of cycles
 
         EXAMPLES::
 
-            sage: posets.SymmetricGroupAbsoluteOrderPoset(4)                            # optional - sage.groups
+            sage: posets.SymmetricGroupAbsoluteOrderPoset(4)                            # needs sage.groups
             Finite poset containing 24 elements
-            sage: posets.SymmetricGroupAbsoluteOrderPoset(3, labels="cycles")           # optional - sage.groups
+            sage: posets.SymmetricGroupAbsoluteOrderPoset(3, labels="cycles")           # needs sage.groups
             Finite poset containing 6 elements
-            sage: posets.SymmetricGroupAbsoluteOrderPoset(3, labels="reduced_words")    # optional - sage.groups
+            sage: posets.SymmetricGroupAbsoluteOrderPoset(3, labels="reduced_words")    # needs sage.groups
             Finite poset containing 6 elements
         """
         from sage.groups.perm_gps.permgroup_named import SymmetricGroup
@@ -1348,7 +1349,7 @@ class Posets(metaclass=ClasscallMetaclass):
             element_labels = {s: "".join(x for x in s.cycle_string() if x != ',')
                               for s in W}
 
-        return Poset({s: s.absolute_covers() for s in W}, element_labels)
+        return Poset({s: list(s.absolute_covers()) for s in W}, element_labels)
 
     @staticmethod
     def UpDownPoset(n, m=1):
@@ -1361,8 +1362,8 @@ class Posets(metaclass=ClasscallMetaclass):
 
         INPUT:
 
-        - ``n`` - nonnegative integer, number of elements in the poset
-        - ``m`` - nonnegative integer (default 1), how frequently down
+        - ``n`` -- nonnegative integer, number of elements in the poset
+        - ``m`` -- nonnegative integer (default 1), how frequently down
           steps occur
 
         OUTPUT:
@@ -1380,7 +1381,7 @@ class Posets(metaclass=ClasscallMetaclass):
 
         Fibonacci numbers as the number of antichains of a poset::
 
-            sage: [len(posets.UpDownPoset(n).antichains().list()) for n in range(6)]    # optional - sage.combinat
+            sage: [len(posets.UpDownPoset(n).antichains().list()) for n in range(6)]
             [1, 2, 3, 5, 8, 13]
 
         TESTS::
@@ -1392,9 +1393,9 @@ class Posets(metaclass=ClasscallMetaclass):
         try:
             m = Integer(m)
         except TypeError:
-            raise TypeError("parameter m must be an integer, not {0}".format(m))
+            raise TypeError(f"parameter m must be an integer, not {m}")
         if m < 1:
-            raise ValueError("parameter m must be positive, not {0}".format(m))
+            raise ValueError(f"parameter m must be positive, not {m}")
 
         covers = [[i, i + 1] if (i + 1) % (m + 1) else [i + 1, i]
                   for i in range(n - 1)]
@@ -1414,13 +1415,13 @@ class Posets(metaclass=ClasscallMetaclass):
 
         EXAMPLES::
 
-            sage: P = posets.YoungDiagramPoset(Partition([2, 2])); P                    # optional - sage.combinat
+            sage: P = posets.YoungDiagramPoset(Partition([2, 2])); P
             Finite meet-semilattice containing 4 elements
 
-            sage: sorted(P.cover_relations())                                           # optional - sage.combinat
+            sage: sorted(P.cover_relations())
             [[(0, 0), (0, 1)], [(0, 0), (1, 0)], [(0, 1), (1, 1)], [(1, 0), (1, 1)]]
 
-            sage: posets.YoungDiagramPoset([3, 2], dual=True)                           # optional - sage.combinat
+            sage: posets.YoungDiagramPoset([3, 2], dual=True)
             Finite join-semilattice containing 5 elements
         """
         from sage.combinat.partition import Partition
@@ -1460,9 +1461,9 @@ class Posets(metaclass=ClasscallMetaclass):
 
         EXAMPLES::
 
-            sage: P = posets.YoungsLattice(3); P                                        # optional - sage.combinat
+            sage: P = posets.YoungsLattice(3); P
             Finite meet-semilattice containing 7 elements
-            sage: P.cover_relations()                                                   # optional - sage.combinat
+            sage: P.cover_relations()
             [[[], [1]],
              [[1], [1, 1]],
              [[1], [2]],
@@ -1488,10 +1489,10 @@ class Posets(metaclass=ClasscallMetaclass):
 
         EXAMPLES::
 
-            sage: P = posets.YoungsLatticePrincipalOrderIdeal(Partition([2,2]))         # optional - sage.combinat
-            sage: P                                                                     # optional - sage.combinat
+            sage: P = posets.YoungsLatticePrincipalOrderIdeal(Partition([2,2]))
+            sage: P
             Finite lattice containing 6 elements
-            sage: P.cover_relations()                                                   # optional - sage.combinat
+            sage: P.cover_relations()
             [[[], [1]],
              [[1], [1, 1]],
              [[1], [2]],
@@ -1527,16 +1528,16 @@ class Posets(metaclass=ClasscallMetaclass):
 
         EXAMPLES::
 
-            sage: Y5 = posets.YoungFibonacci(5); Y5                                     # optional - sage.combinat
+            sage: Y5 = posets.YoungFibonacci(5); Y5
             Finite meet-semilattice containing 20 elements
-            sage: sorted(Y5.upper_covers(Word('211')))                                  # optional - sage.combinat
+            sage: sorted(Y5.upper_covers(Word('211')))
             [word: 1211, word: 2111, word: 221]
 
         TESTS::
 
-            sage: posets.YoungFibonacci(0)                                              # optional - sage.combinat
+            sage: posets.YoungFibonacci(0)
             Finite meet-semilattice containing 1 elements
-            sage: posets.YoungFibonacci(1)                                              # optional - sage.combinat
+            sage: posets.YoungFibonacci(1)
             Finite meet-semilattice containing 2 elements
         """
         from sage.combinat.posets.lattices import FiniteMeetSemilattice
@@ -1550,7 +1551,7 @@ class Posets(metaclass=ClasscallMetaclass):
 
         covers = []
         current_level = ['']
-        for i in range(1, n + 1):
+        for _ in range(1, n + 1):
             new_level = set()
             for low in current_level:
                 ind = low.find('1')
@@ -1601,7 +1602,7 @@ class Posets(metaclass=ClasscallMetaclass):
     def PermutationPattern(n):
         r"""
         Return the poset of permutations under pattern containment
-        up to rank ``n``.
+        up to rank `n`.
 
         INPUT:
 
@@ -1616,9 +1617,9 @@ class Posets(metaclass=ClasscallMetaclass):
 
         EXAMPLES::
 
-            sage: P4 = posets.PermutationPattern(4); P4                                 # optional - sage.combinat
+            sage: P4 = posets.PermutationPattern(4); P4
             Finite poset containing 33 elements
-            sage: sorted(P4.lower_covers(Permutation([2,4,1,3])))                       # optional - sage.combinat
+            sage: sorted(P4.lower_covers(Permutation([2,4,1,3])))
             [[1, 3, 2], [2, 1, 3], [2, 3, 1], [3, 1, 2]]
 
         .. SEEALSO::
@@ -1627,9 +1628,9 @@ class Posets(metaclass=ClasscallMetaclass):
 
         TESTS::
 
-            sage: posets.PermutationPattern(1)                                          # optional - sage.combinat
+            sage: posets.PermutationPattern(1)
             Finite poset containing 1 elements
-            sage: posets.PermutationPattern(2)                                          # optional - sage.combinat
+            sage: posets.PermutationPattern(2)
             Finite poset containing 3 elements
         """
         n = check_int(n, 1)
@@ -1660,9 +1661,9 @@ class Posets(metaclass=ClasscallMetaclass):
 
             sage: t = Permutation([2,3,1])
             sage: b = Permutation([4,6,2,3,5,1])
-            sage: R = posets.PermutationPatternInterval(t, b); R                        # optional - sage.combinat
+            sage: R = posets.PermutationPatternInterval(t, b); R
             Finite poset containing 14 elements
-            sage: R.moebius_function(R.bottom(),R.top())                                # optional - sage.combinat
+            sage: R.moebius_function(R.bottom(),R.top())
             -4
 
         .. SEEALSO::
@@ -1673,14 +1674,14 @@ class Posets(metaclass=ClasscallMetaclass):
         TESTS::
 
             sage: p = Permutation([1])
-            sage: posets.PermutationPatternInterval(p, p)                               # optional - sage.combinat
+            sage: posets.PermutationPatternInterval(p, p)
             Finite poset containing 1 elements
         """
         P = Permutations()
         top = P(top)
         bottom = P(bottom)
         if not top.has_pattern(bottom):
-            raise ValueError("{} doesn't contain {} as a pattern".format(top, bottom))
+            raise ValueError(f"{top} doesn't contain {bottom} as a pattern")
         # Make a list of lists of elements in the interval divided by rank.
         # List will be flattened at the end
         elem = [[top]]
@@ -1732,7 +1733,7 @@ class Posets(metaclass=ClasscallMetaclass):
 
             sage: t = Permutation([3,2,1])
             sage: b = Permutation([6,3,4,5,2,1])
-            sage: A = posets.PermutationPatternOccurrenceInterval(t, b, (0,2,4)); A     # optional - sage.combinat
+            sage: A = posets.PermutationPatternOccurrenceInterval(t, b, (0,2,4)); A
             Finite poset containing 8 elements
 
         .. SEEALSO::
@@ -1818,11 +1819,11 @@ class Posets(metaclass=ClasscallMetaclass):
             sage: len(M.cover_relations())
             7
 
-            sage: P = posets.MobilePoset(posets.RibbonPoset(7, [1,3]),                  # optional - sage.combinat
-            ....: {1: [posets.YoungDiagramPoset([3, 2], dual=True)],
-            ....: 3: [posets.DoubleTailedDiamond(6)]},
-            ....: anchor=(4, 2, posets.ChainPoset(6)))
-            sage: len(P.cover_relations())                                              # optional - sage.combinat
+            sage: P = posets.MobilePoset(posets.RibbonPoset(7, [1,3]),
+            ....:         {1: [posets.YoungDiagramPoset([3, 2], dual=True)],
+            ....:          3: [posets.DoubleTailedDiamond(6)]},
+            ....:         anchor=(4, 2, posets.ChainPoset(6)))
+            sage: len(P.cover_relations())
             33
         """
         elements = []
@@ -1832,19 +1833,17 @@ class Posets(metaclass=ClasscallMetaclass):
         elements.extend(ribbon._elements)
 
         if anchor:
-            for cr in anchor[2].cover_relations():
-                cover_relations.append(((anchor[0], cr[0]), (anchor[0], cr[1])))
+            cover_relations.extend(((anchor[0], cr[0]), (anchor[0], cr[1]))
+                                   for cr in anchor[2].cover_relations())
             cover_relations.append((anchor[0], (anchor[0], anchor[1])))
 
-            for elmt in anchor[2]._elements:
-                elements.append((anchor[0], elmt))
+            elements.extend((anchor[0], elmt) for elmt in anchor[2]._elements)
 
         for r, hangs in hangers.items():
             for i, h in enumerate(hangs):
-                for v in h._elements:
-                    elements.append((r, i, v))
-                for cr in h.cover_relations():
-                    cover_relations.append(((r, i, cr[0]), (r, i, cr[1])))
+                elements.extend((r, i, v) for v in h._elements)
+                cover_relations.extend(((r, i, cr[0]), (r, i, cr[1]))
+                                       for cr in h.cover_relations())
                 cover_relations.append(((r, i, h.top()), r))
 
         return Mobile(DiGraph([elements, cover_relations]))
@@ -1888,14 +1887,14 @@ def _random_lattice(n, p):
         meet for `e, m` for all `m \in M`. We do that by keeping
         track of meet matrix and list of maximal elements.
     """
-    from sage.functions.other import floor
+    from sage.arith.misc import integer_floor as floor
     from sage.misc.functional import sqrt
     from sage.misc.prandom import random
 
     n = n - 1
     meets = [[None] * n for _ in range(n)]
     meets[0][0] = 0
-    maxs = set([0])
+    maxs = {0}
     lc_all = [[]]  # No lower covers for the bottom element.
 
     for i in range(1, n):
@@ -2039,8 +2038,8 @@ def _random_distributive_lattice(n):
 
     EXAMPLES::
 
-        sage: g = sage.combinat.posets.poset_examples._random_distributive_lattice(10)  # optional - sage.modules
-        sage: Poset(g).order_ideals_lattice(as_ideals=False).cardinality()              # optional - sage.modules
+        sage: g = sage.combinat.posets.poset_examples._random_distributive_lattice(10)
+        sage: Poset(g).order_ideals_lattice(as_ideals=False).cardinality()
         10
 
     ALGORITHM:
@@ -2095,8 +2094,8 @@ def _random_stone_lattice(n):
 
     EXAMPLES::
 
-        sage: g = sage.combinat.posets.poset_examples._random_stone_lattice(10)         # optional - sage.combinat
-        sage: LatticePoset(g).is_stone()                                                # optional - sage.combinat
+        sage: g = sage.combinat.posets.poset_examples._random_stone_lattice(10)
+        sage: LatticePoset(g).is_stone()
         True
 
     ALGORITHM:
