@@ -1,3 +1,4 @@
+# sage.doctest: needs sage.libs.gap sage.groups
 r"""
 Hecke algebra representations
 """
@@ -42,7 +43,7 @@ class HeckeAlgebraRepresentation(WithEqualityById, SageObject):
     - ``domain`` -- a vector space
     - ``f`` -- a function ``f(l,i)`` taking a basis element `l` of ``domain`` and an index `i`, and returning `F_i`
     - ``cartan_type`` -- The Cartan type of the Hecke algebra
-    - ``q1,q2`` -- The eigenvalues of the generators `T` of the Hecke algebra
+    - ``q1``, ``q2`` -- The eigenvalues of the generators `T` of the Hecke algebra
     - ``side`` -- "left" or "right" (default: "right")
       whether this is a left or right representation
 
@@ -112,7 +113,7 @@ class HeckeAlgebraRepresentation(WithEqualityById, SageObject):
             on Algebra of Weyl Group of type ['A', 3]
             (as a matrix group acting on the ambient space) over Rational Field"
         """
-        return "A representation of the %s-Hecke algebra of type %s on %s"%((self._q1,self._q2), self.cartan_type(), self.domain())
+        return "A representation of the %s-Hecke algebra of type %s on %s" % ((self._q1,self._q2), self.cartan_type(), self.domain())
 
     @cached_method
     def parameters(self, i):
@@ -167,7 +168,8 @@ class HeckeAlgebraRepresentation(WithEqualityById, SageObject):
 
             sage: H = WeylGroup(["A",3]).algebra(QQ).demazure_lusztig_operators(-1,1)
             sage: H.domain()
-            Algebra of Weyl Group of type ['A', 3] (as a matrix group acting on the ambient space) over Rational Field
+            Algebra of Weyl Group of type ['A', 3] (as a matrix group
+             acting on the ambient space) over Rational Field
         """
         return self._domain
 
@@ -428,7 +430,8 @@ class HeckeAlgebraRepresentation(WithEqualityById, SageObject):
             sage: x = KW.monomial(W.an_element()); x
             123
             sage: rho.Tw_inverse(word)(x)
-            1/q2^2*12321 + ((-q1-q2)/(q1*q2^2))*1231 + ((-q1-q2)/(q1*q2^2))*1232 + ((q1^2+2*q1*q2+q2^2)/(q1^2*q2^2))*123
+            1/q2^2*12321 + ((-q1-q2)/(q1*q2^2))*1231 + ((-q1-q2)/(q1*q2^2))*1232
+             + ((q1^2+2*q1*q2+q2^2)/(q1^2*q2^2))*123
             sage: rho.Tw(word)(_)
             123
         """
@@ -464,26 +467,30 @@ class HeckeAlgebraRepresentation(WithEqualityById, SageObject):
 
         def Ti(x,i,c):
             return T[i](x)+c*x
-        # Check the quadratic relation
-        for i in cartan_type.index_set():
-            for x in elements:
-                tester.assertTrue(Ti(Ti(x,i,-q2),i,-q1).is_zero())
-        G = cartan_type.coxeter_diagram()
-        # Check the braid relation
-        for (i, j) in Subsets(cartan_type.index_set(), 2):
-            if G.has_edge(i,j):
-                o = G.edge_label(i,j)
-            else:
-                o = 2
-            if o == infinity:
-                continue
-            for x in elements:
-                y = x
-                for k in range(o):
-                    x = T[i](x)
-                    y = T[j](y)
-                    y,x = x,y
-                tester.assertEqual(x, y)
+
+        try:
+            # Check the quadratic relation
+            for i in cartan_type.index_set():
+                for x in elements:
+                    tester.assertTrue(Ti(Ti(x,i,-q2),i,-q1).is_zero())
+            G = cartan_type.coxeter_diagram()
+            # Check the braid relation
+            for (i, j) in Subsets(cartan_type.index_set(), 2):
+                if G.has_edge(i,j):
+                    o = G.edge_label(i,j)
+                else:
+                    o = 2
+                if o == infinity:
+                    continue
+                for x in elements:
+                    y = x
+                    for k in range(o):
+                        x = T[i](x)
+                        y = T[j](y)
+                        y,x = x,y
+                    tester.assertEqual(x, y)
+        except ImportError:
+            pass
 
     def _test_inverse(self, **options):
         r"""
@@ -502,14 +509,17 @@ class HeckeAlgebraRepresentation(WithEqualityById, SageObject):
         elements = self.domain().some_elements()
         q1 = self._q1
         q2 = self._q2
-        if q1.is_unit() and q2.is_unit():
-            I = self.cartan_type().index_set()
-            for w in [[i] for i in I] + [tuple(I)]:
-                Tw = self.Tw(w)
-                Tw_inverse = self.Tw_inverse(w)
-                for x in elements:
-                    tester.assertEqual(Tw_inverse(Tw(x)), x)
-                    tester.assertEqual(Tw(Tw_inverse(x)), x)
+        try:
+            if q1.is_unit() and q2.is_unit():
+                I = self.cartan_type().index_set()
+                for w in [[i] for i in I] + [tuple(I)]:
+                    Tw = self.Tw(w)
+                    Tw_inverse = self.Tw_inverse(w)
+                    for x in elements:
+                        tester.assertEqual(Tw_inverse(Tw(x)), x)
+                        tester.assertEqual(Tw(Tw_inverse(x)), x)
+        except ImportError:
+            pass
 
     def Y_lambdacheck(self, lambdacheck):
         r"""
@@ -540,9 +550,12 @@ class HeckeAlgebraRepresentation(WithEqualityById, SageObject):
             sage: x = KW.monomial(W.an_element()); x
             12
             sage: Y1(x)
-            ((-q1^2-2*q1*q2-q2^2)/(-q2^2))*2121 + ((q1^3+q1^2*q2+q1*q2^2+q2^3)/(-q1*q2^2))*121 + ((q1^2+q1*q2)/(-q2^2))*212 + ((-q1^2)/(-q2^2))*12
+            ((-q1^2-2*q1*q2-q2^2)/(-q2^2))*2121
+             + ((q1^3+q1^2*q2+q1*q2^2+q2^3)/(-q1*q2^2))*121
+             + ((q1^2+q1*q2)/(-q2^2))*212 + ((-q1^2)/(-q2^2))*12
             sage: Y2(x)
-            ((-q1^4-q1^3*q2-q1*q2^3-q2^4)/(-q1^3*q2))*2121 + ((q1^3+q1^2*q2+q1*q2^2+q2^3)/(-q1^2*q2))*121 + (q2^3/(-q1^3))*12
+            ((-q1^4-q1^3*q2-q1*q2^3-q2^4)/(-q1^3*q2))*2121
+             + ((q1^3+q1^2*q2+q1*q2^2+q2^3)/(-q1^2*q2))*121 + (q2^3/(-q1^3))*12
             sage: Y1(Y2(x))
             ((q1*q2+q2^2)/q1^2)*212 + ((-q2)/q1)*12
             sage: Y2(Y1(x))
@@ -624,8 +637,8 @@ class HeckeAlgebraRepresentation(WithEqualityById, SageObject):
         # works for our two main examples (action of affine W on W,
         # and Macdonald polynomials)
         if self._side == "left":
-            word = tuple([x for x in reversed(word)])
-            signs = tuple([x for x in reversed(signs)])
+            word = tuple(reversed(word))
+            signs = tuple(reversed(signs))
         # The power of q implements the fact that Y^\deltacheck = 1/q.
         # The classical simple coroots have no \deltacheck term.
         # alpha[0] has a \deltacheck with coefficient one
@@ -742,9 +755,11 @@ class HeckeAlgebraRepresentation(WithEqualityById, SageObject):
             sage: [E[w] for w in W]
             [2121 - 121 - 212 + 12 + 21 - 1 - 2 + ,
              -2121 + 212,
-             (q2/(q1-q2))*2121 + (q2/(-q1+q2))*121 + (q2/(-q1+q2))*212 - 12 + ((-q2)/(-q1+q2))*21 + 2,
+             (q2/(q1-q2))*2121 + (q2/(-q1+q2))*121
+                 + (q2/(-q1+q2))*212 - 12 + ((-q2)/(-q1+q2))*21 + 2,
              ((-q2^2)/(-q1^2+q1*q2-q2^2))*2121 - 121 + (q2^2/(-q1^2+q1*q2-q2^2))*212 + 21,
-             ((-q1^2-q2^2)/(q1^2-q1*q2+q2^2))*2121 + ((-q1^2-q2^2)/(-q1^2+q1*q2-q2^2))*121 + ((-q2^2)/(-q1^2+q1*q2-q2^2))*212 + (q2^2/(-q1^2+q1*q2-q2^2))*12 - 21 + 1,
+             ((-q1^2-q2^2)/(q1^2-q1*q2+q2^2))*2121 + ((-q1^2-q2^2)/(-q1^2+q1*q2-q2^2))*121
+                 + ((-q2^2)/(-q1^2+q1*q2-q2^2))*212 + (q2^2/(-q1^2+q1*q2-q2^2))*12 - 21 + 1,
              2121,
              (q2/(-q1+q2))*2121 + ((-q2)/(-q1+q2))*121 - 212 + 12,
              -2121 + 121]
@@ -813,7 +828,7 @@ class CherednikOperatorsEigenvectors(UniqueRepresentation, SageObject):
           of the generators of an affine Hecke algebra on ``self``. By
           default, this is ``T``.
 
-        - ``normalized`` -- boolean (default: True) whether the
+        - ``normalized`` -- boolean (default: ``True``) whether the
           eigenvector `E_\mu` is normalized so that `\mu` has
           coefficient `1`.
 
@@ -830,7 +845,8 @@ class CherednikOperatorsEigenvectors(UniqueRepresentation, SageObject):
             sage: E.keys()
             Weyl Group of type ['B', 3] (as a matrix group acting on the ambient space)
             sage: E.domain()
-            Algebra of Weyl Group of type ['B', 3] (as a matrix group acting on the ambient space) over Fraction Field of Multivariate Polynomial Ring in q1, q2 over Rational Field
+            Algebra of Weyl Group of type ['B', 3] (as a matrix group acting on the ambient space)
+             over Fraction Field of Multivariate Polynomial Ring in q1, q2 over Rational Field
             sage: E._T == E._T_Y
             True
         """
@@ -855,7 +871,7 @@ class CherednikOperatorsEigenvectors(UniqueRepresentation, SageObject):
             sage: E.cartan_type()
             ['B', 3, 1]
 
-            sage: NonSymmetricMacdonaldPolynomials(["B", 2, 1]).cartan_type()
+            sage: NonSymmetricMacdonaldPolynomials(["B", 2, 1]).cartan_type()           # needs sage.graphs
             ['B', 2, 1]
         """
         return self._T_Y.cartan_type()
@@ -872,7 +888,9 @@ class CherednikOperatorsEigenvectors(UniqueRepresentation, SageObject):
             sage: KW = W.algebra(K)
             sage: E = KW.demazure_lusztig_eigenvectors(q1, q2)
             sage: E.domain()
-            Algebra of Weyl Group of type ['B', 3] (as a matrix group acting on the ambient space) over Multivariate Polynomial Ring in q1, q2 over Rational Field
+            Algebra of Weyl Group of type ['B', 3]
+             (as a matrix group acting on the ambient space)
+             over Multivariate Polynomial Ring in q1, q2 over Rational Field
         """
         return self._T.domain()
 
