@@ -30,7 +30,7 @@ class CartanType(cartan_type.CartanType_decorator):
     We take the Cartan type `B_4`::
 
         sage: T = CartanType(['B',4])
-        sage: T.dynkin_diagram()
+        sage: T.dynkin_diagram()                                                        # needs sage.graphs
         O---O---O=>=O
         1   2   3   4
         B4
@@ -38,14 +38,14 @@ class CartanType(cartan_type.CartanType_decorator):
     And mark some of its nodes::
 
         sage: T = T.marked_nodes([2,3])
-        sage: T.dynkin_diagram()
+        sage: T.dynkin_diagram()                                                        # needs sage.graphs
         O---X---X=>=O
         1   2   3   4
         B4 with nodes (2, 3) marked
 
     Markings are not additive::
 
-        sage: T.marked_nodes([1,4]).dynkin_diagram()
+        sage: T.marked_nodes([1,4]).dynkin_diagram()                                    # needs sage.graphs
         X---O---O=>=X
         1   2   3   4
         B4 with nodes (1, 4) marked
@@ -53,7 +53,7 @@ class CartanType(cartan_type.CartanType_decorator):
     And trivial relabelling are honoured nicely::
 
         sage: T = T.marked_nodes([])
-        sage: T.dynkin_diagram()
+        sage: T.dynkin_diagram()                                                        # needs sage.graphs
         O---O---O=>=O
         1   2   3   4
         B4
@@ -160,14 +160,14 @@ class CartanType(cartan_type.CartanType_decorator):
            sage: CartanType(['F', 4, 1]).marked_nodes([0, 2])._repr_(compact = True)
            'F4~ with nodes (0, 2) marked'
 
-            sage: D = DynkinDiagram("A2")
-            sage: D.marked_nodes([1])
+            sage: D = DynkinDiagram("A2")                                               # needs sage.graphs
+            sage: D.marked_nodes([1])                                                   # needs sage.graphs
             O---O
             1   2
             A2 with node 1 marked
 
-            sage: CM = CartanMatrix([[2,-4],[-5,2]])
-            sage: CM.marked_nodes([1])
+            sage: CM = CartanMatrix([[2,-4],[-5,2]])                                    # needs sage.graphs
+            sage: CM.marked_nodes([1])                                                  # needs sage.graphs
             [ 2 -4]
             [-5  2] with node 1 marked
         """
@@ -278,7 +278,7 @@ class CartanType(cartan_type.CartanType_decorator):
         ret += "\\draw[shift={{({}, {})}}, {}, {}] (0.25cm, -0.25cm) -- (-0.25cm, 0.25cm);\n".format(x, y, color, thickness)
         return ret
 
-    def _latex_dynkin_diagram(self, label=lambda i: i, node=None, node_dist=2):
+    def _latex_dynkin_diagram(self, label=None, node=None, node_dist=2):
         r"""
         Return a latex representation of the Dynkin diagram.
 
@@ -296,11 +296,13 @@ class CartanType(cartan_type.CartanType_decorator):
             \draw[fill=white] (6 cm, 0 cm) circle (.25cm) node[below=4pt]{$4$};
             <BLANKLINE>
         """
+        if label is None:
+            label = lambda i: i
         if node is None:
             node = self._latex_draw_node
         return self._type._latex_dynkin_diagram(label, node, node_dist)
 
-    def ascii_art(self, label=lambda i: i, node=None):
+    def ascii_art(self, label=None, node=None):
         """
         Return an ascii art representation of this Cartan type.
 
@@ -320,6 +322,8 @@ class CartanType(cartan_type.CartanType_decorator):
             X---O---X=>=O---O
             0   1   2   3   4
         """
+        if label is None:
+            label = lambda i: i
         if node is None:
             node = self._ascii_art_node
         return self._type.ascii_art(label, node)
@@ -330,7 +334,7 @@ class CartanType(cartan_type.CartanType_decorator):
 
         EXAMPLES::
 
-            sage: CartanType(["G", 2]).marked_nodes([2]).dynkin_diagram()
+            sage: CartanType(["G", 2]).marked_nodes([2]).dynkin_diagram()               # needs sage.graphs
               3
             O=<=X
             1   2
@@ -340,11 +344,11 @@ class CartanType(cartan_type.CartanType_decorator):
 
         To be compared with the examples in :meth:`ascii_art`::
 
-            sage: CartanType(["G", 2]).relabel({1:2,2:1}).dynkin_diagram().edges(sort=True)
+            sage: CartanType(["G", 2]).relabel({1:2,2:1}).dynkin_diagram().edges(sort=True)         # needs sage.graphs
             [(1, 2, 3), (2, 1, 1)]
-            sage: CartanType(["B", 3, 1]).relabel([1,3,2,0]).dynkin_diagram().edges(sort=True)
+            sage: CartanType(["B", 3, 1]).relabel([1,3,2,0]).dynkin_diagram().edges(sort=True)      # needs sage.graphs
             [(0, 2, 1), (1, 2, 1), (2, 0, 2), (2, 1, 1), (2, 3, 1), (3, 2, 1)]
-            sage: CartanType(["F", 4, 1]).relabel(lambda n: 4-n).dynkin_diagram().edges(sort=True)
+            sage: CartanType(["F", 4, 1]).relabel(lambda n: 4-n).dynkin_diagram().edges(sort=True)  # needs sage.graphs
             [(0, 1, 1), (1, 0, 1), (1, 2, 1), (2, 1, 2), (2, 3, 1), (3, 2, 1), (3, 4, 1), (4, 3, 1)]
         """
         result = self._type.dynkin_diagram().copy()
@@ -360,11 +364,11 @@ class CartanType(cartan_type.CartanType_decorator):
         EXAMPLES::
 
             sage: T = CartanType(["BC",3, 2])
-            sage: T.marked_nodes([1,3]).dual().dynkin_diagram()
+            sage: T.marked_nodes([1,3]).dual().dynkin_diagram()                         # needs sage.graphs
             O=>=X---O=>=X
             0   1   2   3
             BC3~* with nodes (1, 3) marked
-            sage: T.dual().marked_nodes([1,3]).dynkin_diagram()
+            sage: T.dual().marked_nodes([1,3]).dynkin_diagram()                         # needs sage.graphs
             O=>=X---O=>=X
             0   1   2   3
             BC3~* with nodes (1, 3) marked
@@ -378,11 +382,11 @@ class CartanType(cartan_type.CartanType_decorator):
         EXAMPLES::
 
             sage: T = CartanType(["BC",3, 2])
-            sage: T.marked_nodes([1,3]).relabel(lambda x: x+2).dynkin_diagram()
+            sage: T.marked_nodes([1,3]).relabel(lambda x: x+2).dynkin_diagram()         # needs sage.graphs
             O=<=X---O=<=X
             2   3   4   5
             BC3~ relabelled by {0: 2, 1: 3, 2: 4, 3: 5} with nodes (3, 5) marked
-            sage: T.relabel(lambda x: x+2).marked_nodes([3,5]).dynkin_diagram()
+            sage: T.relabel(lambda x: x+2).marked_nodes([3,5]).dynkin_diagram()         # needs sage.graphs
             O=<=X---O=<=X
             2   3   4   5
             BC3~ relabelled by {0: 2, 1: 3, 2: 4, 3: 5} with nodes (3, 5) marked
@@ -425,7 +429,7 @@ class CartanType(cartan_type.CartanType_decorator):
             Finite family {0: (0,), 1: (2,), 2: (1, 3, 4)}
             sage: CartanType(['G',2,1]).dual()._default_folded_cartan_type().folding_orbit()
             Finite family {0: (0,), 1: (1, 3, 4), 2: (2,)}
-            sage: CartanType(['C',3,1]).relabel({0:1, 1:0, 2:3, 3:2}).as_folding().scaling_factors()
+            sage: CartanType(['C',3,1]).relabel({0:1, 1:0, 2:3, 3:2}).as_folding().scaling_factors()                    # needs sage.graphs
             Finite family {0: 1, 1: 2, 2: 2, 3: 1}
         """
         from sage.combinat.root_system.type_folded import CartanTypeFolded
@@ -461,7 +465,7 @@ class AmbientSpace(ambient_space.AmbientSpace):
 
         sage: L = CartanType(["F",4]).marked_nodes([1,3]).root_system().ambient_space(); L
         Ambient space of the Root system of type ['F', 4] with nodes (1, 3) marked
-        sage: TestSuite(L).run()
+        sage: TestSuite(L).run()                                                        # needs sage.graphs
     """
     @lazy_attribute
     def _space(self):
@@ -567,11 +571,11 @@ class CartanType_finite(CartanType, cartan_type.CartanType_finite):
         EXAMPLES::
 
             sage: B4 = CartanType(['B',4]).marked_nodes([1,3])
-            sage: B4.dynkin_diagram()
+            sage: B4.dynkin_diagram()                                                   # needs sage.graphs
             X---O---X=>=O
             1   2   3   4
             B4 with nodes (1, 3) marked
-            sage: B4.affine().dynkin_diagram()
+            sage: B4.affine().dynkin_diagram()                                          # needs sage.graphs
                 O 0
                 |
                 |
@@ -670,7 +674,7 @@ class CartanType_affine(CartanType, cartan_type.CartanType_affine):
         EXAMPLES::
 
             sage: T = CartanType(['A',4,1]).marked_nodes([0,2,4])
-            sage: T.dynkin_diagram()
+            sage: T.dynkin_diagram()                                                    # needs sage.graphs
             0
             X-----------+
             |           |
@@ -679,10 +683,9 @@ class CartanType_affine(CartanType, cartan_type.CartanType_affine):
             1   2   3   4
             A4~ with nodes (0, 2, 4) marked
 
-            sage: T0 = T.classical()
-            sage: T0
+            sage: T0 = T.classical(); T0
             ['A', 4] with nodes (2, 4) marked
-            sage: T0.dynkin_diagram()
+            sage: T0.dynkin_diagram()                                                   # needs sage.graphs
             O---X---O---X
             1   2   3   4
             A4 with nodes (2, 4) marked
