@@ -10,7 +10,7 @@ Root system data for relabelled Cartan types
 
 from sage.misc.cachefunc import cached_method
 from sage.misc.lazy_attribute import lazy_attribute
-from sage.sets.family import FiniteFamily
+from sage.sets.family import Family, FiniteFamily
 from sage.combinat.root_system import cartan_type
 from sage.combinat.root_system import ambient_space
 from sage.combinat.root_system.root_lattice_realizations import RootLatticeRealizations
@@ -55,7 +55,7 @@ class CartanType(cartan_type.CartanType_decorator):
             return type
 
         relabelling = FiniteFamily(relabelling) # Hack to emulate a frozendict which would be hashable!!!!
-        return super(CartanType, cls).__classcall__(cls, type, relabelling)
+        return super().__classcall__(cls, type, relabelling)
 
     def __init__(self, type, relabelling):
         """
@@ -75,7 +75,7 @@ class CartanType(cartan_type.CartanType_decorator):
         We take the Cartan type `B_4`::
 
             sage: T = CartanType(['B',4])
-            sage: T.dynkin_diagram()
+            sage: T.dynkin_diagram()                                                    # needs sage.graphs
             O---O---O=>=O
             1   2   3   4
             B4
@@ -85,23 +85,23 @@ class CartanType(cartan_type.CartanType_decorator):
             sage: cycle = {1:2, 2:3, 3:4, 4:1}
 
             sage: T = T.relabel(cycle)
-            sage: T.dynkin_diagram()
+            sage: T.dynkin_diagram()                                                    # needs sage.graphs
             O---O---O=>=O
             2   3   4   1
             B4 relabelled by {1: 2, 2: 3, 3: 4, 4: 1}
-            sage: T.dynkin_diagram().edges(sort=True)
+            sage: T.dynkin_diagram().edges(sort=True)                                   # needs sage.graphs
             [(1, 4, 1), (2, 3, 1), (3, 2, 1), (3, 4, 1), (4, 1, 2), (4, 3, 1)]
 
         Multiple relabelling are recomposed into a single one::
 
             sage: T = T.relabel(cycle)
-            sage: T.dynkin_diagram()
+            sage: T.dynkin_diagram()                                                    # needs sage.graphs
             O---O---O=>=O
             3   4   1   2
             B4 relabelled by {1: 3, 2: 4, 3: 1, 4: 2}
 
             sage: T = T.relabel(cycle)
-            sage: T.dynkin_diagram()
+            sage: T.dynkin_diagram()                                                    # needs sage.graphs
             O---O---O=>=O
             4   1   2   3
             B4 relabelled by {1: 4, 2: 1, 3: 2, 4: 3}
@@ -109,7 +109,7 @@ class CartanType(cartan_type.CartanType_decorator):
         And trivial relabelling are honoured nicely::
 
             sage: T = T.relabel(cycle)
-            sage: T.dynkin_diagram()
+            sage: T.dynkin_diagram()                                                    # needs sage.graphs
             O---O---O=>=O
             1   2   3   4
             B4
@@ -117,7 +117,7 @@ class CartanType(cartan_type.CartanType_decorator):
         TESTS:
 
         Test that the produced Cartan type is in the appropriate
-        abstract classes (see :trac:`13724`)::
+        abstract classes (see :issue:`13724`)::
 
             sage: ct = CartanType(['B',4]).relabel(cycle)
             sage: TestSuite(ct).run()
@@ -146,25 +146,25 @@ class CartanType(cartan_type.CartanType_decorator):
             sage: isinstance(ct, cartan_type.CartanType_simply_laced)
             True
 
-        Check for the original issues of :trac:`13724`::
+        Check for the original issues of :issue:`13724`::
 
             sage: A3 = CartanType("A3")
-            sage: A3.cartan_matrix()
+            sage: A3.cartan_matrix()                                                    # needs sage.graphs
             [ 2 -1  0]
             [-1  2 -1]
             [ 0 -1  2]
             sage: A3r = A3.relabel({1:2,2:3,3:1})
-            sage: A3r.cartan_matrix()
+            sage: A3r.cartan_matrix()                                                   # needs sage.graphs
             [ 2  0 -1]
             [ 0  2 -1]
             [-1 -1  2]
 
             sage: ct = CartanType(["D",4,3]).classical(); ct
             ['G', 2]
-            sage: ct.symmetrizer()
+            sage: ct.symmetrizer()                                                      # needs sage.graphs
             Finite family {1: 1, 2: 3}
 
-        Check the underlying issue of :trac:`24892`, that the root system
+        Check the underlying issue of :issue:`24892`, that the root system
         of a relabelled non-crystallographic Cartan type has an
         ``ambient_space()`` that does not result in an error (note that
         this should actually return a valid ambient space, which requires
@@ -173,10 +173,10 @@ class CartanType(cartan_type.CartanType_decorator):
             sage: rI5 = CartanType(['I',5]).relabel({1:0,2:1})
             sage: rI5.root_system().ambient_space()
         """
-        assert isinstance(relabelling, FiniteFamily)
         cartan_type.CartanType_decorator.__init__(self, type)
-        self._relabelling = relabelling._dictionary
-        self._relabelling_inverse = relabelling.inverse_family()._dictionary
+        relabelling = Family(relabelling)
+        self._relabelling = dict(relabelling.items())
+        self._relabelling_inverse = dict(relabelling.inverse_family().items())
         self._index_set = tuple(sorted(relabelling[i] for i in type.index_set()))
         # TODO: design an appropriate infrastructure to handle this
         # automatically? Maybe using categories and axioms?
@@ -271,7 +271,7 @@ class CartanType(cartan_type.CartanType_decorator):
             ret += " \\text{ relabelled by } " + latex(self._relabelling)
         return ret
 
-    def _latex_dynkin_diagram(self, label=lambda i: i, node=None, node_dist=2):
+    def _latex_dynkin_diagram(self, label=None, node=None, node_dist=2):
         r"""
         Return a latex representation of the Dynkin diagram.
 
@@ -285,9 +285,11 @@ class CartanType(cartan_type.CartanType_decorator):
             \draw[fill=white] (6 cm, 0 cm) circle (.25cm) node[below=4pt]{$2$};
             <BLANKLINE>
         """
+        if label is None:
+            label = lambda i: i
         return self._type._latex_dynkin_diagram(lambda i: label(self._relabelling[i]), node, node_dist)
 
-    def ascii_art(self, label=lambda i: i, node=None):
+    def ascii_art(self, label=None, node=None):
         """
         Return an ascii art representation of this Cartan type.
 
@@ -307,6 +309,8 @@ class CartanType(cartan_type.CartanType_decorator):
             O---O---O=>=O---O
             4   3   2   1   0
         """
+        if label is None:
+            label = lambda i: i
         if node is None:
             node = self._ascii_art_node
         return self._type.ascii_art(lambda i: label(self._relabelling[i]), node)
@@ -317,7 +321,7 @@ class CartanType(cartan_type.CartanType_decorator):
 
         EXAMPLES::
 
-            sage: CartanType(["G", 2]).relabel({1:2,2:1}).dynkin_diagram()
+            sage: CartanType(["G", 2]).relabel({1:2,2:1}).dynkin_diagram()              # needs sage.graphs
               3
             O=<=O
             2   1
@@ -327,11 +331,11 @@ class CartanType(cartan_type.CartanType_decorator):
 
         To be compared with the examples in :meth:`ascii_art`::
 
-            sage: CartanType(["G", 2]).relabel({1:2,2:1}).dynkin_diagram().edges(sort=True)
+            sage: CartanType(["G", 2]).relabel({1:2,2:1}).dynkin_diagram().edges(sort=True)         # needs sage.graphs
             [(1, 2, 3), (2, 1, 1)]
-            sage: CartanType(["B", 3, 1]).relabel([1,3,2,0]).dynkin_diagram().edges(sort=True)
+            sage: CartanType(["B", 3, 1]).relabel([1,3,2,0]).dynkin_diagram().edges(sort=True)      # needs sage.graphs
             [(0, 2, 1), (1, 2, 1), (2, 0, 2), (2, 1, 1), (2, 3, 1), (3, 2, 1)]
-            sage: CartanType(["F", 4, 1]).relabel(lambda n: 4-n).dynkin_diagram().edges(sort=True)
+            sage: CartanType(["F", 4, 1]).relabel(lambda n: 4-n).dynkin_diagram().edges(sort=True)  # needs sage.graphs
             [(0, 1, 1), (1, 0, 1), (1, 2, 1), (2, 1, 2), (2, 3, 1), (3, 2, 1), (3, 4, 1), (4, 3, 1)]
         """
         # Maybe we want to move this up as a relabel method for Dynkin diagram
@@ -361,11 +365,11 @@ class CartanType(cartan_type.CartanType_decorator):
 
             sage: T = CartanType(["BC",3, 2])
             sage: cycle = {1:2, 2:3, 3:0, 0:1}
-            sage: T.relabel(cycle).dual().dynkin_diagram()
+            sage: T.relabel(cycle).dual().dynkin_diagram()                              # needs sage.graphs
             O=>=O---O=>=O
             1   2   3   0
             BC3~* relabelled by {0: 1, 1: 2, 2: 3, 3: 0}
-            sage: T.dual().relabel(cycle).dynkin_diagram()
+            sage: T.dual().relabel(cycle).dynkin_diagram()                              # needs sage.graphs
             O=>=O---O=>=O
             1   2   3   0
             BC3~* relabelled by {0: 1, 1: 2, 2: 3, 3: 0}
@@ -384,7 +388,7 @@ class CartanType(cartan_type.CartanType_decorator):
             Finite family {0: (0,), 1: (2,), 2: (1, 3, 4)}
             sage: CartanType(['G',2,1]).dual()._default_folded_cartan_type().folding_orbit()
             Finite family {0: (0,), 1: (1, 3, 4), 2: (2,)}
-            sage: CartanType(['C',3,1]).relabel({0:1, 1:0, 2:3, 3:2}).as_folding().scaling_factors()
+            sage: CartanType(['C',3,1]).relabel({0:1, 1:0, 2:3, 3:2}).as_folding().scaling_factors()                    # needs sage.graphs
             Finite family {0: 1, 1: 2, 2: 2, 3: 1}
         """
         from sage.combinat.root_system.type_folded import CartanTypeFolded
@@ -413,9 +417,9 @@ class CartanType(cartan_type.CartanType_decorator):
         EXAMPLES::
 
             sage: ct = CartanType(['H', 3]).relabel({1:3,2:2,3:1})
-            sage: G = ct.coxeter_diagram(); G
+            sage: G = ct.coxeter_diagram(); G                                           # needs sage.graphs
             Graph on 3 vertices
-            sage: G.edges(sort=True)
+            sage: G.edges(sort=True)                                                    # needs sage.graphs
             [(1, 2, 5), (2, 3, 3)]
         """
         return self._type.coxeter_diagram().relabel(self._relabelling, inplace=False, immutable=True)
@@ -436,7 +440,7 @@ class AmbientSpace(ambient_space.AmbientSpace):
         sage: cycle = {1:2, 2:3, 3:4, 4:1}
         sage: L = CartanType(["F",4]).relabel(cycle).root_system().ambient_space(); L
         Ambient space of the Root system of type ['F', 4] relabelled by {1: 2, 2: 3, 3: 4, 4: 1}
-        sage: TestSuite(L).run()
+        sage: TestSuite(L).run()                                                        # needs sage.graphs
     """
 
     @lazy_attribute
@@ -555,11 +559,11 @@ class CartanType_finite(CartanType, cartan_type.CartanType_finite):
         EXAMPLES::
 
             sage: B4 = CartanType(['B',4])
-            sage: B4.dynkin_diagram()
+            sage: B4.dynkin_diagram()                                                   # needs sage.graphs
             O---O---O=>=O
             1   2   3   4
             B4
-            sage: B4.affine().dynkin_diagram()
+            sage: B4.affine().dynkin_diagram()                                          # needs sage.graphs
                 O 0
                 |
                 |
@@ -569,11 +573,11 @@ class CartanType_finite(CartanType, cartan_type.CartanType_finite):
 
         If possible, this reuses the original label for the special node::
 
-            sage: T = B4.relabel({1:2, 2:3, 3:4, 4:1}); T.dynkin_diagram()
+            sage: T = B4.relabel({1:2, 2:3, 3:4, 4:1}); T.dynkin_diagram()              # needs sage.graphs
             O---O---O=>=O
             2   3   4   1
             B4 relabelled by {1: 2, 2: 3, 3: 4, 4: 1}
-            sage: T.affine().dynkin_diagram()
+            sage: T.affine().dynkin_diagram()                                           # needs sage.graphs
                 O 0
                 |
                 |
@@ -583,11 +587,11 @@ class CartanType_finite(CartanType, cartan_type.CartanType_finite):
 
         Otherwise, it chooses a label for the special_node in `0,1,...`::
 
-            sage: T = B4.relabel({1:0, 2:1, 3:2, 4:3}); T.dynkin_diagram()
+            sage: T = B4.relabel({1:0, 2:1, 3:2, 4:3}); T.dynkin_diagram()              # needs sage.graphs
             O---O---O=>=O
             0   1   2   3
             B4 relabelled by {1: 0, 2: 1, 3: 2, 4: 3}
-            sage: T.affine().dynkin_diagram()
+            sage: T.affine().dynkin_diagram()                                           # needs sage.graphs
                 O 4
                 |
                 |
@@ -595,7 +599,7 @@ class CartanType_finite(CartanType, cartan_type.CartanType_finite):
             0   1   2   3
             B4~ relabelled by {0: 4, 1: 0, 2: 1, 3: 2, 4: 3}
 
-        This failed before :trac:`13724`::
+        This failed before :issue:`13724`::
 
             sage: ct = CartanType(["G",2]).dual(); ct
             ['G', 2] relabelled by {1: 2, 2: 1}
@@ -645,7 +649,7 @@ class CartanType_affine(CartanType, cartan_type.CartanType_affine):
         EXAMPLES::
 
             sage: A41 = CartanType(['A',4,1])
-            sage: A41.dynkin_diagram()
+            sage: A41.dynkin_diagram()                                                  # needs sage.graphs
             0
             O-----------+
             |           |
@@ -657,7 +661,7 @@ class CartanType_affine(CartanType, cartan_type.CartanType_affine):
             sage: T = A41.relabel({0:1, 1:2, 2:3, 3:4, 4:0})
             sage: T
             ['A', 4, 1] relabelled by {0: 1, 1: 2, 2: 3, 3: 4, 4: 0}
-            sage: T.dynkin_diagram()
+            sage: T.dynkin_diagram()                                                    # needs sage.graphs
             1
             O-----------+
             |           |
@@ -669,7 +673,7 @@ class CartanType_affine(CartanType, cartan_type.CartanType_affine):
             sage: T0 = T.classical()
             sage: T0
             ['A', 4] relabelled by {1: 2, 2: 3, 3: 4, 4: 0}
-            sage: T0.dynkin_diagram()
+            sage: T0.dynkin_diagram()                                                   # needs sage.graphs
             O---O---O---O
             2   3   4   0
             A4 relabelled by {1: 2, 2: 3, 3: 4, 4: 0}
