@@ -1,3 +1,4 @@
+# sage.doctest: needs sage.combinat sage.modules
 """
 Elementary symmetric functions
 """
@@ -370,7 +371,7 @@ class SymmetricFunctionAlgebra_elementary(multiplicative.SymmetricFunctionAlgebr
             By default, we return a rational functions in `q`.  Sometimes
             it is better to obtain an element of the symbolic ring::
 
-                sage: x.principal_specialization(q=var("q"))                            # optional - sage.symbolic
+                sage: x.principal_specialization(q=var("q"))                            # needs sage.symbolic
                 -3*q/((q^2 - 1)*(q - 1)^2) - 5/(q - 1)^3 + 1
 
             TESTS::
@@ -468,7 +469,7 @@ class SymmetricFunctionAlgebra_elementary(multiplicative.SymmetricFunctionAlgebr
                 sage: x.exponential_specialization()
                 1/12*t^5
                 sage: x = 5*e[2] + 3*e[1] + 1
-                sage: x.exponential_specialization(t=var("t"), q=var("q"))              # optional - sage.symbolic
+                sage: x.exponential_specialization(t=var("t"), q=var("q"))              # needs sage.symbolic
                 5*q*t^2/(q + 1) + 3*t + 1
 
             TESTS::
