@@ -111,7 +111,7 @@ class SixVertexConfiguration(ClonableArray):
         EXAMPLES::
 
             sage: M = SixVertexModel(3, boundary_conditions='ice')
-            sage: [x.to_signed_matrix() for x in M]
+            sage: [x.to_signed_matrix() for x in M]                                     # needs sage.modules
             [
             [1 0 0]  [1 0 0]  [ 0  1  0]  [0 1 0]  [0 1 0]  [0 0 1]  [0 0 1]
             [0 1 0]  [0 0 1]  [ 1 -1  1]  [1 0 0]  [0 0 1]  [1 0 0]  [0 1 0]
@@ -137,10 +137,10 @@ class SixVertexConfiguration(ClonableArray):
 
         - ``color`` -- can be any of the following:
 
-          * ``4`` - use 4 colors: black, red, blue, and green with each
+          * ``4`` -- use 4 colors: black, red, blue, and green with each
             corresponding to up, right, down, and left respectively
-          * ``2`` - use 2 colors: red for horizontal, blue for vertical arrows
-          * ``'sign'`` - use red for right and down arrows, blue for left
+          * ``2`` -- use 2 colors: red for horizontal, blue for vertical arrows
+          * ``'sign'`` -- use red for right and down arrows, blue for left
             and up arrows
           * a list of 4 colors for each direction
           * a function which takes a direction and a boolean corresponding
@@ -149,7 +149,7 @@ class SixVertexConfiguration(ClonableArray):
         EXAMPLES::
 
             sage: M = SixVertexModel(2, boundary_conditions='ice')
-            sage: print(M[0].plot().description())                                      # optional - sage.plot
+            sage: print(M[0].plot().description())                                      # needs sage.plot
             Arrow from (-1.0,0.0) to (0.0,0.0)
             Arrow from (-1.0,1.0) to (0.0,1.0)
             Arrow from (0.0,0.0) to (0.0,-1.0)
@@ -361,13 +361,13 @@ class SixVertexModel(UniqueRepresentation, Parent):
 
       There are also the following predefined boundary conditions:
 
-      * ``'ice'`` - The top and bottom boundary conditions are outward and the
+      * ``'ice'`` -- The top and bottom boundary conditions are outward and the
         left and right boundary conditions are inward; this gives the square
         ice model. Also called domain wall boundary conditions.
-      * ``'domain wall'`` - Same as ``'ice'``.
-      * ``'alternating'`` - The boundary conditions alternate between inward
+      * ``'domain wall'`` -- Same as ``'ice'``.
+      * ``'alternating'`` -- The boundary conditions alternate between inward
         and outward.
-      * ``'free'`` - There are no boundary conditions.
+      * ``'free'`` -- There are no boundary conditions.
 
     EXAMPLES:
 
@@ -392,7 +392,7 @@ class SixVertexModel(UniqueRepresentation, Parent):
         sage: M = SixVertexModel(4, boundary_conditions='ice')
         sage: len(M)
         42
-        sage: all(len(SixVertexModel(n, boundary_conditions='ice'))
+        sage: all(len(SixVertexModel(n, boundary_conditions='ice'))                     # needs sage.modules
         ....:     == AlternatingSignMatrices(n).cardinality() for n in range(1, 7))
         True
 
@@ -438,7 +438,7 @@ class SixVertexModel(UniqueRepresentation, Parent):
             cond = []
             for dummy in range(2):
                 val = []
-                for k in range(m):
+                for _ in range(m):
                     val.append(bdry)
                     bdry = not bdry
                 cond.append(tuple(val))
@@ -650,7 +650,7 @@ class SixVertexModel(UniqueRepresentation, Parent):
         EXAMPLES::
 
             sage: M = SixVertexModel(3, boundary_conditions='ice')
-            sage: M.partition_function(2, [1,2,1,2,1,2])                                # optional - sage.symbolic
+            sage: M.partition_function(2, [1,2,1,2,1,2])                                # needs sage.symbolic
             e^(-24) + 2*e^(-28) + e^(-30) + 2*e^(-32) + e^(-36)
 
         REFERENCES:
@@ -693,8 +693,8 @@ class SquareIceModel(SixVertexModel):
         EXAMPLES::
 
             sage: M = SixVertexModel(3, boundary_conditions='ice')
-            sage: asm = AlternatingSignMatrix([[0,1,0],[1,-1,1],[0,1,0]])
-            sage: M.from_alternating_sign_matrix(asm)
+            sage: asm = AlternatingSignMatrix([[0,1,0],[1,-1,1],[0,1,0]])               # needs sage.modules
+            sage: M.from_alternating_sign_matrix(asm)                                   # needs sage.modules
                 ^    ^    ^
                 |    |    |
             --> # -> # <- # <--
@@ -710,11 +710,11 @@ class SquareIceModel(SixVertexModel):
         TESTS::
 
             sage: M = SixVertexModel(5, boundary_conditions='ice')
-            sage: ASM = AlternatingSignMatrices(5)
-            sage: all(M.from_alternating_sign_matrix(x.to_alternating_sign_matrix()) == x
+            sage: ASM = AlternatingSignMatrices(5)                                      # needs sage.modules
+            sage: all(M.from_alternating_sign_matrix(x.to_alternating_sign_matrix()) == x           # needs sage.modules
             ....:     for x in M)
             True
-            sage: all(M.from_alternating_sign_matrix(x).to_alternating_sign_matrix() == x
+            sage: all(M.from_alternating_sign_matrix(x).to_alternating_sign_matrix() == x           # needs sage.modules
             ....:     for x in ASM)
             True
         """
@@ -766,12 +766,12 @@ class SquareIceModel(SixVertexModel):
             EXAMPLES::
 
                 sage: M = SixVertexModel(4, boundary_conditions='ice')
-                sage: M[6].to_alternating_sign_matrix()
+                sage: M[6].to_alternating_sign_matrix()                                 # needs sage.modules
                 [1 0 0 0]
                 [0 0 0 1]
                 [0 0 1 0]
                 [0 1 0 0]
-                sage: M[7].to_alternating_sign_matrix()
+                sage: M[7].to_alternating_sign_matrix()                                 # needs sage.modules
                 [ 0  1  0  0]
                 [ 1 -1  1  0]
                 [ 0  1 -1  1]
