@@ -1,55 +1,44 @@
-# -*- coding: utf-8 -*-
 r"""
 The On-Line Encyclopedia of Integer Sequences (OEIS)
 
 You can query the OEIS (Online Database of Integer Sequences) through Sage in
 order to:
 
-    - identify a sequence from its first terms.
-    - obtain more terms, formulae, references, etc. for a given sequence.
-
-AUTHORS:
-
-- Thierry Monteil (2012-02-10 -- 2013-06-21): initial version.
-
-- Vincent Delecroix (2014): modifies continued fractions because of :trac:`14567`
-
-- Moritz Firsching (2016): modifies handling of dead sequence, see :trac:`17330`
-
-- Thierry Monteil (2019): refactorization (unique representation :trac:`28480`,
-  laziness :trac:`28627`)
+- identify a sequence from its first terms.
+- obtain more terms, formulae, references, etc. for a given sequence.
 
 EXAMPLES::
 
-        sage: oeis
-        The On-Line Encyclopedia of Integer Sequences (https://oeis.org/)
+    sage: oeis
+    The On-Line Encyclopedia of Integer Sequences (https://oeis.org/)
 
 What about a sequence starting with `3, 7, 15, 1` ?
 
 ::
 
-    sage: search = oeis([3, 7, 15, 1], max_results=4) ; search  # optional -- internet # random
+    sage: # optional - internet
+    sage: search = oeis([3, 7, 15, 1], max_results=4); search   # random
     0: A001203: Simple continued fraction expansion of Pi.
     1: A240698: Partial sums of divisors of n, cf. A027750.
     2: A082495: a(n) = (2^n - 1) mod n.
-    3: A165416: Irregular array read by rows: The n-th row contains those distinct positive integers that each, when written in binary, occurs as a substring in binary n.
-
-    sage: [u.id() for u in search]                      # optional -- internet  # random
+    3: A165416: Irregular array read by rows: The n-th row contains those
+                distinct positive integers that each, when written in binary,
+                occurs as a substring in binary n.
+    sage: [u.id() for u in search]                              # random
     ['A001203', 'A240698', 'A082495', 'A165416']
-    sage: c = search[0] ; c                             # optional -- internet
+    sage: c = search[0]; c
     A001203: Simple continued fraction expansion of Pi.
 
 ::
 
-    sage: c.first_terms(15)                             # optional -- internet
+    sage: # optional - internet
+    sage: c.first_terms(15)
     (3, 7, 15, 1, 292, 1, 1, 1, 2, 1, 3, 1, 14, 2, 1)
-
-    sage: c.examples()                                  # optional -- internet
+    sage: c.examples()
     0: Pi = 3.1415926535897932384...
     1:    = 3 + 1/(7 + 1/(15 + 1/(1 + 1/(292 + ...))))
     2:    = [a_0; a_1, a_2, a_3, ...] = [3; 7, 15, 1, 292, ...].
-
-    sage: c.comments()                                  # optional -- internet
+    sage: c.comments()
     0: The first 5821569425 terms were computed by _Eric W. Weisstein_ on Sep 18 2011.
     1: The first 10672905501 terms were computed by _Eric W. Weisstein_ on Jul 17 2013.
     2: The first 15000000000 terms were computed by _Eric W. Weisstein_ on Jul 27 2013.
@@ -57,51 +46,49 @@ What about a sequence starting with `3, 7, 15, 1` ?
 
 ::
 
-    sage: x = c.natural_object() ; type(x)              # optional -- internet
+    sage: # optional - internet
+    sage: x = c.natural_object(); type(x)
     <class 'sage.rings.continued_fraction.ContinuedFraction_periodic'>
-
-    sage: x.convergents()[:7]                           # optional -- internet
+    sage: x.convergents()[:7]
     [3, 22/7, 333/106, 355/113, 103993/33102, 104348/33215, 208341/66317]
-
-    sage: RR(x.value())                                 # optional -- internet
+    sage: RR(x.value())
     3.14159265358979
-    sage: RR(x.value()) == RR(pi)                       # optional -- internet
+    sage: RR(x.value()) == RR(pi)
     True
 
-What about posets ? Are they hard to count ? To which other structures are they
-related ?
+What about posets? Are they hard to count? To which other structures are they
+related?
 
 ::
 
+    sage: # optional - internet
     sage: [Posets(i).cardinality() for i in range(10)]
     [1, 1, 2, 5, 16, 63, 318, 2045, 16999, 183231]
-    sage: oeis(_)                                       # optional -- internet
+    sage: oeis(_)
     0: A000112: Number of partially ordered sets ("posets") with n unlabeled elements.
-    sage: p = _[0]                                      # optional -- internet
-
-::
-
-    sage: 'hard' in p.keywords()                        # optional -- internet
+    sage: p = _[0]
+    sage: 'hard' in p.keywords()
     True
-    sage: len(p.formulas())                             # optional -- internet
+    sage: len(p.formulas())
     0
-    sage: len(p.first_terms())                          # optional -- internet
+    sage: len(p.first_terms())
     17
-
-::
-
-    sage: p.cross_references(fetch=True)        # optional -- internet   # random
-    0: A000798: Number of different quasi-orders (or topologies, or transitive digraphs) with n labeled elements.
-    1: A001035: Number of partially ordered sets ("posets") with n labeled elements (or labeled acyclic transitive digraphs).
+    sage: p.cross_references(fetch=True)    # random
+    0: A000798: Number of different quasi-orders (or topologies, or transitive digraphs)
+                with n labeled elements.
+    1: A001035: Number of partially ordered sets ("posets") with n labeled elements
+                (or labeled acyclic transitive digraphs).
     2: A001930: Number of topologies, or transitive digraphs with n unlabeled nodes.
     3: A006057: Number of topologies on n labeled points satisfying axioms T_0-T_4.
     4: A079263: Number of constrained mixed models with n factors.
     5: A079265: Number of antisymmetric transitive binary relations on n unlabeled points.
-    6: A263859: Triangle read by rows: T(n,k) (n>=1, k>=0) is the number of posets with n elements and rank k (or depth k+1).
+    6: A263859: Triangle read by rows: T(n,k) (n>=1, k>=0) is the number of posets
+                with n elements and rank k (or depth k+1).
     7: A316978: Number of factorizations of n into factors > 1 with no equivalent primes.
     8: A319559: Number of non-isomorphic T_0 set systems of weight n.
     9: A326939: Number of T_0 sets of subsets of {1..n} that cover all n vertices.
-    10: A326943: Number of T_0 sets of subsets of {1..n} that cover all n vertices and are closed under intersection.
+    10: A326943: Number of T_0 sets of subsets of {1..n} that cover all n vertices and
+                 are closed under intersection.
     ...
 
 What does the Taylor expansion of the `e^{e^x-1}` function have to do with
@@ -109,25 +96,22 @@ primes ?
 
 ::
 
+    sage: # optional - internet, needs sage.symbolic
     sage: x = var('x') ; f(x) = e^(e^x - 1)
-    sage: L = [a*factorial(b) for a,b in taylor(f(x), x, 0, 20).coefficients()] ; L
+    sage: L = [a*factorial(b) for a,b in taylor(f(x), x, 0, 20).coefficients()]; L
     [1, 1, 2, 5, 15, 52, 203, 877, 4140, 21147, 115975, 678570, 4213597,
-    27644437, 190899322, 1382958545, 10480142147, 82864869804, 682076806159,
-    5832742205057, 51724158235372]
-
-    sage: oeis(L)                                       # optional -- internet
-    0: A000110: Bell or exponential numbers: number of ways to partition a set of n labeled elements.
+     27644437, 190899322, 1382958545, 10480142147, 82864869804, 682076806159,
+     5832742205057, 51724158235372]
+    sage: oeis(L)
+    0: A000110: Bell or exponential numbers: number of ways to partition
+                a set of n labeled elements.
     1: A292935: E.g.f.: exp(exp(-x) - 1).
-
-    sage: b = _[0]                                      # optional -- internet
-
-    sage: b.formulas()[0]                               # optional -- internet
+    sage: b = _[0]
+    sage: b.formulas()[0]
     'E.g.f.: exp(exp(x) - 1).'
-
-    sage: [i for i in b.comments() if 'prime' in i][-1]     # optional -- internet
-    'Number n is prime if ...'
-
-    sage: [n for n in range(2, 20) if (b(n)-2) % n == 0]    # optional -- internet
+    sage: [i for i in b.comments() if 'prime' in i][-1]
+    'When n is prime, ...'
+    sage: [n for n in range(2, 20) if (b(n)-2) % n == 0]
     [2, 3, 5, 7, 11, 13, 17, 19]
 
 .. SEEALSO::
@@ -138,13 +122,13 @@ primes ?
     - Some infinite OEIS sequences are implemented in Sage, via the
       :mod:`sloane_functions <sage.combinat.sloane_functions>` module.
 
-.. TODO::
+AUTHORS:
 
-    - in case of flood, suggest the user to install the off-line database instead.
-    - interface with the off-line database (or reimplement it).
-
-Classes and methods
--------------------
+- Thierry Monteil (2012-02-10 -- 2013-06-21): initial version.
+- Vincent Delecroix (2014): modifies continued fractions because of :issue:`14567`
+- Moritz Firsching (2016): modifies handling of dead sequence, see :issue:`17330`
+- Thierry Monteil (2019): refactorization (unique representation :issue:`28480`,
+  laziness :issue:`28627`)
 """
 
 # ****************************************************************************
@@ -191,7 +175,7 @@ def _fetch(url):
 
     TESTS::
 
-        sage: from sage.databases.oeis import _fetch, oeis_url
+        sage: from sage.databases.oeis import _fetch, oeis_url  # optional -- internet
         sage: _fetch(oeis_url + 'hints.html')[-8:-1]            # optional -- internet
         '</html>'
     """
@@ -201,8 +185,8 @@ def _fetch(url):
         result = f.read()
         f.close()
         return bytes_to_str(result)
-    except IOError as msg:
-        raise IOError("%s\nerror fetching %s" % (msg, url))
+    except OSError as msg:
+        raise OSError("%s\nerror fetching %s" % (msg, url))
 
 
 def _urls(html_string):
@@ -261,18 +245,18 @@ class OEIS:
     Sequences. You can query it using its methods, but ``OEIS`` can also be
     called directly with three arguments:
 
-    - ``query`` - it can be:
+    - ``query`` -- it can be:
 
       - a string representing an OEIS ID (e.g. 'A000045').
       - an integer representing an OEIS ID (e.g. 45).
       - a list representing a sequence of integers.
       - a string, representing a text search.
 
-    - ``max_results`` - (integer, default: 30) the maximum number of
+    - ``max_results`` -- (integer, default: 30) the maximum number of
       results to return, they are sorted according to their relevance. In
       any cases, the OEIS website will never provide more than 100 results.
 
-    - ``first_result`` - (integer, default: 0) allow to skip the
+    - ``first_result`` -- (integer, default: 0) allow to skip the
       ``first_result`` first results in the search, to go further.
       This is useful if you are looking for a sequence that may appear
       after the 100 first found sequences.
@@ -299,16 +283,17 @@ class OEIS:
 
         sage: oeis('A000040')                           # optional -- internet
         A000040: The prime numbers.
-
         sage: oeis(45)                                  # optional -- internet
         A000045: Fibonacci numbers: F(n) = F(n-1) + F(n-2) with F(0) = 0 and F(1) = 1.
 
     The database can be searched by subsequence::
 
-        sage: search = oeis([1,2,3,5,8,13]) ; search    # optional -- internet
+        sage: search = oeis([1,2,3,5,8,13]); search     # optional -- internet
         0: A000045: Fibonacci numbers: F(n) = F(n-1) + F(n-2) with F(0) = 0 and F(1) = 1.
         1: A290689: Number of transitive rooted trees with n nodes.
-        2: A027926: Triangular array T read by rows: T(n,0) = T(n,2n) = 1 for n >= 0; T(n,1) = 1 for n >= 1; T(n,k) = T(n-1,k-2) + T(n-1,k-1) for k = 2..2n-1, n >= 2.
+        2: A027926: Triangular array T read by rows: T(n,0) = T(n,2n) = 1 for n >= 0;
+                    T(n,1) = 1 for n >= 1; T(n,k) = T(n-1,k-2) + T(n-1,k-1)
+                    for k = 2..2n-1, n >= 2.
 
         sage: fibo = search[0]                          # optional -- internet
 
@@ -322,12 +307,12 @@ class OEIS:
         14930352, 24157817, 39088169, 63245986, 102334155)
 
         sage: fibo.cross_references()[0]                # optional -- internet
-        'A039834'
+        'A001622'
 
         sage: fibo == oeis(45)                          # optional -- internet
         True
 
-        sage: sfibo = oeis('A039834')
+        sage: sfibo = oeis('A039834')                   # optional -- internet
         sage: sfibo.first_terms()                       # optional -- internet
         (1, 1, 0, 1, -1, 2, -3, 5, -8, 13, -21, 34, -55, 89, -144, 233,
         -377, 610, -987, 1597, -2584, 4181, -6765, 10946, -17711, 28657,
@@ -349,9 +334,10 @@ class OEIS:
 
     The database can be searched by description::
 
-        sage: oeis('prime gap factorization', max_results=4) # optional --internet # random
+        sage: oeis('prime gap factorization', max_results=4)  # random  # optional -- internet
         0: A073491: Numbers having no prime gaps in their factorization.
-        1: A073485: Product of any number of consecutive primes; squarefree numbers with no gaps in their prime factorization.
+        1: A073485: Product of any number of consecutive primes; squarefree numbers
+                    with no gaps in their prime factorization.
         2: A073490: Number of prime gaps in factorization of n.
         3: A073492: Numbers having at least one prime gap in their factorization.
 
@@ -362,7 +348,9 @@ class OEIS:
             sage: oeis([1,2,3,5,8,13])                  # optional -- internet
             0: A000045: Fibonacci numbers: F(n) = F(n-1) + F(n-2) with F(0) = 0 and F(1) = 1.
             1: A290689: Number of transitive rooted trees with n nodes.
-            2: A027926: Triangular array T read by rows: T(n,0) = T(n,2n) = 1 for n >= 0; T(n,1) = 1 for n >= 1; T(n,k) = T(n-1,k-2) + T(n-1,k-1) for k = 2..2n-1, n >= 2.
+            2: A027926: Triangular array T read by rows: T(n,0) = T(n,2n) = 1 for n >= 0;
+                        T(n,1) = 1 for n >= 1; T(n,k) = T(n-1,k-2) + T(n-1,k-1)
+                        for k = 2..2n-1, n >= 2.
 
             sage: oeis('A000045')                       # optional -- internet
             A000045: Fibonacci numbers: F(n) = F(n-1) + F(n-2) with F(0) = 0 and F(1) = 1.
@@ -510,7 +498,8 @@ class OEIS:
                    'start': str(first_result)}
         url = oeis_url + "search?" + urlencode(options)
         sequence_list = _fetch(url).split('\n\n')[2:-1]
-        return FancyTuple([self.find_by_entry(entry=_) for _ in sequence_list])
+        T = [self.find_by_entry(entry=s) for s in sequence_list]
+        return FancyTuple([s for s in T if not s.is_dead()])
 
     def find_by_subsequence(self, subsequence, max_results=3, first_result=0):
         r"""
@@ -659,20 +648,19 @@ class OEISSequence(SageObject, UniqueRepresentation):
         between calling and getting item, see :meth:`__call__` for more details
         ::
 
+            sage: # optional - internet
             sage: sfibo = oeis('A039834')
-            sage: sfibo.first_terms()[:10]              # optional -- internet
+            sage: sfibo.first_terms()[:10]
             (1, 1, 0, 1, -1, 2, -3, 5, -8, 13)
-
-            sage: sfibo(-2)                             # optional -- internet
+            sage: sfibo(-2)
             1
-            sage: sfibo(3)                              # optional -- internet
+            sage: sfibo(3)
             2
-            sage: sfibo.offsets()                       # optional -- internet
+            sage: sfibo.offsets()
             (-2, 6)
-
-            sage: sfibo[0]                              # optional -- internet
+            sage: sfibo[0]
             1
-            sage: sfibo[6]                              # optional -- internet
+            sage: sfibo[6]
             -3
 
     .. automethod:: __call__
@@ -718,11 +706,12 @@ class OEISSequence(SageObject, UniqueRepresentation):
 
         TESTS::
 
+            sage: # optional -- internet
             sage: s = oeis._imaginary_sequence(ident='A004238')
             sage: s
             A004238: The characteristic sequence of 42 plus one, starting from 38.
-            sage: s.online_update()                     # optional -- internet
-            sage: s                                     # optional -- internet
+            sage: s.online_update()
+            sage: s
             A004238: a(n) = 100*log(n) rounded to nearest integer.
         """
         options = {'q': self._id, 'n': '1', 'fmt': 'text'}
@@ -733,12 +722,16 @@ class OEISSequence(SageObject, UniqueRepresentation):
         except AttributeError:
             pass
 
-    def _field(self, key):
+    def _field(self, key, warn=True):
         r"""
         Return the ``key`` field of the entry of ``self``.
 
         This method allows to handle the ``_fields`` dictionary in a lazy way.
 
+        INPUT:
+
+        - ``warn`` -- ignored
+
         TESTS::
 
             sage: s = oeis._imaginary_sequence()
@@ -752,7 +745,6 @@ class OEISSequence(SageObject, UniqueRepresentation):
             for line in self.raw_entry().splitlines():
                 fields[line[1]].append(line[11:])
             self._fields = fields
-            self.is_dead(warn_only=True)
             return self._fields[key]
 
     def id(self, format='A'):
@@ -843,7 +835,7 @@ class OEISSequence(SageObject, UniqueRepresentation):
             A000045: Fibonacci numbers: F(n) = F(n-1) + F(n-2) with F(0) = 0 and F(1) = 1.
 
             sage: print(f.raw_entry())                  # optional -- internet
-            %I A000045 M0692 N0256
+            %I A000045 M0692 N0256...
             %S A000045 0,1,1,2,3,5,8,13,21,34,55,89,144,...
             %T A000045 10946,17711,28657,46368,...
             ...
@@ -909,7 +901,12 @@ class OEISSequence(SageObject, UniqueRepresentation):
             sage: s.old_IDs()
             ('M9999', 'N9999')
         """
-        return tuple(self._field('I')[0].split(' '))
+        s = self._field('I')[0]
+        # We remove all parts after '#'
+        s = s.split('#')[0].strip()
+        if not s:
+            return ()
+        return tuple(s.split(' '))
 
     def offsets(self):
         r"""
@@ -970,7 +967,7 @@ class OEISSequence(SageObject, UniqueRepresentation):
         """
         return self._field('A')[0]
 
-    def keywords(self):
+    def keywords(self, warn=True):
         r"""
         Return the keywords associated to the sequence ``self``.
 
@@ -996,7 +993,7 @@ class OEISSequence(SageObject, UniqueRepresentation):
             sage: s.keywords()
             ('nonn', 'hard')
         """
-        return tuple(self._field('K')[0].split(','))
+        return tuple(self._field('K', warn=warn)[0].split(','))
 
     def natural_object(self):
         r"""
@@ -1005,11 +1002,11 @@ class OEISSequence(SageObject, UniqueRepresentation):
         OUTPUT:
 
         - If the sequence ``self`` corresponds to the digits of a real
-              number, returns the associated real number (as an element of
-              RealLazyField()).
+          number, returns the associated real number (as an element of
+          RealLazyField()).
 
         - If the sequence ``self`` corresponds to the convergents of a
-              continued fraction, returns the associated continued fraction.
+          continued fraction, returns the associated continued fraction.
 
         .. WARNING::
 
@@ -1024,25 +1021,25 @@ class OEISSequence(SageObject, UniqueRepresentation):
 
         EXAMPLES::
 
-            sage: g = oeis("A002852") ; g               # optional -- internet
+            sage: g = oeis("A002852"); g                # optional -- internet
             A002852: Continued fraction for Euler's constant (or Euler-Mascheroni constant) gamma.
 
-            sage: x = g.natural_object() ; type(x)      # optional -- internet
+            sage: x = g.natural_object(); type(x)       # optional -- internet
             <class 'sage.rings.continued_fraction.ContinuedFraction_periodic'>
 
             sage: RDF(x) == RDF(euler_gamma)            # optional -- internet
             True
 
-            sage: cfg = continued_fraction(euler_gamma)
-            sage: x[:90] == cfg[:90]                    # optional -- internet
+            sage: cfg = continued_fraction(euler_gamma)                                 # needs sage.symbolic
+            sage: x[:90] == cfg[:90]                    # optional - internet           # needs sage.symbolic
             True
 
         ::
 
-            sage: ee = oeis('A001113') ; ee             # optional -- internet
+            sage: ee = oeis('A001113'); ee              # optional -- internet
             A001113: Decimal expansion of e.
 
-            sage: x = ee.natural_object() ; x           # optional -- internet
+            sage: x = ee.natural_object(); x            # optional -- internet
             2.718281828459046?
 
             sage: x.parent()                            # optional -- internet
@@ -1053,26 +1050,28 @@ class OEISSequence(SageObject, UniqueRepresentation):
 
         ::
 
-            sage: av = oeis('A087778') ; av             # optional -- internet
-            A087778: Decimal expansion ... Avogadro...
+            sage: av = oeis('A322578'); av              # optional -- internet
+            A322578: Decimal expansion ... Avogadro...
 
             sage: av.natural_object()                   # optional -- internet
-            6.022141000000000?e23
+            6.022140760000000?e23
 
         ::
 
-            sage: fib = oeis('A000045') ; fib           # optional -- internet
+            sage: fib = oeis('A000045'); fib            # optional -- internet
             A000045: Fibonacci numbers: F(n) = F(n-1) + F(n-2) with F(0) = 0 and F(1) = 1.
 
-            sage: x = fib.natural_object() ; x.universe()         # optional -- internet
+            sage: x = fib.natural_object(); x.universe()    # optional -- internet
             Non negative integer semiring
 
         ::
 
-            sage: sfib = oeis('A039834') ; sfib         # optional -- internet
-            A039834: a(n+2) = -a(n+1) + a(n) (signed Fibonacci numbers) with a(-2) = a(-1) = 1; or Fibonacci numbers (A000045) extended to negative indices.
+            sage: sfib = oeis('A039834'); sfib         # optional -- internet
+            A039834: a(n+2) = -a(n+1) + a(n) (signed Fibonacci numbers) with
+                     a(-2) = a(-1) = 1; or Fibonacci numbers (A000045)
+                     extended to negative indices.
 
-            sage: x = sfib.natural_object() ; x.universe()    # optional -- internet
+            sage: x = sfib.natural_object(); x.universe()   # optional -- internet
             Integer Ring
 
         TESTS::
@@ -1106,25 +1105,18 @@ class OEISSequence(SageObject, UniqueRepresentation):
             from sage.rings.integer_ring import ZZ
             return Sequence(self.first_terms(), ZZ)
 
-    def is_dead(self, warn_only=False):
+    def is_dead(self, warn_only=False) -> bool:
         r"""
-        Tell whether the sequence is dead (i.e. erroneous).
+        Tell whether the sequence is dead.
 
         INPUT:
 
-        - warn_only -- (bool, default: ``False``), whether to warn when the
-          sequence is dead instead of returning a boolean.
+        - ``warn_only`` -- ignored
 
         EXAMPLES:
 
-        A warn_only test is triggered as soon as some information on the
-        sequence is queried::
-
-            sage: s = oeis(17)
+            sage: s = oeis(17)                      # optional -- internet
             sage: s                                 # optional -- internet
-            doctest:warning
-            ...
-            RuntimeWarning: This sequence is dead: "A000017: Erroneous version of A032522."
             A000017: Erroneous version of A032522.
 
         TESTS::
@@ -1138,20 +1130,12 @@ class OEISSequence(SageObject, UniqueRepresentation):
 
             sage: u = oeis._imaginary_sequence(ident='A999994', keywords='dead')
             sage: u
-            doctest:warning
-            ...
-            RuntimeWarning: This sequence is dead: "A999994: The characteristic sequence of 42 plus one, starting from 38."
             A999994: The characteristic sequence of 42 plus one, starting from 38.
 
             sage: u.is_dead()
             True
         """
-        if warn_only:
-            if 'dead' in self.keywords():
-                from warnings import warn
-                warn('This sequence is dead: "{}: {}"'.format(self.id(), self.name()), RuntimeWarning)
-        else:
-            return 'dead' in self.keywords()
+        return 'dead' in self.keywords()
 
     def is_finite(self):
         r"""
@@ -1263,18 +1247,15 @@ class OEISSequence(SageObject, UniqueRepresentation):
 
         EXAMPLES::
 
-            sage: f = oeis(45) ; f                      # optional -- internet
+            sage: f = oeis(45); f                       # optional -- internet
             A000045: Fibonacci numbers: F(n) = F(n-1) + F(n-2) with F(0) = 0 and F(1) = 1.
 
             sage: f.first_terms()[:10]                  # optional -- internet
             (0, 1, 1, 2, 3, 5, 8, 13, 21, 34)
 
-        Handle dead sequences, see :trac:`17330` ::
+        Handle dead sequences, see :issue:`17330` ::
 
-            sage: oeis(5000).first_terms(12)              # optional -- internet
-            doctest:warning
-            ...
-            RuntimeWarning: This sequence is dead: "A005000: Erroneous version of A006505."
+            sage: oeis(5000).first_terms(12)            # optional -- internet
             (1, 0, 0, 1, 1, 1, 11, 36, 92, 491, 2537)
 
         TESTS::
@@ -1440,14 +1421,15 @@ class OEISSequence(SageObject, UniqueRepresentation):
             sage: w = oeis(7540) ; w                    # optional -- internet
             A007540: Wilson primes: primes p such that (p-1)! == -1 (mod p^2).
 
-            sage: i = w.__iter__()                      # optional -- internet
-            sage: next(i)                               # optional -- internet
+            sage: # optional - internet
+            sage: i = w.__iter__()
+            sage: next(i)
             5
-            sage: next(i)                               # optional -- internet
+            sage: next(i)
             13
-            sage: next(i)                               # optional -- internet
+            sage: next(i)
             563
-            sage: next(i)                               # optional -- internet
+            sage: next(i)
             Traceback (most recent call last):
             ...
             LookupError: future values not provided by OEIS
@@ -1517,17 +1499,16 @@ class OEISSequence(SageObject, UniqueRepresentation):
         INPUT:
 
         - ``browse`` -- an integer, a list of integers, or the word 'all'
-          (default: ``None``) : which links to open in a web browser.
+          (default: ``None``): which links to open in a web browser.
 
-        - ``format`` -- string (default: 'guess') : how to display the links.
+        - ``format`` -- string (default: 'guess'): how to display the links.
 
-        OUTPUT:
+        OUTPUT: Tuple of strings (with fancy formatting):
 
-        - tuple of strings (with fancy formatting):
-            - if ``format`` is ``url``, returns a tuple of absolute links without description.
-            - if ``format`` is ``html``, returns nothing but prints a tuple of clickable absolute links in their context.
-            - if ``format`` is ``guess``, adapts the output to the context (command line or notebook).
-            - if ``format`` is ``raw``, the links as they appear in the database, relative links are not made absolute.
+        - if ``format`` is ``url``, returns a tuple of absolute links without description.
+        - if ``format`` is ``html``, returns nothing but prints a tuple of clickable absolute links in their context.
+        - if ``format`` is ``guess``, adapts the output to the context (command line or notebook).
+        - if ``format`` is ``raw``, the links as they appear in the database, relative links are not made absolute.
 
         EXAMPLES::
 
@@ -1562,13 +1543,14 @@ class OEISSequence(SageObject, UniqueRepresentation):
         """
         def url_absolute(s):
             return re.sub(r'\"\/', '\"' + oeis_url, s)
+
         if browse is None:
             if format == 'guess':
                 return self.links(format='url')
             elif format == 'raw':
                 return FancyTuple(self._field('H'))
             elif format == 'html':
-                return HtmlFragment(FancyTuple([url_absolute(_) for _ in self._field('H')]))
+                return HtmlFragment(FancyTuple([url_absolute(f) for f in self._field('H')]))
             elif format == 'url':
                 url_list = flatten([_urls(url_absolute(string)) for string in self._field('H')])
                 return FancyTuple(url_list)
@@ -1605,7 +1587,6 @@ class OEISSequence(SageObject, UniqueRepresentation):
             sage: s = oeis._imaginary_sequence()
             sage: s.formulas()
             0: For n big enough, s(n+1) - s(n) = 0.
-
         """
         return FancyTuple(self._field('F'))
 
@@ -1621,7 +1602,7 @@ class OEISSequence(SageObject, UniqueRepresentation):
         OUTPUT:
 
         - if ``fetch`` is ``False``, return a list of OEIS IDs (strings).
-        - if ``fetch`` if ``True``, return a tuple of OEIS sequences.
+        - if ``fetch`` is ``True``, return a tuple of OEIS sequences.
 
         EXAMPLES::
 
@@ -1635,7 +1616,9 @@ class OEISSequence(SageObject, UniqueRepresentation):
             0: A000010: Euler totient function phi(n): count numbers <= n and prime to n.
             1: A002088: Sum of totient function: a(n) = Sum_{k=1..n} phi(k), cf. A000010.
             2: A011755: a(n) = Sum_{k=1..n} k*phi(k).
-            3: A049695: Array T read by diagonals; T(i,j) is the number of nonnegative slopes of lines determined by 2 lattice points in [ 0,i ] X [ 0,j ] if i > 0; T(0,j)=1 if j > 0; T(0,0)=0.
+            3: A049695: Array T read by diagonals; T(i,j) is the number of nonnegative
+                        slopes of lines determined by 2 lattice points in
+                        [ 0,i ] X [ 0,j ] if i > 0; T(0,j)=1 if j > 0; T(0,0)=0.
             4: A049703: a(0) = 0; for n>0, a(n) = A005598(n)/2.
             5: A103116: a(n) = Sum_{i=1..n} (n-i+1)*phi(i).
 
@@ -1649,9 +1632,9 @@ class OEISSequence(SageObject, UniqueRepresentation):
         """
         ref_list = re.findall('A[0-9]{6}', " ".join(self._field('Y')))
         if fetch:
-            return FancyTuple([oeis.find_by_id(_) for _ in ref_list])
-        else:
-            return tuple(ref_list)
+            T = [oeis.find_by_id(r) for r in ref_list]
+            return FancyTuple([s for s in T if not s.is_dead()])
+        return tuple(ref_list)
 
     def extensions_or_errors(self):
         r"""
@@ -1664,8 +1647,10 @@ class OEISSequence(SageObject, UniqueRepresentation):
 
         EXAMPLES::
 
-            sage: sfibo = oeis('A039834') ; sfibo       # optional -- internet
-            A039834: a(n+2) = -a(n+1) + a(n) (signed Fibonacci numbers) with a(-2) = a(-1) = 1; or Fibonacci numbers (A000045) extended to negative indices.
+            sage: sfibo = oeis('A039834'); sfibo        # optional -- internet
+            A039834: a(n+2) = -a(n+1) + a(n) (signed Fibonacci numbers) with
+                     a(-2) = a(-1) = 1; or Fibonacci numbers (A000045) extended
+                     to negative indices.
 
             sage: sfibo.extensions_or_errors()[0]       # optional -- internet
             'Signs corrected by _Len Smiley_ and _N. J. A. Sloane_'
@@ -1675,7 +1660,6 @@ class OEISSequence(SageObject, UniqueRepresentation):
             sage: s = oeis._imaginary_sequence()
             sage: s.extensions_or_errors()
             0: This sequence does not contain errors.
-
         """
         return FancyTuple(self._field('E'))
 
@@ -1689,7 +1673,7 @@ class OEISSequence(SageObject, UniqueRepresentation):
 
         EXAMPLES::
 
-            sage: c = oeis(1203) ; c                    # optional -- internet
+            sage: c = oeis(1203); c                     # optional -- internet
             A001203: Simple continued fraction expansion of Pi.
 
             sage: c.examples()                          # optional -- internet
@@ -1715,7 +1699,7 @@ class OEISSequence(SageObject, UniqueRepresentation):
 
         EXAMPLES::
 
-            sage: f = oeis(45) ; f                      # optional -- internet
+            sage: f = oeis(45); f                       # optional -- internet
             A000045: Fibonacci numbers: F(n) = F(n-1) + F(n-2) with F(0) = 0 and F(1) = 1.
 
             sage: f.comments()[:8]                      # optional -- internet
@@ -1747,7 +1731,7 @@ class OEISSequence(SageObject, UniqueRepresentation):
 
         EXAMPLES::
 
-            sage: f = oeis(45) ; f                      # optional -- internet
+            sage: f = oeis(45); f                       # optional -- internet
             A000045: Fibonacci numbers: F(n) = F(n-1) + F(n-2) with F(0) = 0 and F(1) = 1.
 
             sage: f.url()                               # optional -- internet
@@ -1767,7 +1751,7 @@ class OEISSequence(SageObject, UniqueRepresentation):
 
         EXAMPLES::
 
-            sage: f = oeis(45) ; f                      # optional -- internet webbrowser
+            sage: f = oeis(45); f                       # optional -- internet webbrowser
             A000045: Fibonacci numbers: F(n) = F(n-1) + F(n-2) with F(0) = 0 and F(1) = 1.
 
             sage: f.browse()                            # optional -- internet webbrowser
@@ -1782,7 +1766,7 @@ class OEISSequence(SageObject, UniqueRepresentation):
 
     def show(self):
         r"""
-        Display most available informations about the sequence ``self``.
+        Display most available information about the sequence ``self``.
 
         EXAMPLES::
 
@@ -2001,17 +1985,14 @@ class OEISSequence(SageObject, UniqueRepresentation):
 
         One correct sequence::
 
-            sage: s = oeis.find_by_id('A027642')     # optional -- internet
-            sage: s.test_compile_sage_code()    # optional -- internet
+            sage: s = oeis.find_by_id('A027642')        # optional -- internet
+            sage: s.test_compile_sage_code()            # optional -- internet
             True
 
         One dead sequence::
 
-            sage: s = oeis.find_by_id('A000154')     # optional -- internet
-            sage: s.test_compile_sage_code()    # optional -- internet
-            doctest:warning
-            ...
-            RuntimeWarning: This sequence is dead: ...
+            sage: s = oeis.find_by_id('A000154')        # optional -- internet
+            sage: s.test_compile_sage_code()            # optional -- internet
             True
         """
         if self.is_dead():
@@ -2032,7 +2013,7 @@ class FancyTuple(tuple):
     EXAMPLES::
 
         sage: from sage.databases.oeis import FancyTuple
-        sage: t = FancyTuple(['zero', 'one', 'two', 'three', 4]) ; t
+        sage: t = FancyTuple(['zero', 'one', 'two', 'three', 4]); t
         0: zero
         1: one
         2: two
@@ -2050,14 +2031,14 @@ class FancyTuple(tuple):
         EXAMPLES::
 
             sage: from sage.databases.oeis import FancyTuple
-            sage: t = FancyTuple(['zero', 'one', 'two', 'three', 4]) ; t
+            sage: t = FancyTuple(['zero', 'one', 'two', 'three', 4]); t
             0: zero
             1: one
             2: two
             3: three
             4: 4
 
-            sage: t = FancyTuple(['Français', 'Español', '中文']) ; t
+            sage: t = FancyTuple(['Français', 'Español', '中文']); t
             0: Français
             1: Español
             2: 中文
@@ -2101,7 +2082,7 @@ class FancyTuple(tuple):
             sage: ft[-1] == 'ç'
             True
 
-        Check that :trac:`26997` is fixed::
+        Check that :issue:`26997` is fixed::
 
             sage: FancyTuple([[1,2,3],(4,5,6)])
             0: [1, 2, 3]
