@@ -42,23 +42,22 @@ from sage.dynamics.arithmetic_dynamics.generic_ds import DynamicalSystem
 from sage.matrix.constructor import identity_matrix
 from sage.misc.cachefunc import cached_method
 from sage.misc.classcall_metaclass import typecall
-from sage.rings.all import Integer
-from sage.rings.finite_rings.finite_field_constructor import is_PrimeFiniteField
-from sage.rings.finite_rings.finite_field_constructor import is_FiniteField
+from sage.rings.integer import Integer
+from sage.rings.finite_rings.finite_field_base import FiniteField
 from sage.rings.fraction_field import FractionField
-from sage.rings.fraction_field import is_FractionField
+from sage.rings.fraction_field import FractionField_generic
 from sage.rings.quotient_ring import is_QuotientRing
 from sage.schemes.affine.affine_morphism import SchemeMorphism_polynomial_affine_space
 from sage.schemes.affine.affine_morphism import SchemeMorphism_polynomial_affine_space_field
 from sage.schemes.affine.affine_morphism import SchemeMorphism_polynomial_affine_space_finite_field
-from sage.schemes.affine.affine_space import is_AffineSpace
+from sage.schemes.affine.affine_space import AffineSpace_generic
 from sage.schemes.affine.affine_space import AffineSpace
 from sage.schemes.affine.affine_subscheme import AlgebraicScheme_subscheme_affine
 from sage.schemes.generic.morphism import SchemeMorphism_polynomial
 from sage.structure.element import get_coercion_model
-from sage.symbolic.ring import is_SymbolicExpressionRing
-from sage.symbolic.ring import var
-from sage.symbolic.ring import SR
+
+import sage.rings.abc
+
 
 class DynamicalSystem_affine(SchemeMorphism_polynomial_affine_space,
                              DynamicalSystem):
@@ -163,8 +162,9 @@ class DynamicalSystem_affine(SchemeMorphism_polynomial_affine_space,
 
     If you pass in quotient ring elements, they are reduced::
 
+        sage: # needs sage.libs.singular
         sage: A.<x,y,z> = AffineSpace(QQ, 3)
-        sage: X = A.subscheme([x-y])
+        sage: X = A.subscheme([x - y])
         sage: u,v,w = X.coordinate_ring().gens()
         sage: DynamicalSystem_affine([u, v, u+v], domain=X)
         Dynamical System of Closed subscheme of Affine Space of dimension 3
@@ -175,9 +175,10 @@ class DynamicalSystem_affine(SchemeMorphism_polynomial_affine_space,
 
     ::
 
+        sage: # needs sage.libs.singular
         sage: R.<t> = PolynomialRing(QQ)
         sage: A.<x,y,z> = AffineSpace(R, 3)
-        sage: X = A.subscheme(x^2-y^2)
+        sage: X = A.subscheme(x^2 - y^2)
         sage: H = End(X)
         sage: f = H([x^2/(t*y), t*y^2, x*z])
         sage: DynamicalSystem_affine(f)
@@ -189,11 +190,11 @@ class DynamicalSystem_affine(SchemeMorphism_polynomial_affine_space,
 
     ::
 
-        sage: x = var('x')
-        sage: DynamicalSystem_affine(x^2+1)
+        sage: x = var('x')                                                              # needs sage.symbolic
+        sage: DynamicalSystem_affine(x^2 + 1)                                           # needs sage.symbolic
         Traceback (most recent call last):
         ...
-        TypeError: Symbolic Ring cannot be the base ring
+        TypeError: symbolic ring cannot be the base ring
     """
 
     @staticmethod
@@ -230,7 +231,7 @@ class DynamicalSystem_affine(SchemeMorphism_polynomial_affine_space,
             sage: f = DynamicalSystem_affine([x+y+z, y*z])
             Traceback (most recent call last):
             ...
-            ValueError: Number of polys does not match dimension of Affine Space of dimension 3 over Rational Field
+            ValueError: number of polys does not match dimension of Affine Space of dimension 3 over Rational Field
 
         ::
 
@@ -245,13 +246,13 @@ class DynamicalSystem_affine(SchemeMorphism_polynomial_affine_space,
             R = morphism.base_ring()
             polys = list(morphism)
             domain = morphism.domain()
-            if not is_AffineSpace(domain) and not isinstance(domain, AlgebraicScheme_subscheme_affine):
+            if not isinstance(domain, AffineSpace_generic) and not isinstance(domain, AlgebraicScheme_subscheme_affine):
                 raise ValueError('"domain" must be an affine scheme')
             if domain != morphism_or_polys.codomain():
                 raise ValueError('domain and codomain do not agree')
             if R not in Fields():
                 return typecall(cls, polys, domain)
-            if is_FiniteField(R):
+            if isinstance(R, FiniteField):
                 return DynamicalSystem_affine_finite_field(polys, domain)
             return DynamicalSystem_affine_field(polys, domain)
         elif isinstance(morphism_or_polys,(list, tuple)):
@@ -260,7 +261,7 @@ class DynamicalSystem_affine(SchemeMorphism_polynomial_affine_space,
             polys = [morphism_or_polys]
 
         PR = get_coercion_model().common_parent(*polys)
-        fraction_field = any(is_FractionField(poly.parent()) for poly in polys)
+        fraction_field = any(isinstance(poly.parent(), FractionField_generic) for poly in polys)
         if fraction_field:
             K = PR.base_ring().fraction_field()
             # Replace base ring with its fraction field
@@ -275,8 +276,8 @@ class DynamicalSystem_affine(SchemeMorphism_polynomial_affine_space,
             else:
                 polys = [PR(poly) for poly in polys]
         if domain is None:
-            if PR is SR:
-                raise TypeError("Symbolic Ring cannot be the base ring")
+            if isinstance(PR, sage.rings.abc.SymbolicRing):
+                raise TypeError("symbolic ring cannot be the base ring")
             if fraction_field:
                 PR = PR.ring()
             domain = AffineSpace(PR)
@@ -290,17 +291,17 @@ class DynamicalSystem_affine(SchemeMorphism_polynomial_affine_space,
             except TypeError:
                 raise TypeError('coefficients of polynomial not in {}'.format(domain.base_ring()))
         if len(polys) != domain.ambient_space().coordinate_ring().ngens():
-            raise ValueError('Number of polys does not match dimension of {}'.format(domain))
+            raise ValueError(f'number of polys does not match dimension of {domain}')
         R = domain.base_ring()
-        if R is SR:
-            raise TypeError("Symbolic Ring cannot be the base ring")
-        if not is_AffineSpace(domain) and not isinstance(domain, AlgebraicScheme_subscheme_affine):
+        if isinstance(R, sage.rings.abc.SymbolicRing):
+            raise TypeError("symbolic ring cannot be the base ring")
+        if not isinstance(domain, AffineSpace_generic) and not isinstance(domain, AlgebraicScheme_subscheme_affine):
             raise ValueError('"domain" must be an affine scheme')
 
         if R not in Fields():
             return typecall(cls, polys, domain)
-        if is_FiniteField(R):
-                return DynamicalSystem_affine_finite_field(polys, domain)
+        if isinstance(R, FiniteField):
+            return DynamicalSystem_affine_finite_field(polys, domain)
         return DynamicalSystem_affine_field(polys, domain)
 
     def __init__(self, polys_or_rat_fncts, domain):
@@ -319,7 +320,8 @@ class DynamicalSystem_affine(SchemeMorphism_polynomial_affine_space,
         """
         L = polys_or_rat_fncts
         # Next attribute needed for _fast_eval and _fastpolys
-        self._is_prime_finite_field = is_PrimeFiniteField(L[0].base_ring())
+        R = L[0].base_ring()
+        self._is_prime_finite_field = isinstance(R, FiniteField) and R.is_prime_field()
         DynamicalSystem.__init__(self, L, domain)
 
     def __copy__(self):
@@ -397,10 +399,11 @@ class DynamicalSystem_affine(SchemeMorphism_polynomial_affine_space,
 
         ::
 
+            sage: # needs sage.rings.number_field
             sage: R.<a> = PolynomialRing(QQbar)
             sage: A.<x,y> = AffineSpace(R, 2)
-            sage: f = DynamicalSystem_affine([QQbar(sqrt(2))*x*y, a*x^2])
-            sage: f.homogenize(2)
+            sage: f = DynamicalSystem_affine([QQbar(sqrt(2))*x*y, a*x^2])               # needs sage.symbolic
+            sage: f.homogenize(2)                                                       # needs sage.symbolic
             Dynamical System of Projective Space of dimension 2 over Univariate
             Polynomial Ring in a over Algebraic Field
               Defn: Defined on coordinates by sending (x0 : x1 : x2) to
@@ -453,7 +456,7 @@ class DynamicalSystem_affine(SchemeMorphism_polynomial_affine_space,
 
             sage: A.<x> = AffineSpace(ZZ, 1)
             sage: f = DynamicalSystem_affine([(x^2+1)/x])
-            sage: f.dynatomic_polynomial(4)
+            sage: f.dynatomic_polynomial(4)                                             # needs sage.libs.pari
             2*x^12 + 18*x^10 + 57*x^8 + 79*x^6 + 48*x^4 + 12*x^2 + 1
 
         ::
@@ -507,8 +510,8 @@ class DynamicalSystem_affine(SchemeMorphism_polynomial_affine_space,
         ::
 
             sage: A.<x> = AffineSpace(CC,1)
-            sage: F = DynamicalSystem_affine([1/2*x^2 + CC(sqrt(3))])
-            sage: F.dynatomic_polynomial([1,1])
+            sage: F = DynamicalSystem_affine([1/2*x^2 + CC(sqrt(3))])                   # needs sage.symbolic
+            sage: F.dynatomic_polynomial([1,1])                                         # needs sage.symbolic
             (0.125000000000000*x^4 + 0.366025403784439*x^2 + 1.50000000000000)/(0.500000000000000*x^2 - x + 1.73205080756888)
 
         TESTS::
@@ -520,8 +523,8 @@ class DynamicalSystem_affine(SchemeMorphism_polynomial_affine_space,
             sage: G.dehomogenize(1).dynatomic_polynomial(2)
             (1/4*c + 1/4)*x^2 + (-c - 1/2)*x + c + 1
         """
-        from sage.schemes.affine.affine_space import is_AffineSpace
-        if not is_AffineSpace(self.domain()):
+        from sage.schemes.affine.affine_space import AffineSpace_generic
+        if not isinstance(self.domain(), AffineSpace_generic):
             raise NotImplementedError("not implemented for subschemes")
         if self.domain().dimension_relative() > 1:
             raise TypeError("does not make sense in dimension >1")
@@ -529,7 +532,8 @@ class DynamicalSystem_affine(SchemeMorphism_polynomial_affine_space,
         F = G.dynatomic_polynomial(period)
         T = G.domain().coordinate_ring()
         S = self.domain().coordinate_ring()
-        if is_SymbolicExpressionRing(F.parent()):
+        if isinstance(F.parent(), sage.rings.abc.SymbolicRing):
+            from sage.symbolic.ring import var
             u = var(self.domain().coordinate_ring().variable_name())
             return F.subs({F.variables()[0]:u,F.variables()[1]:1})
         elif T(F.denominator()).degree() == 0:
@@ -660,11 +664,11 @@ class DynamicalSystem_affine(SchemeMorphism_polynomial_affine_space,
         """
         n = int(n)
         if n == 0:
-            return(P)
+            return P
         Q = P
         for i in range(n):
             Q = self(Q)
-        return(Q)
+        return Q
 
     def orbit(self, P, n):
         r"""
@@ -717,7 +721,7 @@ class DynamicalSystem_affine(SchemeMorphism_polynomial_affine_space,
              ((-t^16 + 3*t^13 - 3*t^10 + t^7 + t^5 + t^3 - 1)/(t^5 + t^3 - 1), -t^9 - t^7 + t^4)]
         """
         Q = P
-        if isinstance(n, list) or isinstance(n, tuple):
+        if isinstance(n, (list, tuple)):
             bounds = list(n)
         else:
             bounds = [0,n]
@@ -727,7 +731,7 @@ class DynamicalSystem_affine(SchemeMorphism_polynomial_affine_space,
         for i in range(bounds[0]+1, bounds[1]+1):
             Q = self(Q)
             orb.append(Q)
-        return(orb)
+        return orb
 
     def multiplier(self, P, n, check=True):
         r"""
@@ -769,7 +773,7 @@ class DynamicalSystem_affine(SchemeMorphism_polynomial_affine_space,
 
             sage: P.<x> = AffineSpace(CC, 1)
             sage: f = DynamicalSystem_affine([x^2 + 1/2])
-            sage: f.multiplier(P([0.5 + 0.5*I]), 1)
+            sage: f.multiplier(P([0.5 + 0.5*I]), 1)                                     # needs sage.symbolic
             [1.00000000000000 + 1.00000000000000*I]
 
         ::
@@ -783,7 +787,7 @@ class DynamicalSystem_affine(SchemeMorphism_polynomial_affine_space,
         ::
 
             sage: P.<x,y> = AffineSpace(QQ, 2)
-            sage: X = P.subscheme([x^2-y^2])
+            sage: X = P.subscheme([x^2 - y^2])
             sage: f = DynamicalSystem_affine([x^2, y^2], domain=X)
             sage: f.multiplier(X([1, 1]), 1)
             [2 0]
@@ -822,7 +826,7 @@ class DynamicalSystem_affine(SchemeMorphism_polynomial_affine_space,
         EXAMPLES::
 
             sage: A.<t> = AffineSpace(QQ, 1)
-            sage: f = DynamicalSystem_affine([t^2+1])
+            sage: f = DynamicalSystem_affine([t^2 + 1])
             sage: f.conjugate(matrix([[1,2], [0,1]]))
             Dynamical System of Affine Space of dimension 1 over Rational Field
               Defn: Defined on coordinates by sending (t) to
@@ -831,18 +835,20 @@ class DynamicalSystem_affine(SchemeMorphism_polynomial_affine_space,
         ::
 
             sage: A.<x,y> = AffineSpace(ZZ,2)
-            sage: f = DynamicalSystem_affine([x^3+y^3,y^2])
+            sage: f = DynamicalSystem_affine([x^3 + y^3, y^2])
             sage: f.conjugate(matrix([[1,2,3], [0,1,2], [0,0,1]]))
             Dynamical System of Affine Space of dimension 2 over Integer Ring
               Defn: Defined on coordinates by sending (x, y) to
-                    (x^3 + 6*x^2*y + 12*x*y^2 + 9*y^3 + 9*x^2 + 36*x*y + 40*y^2 + 27*x + 58*y + 28, y^2 + 4*y + 2)
+                    (x^3 + 6*x^2*y + 12*x*y^2 + 9*y^3
+                      + 9*x^2 + 36*x*y + 40*y^2 + 27*x + 58*y + 28, y^2 + 4*y + 2)
 
         ::
 
+            sage: # needs sage.rings.number_field
             sage: R.<x> = PolynomialRing(QQ)
-            sage: K.<i> = NumberField(x^2+1)
+            sage: K.<i> = NumberField(x^2 + 1)
             sage: A.<x> = AffineSpace(ZZ,1)
-            sage: f = DynamicalSystem_affine([x^3+2*x^2+3])
+            sage: f = DynamicalSystem_affine([x^3 + 2*x^2 + 3])
             sage: f.conjugate(matrix([[i,i], [0,-i]]))
             Dynamical System of Affine Space of dimension 1 over Integer Ring
               Defn: Defined on coordinates by sending (x) to
@@ -853,6 +859,36 @@ class DynamicalSystem_affine(SchemeMorphism_polynomial_affine_space,
         f = self.homogenize(d).conjugate(M)
         return f.dehomogenize(d)
 
+    def degree(self):
+        r"""
+        Return the degree of the affine dynamical system.
+
+        EXAMPLES::
+
+            sage: # needs sage.rings.number_field
+            sage: R.<c> = QuadraticField(7)
+            sage: A.<x,y,z> = AffineSpace(R, 3)
+            sage: f = DynamicalSystem_affine([x^2 + y^5 + c, x^11, z^19])
+            sage: f.degree()
+            19
+
+        ::
+
+            sage: R.<c> = QQ[]
+            sage: A.<x> = AffineSpace(R, 1)
+            sage: f = DynamicalSystem_affine([x^4])
+            sage: f.degree()
+            4
+
+        ::
+
+            sage: A.<x,y> = AffineSpace(QQ, 2)
+            sage: f = DynamicalSystem_affine([x, y/(1 + x^2)])
+            sage: f.degree()
+            2
+        """
+        return self.as_scheme_morphism().degree()
+
 class DynamicalSystem_affine_field(DynamicalSystem_affine,
                                    SchemeMorphism_polynomial_affine_space_field):
     @cached_method
@@ -881,9 +917,10 @@ class DynamicalSystem_affine_field(DynamicalSystem_affine,
 
         EXAMPLES::
 
+            sage: # needs sage.rings.number_field
             sage: K.<v> = QuadraticField(5)
             sage: A.<x,y> = AffineSpace(K, 2)
-            sage: f = DynamicalSystem_affine([x^2-y^2, y^2])
+            sage: f = DynamicalSystem_affine([x^2 - y^2, y^2])
             sage: f.weil_restriction()
             Dynamical System of Affine Space of dimension 4 over Rational Field
               Defn: Defined on coordinates by sending (z0, z1, z2, z3) to
@@ -891,6 +928,7 @@ class DynamicalSystem_affine_field(DynamicalSystem_affine,
 
         ::
 
+            sage: # needs sage.rings.number_field
             sage: K.<v> = QuadraticField(5)
             sage: PS.<x,y> = AffineSpace(K, 2)
             sage: f = DynamicalSystem_affine([x, y])
@@ -910,13 +948,14 @@ class DynamicalSystem_affine_field(DynamicalSystem_affine,
         The base field of the map could be strictly larger than
         the field where all of the coefficients are defined. This function
         reduces the base field to the minimal possible. This can be done when
-        the base ring is a number field, QQbar, a finite field, or algebraic
+        the base ring is a number field, ``QQbar``, a finite field, or algebraic
         closure of a finite field.
 
         OUTPUT: A dynamical system
 
         EXAMPLES::
 
+            sage: # needs sage.rings.finite_rings
             sage: K.<t> = GF(5^2)
             sage: A.<x,y> = AffineSpace(K, 2)
             sage: f = DynamicalSystem_affine([x^2 + 3*y^2, 3*y^2])
@@ -927,15 +966,20 @@ class DynamicalSystem_affine_field(DynamicalSystem_affine,
 
         ::
 
+            sage: # needs sage.rings.number_field sage.symbolic
             sage: A.<x,y> = AffineSpace(QQbar, 2)
-            sage: f = DynamicalSystem_affine([x^2 + QQbar(sqrt(3))*y^2, QQbar(sqrt(-1))*y^2])
+            sage: f = DynamicalSystem_affine([x^2 + QQbar(sqrt(3))*y^2,
+            ....:                             QQbar(sqrt(-1))*y^2])
             sage: f.reduce_base_field()
-            Dynamical System of Affine Space of dimension 2 over Number Field in a with defining polynomial y^4 - y^2 + 1 with a = -0.866025403784439? + 0.50000000000000000?*I
+            Dynamical System of Affine Space of dimension 2 over Number Field in a
+             with defining polynomial y^4 - y^2 + 1
+             with a = -0.866025403784439? + 0.50000000000000000?*I
               Defn: Defined on coordinates by sending (x, y) to
                     (x^2 + (a^3 - 2*a)*y^2, (a^3)*y^2)
 
         ::
 
+            sage: # needs sage.rings.number_field
             sage: K.<v> = CyclotomicField(5)
             sage: A.<x,y> = AffineSpace(K, 2)
             sage: f = DynamicalSystem_affine([(3*x^2 + y) / (5*x), (y^2+1) / (x+y)])
@@ -971,6 +1015,7 @@ class DynamicalSystem_affine_finite_field(DynamicalSystem_affine_field,
 
         ::
 
+            sage: # needs sage.rings.finite_rings
             sage: A.<x,y,z> = AffineSpace(GF(49, 't'), 3)
             sage: f = DynamicalSystem_affine([x^2 - z, x - y + z, y^2 - x^2])
             sage: f.orbit_structure(A(1, 1, 2))
@@ -979,12 +1024,12 @@ class DynamicalSystem_affine_finite_field(DynamicalSystem_affine_field,
         orbit = []
         index = 1
         Q = P
-        while not Q in orbit:
+        while Q not in orbit:
             orbit.append(Q)
             Q = self(Q)
             index += 1
         I = orbit.index(Q)
-        return([I, index-I-1])
+        return [I, index - I - 1]
 
     def cyclegraph(self):
         r"""
@@ -998,29 +1043,30 @@ class DynamicalSystem_affine_finite_field(DynamicalSystem_affine_field,
         EXAMPLES::
 
             sage: P.<x,y> = AffineSpace(GF(5), 2)
-            sage: f = DynamicalSystem_affine([x^2-y, x*y+1])
-            sage: f.cyclegraph()
+            sage: f = DynamicalSystem_affine([x^2 - y, x*y + 1])
+            sage: f.cyclegraph()                                                        # needs sage.graphs
             Looped digraph on 25 vertices
 
         ::
 
+            sage: # needs sage.rings.finite_rings
             sage: P.<x> = AffineSpace(GF(3^3, 't'), 1)
-            sage: f = DynamicalSystem_affine([x^2-1])
-            sage: f.cyclegraph()
+            sage: f = DynamicalSystem_affine([x^2 - 1])
+            sage: f.cyclegraph()                                                        # needs sage.graphs
             Looped digraph on 27 vertices
 
         ::
 
             sage: P.<x,y> = AffineSpace(GF(7), 2)
-            sage: X = P.subscheme(x-y)
+            sage: X = P.subscheme(x - y)
             sage: f = DynamicalSystem_affine([x^2, y^2], domain=X)
-            sage: f.cyclegraph()
+            sage: f.cyclegraph()                                                        # needs sage.graphs
             Looped digraph on 7 vertices
         """
         V = []
         E = []
-        from sage.schemes.affine.affine_space import is_AffineSpace
-        if is_AffineSpace(self.domain()):
+        from sage.schemes.affine.affine_space import AffineSpace_generic
+        if isinstance(self.domain(), AffineSpace_generic):
             for P in self.domain():
                 V.append(str(P))
                 Q = self(P)
