@@ -12,15 +12,16 @@ AUTHORS:
 
 EXAMPLES:
 
-Examples from :trac:`9908`::
+Examples from :issue:`9908`::
 
+    sage: # needs sage.symbolic
     sage: maxima('integrate(bessel_j(2, x), x)').sage()
     1/24*x^3*hypergeometric((3/2,), (5/2, 3), -1/4*x^2)
     sage: sum(((2*I)^x/(x^3 + 1)*(1/4)^x), x, 0, oo)
     hypergeometric((1, 1, -1/2*I*sqrt(3) - 1/2, 1/2*I*sqrt(3) - 1/2),...
     (2, -1/2*I*sqrt(3) + 1/2, 1/2*I*sqrt(3) + 1/2), 1/2*I)
     sage: res = sum((-1)^x/((2*x + 1)*factorial(2*x + 1)), x, 0, oo)
-    sage: res  # not tested - depends on maxima version
+    sage: res                                   # not tested (depends on maxima version)
     hypergeometric((1/2,), (3/2, 3/2), -1/4)
     sage: res in [hypergeometric((1/2,), (3/2, 3/2), -1/4), sin_integral(1)]
     True
@@ -28,6 +29,7 @@ Examples from :trac:`9908`::
 Simplification (note that ``simplify_full`` does not yet call
 ``simplify_hypergeometric``)::
 
+    sage: # needs sage.symbolic
     sage: hypergeometric([-2], [], x).simplify_hypergeometric()
     x^2 - 2*x + 1
     sage: hypergeometric([], [], x).simplify_hypergeometric()
@@ -41,14 +43,15 @@ Simplification (note that ``simplify_full`` does not yet call
 
 Equality testing::
 
-    sage: bool(hypergeometric([], [], x).derivative(x) ==
+    sage: bool(hypergeometric([], [], x).derivative(x) ==                               # needs sage.symbolic
     ....:      hypergeometric([], [], x))  # diff(e^x, x) == e^x
     True
-    sage: bool(hypergeometric([], [], x) == hypergeometric([], [1], x))
+    sage: bool(hypergeometric([], [], x) == hypergeometric([], [1], x))                 # needs sage.symbolic
     False
 
 Computing terms and series::
 
+    sage: # needs sage.symbolic
     sage: var('z')
     z
     sage: hypergeometric([], [], z).series(z, 0)
@@ -60,6 +63,7 @@ Computing terms and series::
     sage: hypergeometric([], [], z).series(z, 3)
     1 + 1*z + 1/2*z^2 + Order(z^3)
 
+    sage: # needs sage.symbolic
     sage: hypergeometric([-2], [], z).series(z, 3)
     1 + (-2)*z + 1*z^2
     sage: hypergeometric([-2], [], z).series(z, 6)
@@ -71,33 +75,35 @@ Computing terms and series::
     sage: hypergeometric([-2], [], z).series(z, 2).is_terminating_series()
     False
 
-    sage: hypergeometric([1], [], z).series(z, 6)
+    sage: hypergeometric([1], [], z).series(z, 6)                                       # needs sage.symbolic
     1 + 1*z + 1*z^2 + 1*z^3 + 1*z^4 + 1*z^5 + Order(z^6)
-    sage: hypergeometric([], [1/2], -z^2/4).series(z, 11)
+    sage: hypergeometric([], [1/2], -z^2/4).series(z, 11)                               # needs sage.symbolic
     1 + (-1/2)*z^2 + 1/24*z^4 + (-1/720)*z^6 + 1/40320*z^8 +...
     (-1/3628800)*z^10 + Order(z^11)
 
-    sage: hypergeometric([1], [5], x).series(x, 5)
+    sage: hypergeometric([1], [5], x).series(x, 5)                                      # needs sage.symbolic
     1 + 1/5*x + 1/30*x^2 + 1/210*x^3 + 1/1680*x^4 + Order(x^5)
 
-    sage: sum(hypergeometric([1, 2], [3], 1/3).terms(6)).n()
+    sage: sum(hypergeometric([1, 2], [3], 1/3).terms(6)).n()                            # needs sage.symbolic
     1.29788359788360
-    sage: hypergeometric([1, 2], [3], 1/3).n()
+    sage: hypergeometric([1, 2], [3], 1/3).n()                                          # needs sage.symbolic
     1.29837194594696
-    sage: hypergeometric([], [], x).series(x, 20)(x=1).n() == e.n()
+    sage: hypergeometric([], [], x).series(x, 20)(x=1).n() == e.n()                     # needs sage.symbolic
     True
 
 Plotting::
 
+    sage: # needs sage.symbolic
     sage: f(x) = hypergeometric([1, 1], [3, 3, 3], x)
-    sage: plot(f, x, -30, 30)
+    sage: plot(f, x, -30, 30)                                                           # needs sage.plot
     Graphics object consisting of 1 graphics primitive
     sage: g(x) = hypergeometric([x], [], 2)
-    sage: complex_plot(g, (-1, 1), (-1, 1))
+    sage: complex_plot(g, (-1, 1), (-1, 1))                                             # needs sage.plot
     Graphics object consisting of 1 graphics primitive
 
 Numeric evaluation::
 
+    sage: # needs sage.symbolic
     sage: hypergeometric([1], [], 1/10).n()  # geometric series
     1.11111111111111
     sage: hypergeometric([], [], 1).n()  # e
@@ -115,42 +121,42 @@ Numeric evaluation::
 
 Conversions::
 
-    sage: maxima(hypergeometric([1, 1, 1], [3, 3, 3], x))
+    sage: maxima(hypergeometric([1, 1, 1], [3, 3, 3], x))                               # needs sage.symbolic
     hypergeometric([1,1,1],[3,3,3],_SAGE_VAR_x)
-    sage: hypergeometric((5, 4), (4, 4), 3)._sympy_()
+    sage: hypergeometric((5, 4), (4, 4), 3)._sympy_()                                   # needs sympy sage.symbolic
     hyper((5, 4), (4, 4), 3)
-    sage: hypergeometric((5, 4), (4, 4), 3)._mathematica_init_()
+    sage: hypergeometric((5, 4), (4, 4), 3)._mathematica_init_()                        # needs sage.symbolic
     'HypergeometricPFQ[{5,4},{4,4},3]'
 
 Arbitrary level of nesting for conversions::
 
-    sage: maxima(nest(lambda y: hypergeometric([y], [], x), 3, 1))
+    sage: maxima(nest(lambda y: hypergeometric([y], [], x), 3, 1))                      # needs sage.symbolic
     1/(1-_SAGE_VAR_x)^(1/(1-_SAGE_VAR_x)^(1/(1-_SAGE_VAR_x)))
-    sage: maxima(nest(lambda y: hypergeometric([y], [3], x), 3, 1))._sage_()
+    sage: maxima(nest(lambda y: hypergeometric([y], [3], x), 3, 1))._sage_()            # needs sage.symbolic
     hypergeometric((hypergeometric((hypergeometric((1,), (3,), x),), (3,),...
     x),), (3,), x)
-    sage: nest(lambda y: hypergeometric([y], [], x), 3, 1)._mathematica_init_()
+    sage: nest(lambda y: hypergeometric([y], [], x), 3, 1)._mathematica_init_()         # needs sage.symbolic
     'HypergeometricPFQ[{HypergeometricPFQ[{HypergeometricPFQ[{1},{},x]},...
 
 The confluent hypergeometric functions can arise as solutions to second-order
 differential equations (example from `here <http://ask.sagemath.org/question/
 1168/how-can-one-use-maxima-kummer-confluent-functions>`_)::
 
-    sage: var('m')
+    sage: var('m')                                                                      # needs sage.symbolic
     m
-    sage: y = function('y')(x)
-    sage: desolve(diff(y, x, 2) + 2*x*diff(y, x) - 4*m*y, y,
+    sage: y = function('y')(x)                                                          # needs sage.symbolic
+    sage: desolve(diff(y, x, 2) + 2*x*diff(y, x) - 4*m*y, y,                            # needs sage.symbolic
     ....:         contrib_ode=true, ivar=x)
     [y(x) == _K1*hypergeometric_M(-m, 1/2, -x^2) +...
      _K2*hypergeometric_U(-m, 1/2, -x^2)]
 
 Series expansions of confluent hypergeometric functions::
 
-    sage: hypergeometric_M(2, 2, x).series(x, 3)
+    sage: hypergeometric_M(2, 2, x).series(x, 3)                                        # needs sage.symbolic
     1 + 1*x + 1/2*x^2 + Order(x^3)
-    sage: hypergeometric_U(2, 2, x).series(x == 3, 100).subs(x=1).n()
+    sage: hypergeometric_U(2, 2, x).series(x == 3, 100).subs(x=1).n()                   # needs sage.symbolic
     0.403652637676806
-    sage: hypergeometric_U(2, 2, 1).n()
+    sage: hypergeometric_U(2, 2, 1).n()                                                 # needs mpmath sage.symbolic
     0.403652637676806
 """
 
@@ -174,18 +180,24 @@ from sage.functions.gamma import gamma
 from sage.functions.hyperbolic import cosh, sinh
 from sage.functions.log import exp, log
 from sage.functions.other import sqrt, real_part
-from sage.libs.mpmath import utils as mpmath_utils
-from sage.misc.latex import latex
+from sage.misc.lazy_import import lazy_import
 from sage.misc.misc_c import prod
 from sage.rings.infinity import Infinity
 from sage.rings.integer import Integer
 from sage.rings.integer_ring import ZZ
 from sage.rings.rational_field import QQ
-from sage.structure.element import get_coercion_model
-from sage.symbolic.constants import pi
-from sage.symbolic.expression import Expression
+from sage.structure.element import Expression, get_coercion_model
 from sage.symbolic.function import BuiltinFunction
-from sage.symbolic.ring import SR
+
+lazy_import('sage.misc.latex', 'latex')
+
+lazy_import('sage.symbolic.constants', 'pi')
+lazy_import('sage.symbolic.ring', 'SR')
+
+lazy_import('sage.libs.mpmath.utils', 'call', as_='_mpmath_utils_call')
+lazy_import('mpmath', 'hyp1f1', as_='_mpmath_hyp1f1')
+lazy_import('mpmath', 'hyper', as_='_mpmath_hyper')
+lazy_import('mpmath', 'hyperu', as_='_mpmath_hyperu')
 
 
 def rational_param_as_tuple(x):
@@ -200,7 +212,7 @@ def rational_param_as_tuple(x):
         (1, 2)
         sage: rational_param_as_tuple(3)
         3
-        sage: rational_param_as_tuple(pi)
+        sage: rational_param_as_tuple(pi)                                               # needs sage.symbolic
         pi
     """
     try:
@@ -237,7 +249,7 @@ class Hypergeometric(BuiltinFunction):
 
         EXAMPLES::
 
-            sage: maxima(hypergeometric)
+            sage: maxima(hypergeometric)                                                # needs sage.symbolic
             hypergeometric
 
         TESTS::
@@ -268,6 +280,7 @@ class Hypergeometric(BuiltinFunction):
 
         EXAMPLES::
 
+            sage: # needs sage.symbolic
             sage: hypergeometric([], [], 1)
             hypergeometric((), (), 1)
             sage: hypergeometric([], [1], 1)
@@ -292,7 +305,7 @@ class Hypergeometric(BuiltinFunction):
         r"""
         TESTS::
 
-            sage: latex(hypergeometric([1, 1], [2], -1))
+            sage: latex(hypergeometric([1, 1], [2], -1))                                # needs sage.symbolic
             \,_2F_1\left(\begin{matrix} 1,1 \\ 2 \end{matrix} ; -1 \right)
 
         """
@@ -306,7 +319,7 @@ class Hypergeometric(BuiltinFunction):
         """
         EXAMPLES::
 
-            sage: hypergeometric([], [], 0)
+            sage: hypergeometric([], [], 0)                                             # needs sage.symbolic
             1
         """
         if not isinstance(a, tuple) or not isinstance(b, tuple):
@@ -329,12 +342,12 @@ class Hypergeometric(BuiltinFunction):
 
         EXAMPLES::
 
-            sage: hypergeometric._evalf_try_((1.0,), (2.0,), 3.0)
+            sage: hypergeometric._evalf_try_((1.0,), (2.0,), 3.0)                       # needs mpmath
             6.36184564106256
-            sage: hypergeometric._evalf_try_((1.0, 1), (), 3.0)
+            sage: hypergeometric._evalf_try_((1.0, 1), (), 3.0)                         # needs mpmath
             -0.0377593153441588 + 0.750349833788561*I
             sage: hypergeometric._evalf_try_((1, 1), (), 3)    # exact input
-            sage: hypergeometric._evalf_try_((x,), (), 1.0)    # symbolic
+            sage: hypergeometric._evalf_try_((x,), (), 1.0)    # symbolic               # needs sage.symbolic
             sage: hypergeometric._evalf_try_(1.0, 2.0, 3.0)    # not tuples
         """
         # We need to override this for hypergeometric functions since
@@ -353,32 +366,31 @@ class Hypergeometric(BuiltinFunction):
         """
         TESTS::
 
-            sage: hypergeometric([1, 1], [2], -1).n()
+            sage: hypergeometric([1, 1], [2], -1).n()                                   # needs sage.symbolic
             0.693147180559945
-            sage: hypergeometric([], [], RealField(100)(1))
+            sage: hypergeometric([], [], RealField(100)(1))                             # needs sage.rings.real_mpfr sage.symbolic
             2.7182818284590452353602874714
 
         """
         if not isinstance(a, tuple) or not isinstance(b, tuple):
             raise TypeError("The first two parameters must be of type list")
-        from mpmath import hyper
         aa = [rational_param_as_tuple(c) for c in a]
         bb = [rational_param_as_tuple(c) for c in b]
-        return mpmath_utils.call(hyper, aa, bb, z, parent=parent)
+        return _mpmath_utils_call(_mpmath_hyper, aa, bb, z, parent=parent)
 
     def _tderivative_(self, a, b, z, *args, **kwargs):
         """
         EXAMPLES::
 
-            sage: hypergeometric([1/3, 2/3], [5], x^2).diff(x)
+            sage: hypergeometric([1/3, 2/3], [5], x^2).diff(x)                          # needs sage.symbolic
             4/45*x*hypergeometric((4/3, 5/3), (6,), x^2)
-            sage: hypergeometric([1, 2], [x], 2).diff(x)
+            sage: hypergeometric([1, 2], [x], 2).diff(x)                                # needs sage.symbolic
             Traceback (most recent call last):
             ...
             NotImplementedError: derivative of hypergeometric function with...
             respect to parameters. Try calling .simplify_hypergeometric()...
             first.
-            sage: hypergeometric([1/3, 2/3], [5], 2).diff(x)
+            sage: hypergeometric([1/3, 2/3], [5], 2).diff(x)                            # needs sage.symbolic
             0
         """
         diff_param = kwargs['diff_param']
@@ -404,16 +416,17 @@ class Hypergeometric(BuiltinFunction):
 
             EXAMPLES::
 
+                sage: # needs sage.symbolic
                 sage: h = hypergeometric([], [], x)
                 sage: from sage.ext.fast_callable import ExpressionTreeBuilder
                 sage: etb = ExpressionTreeBuilder(vars=['x'])
                 sage: h._fast_callable_(etb)
                 {hypergeometric((), (), x)}(v_0)
 
-                sage: var('x, y')
+                sage: var('x, y')                                                       # needs sage.symbolic
                 (x, y)
-                sage: f = fast_callable(hypergeometric([y], [], x), vars=[x, y])
-                sage: f(3, 4)
+                sage: f = fast_callable(hypergeometric([y], [], x), vars=[x, y])        # needs sage.symbolic
+                sage: f(3, 4)                                                           # needs sage.symbolic
                 hypergeometric((4,), (), 3)
             """
             return etb.call(self, *map(etb.var, etb._vars))
@@ -424,7 +437,7 @@ class Hypergeometric(BuiltinFunction):
 
             EXAMPLES::
 
-                sage: hypergeometric([2, 1, 3], [5, 4],
+                sage: hypergeometric([2, 1, 3], [5, 4],                                 # needs sage.symbolic
                 ....:                1/2).sorted_parameters()
                 hypergeometric((1, 2, 3), (4, 5), 1/2)
             """
@@ -437,12 +450,12 @@ class Hypergeometric(BuiltinFunction):
 
             EXAMPLES::
 
-                sage: hypergeometric([1, 1, 2, 5], [5, 1, 4],
+                sage: hypergeometric([1, 1, 2, 5], [5, 1, 4],                           # needs sage.symbolic
                 ....:                1/2).eliminate_parameters()
                 hypergeometric((1, 2), (4,), 1/2)
-                sage: hypergeometric([x], [x], x).eliminate_parameters()
+                sage: hypergeometric([x], [x], x).eliminate_parameters()                # needs sage.symbolic
                 hypergeometric((), (), x)
-                sage: hypergeometric((5, 4), (4, 4), 3).eliminate_parameters()
+                sage: hypergeometric((5, 4), (4, 4), 3).eliminate_parameters()          # needs sage.symbolic
                 hypergeometric((5,), (4,), 3)
             """
             aa = list(a)  # tuples are immutable
@@ -475,6 +488,7 @@ class Hypergeometric(BuiltinFunction):
 
             EXAMPLES::
 
+                sage: # needs sage.symbolic
                 sage: hypergeometric([2], [3, 4], 5).is_termwise_finite()
                 True
                 sage: hypergeometric([2], [-3, 4], 5).is_termwise_finite()
@@ -485,6 +499,7 @@ class Hypergeometric(BuiltinFunction):
                 ....:                5).is_termwise_finite()  # ambiguous
                 False
 
+                sage: # needs sage.symbolic
                 sage: hypergeometric([0], [-1], 5).is_termwise_finite()
                 True
                 sage: hypergeometric([0], [0],
@@ -525,11 +540,11 @@ class Hypergeometric(BuiltinFunction):
 
             EXAMPLES::
 
-                sage: hypergeometric([1, 2], [3, 4], x).is_terminating()
+                sage: hypergeometric([1, 2], [3, 4], x).is_terminating()                # needs sage.symbolic
                 False
-                sage: hypergeometric([1, -2], [3, 4], x).is_terminating()
+                sage: hypergeometric([1, -2], [3, 4], x).is_terminating()               # needs sage.symbolic
                 True
-                sage: hypergeometric([1, -2], [], x).is_terminating()
+                sage: hypergeometric([1, -2], [], x).is_terminating()                   # needs sage.symbolic
                 True
             """
             if z == 0:
@@ -548,18 +563,19 @@ class Hypergeometric(BuiltinFunction):
 
             Degree giving infinite radius of convergence::
 
-                sage: hypergeometric([2, 3], [4, 5],
+                sage: hypergeometric([2, 3], [4, 5],                                    # needs sage.symbolic
                 ....:                6).is_absolutely_convergent()
                 True
-                sage: hypergeometric([2, 3], [-4, 5],
+                sage: hypergeometric([2, 3], [-4, 5],                                   # needs sage.symbolic
                 ....:                6).is_absolutely_convergent()  # undefined
                 False
-                sage: (hypergeometric([2, 3], [-4, 5], Infinity)
+                sage: (hypergeometric([2, 3], [-4, 5], Infinity)                        # needs sage.symbolic
                 ....:  .is_absolutely_convergent())  # undefined
                 False
 
             Ordinary geometric series (unit radius of convergence)::
 
+                sage: # needs sage.symbolic
                 sage: hypergeometric([1], [], 1/2).is_absolutely_convergent()
                 True
                 sage: hypergeometric([1], [], 2).is_absolutely_convergent()
@@ -573,6 +589,7 @@ class Hypergeometric(BuiltinFunction):
 
             Degree `p = q+1` (unit radius of convergence)::
 
+                sage: # needs sage.symbolic
                 sage: hypergeometric([2, 3], [4], 6).is_absolutely_convergent()
                 False
                 sage: hypergeometric([2, 3], [4], 1).is_absolutely_convergent()
@@ -596,13 +613,13 @@ class Hypergeometric(BuiltinFunction):
 
             Degree giving zero radius of convergence::
 
-                sage: hypergeometric([1, 2, 3], [4],
+                sage: hypergeometric([1, 2, 3], [4],                                    # needs sage.symbolic
                 ....:                2).is_absolutely_convergent()
                 False
-                sage: hypergeometric([1, 2, 3], [4],
+                sage: hypergeometric([1, 2, 3], [4],                                    # needs sage.symbolic
                 ....:                1/2).is_absolutely_convergent()
                 False
-                sage: (hypergeometric([1, 2, -3], [4], 1/2)
+                sage: (hypergeometric([1, 2, -3], [4], 1/2)                             # needs sage.symbolic
                 ....:  .is_absolutely_convergent())  # polynomial
                 True
             """
@@ -627,11 +644,11 @@ class Hypergeometric(BuiltinFunction):
 
             EXAMPLES::
 
-                sage: list(hypergeometric([-2, 1], [3, 4], x).terms())
+                sage: list(hypergeometric([-2, 1], [3, 4], x).terms())                  # needs sage.symbolic
                 [1, -1/6*x, 1/120*x^2]
-                sage: list(hypergeometric([-2, 1], [3, 4], x).terms(2))
+                sage: list(hypergeometric([-2, 1], [3, 4], x).terms(2))                 # needs sage.symbolic
                 [1, -1/6*x]
-                sage: list(hypergeometric([-2, 1], [3, 4], x).terms(0))
+                sage: list(hypergeometric([-2, 1], [3, 4], x).terms(0))                 # needs sage.symbolic
                 []
             """
             if n is None:
@@ -658,9 +675,9 @@ class Hypergeometric(BuiltinFunction):
 
             EXAMPLES::
 
+                sage: # needs sage.symbolic
                 sage: x = hypergeometric([6, 1], [3, 4, 5], 10)
-                sage: y = x.deflated()
-                sage: y
+                sage: y = x.deflated(); y
                 1/252*hypergeometric((4,), (7, 8), 10)
                  + 1/12*hypergeometric((3,), (6, 7), 10)
                  + 1/2*hypergeometric((2,), (5, 6), 10)
@@ -669,9 +686,9 @@ class Hypergeometric(BuiltinFunction):
                 2.87893612686782
                 2.87893612686782
 
+                sage: # needs sage.symbolic
                 sage: x = hypergeometric([6, 7], [3, 4, 5], 10)
-                sage: y = x.deflated()
-                sage: y
+                sage: y = x.deflated(); y
                 25/27216*hypergeometric((), (11,), 10)
                  + 25/648*hypergeometric((), (10,), 10)
                  + 265/504*hypergeometric((), (9,), 10)
@@ -691,9 +708,9 @@ class Hypergeometric(BuiltinFunction):
 
             EXAMPLES::
 
+                sage: # needs sage.symbolic
                 sage: x = hypergeometric([5], [4], 3)
-                sage: y = x.deflated()
-                sage: y
+                sage: y = x.deflated(); y
                 7/4*hypergeometric((), (), 3)
                 sage: x.n(); y.n()
                 35.1496896155784
@@ -748,6 +765,7 @@ def closed_form(hyp):
 
     EXAMPLES::
 
+        sage: # needs sage.symbolic
         sage: from sage.functions.hypergeometric import closed_form
         sage: var('a b c z')
         (a, b, c, z)
@@ -939,26 +957,29 @@ class Hypergeometric_M(BuiltinFunction):
 
     EXAMPLES::
 
+
+        sage: hypergeometric_M(1, 1, 1.)                                                # needs mpmath
+        2.71828182845905
+
+        sage: # needs sage.symbolic
         sage: hypergeometric_M(1, 1, 1)
         hypergeometric_M(1, 1, 1)
-        sage: hypergeometric_M(1, 1, 1.)
-        2.71828182845905
-        sage: hypergeometric_M(1, 1, 1).n(70)
+        sage: hypergeometric_M(1, 1, 1).n(70)                                           # needs mpmath
         2.7182818284590452354
         sage: hypergeometric_M(1, 1, 1).simplify_hypergeometric()
         e
-        sage: hypergeometric_M(1, 1/2, x).simplify_hypergeometric()
-        (-I*sqrt(pi)*x*erf(I*sqrt(-x))*e^x + sqrt(-x))/sqrt(-x)
         sage: hypergeometric_M(1, 3/2, 1).simplify_hypergeometric()
         1/2*sqrt(pi)*erf(1)*e
+        sage: hypergeometric_M(1, 1/2, x).simplify_hypergeometric()
+        (-I*sqrt(pi)*x*erf(I*sqrt(-x))*e^x + sqrt(-x))/sqrt(-x)
     """
     def __init__(self):
         r"""
         TESTS::
 
-            sage: maxima(hypergeometric_M(1,1,x))
+            sage: maxima(hypergeometric_M(1,1,x))                                       # needs sage.symbolic
             kummer_m(1,1,_SAGE_VAR_x)
-            sage: latex(hypergeometric_M(1,1,x))
+            sage: latex(hypergeometric_M(1,1,x))                                        # needs sage.symbolic
             M\left(1, 1, x\right)
         """
         BuiltinFunction.__init__(self, 'hypergeometric_M', nargs=3,
@@ -973,8 +994,8 @@ class Hypergeometric_M(BuiltinFunction):
         """
         TESTS::
 
-            sage: (a,b)=var('a,b')
-            sage: hypergeometric_M(a,b,0)
+            sage: a, b = var('a,b')                                                     # needs sage.symbolic
+            sage: hypergeometric_M(a, b, 0)                                             # needs sage.symbolic
             1
         """
         if not isinstance(z, Expression) and z == 0:
@@ -985,19 +1006,18 @@ class Hypergeometric_M(BuiltinFunction):
         """
         TESTS::
 
-            sage: hypergeometric_M(1,1,1).n()
+            sage: hypergeometric_M(1,1,1).n()                                           # needs mpmath sage.symbolic
             2.71828182845905
         """
-        from mpmath import hyp1f1
-        return mpmath_utils.call(hyp1f1, a, b, z, parent=parent)
+        return _mpmath_utils_call(_mpmath_hyp1f1, a, b, z, parent=parent)
 
     def _derivative_(self, a, b, z, diff_param):
         """
         TESTS::
 
-            sage: diff(hypergeometric_M(1,1,x),x,3)
+            sage: diff(hypergeometric_M(1, 1, x), x, 3)                                 # needs sage.symbolic
             hypergeometric_M(4, 4, x)
-            sage: diff(hypergeometric_M(x,1,1),x,3)
+            sage: diff(hypergeometric_M(x, 1, 1), x, 3)                                 # needs sage.symbolic
             Traceback (most recent call last):
             ...
             NotImplementedError: derivative of hypergeometric function with respect to parameters
@@ -1014,9 +1034,9 @@ class Hypergeometric_M(BuiltinFunction):
 
             EXAMPLES::
 
-                sage: var('a b z')
+                sage: var('a b z')                                                      # needs sage.symbolic
                 (a, b, z)
-                sage: hypergeometric_M(a, b, z).generalized()
+                sage: hypergeometric_M(a, b, z).generalized()                           # needs sage.symbolic
                 hypergeometric((a,), (b,), z)
 
             """
@@ -1050,29 +1070,32 @@ class Hypergeometric_U(BuiltinFunction):
 
     EXAMPLES::
 
+        sage: # needs mpmath
         sage: hypergeometric_U(1, 1, 1)
         hypergeometric_U(1, 1, 1)
         sage: hypergeometric_U(1, 1, 1.)
         0.596347362323194
-        sage: hypergeometric_U(1, 1, 1).n(70)
+
+        sage: # needs sage.symbolic
+        sage: hypergeometric_U(1, 1, 1).n(70)                                           # needs mpmath
         0.59634736232319407434
-        sage: hypergeometric_U(10^4, 1/3, 1).n()
+        sage: hypergeometric_U(10^4, 1/3, 1).n()                                        # needs sage.libs.pari
         6.60377008885811e-35745
-        sage: hypergeometric_U(2 + I, 2, 1).n()
-        0.183481989942099 - 0.458685959185190*I
-        sage: hypergeometric_U(1, 3, x).simplify_hypergeometric()
-        (x + 1)/x^2
         sage: hypergeometric_U(1, 2, 2).simplify_hypergeometric()
         1/2
 
+        sage: hypergeometric_U(2 + I, 2, 1).n()                                         # needs sage.symbolic
+        0.183481989942099 - 0.458685959185190*I
+        sage: hypergeometric_U(1, 3, x).simplify_hypergeometric()                       # needs sage.symbolic
+        (x + 1)/x^2
     """
     def __init__(self):
         r"""
         TESTS::
 
-            sage: maxima(hypergeometric_U(1,1,x))
+            sage: maxima(hypergeometric_U(1, 1, x))                                     # needs sage.symbolic
             kummer_u(1,1,_SAGE_VAR_x)
-            sage: latex(hypergeometric_U(1,1,x))
+            sage: latex(hypergeometric_U(1, 1, x))                                      # needs sage.symbolic
             U\left(1, 1, x\right)
         """
         BuiltinFunction.__init__(self, 'hypergeometric_U', nargs=3,
@@ -1090,19 +1113,18 @@ class Hypergeometric_U(BuiltinFunction):
         """
         TESTS::
 
-            sage: hypergeometric_U(1,1,1).n()
+            sage: hypergeometric_U(1, 1, 1).n()                                         # needs mpmath sage.symbolic
             0.596347362323194
         """
-        from mpmath import hyperu
-        return mpmath_utils.call(hyperu, a, b, z, parent=parent)
+        return _mpmath_utils_call(_mpmath_hyperu, a, b, z, parent=parent)
 
     def _derivative_(self, a, b, z, diff_param):
         """
         TESTS::
 
-            sage: diff(hypergeometric_U(1,1,x),x,3)
+            sage: diff(hypergeometric_U(1, 1, x), x, 3)                                 # needs sage.symbolic
             -6*hypergeometric_U(4, 4, x)
-            sage: diff(hypergeometric_U(x,1,1),x,3)
+            sage: diff(hypergeometric_U(x, 1, 1), x, 3)                                 # needs sage.symbolic
             Traceback (most recent call last):
             ...
             NotImplementedError: derivative of hypergeometric function with respect to parameters
@@ -1119,6 +1141,7 @@ class Hypergeometric_U(BuiltinFunction):
 
             EXAMPLES::
 
+                sage: # needs sage.symbolic
                 sage: var('a b z')
                 (a, b, z)
                 sage: hypergeometric_U(a, b, z).generalized()
