@@ -141,15 +141,27 @@ AUTHORS:
 # ****************************************************************************
 
 import sage.rings.abc
-from sage.rings.integer import Integer
-from sage.misc.latex import latex
-from sage.rings.integer_ring import ZZ
-from sage.symbolic.constants import pi
-from sage.symbolic.function import BuiltinFunction
-from sage.libs.mpmath import utils as mpmath_utils
-from sage.functions.all import sin, cot, exp
+
 from sage.misc.functional import sqrt
-from sage.symbolic.constants import I
+from sage.misc.lazy_import import lazy_import
+from sage.rings.integer import Integer
+from sage.rings.integer_ring import ZZ
+from sage.structure.element import parent as s_parent
+from sage.symbolic.function import BuiltinFunction
+
+lazy_import('sage.functions.jacobi', 'jacobi_am_f')
+lazy_import('sage.functions.log', ['exp'])
+lazy_import('sage.functions.trig', ['sin', 'cot'])
+
+lazy_import('sage.misc.latex', 'latex')
+
+lazy_import('sage.symbolic.constants', ['I', 'pi'])
+
+lazy_import('sage.libs.mpmath.utils', 'call', as_='_mpmath_utils_call')
+lazy_import('mpmath',
+            ['spherharm', 'ellipe', 'ellipf', 'ellipk', 'ellippi'],
+            as_=['_mpmath_spherharm', '_mpmath_ellipe', '_mpmath_ellipf',
+                 '_mpmath_ellipk', '_mpmath_ellippi'])
 
 
 class SphericalHarmonic(BuiltinFunction):
@@ -161,6 +173,7 @@ class SphericalHarmonic(BuiltinFunction):
 
     EXAMPLES::
 
+        sage: # needs sage.symbolic
         sage: x, y = var('x, y')
         sage: spherical_harmonic(3, 2, x, y)
         1/8*sqrt(30)*sqrt(7)*cos(x)*e^(2*I*y)*sin(x)^2/sqrt(pi)
@@ -175,6 +188,7 @@ class SphericalHarmonic(BuiltinFunction):
 
     The degree `n` and the order `m` can be symbolic::
 
+        sage: # needs sage.symbolic
         sage: n, m = var('n m')
         sage: spherical_harmonic(n, m, x, y)
         spherical_harmonic(n, m, x, y)
@@ -189,26 +203,30 @@ class SphericalHarmonic(BuiltinFunction):
     The convention regarding the Condon-Shortley phase `(-1)^m` is the same
     as for SymPy's spherical harmonics and :wikipedia:`Spherical_harmonics`::
 
+        sage: # needs sage.symbolic
         sage: spherical_harmonic(1, 1, x, y)
         -1/4*sqrt(3)*sqrt(2)*e^(I*y)*sin(x)/sqrt(pi)
-        sage: from sympy import Ynm
-        sage: Ynm(1, 1, x, y).expand(func=True)
+        sage: from sympy import Ynm                                                     # needs sympy
+        sage: Ynm(1, 1, x, y).expand(func=True)                                         # needs sympy
         -sqrt(6)*exp(I*y)*sin(x)/(4*sqrt(pi))
-        sage: spherical_harmonic(1, 1, x, y) - Ynm(1, 1, x, y)
+        sage: spherical_harmonic(1, 1, x, y) - Ynm(1, 1, x, y)                          # needs sympy
         0
 
     It also agrees with SciPy's spherical harmonics::
 
-        sage: spherical_harmonic(1, 1, pi/2, pi).n()  # abs tol 1e-14
+        sage: spherical_harmonic(1, 1, pi/2, pi).n()  # abs tol 1e-14                   # needs sage.symbolic
         0.345494149471335
-        sage: from scipy.special import sph_harm  # NB: arguments x and y are swapped
-        sage: sph_harm(1, 1, pi.n(), (pi/2).n())  # abs tol 1e-14
+        sage: from scipy.special import sph_harm  # NB: arguments x and y are swapped   # needs scipy
+        sage: import numpy as np                                                        # needs scipy
+        sage: if int(np.version.short_version[0]) > 1:                                  # needs scipy
+        ....:     np.set_printoptions(legacy="1.25")                                    # needs scipy
+        sage: sph_harm(1, 1, pi.n(), (pi/2).n())  # abs tol 1e-14                       # needs scipy sage.symbolic
         (0.3454941494713355-4.231083042742082e-17j)
 
     Note that this convention differs from the one in Maxima, as revealed by
     the sign difference for odd values of `m`::
 
-        sage: maxima.spherical_harmonic(1, 1, x, y).sage()
+        sage: maxima.spherical_harmonic(1, 1, x, y).sage()                              # needs sage.symbolic
         1/2*sqrt(3/2)*e^(I*y)*sin(x)/sqrt(pi)
 
     It follows that, contrary to Maxima, SageMath uses the same sign convention
@@ -224,8 +242,8 @@ class SphericalHarmonic(BuiltinFunction):
         r"""
         TESTS::
 
-            sage: n, m, theta, phi = var('n m theta phi')
-            sage: spherical_harmonic(n, m, theta, phi)._sympy_()
+            sage: n, m, theta, phi = var('n m theta phi')                               # needs sage.symbolic
+            sage: spherical_harmonic(n, m, theta, phi)._sympy_()                        # needs sympy sage.symbolic
             Ynm(n, m, theta, phi)
         """
         BuiltinFunction.__init__(self, 'spherical_harmonic', nargs=4,
@@ -239,6 +257,7 @@ class SphericalHarmonic(BuiltinFunction):
         r"""
         TESTS::
 
+            sage: # needs sage.symbolic
             sage: x, y = var('x y')
             sage: spherical_harmonic(1, 2, x, y)
             0
@@ -253,30 +272,31 @@ class SphericalHarmonic(BuiltinFunction):
             sage: spherical_harmonic(3 + I, 2., 1, 2)
             -0.351154337307488 - 0.415562233975369*I
 
-        Check that :trac:`20939` is fixed::
+        Check that :issue:`20939` is fixed::
 
-            sage: ex = spherical_harmonic(3, 2, 1, 2*pi/3)
-            sage: QQbar(ex * sqrt(pi)/cos(1)/sin(1)^2).minpoly()
+            sage: ex = spherical_harmonic(3, 2, 1, 2*pi/3)                              # needs sage.symbolic
+            sage: QQbar(ex * sqrt(pi)/cos(1)/sin(1)^2).minpoly()                        # needs sage.rings.number_field sage.symbolic
             x^4 + 105/32*x^2 + 11025/1024
 
         Check whether Sage yields correct results compared to Maxima,
         up to the Condon-Shortley phase factor `(-1)^m`
-        (see :trac:`25034` and :trac:`33117`)::
+        (see :issue:`25034` and :issue:`33117`)::
 
-            sage: spherical_harmonic(1, 1, pi/3, pi/6).n() # abs tol 1e-14
+            sage: # needs sage.symbolic
+            sage: spherical_harmonic(1, 1, pi/3, pi/6).n()  # abs tol 1e-14
             -0.259120612103502 - 0.149603355150537*I
-            sage: maxima.spherical_harmonic(1, 1, pi/3, pi/6).n() # abs tol 1e-14
+            sage: maxima.spherical_harmonic(1, 1, pi/3, pi/6).n()  # abs tol 1e-14
             0.259120612103502 + 0.149603355150537*I
-            sage: spherical_harmonic(1, -1, pi/3, pi/6).n() # abs tol 1e-14
+            sage: spherical_harmonic(1, -1, pi/3, pi/6).n()  # abs tol 1e-14
             0.259120612103502 - 0.149603355150537*I
-            sage: maxima.spherical_harmonic(1, -1, pi/3, pi/6).n() # abs tol 1e-14
+            sage: maxima.spherical_harmonic(1, -1, pi/3, pi/6).n()  # abs tol 1e-14
             -0.259120612103502 + 0.149603355150537*I
 
-        Check that :trac:`33501` is fixed::
+        Check that :issue:`33501` is fixed::
 
-            sage: spherical_harmonic(2, 1, x, y)
+            sage: spherical_harmonic(2, 1, x, y)                                        # needs sage.symbolic
             -1/4*sqrt(6)*sqrt(5)*cos(x)*e^(I*y)*sin(x)/sqrt(pi)
-            sage: spherical_harmonic(5, -3, x, y)
+            sage: spherical_harmonic(5, -3, x, y)                                       # needs sage.symbolic
             -1/32*(9*sqrt(385)*sin(x)^4 - 8*sqrt(385)*sin(x)^2)*e^(-3*I*y)*sin(x)/sqrt(pi)
 
         """
@@ -298,9 +318,9 @@ class SphericalHarmonic(BuiltinFunction):
         r"""
         TESTS::
 
-            sage: spherical_harmonic(3 + I, 2, 1, 2).n(100)
+            sage: spherical_harmonic(3 + I, 2, 1, 2).n(100)                             # needs sage.symbolic
             -0.35115433730748836508201061672 - 0.41556223397536866209990358597*I
-            sage: spherical_harmonic(I, I, I, I).n()
+            sage: spherical_harmonic(I, I, I, I).n()                                    # needs sage.symbolic
             7.66678546069894 - 0.265754432549751*I
 
         Consistency with ``_eval_``::
@@ -308,28 +328,28 @@ class SphericalHarmonic(BuiltinFunction):
             sage: d = lambda a, b: abs(spherical_harmonic(a, b, 1., 2.)
             ....:                      - spherical_harmonic(a, b, 1, 2).n())
             sage: ab = [(0, 0), (1, -1), (1, 0), (1, 1), (3, 2), (3, 3)]
-            sage: all(d(a, b) < 1e-14 for a, b in ab)
+            sage: all(d(a, b) < 1e-14 for a, b in ab)                                   # needs sage.symbolic
             True
 
         """
-        from mpmath import spherharm
-        return mpmath_utils.call(spherharm, n, m, theta, phi, parent=parent)
+        return _mpmath_utils_call(_mpmath_spherharm, n, m, theta, phi, parent=parent)
 
     def _derivative_(self, n, m, theta, phi, diff_param):
         r"""
         TESTS::
 
+            sage: # needs sage.symbolic
             sage: n, m, theta, phi = var('n m theta phi')
             sage: Ynm = spherical_harmonic(n, m, theta, phi)
-            sage: DY_theta = Ynm.diff(theta)
-            sage: DY_theta
+            sage: DY_theta = Ynm.diff(theta); DY_theta
             m*cot(theta)*spherical_harmonic(n, m, theta, phi)
              + sqrt(-(m + n + 1)*(m - n))*e^(-I*phi)*spherical_harmonic(n, m + 1, theta, phi)
             sage: Ynm.diff(phi)
             I*m*spherical_harmonic(n, m, theta, phi)
 
-        Check that :trac:`33117` is fixed::
+        Check that :issue:`33117` is fixed::
 
+            sage: # needs sage.symbolic
             sage: DY_theta.subs({n: 1, m: 0})
             -1/2*sqrt(3)*sin(theta)/sqrt(pi)
             sage: Ynm.subs({n: 1, m: 0}).diff(theta)
@@ -365,8 +385,8 @@ class SphericalHarmonic(BuiltinFunction):
         r"""
         TESTS::
 
-            sage: y = var('y')
-            sage: latex(spherical_harmonic(3, 2, x, y, hold=True))
+            sage: y = var('y')                                                          # needs sage.symbolic
+            sage: latex(spherical_harmonic(3, 2, x, y, hold=True))                      # needs sage.symbolic
             Y_{3}^{2}\left(x, y\right)
         """
         return r"Y_{{{}}}^{{{}}}\left({}, {}\right)".format(
@@ -402,30 +422,31 @@ def elliptic_j(z, prec=53):
 
     EXAMPLES::
 
-        sage: elliptic_j(CC(i))
+        sage: elliptic_j(CC(i))                                                         # needs sage.rings.real_mpfr
         1728.00000000000
-        sage: elliptic_j(sqrt(-2.0))
+        sage: elliptic_j(sqrt(-2.0))                                                    # needs sage.rings.complex_double
         8000.00000000000
-        sage: z = ComplexField(100)(1,sqrt(11))/2
-        sage: elliptic_j(z)
+        sage: z = ComplexField(100)(1, sqrt(11))/2                                      # needs sage.rings.real_mpfr sage.symbolic
+        sage: elliptic_j(z)                                                             # needs sage.rings.real_mpfr sage.symbolic
         -32768.000...
-        sage: elliptic_j(z).real().round()
+        sage: elliptic_j(z).real().round()                                              # needs sage.rings.real_mpfr sage.symbolic
         -32768
 
     ::
 
-        sage: tau = (1 + sqrt(-163))/2
-        sage: (-elliptic_j(tau.n(100)).real().round())^(1/3)
+        sage: tau = (1 + sqrt(-163))/2                                                  # needs sage.symbolic
+        sage: (-elliptic_j(tau.n(100)).real().round())^(1/3)                            # needs sage.symbolic
         640320
 
     This example shows the need for higher precision than the default one of
-    the `ComplexField`, see :trac:`28355`::
+    the `ComplexField`, see :issue:`28355`::
 
-        sage: -elliptic_j(tau) # rel tol 1e-2
+        sage: # needs sage.symbolic
+        sage: -elliptic_j(tau)  # rel tol 1e-2
         2.62537412640767e17 - 732.558854258998*I
-        sage: -elliptic_j(tau,75) # rel tol 1e-2
+        sage: -elliptic_j(tau, 75)  # rel tol 1e-2
         2.625374126407680000000e17 - 0.0001309913593909879441262*I
-        sage: -elliptic_j(tau,100) # rel tol 1e-2
+        sage: -elliptic_j(tau, 100)  # rel tol 1e-2
         2.6253741264076799999999999999e17 - 1.3012822400356887122945119790e-12*I
         sage: (-elliptic_j(tau, 100).real().round())^(1/3)
         640320
@@ -455,16 +476,16 @@ class EllipticE(BuiltinFunction):
 
     EXAMPLES::
 
-        sage: z = var("z")
-        sage: elliptic_e(z, 1)
+        sage: z = var("z")                                                              # needs sage.symbolic
+        sage: elliptic_e(z, 1)                                                          # needs sage.symbolic
         elliptic_e(z, 1)
-        sage: elliptic_e(z, 1).simplify() # not tested - gives wrong answer with maxima < 5.47
+        sage: elliptic_e(z, 1).simplify()       # not tested                            # needs sage.symbolic
         2*round(z/pi) - sin(pi*round(z/pi) - z)
-        sage: elliptic_e(z, 0)
+        sage: elliptic_e(z, 0)                                                          # needs sage.symbolic
         z
-        sage: elliptic_e(0.5, 0.1)  # abs tol 2e-15
+        sage: elliptic_e(0.5, 0.1)  # abs tol 2e-15                                     # needs mpmath
         0.498011394498832
-        sage: elliptic_e(1/2, 1/10).n(200)
+        sage: elliptic_e(1/2, 1/10).n(200)                                              # needs sage.symbolic
         0.4980113944988315331154610406...
 
     .. SEEALSO::
@@ -487,27 +508,28 @@ class EllipticE(BuiltinFunction):
 
             sage: loads(dumps(elliptic_e))
             elliptic_e
-            sage: elliptic_e(x, x)._sympy_()
+            sage: elliptic_e(x, x)._sympy_()                                            # needs sympy sage.symbolic
             elliptic_e(x, x)
 
-        Check that :trac:`34085` is fixed::
+        Check that :issue:`34085` is fixed::
 
-            sage: _ = var("x y")
-            sage: fricas(elliptic_e(x, y))                                      # optional - fricas
+            sage: _ = var("x y")                                                        # needs sage.symbolic
+            sage: fricas(elliptic_e(x, y))                                          # optional - fricas, needs sage.symbolic
             ellipticE(sin(x),y)
 
         However, the conversion is only correct in the interval
         `[-\pi/2, \pi/2]`::
 
-            sage: fricas(elliptic_e(x, y)).D(x).sage()/elliptic_e(x, y).diff(x) # optional - fricas
+            sage: fricas(elliptic_e(x, y)).D(x).sage()/elliptic_e(x, y).diff(x)     # optional - fricas, needs sage.symbolic
             cos(x)/sqrt(-sin(x)^2 + 1)
 
         Numerically::
 
-            sage: f = lambda x, y: elliptic_e(arcsin(x), y).subs(x=x, y=y)      # optional - fricas
-            sage: g = lambda x, y: fricas.ellipticE(x, y).sage()                # optional - fricas
-            sage: d = lambda x, y: f(x, y) - g(x, y)                            # optional - fricas
-            sage: [d(N(-pi/2+x), y) for x in range(1, 3) for y in range(-2,2)]  # optional - fricas tol 1e-8
+            sage: f = lambda x, y: elliptic_e(arcsin(x), y).subs(x=x, y=y)
+            sage: g = lambda x, y: fricas.ellipticE(x, y).sage()
+            sage: d = lambda x, y: f(x, y) - g(x, y)
+            sage: [d(N(-pi/2 + x), y)                           # abs tol 1e-8      # optional - fricas, needs sage.symbolic
+            ....:  for x in range(1, 3) for y in range(-2, 2)]
             [0.000000000000000,
              0.000000000000000,
              0.000000000000000,
@@ -530,6 +552,7 @@ class EllipticE(BuiltinFunction):
         """
         EXAMPLES::
 
+            sage: # needs sage.symbolic
             sage: z = var("z")
             sage: elliptic_e(0, x)
             0
@@ -542,7 +565,7 @@ class EllipticE(BuiltinFunction):
 
         Here arccoth doesn't have 1 in its domain, so we just hold the expression::
 
-            sage: elliptic_e(arccoth(1), x^2*e)
+            sage: elliptic_e(arccoth(1), x^2*e)                                         # needs sage.symbolic
             elliptic_e(+Infinity, x^2*e)
         """
         if z == 0:
@@ -556,32 +579,31 @@ class EllipticE(BuiltinFunction):
         """
         EXAMPLES::
 
-            sage: elliptic_e(0.5, 0.1)
+            sage: elliptic_e(0.5, 0.1)                                                  # needs mpmath
             0.498011394498832
-            sage: elliptic_e(1/2, 1/10).n(200)
+            sage: elliptic_e(1/2, 1/10).n(200)                                          # needs sage.symbolic
             0.4980113944988315331154610406...
-            sage: elliptic_e(I, I).n()
+            sage: elliptic_e(I, I).n()                                                  # needs sage.symbolic
             -0.189847437084712 + 1.03209769372160*I
 
         TESTS:
 
-        This gave an error in Maxima (:trac:`15046`)::
+        This gave an error in Maxima (:issue:`15046`)::
 
-            sage: elliptic_e(2.5, 2.5)
+            sage: elliptic_e(2.5, 2.5)                                                  # needs mpmath
             0.535647771608740 + 1.63996015168665*I
         """
-        R = parent or parent(z)
-        from mpmath import ellipe
-        return mpmath_utils.call(ellipe, z, m, parent=R)
+        R = parent or s_parent(z)
+        return _mpmath_utils_call(_mpmath_ellipe, z, m, parent=R)
 
     def _derivative_(self, z, m, diff_param):
         """
         EXAMPLES::
 
-            sage: x,z = var('x,z')
-            sage: elliptic_e(z, x).diff(z, 1)
+            sage: x, z = var('x,z')                                                     # needs sage.symbolic
+            sage: elliptic_e(z, x).diff(z, 1)                                           # needs sage.symbolic
             sqrt(-x*sin(z)^2 + 1)
-            sage: elliptic_e(z, x).diff(x, 1)
+            sage: elliptic_e(z, x).diff(x, 1)                                           # needs sage.symbolic
             1/2*(elliptic_e(z, x) - elliptic_f(z, x))/x
         """
         if diff_param == 0:
@@ -593,7 +615,7 @@ class EllipticE(BuiltinFunction):
         r"""
         EXAMPLES::
 
-            sage: latex(elliptic_e(pi, x))
+            sage: latex(elliptic_e(pi, x))                                              # needs sage.symbolic
             E(\pi\,|\,x)
         """
         return r"E(%s\,|\,%s)" % (latex(z), latex(m))
@@ -612,9 +634,9 @@ class EllipticEC(BuiltinFunction):
 
     EXAMPLES::
 
-        sage: elliptic_ec(0.1)
+        sage: elliptic_ec(0.1)                                                          # needs mpmath
         1.53075763689776
-        sage: elliptic_ec(x).diff()
+        sage: elliptic_ec(x).diff()                                                     # needs sage.symbolic
         1/2*(elliptic_ec(x) - elliptic_kc(x))/x
 
     .. SEEALSO::
@@ -631,17 +653,17 @@ class EllipticEC(BuiltinFunction):
 
             sage: loads(dumps(elliptic_ec))
             elliptic_ec
-            sage: elliptic_ec(x)._sympy_()
+            sage: elliptic_ec(x)._sympy_()                                              # needs sage.symbolic
             elliptic_e(x)
 
         TESTS::
 
-            sage: fricas(elliptic_ec(x))  # optional - fricas
+            sage: fricas(elliptic_ec(x))                                        # optional - fricas, needs sage.symbolic
             ellipticE(x)
 
-            sage: elliptic_ec(0.5)  # abs tol 1e-8
+            sage: elliptic_ec(0.5)  # abs tol 1e-8                                      # needs sage.symbolic
             1.35064388104768
-            sage: fricas.ellipticE(0.5).sage()  # abs tol 1e-8 # optional - fricas
+            sage: fricas.ellipticE(0.5).sage()  # abs tol 1e-8                  # optional - fricas, needs sage.symbolic
             1.3506438810476755025201749
         """
         BuiltinFunction.__init__(self, 'elliptic_ec', nargs=1, latex_name='E',
@@ -654,11 +676,11 @@ class EllipticEC(BuiltinFunction):
         """
         EXAMPLES::
 
-            sage: elliptic_ec(0)
+            sage: elliptic_ec(0)                                                        # needs sage.symbolic
             1/2*pi
-            sage: elliptic_ec(1)
+            sage: elliptic_ec(1)                                                        # needs sage.symbolic
             1
-            sage: elliptic_ec(x)
+            sage: elliptic_ec(x)                                                        # needs sage.symbolic
             elliptic_ec(x)
         """
         if x == 0:
@@ -670,22 +692,21 @@ class EllipticEC(BuiltinFunction):
         """
         EXAMPLES::
 
-            sage: elliptic_ec(sqrt(2)/2).n()
+            sage: elliptic_ec(sqrt(2)/2).n()                                            # needs sage.symbolic
             1.23742252487318
-            sage: elliptic_ec(sqrt(2)/2).n(200)
+            sage: elliptic_ec(sqrt(2)/2).n(200)                                         # needs sage.symbolic
             1.237422524873181672854746084083...
-            sage: elliptic_ec(I).n()
+            sage: elliptic_ec(I).n()                                                    # needs sage.symbolic
             1.63241178144043 - 0.369219492375499*I
         """
-        R = parent or parent(x)
-        from mpmath import ellipe
-        return mpmath_utils.call(ellipe, x, parent=R)
+        R = parent or s_parent(x)
+        return _mpmath_utils_call(_mpmath_ellipe, x, parent=R)
 
     def _derivative_(self, x, diff_param):
         """
         EXAMPLES::
 
-            sage: elliptic_ec(x).diff()
+            sage: elliptic_ec(x).diff()                                                 # needs sage.symbolic
             1/2*(elliptic_ec(x) - elliptic_kc(x))/x
         """
         return (elliptic_ec(x) - elliptic_kc(x)) / (Integer(2) * x)
@@ -710,7 +731,7 @@ class EllipticEU(BuiltinFunction):
 
     EXAMPLES::
 
-        sage: elliptic_eu (0.5, 0.1)
+        sage: elliptic_eu(0.5, 0.1)                                                     # needs mpmath
         0.496054551286597
 
     .. SEEALSO::
@@ -737,7 +758,7 @@ class EllipticEU(BuiltinFunction):
         """
         EXAMPLES::
 
-            sage: elliptic_eu(1,1)
+            sage: elliptic_eu(1, 1)                                                     # needs sage.symbolic
             elliptic_eu(1, 1)
         """
         pass
@@ -746,22 +767,22 @@ class EllipticEU(BuiltinFunction):
         """
         EXAMPLES::
 
-            sage: elliptic_eu(1,1).n()
+            sage: elliptic_eu(1, 1).n()                                                 # needs sage.symbolic
             0.761594155955765
-            sage: elliptic_eu(1,1).n(200)
+            sage: elliptic_eu(1, 1).n(200)                                              # needs sage.symbolic
             0.7615941559557648881194582...
         """
-        R = parent or parent(u)
-        return mpmath_utils.call(elliptic_eu_f, u, m, parent=R)
+        R = parent or s_parent(u)
+        return _mpmath_utils_call(elliptic_eu_f, u, m, parent=R)
 
     def _derivative_(self, u, m, diff_param):
         """
         EXAMPLES::
 
-            sage: x,m = var('x,m')
-            sage: elliptic_eu(x,m).diff(x)
+            sage: x, m = var('x,m')                                                     # needs sage.symbolic
+            sage: elliptic_eu(x, m).diff(x)                                             # needs sage.symbolic
             sqrt(-m*jacobi_sn(x, m)^2 + 1)*jacobi_dn(x, m)
-            sage: elliptic_eu(x,m).diff(m)
+            sage: elliptic_eu(x, m).diff(m)                                             # needs sage.symbolic
             1/2*(elliptic_eu(x, m)
              - elliptic_f(jacobi_am(x, m), m))/m
              - 1/2*(m*jacobi_cn(x, m)*jacobi_sn(x, m)
@@ -785,7 +806,7 @@ class EllipticEU(BuiltinFunction):
         """
         EXAMPLES::
 
-            sage: latex(elliptic_eu(1,x))
+            sage: latex(elliptic_eu(1, x))                                              # needs sage.symbolic
             E(1;x)
         """
         return r"E(%s;%s)" % (latex(u), latex(m))
@@ -801,13 +822,10 @@ def elliptic_eu_f(u, m):
     EXAMPLES::
 
         sage: from sage.functions.special import elliptic_eu_f
-        sage: elliptic_eu_f(0.5, 0.1)
+        sage: elliptic_eu_f(0.5, 0.1)                                                   # needs mpmath
         mpf('0.49605455128659691')
     """
-    from mpmath import mp
-    from sage.functions.jacobi import jacobi_am_f
-
-    ctx = mp
+    from mpmath import mp as ctx
     prec = ctx.prec
     try:
         u = ctx.convert(u)
@@ -834,12 +852,12 @@ class EllipticF(BuiltinFunction):
 
     EXAMPLES::
 
-        sage: z = var("z")
-        sage: elliptic_f (z, 0)
+        sage: z = var("z")                                                              # needs sage.symbolic
+        sage: elliptic_f(z, 0)                                                          # needs sage.symbolic
         z
-        sage: elliptic_f (z, 1).simplify()
+        sage: elliptic_f(z, 1).simplify()                                               # needs sage.symbolic
         log(tan(1/4*pi + 1/2*z))
-        sage: elliptic_f (0.2, 0.1)
+        sage: elliptic_f(0.2, 0.1)                                                      # needs mpmath
         0.200132506747543
 
     .. SEEALSO::
@@ -856,27 +874,28 @@ class EllipticF(BuiltinFunction):
 
             sage: loads(dumps(elliptic_f))
             elliptic_f
-            sage: elliptic_f(x, 2)._sympy_()
+            sage: elliptic_f(x, 2)._sympy_()                                            # needs sympy sage.symbolic
             elliptic_f(x, 2)
 
-        Check that :trac:`34186` is fixed::
+        Check that :issue:`34186` is fixed::
 
-            sage: _ = var("x y")
-            sage: fricas(elliptic_f(x, y))                                      # optional - fricas
+            sage: _ = var("x y")                                                        # needs sage.symbolic
+            sage: fricas(elliptic_f(x, y))                                          # optional - fricas, needs sage.symbolic
             ellipticF(sin(x),y)
 
         However, the conversion is only correct in the interval
         `[-\pi/2, \pi/2]`::
 
-            sage: fricas(elliptic_f(x, y)).D(x).sage()/elliptic_f(x, y).diff(x) # optional - fricas
+            sage: fricas(elliptic_f(x, y)).D(x).sage()/elliptic_f(x, y).diff(x)     # optional - fricas, needs sage.symbolic
             cos(x)/sqrt(-sin(x)^2 + 1)
 
         Numerically::
 
-            sage: f = lambda x, y: elliptic_f(arcsin(x), y).subs(x=x, y=y)      # optional - fricas
-            sage: g = lambda x, y: fricas.ellipticF(x, y).sage()                # optional - fricas
-            sage: d = lambda x, y: f(x, y) - g(x, y)                            # optional - fricas
-            sage: [d(N(-pi/2+x), y) for x in range(1, 3) for y in range(-2,2)]  # optional - fricas tol 1e-8
+            sage: f = lambda x, y: elliptic_f(arcsin(x), y).subs(x=x, y=y)
+            sage: g = lambda x, y: fricas.ellipticF(x, y).sage()
+            sage: d = lambda x, y: f(x, y) - g(x, y)
+            sage: [d(N(-pi/2 + x), y)                          # abs tol 1e-8       # optional - fricas, needs sage.symbolic
+            ....:  for x in range(1, 3) for y in range(-2,2)]
             [0.000000000000000,
              0.000000000000000,
              0.000000000000000,
@@ -897,13 +916,14 @@ class EllipticF(BuiltinFunction):
         """
         EXAMPLES::
 
-            sage: elliptic_f(x,1)
+            sage: # needs sage.symbolic
+            sage: elliptic_f(x, 1)
             elliptic_f(x, 1)
-            sage: elliptic_f(x,0)
+            sage: elliptic_f(x, 0)
             x
-            sage: elliptic_f(0,1)
+            sage: elliptic_f(0, 1)
             0
-            sage: elliptic_f(pi/2,x)
+            sage: elliptic_f(pi/2, x)
             elliptic_kc(x)
         """
         if m == 0:
@@ -917,25 +937,24 @@ class EllipticF(BuiltinFunction):
         """
         EXAMPLES::
 
-            sage: elliptic_f(1,1).n()
+            sage: elliptic_f(1, 1).n()                                                  # needs sage.symbolic
             1.22619117088352
-            sage: elliptic_f(1,1).n(200)
+            sage: elliptic_f(1, 1).n(200)                                               # needs sage.symbolic
             1.22619117088351707081306096...
-            sage: elliptic_f(I,I).n()
+            sage: elliptic_f(I, I).n()                                                  # needs sage.symbolic
             0.149965060031782 + 0.925097284105771*I
         """
-        R = parent or parent(z)
-        from mpmath import ellipf
-        return mpmath_utils.call(ellipf, z, m, parent=R)
+        R = parent or s_parent(z)
+        return _mpmath_utils_call(_mpmath_ellipf, z, m, parent=R)
 
     def _derivative_(self, z, m, diff_param):
         """
         EXAMPLES::
 
-            sage: x,m = var('x,m')
-            sage: elliptic_f(x,m).diff(x)
+            sage: x, m = var('x,m')                                                     # needs sage.symbolic
+            sage: elliptic_f(x, m).diff(x)                                              # needs sage.symbolic
             1/sqrt(-m*sin(x)^2 + 1)
-            sage: elliptic_f(x,m).diff(m)
+            sage: elliptic_f(x, m).diff(m)                                              # needs sage.symbolic
             -1/2*elliptic_f(x, m)/m
             + 1/4*sin(2*x)/(sqrt(-m*sin(x)^2 + 1)*(m - 1))
             - 1/2*elliptic_e(x, m)/((m - 1)*m)
@@ -953,7 +972,7 @@ class EllipticF(BuiltinFunction):
         r"""
         EXAMPLES::
 
-            sage: latex(elliptic_f(x,pi))
+            sage: latex(elliptic_f(x, pi))                                              # needs sage.symbolic
             F(x\,|\,\pi)
         """
         return r"F(%s\,|\,%s)" % (latex(z), latex(m))
@@ -972,7 +991,7 @@ class EllipticKC(BuiltinFunction):
 
     EXAMPLES::
 
-        sage: elliptic_kc(0.5)
+        sage: elliptic_kc(0.5)                                                          # needs mpmath
         1.85407467730137
 
     .. SEEALSO::
@@ -993,17 +1012,17 @@ class EllipticKC(BuiltinFunction):
 
             sage: loads(dumps(elliptic_kc))
             elliptic_kc
-            sage: elliptic_kc(x)._sympy_()
+            sage: elliptic_kc(x)._sympy_()                                              # needs sage.symbolic
             elliptic_k(x)
 
         TESTS::
 
-            sage: fricas(elliptic_kc(x))  # optional - fricas
+            sage: fricas(elliptic_kc(x))                                        # optional - fricas, needs sage.symbolic
             ellipticK(x)
 
-            sage: elliptic_kc(0.3)  # abs tol 1e-8
+            sage: elliptic_kc(0.3)  # abs tol 1e-8                                      # needs mpmath
             1.71388944817879
-            sage: fricas.ellipticK(0.3).sage()  # abs tol 1e-3 # optional - fricas
+            sage: fricas.ellipticK(0.3).sage()  # abs tol 1e-3                  # optional - fricas, needs sage.symbolic
             1.7138894481787910555457043
         """
         BuiltinFunction.__init__(self, 'elliptic_kc', nargs=1, latex_name='K',
@@ -1016,20 +1035,20 @@ class EllipticKC(BuiltinFunction):
         """
         EXAMPLES::
 
-            sage: elliptic_kc(0)
+            sage: elliptic_kc(0)                                                        # needs sage.symbolic
             1/2*pi
-            sage: elliptic_kc(1/2)
+            sage: elliptic_kc(1/2)                                                      # needs sage.symbolic
             elliptic_kc(1/2)
 
         TESTS:
 
         Check if complex numbers in the arguments are converted to maxima
-        correctly (see :trac:`7557`)::
+        correctly (see :issue:`7557`)::
 
-            sage: t = jacobi_sn(1.2+2*I*elliptic_kc(1-.5),.5)
-            sage: maxima(t) # abs tol 1e-13
+            sage: t = jacobi_sn(1.2 + 2*I*elliptic_kc(1 - .5), .5)                      # needs sage.symbolic
+            sage: maxima(t)  # abs tol 1e-13                                            # needs sage.symbolic
             0.88771548861928029 - 1.7301614091485560e-15*%i
-            sage: t.n() # abs tol 1e-13
+            sage: t.n()  # abs tol 1e-13                                                # needs sage.symbolic
             0.887715488619280 - 1.73016140914856e-15*I
         """
         if z == 0:
@@ -1041,22 +1060,21 @@ class EllipticKC(BuiltinFunction):
         """
         EXAMPLES::
 
-            sage: elliptic_kc(1/2).n()
+            sage: elliptic_kc(1/2).n()                                                  # needs sage.symbolic
             1.85407467730137
-            sage: elliptic_kc(1/2).n(200)
+            sage: elliptic_kc(1/2).n(200)                                               # needs sage.symbolic
             1.85407467730137191843385034...
-            sage: elliptic_kc(I).n()
+            sage: elliptic_kc(I).n()                                                    # needs sage.symbolic
             1.42127228104504 + 0.295380284214777*I
         """
-        R = parent or parent(z)
-        from mpmath import ellipk
-        return mpmath_utils.call(ellipk, z, parent=R)
+        R = parent or s_parent(z)
+        return _mpmath_utils_call(_mpmath_ellipk, z, parent=R)
 
     def _derivative_(self, z, diff_param):
         """
         EXAMPLES::
 
-            sage: elliptic_kc(x).diff(x)
+            sage: elliptic_kc(x).diff(x)                                                # needs sage.symbolic
             -1/2*((x - 1)*elliptic_kc(x)
             + elliptic_ec(x))/((x - 1)*x)
         """
@@ -1085,15 +1103,15 @@ class EllipticPi(BuiltinFunction):
 
     EXAMPLES::
 
-        sage: N(elliptic_pi(1, pi/4, 1))
+        sage: N(elliptic_pi(1, pi/4, 1))                                                # needs sage.symbolic
         1.14779357469632
 
     Compare the value computed by Maxima to the definition as a definite integral
     (using GSL)::
 
-        sage: elliptic_pi(0.1, 0.2, 0.3)
+        sage: elliptic_pi(0.1, 0.2, 0.3)                                                # needs mpmath
         0.200665068220979
-        sage: numerical_integral(1/(1-0.1*sin(x)^2)/sqrt(1-0.3*sin(x)^2), 0.0, 0.2)
+        sage: numerical_integral(1/(1-0.1*sin(x)^2)/sqrt(1-0.3*sin(x)^2), 0.0, 0.2)     # needs sage.symbolic
         (0.2006650682209791, 2.227829789769088e-15)
 
     REFERENCES:
@@ -1106,7 +1124,7 @@ class EllipticPi(BuiltinFunction):
 
             sage: loads(dumps(elliptic_pi))
             elliptic_pi
-            sage: elliptic_pi(x, pi/4, 1)._sympy_()
+            sage: elliptic_pi(x, pi/4, 1)._sympy_()                                     # needs sympy sage.symbolic
             elliptic_pi(x, pi/4, 1)
         """
         BuiltinFunction.__init__(self, 'elliptic_pi', nargs=3,
@@ -1119,9 +1137,9 @@ class EllipticPi(BuiltinFunction):
         """
         EXAMPLES::
 
-            sage: elliptic_pi(x,x,pi)
+            sage: elliptic_pi(x, x, pi)                                                 # needs sympy sage.symbolic
             elliptic_pi(x, x, pi)
-            sage: elliptic_pi(0,x,pi)
+            sage: elliptic_pi(0, x, pi)                                                 # needs sympy sage.symbolic
             elliptic_f(x, pi)
         """
         if n == 0:
@@ -1131,32 +1149,33 @@ class EllipticPi(BuiltinFunction):
         """
         EXAMPLES::
 
-            sage: elliptic_pi(pi,1/2,1).n()
+            sage: # needs sage.symbolic
+            sage: elliptic_pi(pi, 1/2, 1).n()
             0.795062820631931
-            sage: elliptic_pi(pi,1/2,1).n(200)
+            sage: elliptic_pi(pi, 1/2, 1).n(200)
             0.79506282063193125292514098445...
-            sage: elliptic_pi(pi,1,1).n()
+            sage: elliptic_pi(pi, 1, 1).n()
             0.0991592574231369 - 1.30004368185937*I
-            sage: elliptic_pi(pi,I,I).n()
+            sage: elliptic_pi(pi, I, I).n()
             0.0542471560940594 + 0.552096453413081*I
         """
-        R = parent or parent(z)
-        from mpmath import ellippi
-        return mpmath_utils.call(ellippi, n, z, m, parent=R)
+        R = parent or s_parent(z)
+        return _mpmath_utils_call(_mpmath_ellippi, n, z, m, parent=R)
 
     def _derivative_(self, n, z, m, diff_param):
         """
         EXAMPLES::
 
-            sage: n,z,m = var('n,z,m')
-            sage: elliptic_pi(n,z,m).diff(n)
+            sage: # needs sage.symbolic
+            sage: n, z, m = var('n,z,m')
+            sage: elliptic_pi(n, z, m).diff(n)
             1/4*(sqrt(-m*sin(z)^2 + 1)*n*sin(2*z)/(n*sin(z)^2 - 1)
             + 2*(m - n)*elliptic_f(z, m)/n
             + 2*(n^2 - m)*elliptic_pi(n, z, m)/n
             + 2*elliptic_e(z, m))/((m - n)*(n - 1))
-            sage: elliptic_pi(n,z,m).diff(z)
+            sage: elliptic_pi(n, z, m).diff(z)
             -1/(sqrt(-m*sin(z)^2 + 1)*(n*sin(z)^2 - 1))
-            sage: elliptic_pi(n,z,m).diff(m)
+            sage: elliptic_pi(n, z, m).diff(m)
             1/4*(m*sin(2*z)/(sqrt(-m*sin(z)^2 + 1)*(m - 1))
             - 2*elliptic_e(z, m)/(m - 1)
             - 2*elliptic_pi(n, z, m))/(m - n)
@@ -1183,7 +1202,7 @@ class EllipticPi(BuiltinFunction):
         r"""
         EXAMPLES::
 
-            sage: latex(elliptic_pi(x,pi,0))
+            sage: latex(elliptic_pi(x, pi, 0))                                          # needs sage.symbolic
             \Pi(x,\pi,0)
         """
         return r"\Pi(%s,%s,%s)" % (latex(n), latex(z), latex(m))
