@@ -601,7 +601,7 @@ class PolyhedronFace(ConvexSet_closed):
 
         TESTS:
 
-        Check that :trac:`28650` is fixed::
+        Check that :issue:`28650` is fixed::
 
             sage: P = Polyhedron(vertices=[[1,0]], rays=[[1,0], [0,1]])
             sage: P.faces(2)
@@ -960,7 +960,7 @@ class PolyhedronFace(ConvexSet_closed):
 
         TESTS:
 
-        Check that :trac:`32658` is fixed::
+        Check that :issue:`32658` is fixed::
 
             sage: P = polytopes.hypercube(2)
             sage: P.faces(-1)[0].affine_tangent_cone()
