@@ -5,7 +5,6 @@ AUTHORS:
 
 - Mikhail Malakhaltsev (2010-09-25): initial version
 - Joris Vankerschaver  (2010-10-25): implementation, doctests
-
 """
 # ****************************************************************************
 #       Copyright (C) 2010  Mikhail Malakhaltsev <mikarm@gmail.com>
@@ -34,7 +33,7 @@ def _simplify_full_rad(f):
 
     INPUT:
 
-     - ``f`` - a symbolic expression.
+     - ``f`` -- a symbolic expression.
 
     EXAMPLES::
 
@@ -415,7 +414,7 @@ class ParametrizedSurface3D(SageObject):
         name = 'Parametrized surface'
         if self.name is not None:
             name += " ('%s')" % self.name
-        s ='%(designation)s with equation %(eq)s' % \
+        s = '%(designation)s with equation %(eq)s' % \
             {'designation': name, 'eq': str(self.equation)}
         return s
 
@@ -425,7 +424,7 @@ class ParametrizedSurface3D(SageObject):
 
         INPUT:
 
-         - ``coords`` - 2-tuple specifying the intrinsic coordinates ``(u, v)`` of the point.
+         - ``coords`` -- 2-tuple specifying the intrinsic coordinates ``(u, v)`` of the point.
 
         OUTPUT:
 
@@ -457,9 +456,9 @@ class ParametrizedSurface3D(SageObject):
 
         INPUT:
 
-         - ``coords`` - 2-tuple specifying the intrinsic coordinates ``(u, v)`` of the point.
+         - ``coords`` -- 2-tuple specifying the intrinsic coordinates ``(u, v)`` of the point.
 
-         - ``components`` - 2-tuple specifying the components of the tangent vector in the intrinsic coordinate frame.
+         - ``components`` -- 2-tuple specifying the components of the tangent vector in the intrinsic coordinate frame.
 
         OUTPUT:
 
@@ -507,8 +506,8 @@ class ParametrizedSurface3D(SageObject):
 
         INPUT:
 
-         - ``urange`` - 2-tuple specifying the parameter range for `u`.
-         - ``vrange`` - 2-tuple specifying the parameter range for `v`.
+         - ``urange`` -- 2-tuple specifying the parameter range for `u`.
+         - ``vrange`` -- 2-tuple specifying the parameter range for `v`.
 
         EXAMPLES::
 
@@ -575,7 +574,7 @@ class ParametrizedSurface3D(SageObject):
 
         INPUT:
 
-          - ``normalized`` - default ``False`` - specifies whether the normal vector should be normalized.
+          - ``normalized`` -- (default ``False``); specifies whether the normal vector should be normalized.
 
         OUTPUT:
 
@@ -631,7 +630,7 @@ class ParametrizedSurface3D(SageObject):
 
         INPUT:
 
-         - ``index`` - tuple ``(i, j)`` specifying the index of the component `g_{ij}`.
+         - ``index`` -- tuple ``(i, j)`` specifying the index of the component `g_{ij}`.
 
         OUTPUT:
 
@@ -694,7 +693,7 @@ class ParametrizedSurface3D(SageObject):
 
         INPUT:
 
-         - ``vector1``, ``vector2`` - vectors on the surface.
+         - ``vector1``, ``vector2`` -- vectors on the surface.
 
         OUTPUT:
 
@@ -805,7 +804,7 @@ class ParametrizedSurface3D(SageObject):
 
         INPUT:
 
-         - ``index`` - tuple ``(i, j)`` specifying the index of the component `g^{ij}`.
+         - ``index`` -- tuple ``(i, j)`` specifying the index of the component `g^{ij}`.
 
         OUTPUT:
 
@@ -836,7 +835,7 @@ class ParametrizedSurface3D(SageObject):
 
         INPUT:
 
-         - ``theta`` - rotation angle
+         - ``theta`` -- rotation angle
 
         OUTPUT:
 
@@ -888,7 +887,7 @@ class ParametrizedSurface3D(SageObject):
 
         INPUT:
 
-         - ``coordinates`` - either ``ext`` (default) or ``int``.
+         - ``coordinates`` -- either ``ext`` (default) or ``int``.
 
         OUTPUT:
 
@@ -952,8 +951,8 @@ class ParametrizedSurface3D(SageObject):
 
         INPUT:
 
-         - ``index`` - index of the basis vector;
-         - ``coordinates`` - either ``ext`` (default) or ``int``.
+         - ``index`` -- index of the basis vector;
+         - ``coordinates`` -- either ``ext`` (default) or ``int``.
 
         OUTPUT:
 
@@ -988,7 +987,7 @@ class ParametrizedSurface3D(SageObject):
 
         INPUT:
 
-         - ``v`` and ``w`` - vector fields on the surface, expressed
+         - ``v`` and ``w`` -- vector fields on the surface, expressed
            as pairs of functions or as vectors of length 2.
 
         OUTPUT:
@@ -1027,7 +1026,7 @@ class ParametrizedSurface3D(SageObject):
 
         INPUT:
 
-         - ``e1``, ``e2`` - vector fields in intrinsic coordinates on
+         - ``e1``, ``e2`` -- vector fields in intrinsic coordinates on
            the surface, expressed as pairs of functions, or as vectors of
            length 2.
 
@@ -1067,7 +1066,7 @@ class ParametrizedSurface3D(SageObject):
              (2, 2, 2): 0}
             sage: sphere.lie_bracket(EE_int[1],EE_int[2]) - CC[(1,2,1)]*EE_int[1] - CC[(1,2,2)]*EE_int[2]
             (0, 0)
-            """
+        """
         e1 = vector(SR, e1)
         e2 = vector(SR, e2)
 
@@ -1145,7 +1144,7 @@ class ParametrizedSurface3D(SageObject):
 
         INPUT:
 
-         - ``index`` - a 2-tuple ``(i, j)`` specifying the element of the second-order frame.
+         - ``index`` -- a 2-tuple ``(i, j)`` specifying the element of the second-order frame.
 
         OUTPUT:
 
@@ -1196,7 +1195,7 @@ class ParametrizedSurface3D(SageObject):
 
         INPUT:
 
-         - ``index`` - a 2-tuple ``(i, j)``
+         - ``index`` -- a 2-tuple ``(i, j)``
 
         OUTPUT:
 
@@ -1256,7 +1255,7 @@ class ParametrizedSurface3D(SageObject):
 
         INPUT:
 
-         - ``vector1``, ``vector2`` - 2-tuples representing the input vectors.
+         - ``vector1``, ``vector2`` -- 2-tuples representing the input vectors.
 
         OUTPUT:
 
@@ -1410,7 +1409,7 @@ class ParametrizedSurface3D(SageObject):
         """
 
         shop = self.shape_operator_coefficients()
-        shop_matrix=matrix([[shop[(1,1)],shop[(1,2)]],
+        shop_matrix = matrix([[shop[(1,1)],shop[(1,2)]],
                             [shop[(2,1)],shop[(2,2)]]])
         return shop_matrix
 
@@ -1442,9 +1441,6 @@ class ParametrizedSurface3D(SageObject):
             sage: helicoid.principal_directions()
             [(-1/(u^2 + 1), [(1, -(u^2 - sqrt(u^2 + 1) + 1)/(u^2 + 1))], 1),
             (1/(u^2 + 1), [(1, -(u^2 + sqrt(u^2 + 1) + 1)/(u^2 + 1))], 1)]
-
-
-
         """
         return self.shape_operator().eigenvectors_right()
 
@@ -1492,10 +1488,10 @@ class ParametrizedSurface3D(SageObject):
         for i,j,k in product((1, 2), repeat=3):
             dg[(i,j,k)] = _simplify_full_rad(gg[(j,k)].differentiate(x[i]))
 
-        structfun={}
+        structfun = {}
         for i,j,k in product((1, 2), repeat=3):
             structfun[(i,j,k)] = sum(gi[(k,s)]*(dg[(i,j,s)] + dg[(j,i,s)]
-                                                -dg[(s,i,j)])/2
+                                                - dg[(s,i,j)])/2
                                      for s in (1,2))
             structfun[(i,j,k)] = _simplify_full_rad(structfun[(i,j,k)])
         return structfun
@@ -1555,11 +1551,11 @@ class ParametrizedSurface3D(SageObject):
 
         INPUT:
 
-         - ``p0`` - 2-tuple with coordinates of the initial point.
+         - ``p0`` -- 2-tuple with coordinates of the initial point.
 
-         - ``v0`` - 2-tuple with components of the initial tangent vector to the geodesic.
+         - ``v0`` -- 2-tuple with components of the initial tangent vector to the geodesic.
 
-         - ``tinterval`` - List ``[a, b, M]``, where ``(a,b)`` is the domain of the geodesic and ``M`` is the number of subdivision points used when returning the solution.
+         - ``tinterval`` -- List ``[a, b, M]``, where ``(a,b)`` is the domain of the geodesic and ``M`` is the number of subdivision points used when returning the solution.
 
         OUTPUT:
 
@@ -1609,8 +1605,8 @@ class ParametrizedSurface3D(SageObject):
 
         INPUT:
 
-         - ``curve`` - curve in intrinsic coordinates along which to do parallel transport.
-         - ``t`` - curve parameter
+         - ``curve`` -- curve in intrinsic coordinates along which to do parallel transport.
+         - ``t`` -- curve parameter
 
         EXAMPLES::
 
@@ -1667,14 +1663,14 @@ class ParametrizedSurface3D(SageObject):
 
         INPUT:
 
-         - ``curve`` - 2-tuple of functions which determine the curve with respect to
+         - ``curve`` -- 2-tuple of functions which determine the curve with respect to
            the local coordinate system;
 
-         - ``t`` - symbolic variable denoting the curve parameter;
+         - ``t`` -- symbolic variable denoting the curve parameter;
 
-         - ``v0`` - 2-tuple representing the initial vector;
+         - ``v0`` -- 2-tuple representing the initial vector;
 
-         - ``tinterval`` - list ``[a, b, N]``, where ``(a, b)`` is the domain of the curve
+         - ``tinterval`` -- list ``[a, b, N]``, where ``(a, b)`` is the domain of the curve
            and ``N`` is the number of subdivision points.
 
         OUTPUT:
