@@ -36,8 +36,8 @@ def SymplecticPolarGraph(d, q, algorithm=None):
 
     INPUT:
 
-    - ``d,q`` -- integers; note that only even values of `d` are accepted by the
-      function.
+    - ``d``, ``q`` -- integers; note that only even values of `d` are accepted
+      by the function.
 
     - ``algorithm`` -- string (default: ``None``); if set to ``'gap'``, then the
       computation is carried via GAP library interface, computing totally
@@ -216,7 +216,7 @@ def _orthogonal_polar_graph(m, q, sign="+", point_type=[0]):
 
     INPUT:
 
-    - ``m,q`` -- integers; `q` must be a prime power
+    - ``m``, ``q`` -- integers; `q` must be a prime power
 
     - ``sign`` -- string (default: ``"+"``); must be ``"+"`` or ``"-"`` if `m`
       is even, ``"+"`` (default) otherwise
@@ -340,7 +340,7 @@ def OrthogonalPolarGraph(m, q, sign="+"):
 
     INPUT:
 
-    - ``m,q`` -- integers; `q` must be a prime power
+    - ``m``, ``q`` -- integers; `q` must be a prime power
 
     - ``sign`` -- string (default: ``"+"``); must be ``"+"`` or ``"-"`` if `m`
       is even, ``"+"`` (default) otherwise
@@ -535,12 +535,12 @@ def NonisotropicOrthogonalPolarGraph(m, q, sign="+", perp=None):
         deg = (q**n - e)*(q**(n - 1) + e)   # k
         S = [libgap.Elements(libgap.Basis(x))[0]
              for x in libgap.Elements(libgap.Subspaces(W, 1))]
-        (V,) = [x for x in libgap.Orbits(g, S, libgap.OnLines)
-                if len(x) == nvert]
+        (V,) = (x for x in libgap.Orbits(g, S, libgap.OnLines)
+                if len(x) == nvert)
         gp = libgap.Action(g, V, libgap.OnLines)  # make a permutation group
         h = libgap.Stabilizer(gp, 1)
-        (Vh,) = [x for x in libgap.Orbits(h, libgap.Orbit(gp, 1))
-                 if len(x) == deg]
+        (Vh,) = (x for x in libgap.Orbits(h, libgap.Orbit(gp, 1))
+                 if len(x) == deg)
         Vh = Vh[0]
         L = libgap.Orbit(gp, [1, Vh], libgap.OnSets)
         G = Graph()
@@ -613,7 +613,7 @@ def UnitaryPolarGraph(m, q, algorithm="gap"):
 
     INPUT:
 
-    - ``m,q`` -- integers; `q` must be a prime power
+    - ``m``, ``q`` -- integers; `q` must be a prime power
 
     - ``algorithm`` -- string (default: ``"gap"``); if set to 'gap' then the
       computation is carried via GAP library interface, computing totally
@@ -686,7 +686,7 @@ def NonisotropicUnitaryPolarGraph(m, q):
 
     INPUT:
 
-    - ``m,q`` -- integers; `q` must be a prime power
+    - ``m``, ``q`` -- integers; `q` must be a prime power
 
     EXAMPLES::
 
@@ -749,7 +749,7 @@ def UnitaryDualPolarGraph(m, q):
 
     INPUT:
 
-    - ``m,q`` -- integers; `q` must be a prime power
+    - ``m``, ``q`` -- integers; `q` must be a prime power
 
     EXAMPLES:
 
@@ -803,7 +803,7 @@ def SymplecticDualPolarGraph(m, q):
 
     INPUT:
 
-    - ``m,q`` -- integers; `q` must be a prime power, and `m` must be even
+    - ``m``, ``q`` -- integers; `q` must be a prime power, and `m` must be even
 
     EXAMPLES::
 
@@ -1045,7 +1045,7 @@ def T2starGeneralizedQuadrangleGraph(q, dual=False, hyperoval=None, field=None,
 
     using the built-in construction::
 
-        sage: # needs sage.rings.finite_rings
+        sage: # needs sage.combinat sage.rings.finite_rings
         sage: g = graphs.T2starGeneralizedQuadrangleGraph(4); g
         T2*(O,4); GQ(3, 5): Graph on 64 vertices
         sage: g.is_strongly_regular(parameters=True)
@@ -1057,7 +1057,7 @@ def T2starGeneralizedQuadrangleGraph(q, dual=False, hyperoval=None, field=None,
 
     supplying your own hyperoval::
 
-        sage: # needs sage.rings.finite_rings
+        sage: # needs sage.combinat sage.rings.finite_rings
         sage: F = GF(4,'b')
         sage: O = [vector(F,(0,0,0,1)),vector(F,(0,0,1,0))] + [vector(F, (0,1,x^2,x))
         ....:                                                  for x in F]
@@ -1068,7 +1068,7 @@ def T2starGeneralizedQuadrangleGraph(q, dual=False, hyperoval=None, field=None,
 
     TESTS::
 
-        sage: # needs sage.rings.finite_rings
+        sage: # needs sage.combinat sage.rings.finite_rings
         sage: F = GF(4,'b')  # repeating a point...
         sage: O = [vector(F,(0,1,0,0)),vector(F,(0,0,1,0))]+[vector(F, (0,1,x^2,x)) for x in F]
         sage: graphs.T2starGeneralizedQuadrangleGraph(4, hyperoval=O, field=F)
@@ -1168,21 +1168,23 @@ def HaemersGraph(q, hyperoval=None, hyperoval_matching=None, field=None, check_h
 
     using the built-in constructions::
 
-        sage: g = graphs.HaemersGraph(4); g                                             # needs sage.rings.finite_rings
+        sage: # needs sage.combinat sage.rings.finite_rings
+        sage: g = graphs.HaemersGraph(4); g
         Haemers(4): Graph on 96 vertices
-        sage: g.is_strongly_regular(parameters=True)                                    # needs sage.rings.finite_rings
+        sage: g.is_strongly_regular(parameters=True)
         (96, 19, 2, 4)
 
     supplying your own hyperoval_matching::
 
-        sage: g = graphs.HaemersGraph(4, hyperoval_matching=((0,5),(1,4),(2,3))); g     # needs sage.rings.finite_rings
+        sage: # needs sage.combinat sage.rings.finite_rings
+        sage: g = graphs.HaemersGraph(4, hyperoval_matching=((0,5),(1,4),(2,3))); g
         Haemers(4): Graph on 96 vertices
-        sage: g.is_strongly_regular(parameters=True)                                    # needs sage.rings.finite_rings
+        sage: g.is_strongly_regular(parameters=True)
         (96, 19, 2, 4)
 
     TESTS::
 
-        sage: # needs sage.rings.finite_rings
+        sage: # needs sage.combinat sage.rings.finite_rings
         sage: F = GF(4,'b')  # repeating a point...
         sage: O = [vector(F,(0,1,0,0)),vector(F,(0,0,1,0))]+[vector(F, (0,1,x^2,x)) for x in F]
         sage: graphs.HaemersGraph(4, hyperoval=O, field=F)
@@ -1313,7 +1315,7 @@ def CossidentePenttilaGraph(q):
 
     from sage.libs.gap.libgap import libgap
     adj_list = libgap.function_factory("""function(q)
-        local z, e, so, G, nu, G1, G0, B, T, s, O1, O2, x;
+        local z, e, so, G, nu, G1, G0, B, T, s, O1, O2, x, sqo;
         LoadPackage("grape");
         G0:=SO(3,q^2);
         so:=GeneratorsOfGroup(G0);
@@ -1392,7 +1394,7 @@ def Nowhere0WordsTwoWeightCodeGraph(q, hyperoval=None, field=None, check_hyperov
 
     using the built-in construction::
 
-        sage: # needs sage.rings.finite_rings
+        sage: # needs sage.combinat sage.rings.finite_rings
         sage: g = graphs.Nowhere0WordsTwoWeightCodeGraph(8); g
         Nowhere0WordsTwoWeightCodeGraph(8): Graph on 196 vertices
         sage: g.is_strongly_regular(parameters=True)
@@ -1403,7 +1405,7 @@ def Nowhere0WordsTwoWeightCodeGraph(q, hyperoval=None, field=None, check_hyperov
 
     supplying your own hyperoval::
 
-        sage: # needs sage.rings.finite_rings
+        sage: # needs sage.combinat sage.rings.finite_rings
         sage: F = GF(8)
         sage: O = [vector(F,(0,0,1)),vector(F,(0,1,0))] + [vector(F, (1,x^2,x))
         ....:                                              for x in F]
@@ -1414,7 +1416,7 @@ def Nowhere0WordsTwoWeightCodeGraph(q, hyperoval=None, field=None, check_hyperov
 
     TESTS::
 
-        sage: # needs sage.rings.finite_rings
+        sage: # needs sage.combinat sage.rings.finite_rings
         sage: F = GF(8)  # repeating a point...
         sage: O = [vector(F,(1,0,0)),vector(F,(0,1,0))]+[vector(F, (1,x^2,x)) for x in F]
         sage: graphs.Nowhere0WordsTwoWeightCodeGraph(8,hyperoval=O,field=F)
