@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 r"""
 Intersection graphs
 
@@ -409,7 +408,7 @@ def OrthogonalArrayBlockGraph(k, n, OA=None):
 
     INPUT:
 
-    - ``k,n`` (integers)
+    - ``k``, ``n`` -- integers
 
     - ``OA`` -- An orthogonal array. If set to ``None`` (default) then
       :func:`~sage.combinat.designs.orthogonal_arrays.orthogonal_array` is
@@ -464,20 +463,20 @@ def OrthogonalArrayBlockGraph(k, n, OA=None):
 
     But nevertheless isospectral::
 
-        sage: g0.spectrum()                                                             # needs sage.modules
+        sage: g0.spectrum()                                                             # needs sage.modules sage.rings.number_field
         [9, 1, 1, 1, 1, 1, 1, 1, 1, 1, -3, -3, -3, -3, -3, -3]
-        sage: g1.spectrum()                                                             # needs sage.modules
+        sage: g1.spectrum()                                                             # needs sage.modules sage.rings.number_field
         [9, 1, 1, 1, 1, 1, 1, 1, 1, 1, -3, -3, -3, -3, -3, -3]
 
     Note that the graph ``g0`` is actually isomorphic to the affine polar graph
     `VO^+(4,2)`::
 
-        sage: graphs.AffineOrthogonalPolarGraph(4,2,'+').is_isomorphic(g0)              # needs sage.modules
+        sage: graphs.AffineOrthogonalPolarGraph(4,2,'+').is_isomorphic(g0)              # needs sage.libs.gap sage.modules
         True
 
     TESTS::
 
-        sage: G = graphs.OrthogonalArrayBlockGraph(4,6)                                 # needs sage.modules
+        sage: G = graphs.OrthogonalArrayBlockGraph(4,6)                                 # needs sage.modules sage.schemes
         Traceback (most recent call last):
         ...
         NotImplementedError: I don't know how to build an OA(4,6)!
