@@ -1,9 +1,7 @@
-# -*- coding: utf-8 -*-
 r"""
 1-skeletons of Platonic solids
 
 The methods defined here appear in :mod:`sage.graphs.graph_generators`.
-
 """
 # ****************************************************************************
 #
@@ -142,7 +140,7 @@ def OctahedralGraph():
     Construct and show an Octahedral graph::
 
         sage: g = graphs.OctahedralGraph()
-        sage: g.show()  # long time
+        sage: g.show()                          # long time                             # needs sage.plot
 
     Create several octahedral graphs in a Sage graphics array They will be drawn
     differently due to the use of the spring-layout algorithm::
