@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 r"""
 Random graphs
 
@@ -69,7 +68,7 @@ def RandomGNP(n, p, seed=None, fast=True, algorithm='Sage'):
     We plot a random graph on 12 nodes with probability `p = .71`::
 
         sage: gnp = graphs.RandomGNP(12,.71)
-        sage: gnp.show() # long time
+        sage: gnp.show()                        # long time                             # needs sage.plot
 
     We view many random graphs using a graphics array::
 
@@ -194,7 +193,7 @@ def RandomBipartite(n1, n2, p, set_position=False, seed=None):
 
     INPUT:
 
-    - ``n1, n2`` -- Cardinalities of the two sets
+    - ``n1``, ``n2`` -- Cardinalities of the two sets
 
     - ``p`` -- Probability for an edge to exist
 
@@ -222,7 +221,7 @@ def RandomBipartite(n1, n2, p, set_position=False, seed=None):
         ...
         ValueError: parameter p is a probability, and so should be a real value between 0 and 1
 
-    :trac:`12155`::
+    :issue:`12155`::
 
         sage: graphs.RandomBipartite(5, 6, .2).complement()                             # needs numpy
         complement(Random bipartite graph of order 5+6 with edge probability 0.200000000000000): Graph on 11 vertices
@@ -289,7 +288,7 @@ def RandomRegularBipartite(n1, n2, d1, set_position=False, seed=None):
 
     INPUT:
 
-    - ``n1, n2`` -- number of vertices in each side
+    - ``n1``, ``n2`` -- number of vertices in each side
 
     - ``d1`` -- degree of the vertices in the set of cardinality `n1`.
 
@@ -630,7 +629,7 @@ def RandomBoundedToleranceGraph(n, seed=None):
 
     TESTS:
 
-    Check that :trac:`32186` is fixed::
+    Check that :issue:`32186` is fixed::
 
         sage: for _ in range(100): _ = graphs.RandomBoundedToleranceGraph(1)
 
@@ -661,9 +660,9 @@ def RandomBoundedToleranceGraph(n, seed=None):
 
 
 def RandomGNM(n, m, dense=False, seed=None):
-    """
-    Returns a graph randomly picked out of all graphs on n vertices
-    with m edges.
+    r"""
+    Return a graph randomly picked out of all graphs on `n` vertices with `m`
+    edges.
 
     INPUT:
 
@@ -684,7 +683,7 @@ def RandomGNM(n, m, dense=False, seed=None):
         sage: graphs.RandomGNM(5, 10).edges(sort=True, labels=False)                    # needs networkx
         [(0, 1), (0, 2), (0, 3), (0, 4), (1, 2), (1, 3), (1, 4), (2, 3), (2, 4), (3, 4)]
 
-    We plot a random graph on 12 nodes with m = 12::
+    We plot a random graph on 12 nodes and 12 edges::
 
         sage: gnm = graphs.RandomGNM(12, 12)                                            # needs networkx
         sage: gnm.show()                        # long time                             # needs networkx sage.plot
@@ -1217,9 +1216,9 @@ def RandomChordalGraph(n, algorithm="growing", k=None, l=None, f=None, s=None, s
 
     .. SEEALSO::
 
-        - :meth:`~sage.graphs.graph_generators.growing_subtrees`
-        - :meth:`~sage.graphs.graph_generators.connecting_nodes`
-        - :meth:`~sage.graphs.graph_generators.pruned_tree`
+        - :meth:`~sage.graphs.generators.random.growing_subtrees`
+        - :meth:`~sage.graphs.generators.random.connecting_nodes`
+        - :meth:`~sage.graphs.generators.random.pruned_tree`
         - :wikipedia:`Chordal_graph`
         - :meth:`~sage.graphs.generic_graph.GenericGraph.is_chordal`
         - :meth:`~sage.graphs.graph_generators.GraphGenerators.IntersectionGraph`
@@ -1281,24 +1280,24 @@ def RandomChordalGraph(n, algorithm="growing", k=None, l=None, f=None, s=None, s
 
 
 def RandomLobster(n, p, q, seed=None):
-    """
-    Returns a random lobster.
+    r"""
+    Return a random lobster.
 
     A lobster is a tree that reduces to a caterpillar when pruning all
     leaf vertices. A caterpillar is a tree that reduces to a path when
-    pruning all leaf vertices (q=0).
+    pruning all leaf vertices (`q=0`).
 
     INPUT:
 
-    - ``n`` - expected number of vertices in the backbone
+    - ``n`` -- expected number of vertices in the backbone
 
-    - ``p`` - probability of adding an edge to the
+    - ``p`` -- probability of adding an edge to the
       backbone
 
-    - ``q`` - probability of adding an edge (claw) to the
+    - ``q`` -- probability of adding an edge (claw) to the
       arms
 
-    - ``seed`` - a ``random.Random`` seed or a Python ``int`` for the random
+    - ``seed`` -- a ``random.Random`` seed or a Python ``int`` for the random
       number generator (default: ``None``).
 
 
@@ -1337,14 +1336,14 @@ def RandomTree(n, seed=None):
     Returns a random tree on `n` nodes numbered `0` through `n-1`.
 
     By Cayley's theorem, there are `n^{n-2}` trees with vertex
-    set `\{0,1,...,n-1\}`. This constructor chooses one of these uniformly
+    set `\{0,1,\dots,n-1\}`. This constructor chooses one of these uniformly
     at random.
 
     ALGORITHM:
 
     The algorithm works by generating an `(n-2)`-long
     random sequence of numbers chosen independently and uniformly
-    from `\{0,1,\ldots,n-1\}` and then applies an inverse
+    from `\{0,1,\dots,n-1\}` and then applies an inverse
     Prufer transformation.
 
     INPUT:
@@ -1359,7 +1358,7 @@ def RandomTree(n, seed=None):
         sage: G = graphs.RandomTree(10)
         sage: G.is_tree()
         True
-        sage: G.show() # long time
+        sage: G.show()                          # long time                             # needs sage.plot
 
     TESTS:
 
@@ -1460,6 +1459,195 @@ def RandomTreePowerlaw(n, gamma=3, tries=1000, seed=None):
         return False
 
 
+def RandomKTree(n, k, seed=None):
+    r"""
+    Return a random `k`-tree on `n` nodes numbered `0` through `n-1`.
+
+    ALGORITHM:
+
+    The algorithm first generates a complete graph on `k + 1` vertices.
+    Vertices are subsequently generated by randomly choosing one of the
+    existing cliques in the graph, and creating a new clique by replacing
+    one of the vertices in the selected clique with a newly created one.
+
+    INPUT:
+
+    - ``n`` -- number of vertices in the `k`-tree
+
+    - ``k`` -- within a clique each vertex is connected to `k` vertices. `k`
+      also corresponds to the treewidth of the `k`-tree
+
+    - ``seed`` -- a ``random.Random`` seed or a Python ``int`` for the random
+      number generator (default: ``None``)
+
+    TESTS::
+
+        sage: g=graphs.RandomKTree(50,5)
+        sage: g.size()
+        235
+        sage: g.order()
+        50
+        sage: g.treewidth()
+        5
+        sage: graphs.RandomKTree(-5, 5)
+        Traceback (most recent call last):
+        ...
+        ValueError: n must not be negative
+        sage: graphs.RandomKTree(5, -5)
+        Traceback (most recent call last):
+        ...
+        ValueError: k must not be negative
+        sage: graphs.RandomKTree(2, 5)
+        Traceback (most recent call last):
+        ...
+        ValueError: n must be greater than k
+        sage: G = graphs.RandomKTree(50, 0)
+        sage: G.treewidth()
+        0
+
+    EXAMPLES::
+
+        sage: G = graphs.RandomKTree(50, 5)
+        sage: G.treewidth()
+        5
+        sage: G.show()  # not tested
+    """
+    if n < 0:
+        raise ValueError("n must not be negative")
+
+    if k < 0:
+        raise ValueError("k must not be negative")
+
+    # A graph with treewidth 0 has no edges
+    if k == 0:
+        g = Graph(n, name=f"Random 0-tree")
+        return g
+
+    if n < k + 1:
+        raise ValueError("n must be greater than k")
+
+    if seed is not None:
+        set_random_seed(seed)
+
+    g = Graph(name=f"Random {k}-tree")
+    g.add_clique(list(range(k + 1)))
+
+    cliques = [list(range(k+1))]
+
+    # Randomly choose a row, and copy 1 of the cliques
+    # One of those vertices is then replaced with a new vertex
+    for newVertex in range(k + 1, n):
+        copiedClique = cliques[randint(0, len(cliques)-1)].copy()
+        copiedClique[randint(0, k)] = newVertex
+        cliques.append(copiedClique)
+        for u in copiedClique:
+            if u != newVertex:
+                g.add_edge(u, newVertex)
+    return g
+
+
+def RandomPartialKTree(n, k, x, seed=None):
+    r"""
+    Return a random partial `k`-tree on `n` nodes.
+
+    A partial `k`-tree is defined as a subgraph of a `k`-tree. This can also be
+    described as a graph with treewidth at most `k`.
+
+    INPUT:
+
+    - ``n`` -- number of vertices in the `k`-tree
+
+    - ``k`` -- within a clique each vertex is connected to `k` vertices. `k`
+      also corresponds to the treewidth of the `k`-tree
+
+    - ``x`` -- how many edges are deleted from the `k`-tree
+
+    - ``seed`` -- a ``random.Random`` seed or a Python ``int`` for the random
+      number generator (default: ``None``)
+
+    TESTS::
+
+        sage: g=graphs.RandomPartialKTree(50,5,2)
+        sage: g.order()
+        50
+        sage: g.size()
+        233
+        sage: g.treewidth()
+        5
+        sage: graphs.RandomPartialKTree(-5, 5, 2)
+        Traceback (most recent call last):
+        ...
+        ValueError: n must not be negative
+        sage: graphs.RandomPartialKTree(5, -5, 2)
+        Traceback (most recent call last):
+        ...
+        ValueError: k must not be negative
+        sage: G = graphs.RandomPartialKTree(2, 5, 2)
+        Traceback (most recent call last):
+        ...
+        ValueError: n must be greater than k
+        sage: G = graphs.RandomPartialKTree(5, 2, 100)
+        Traceback (most recent call last):
+        ...
+        ValueError: x must be less than the number of edges in the `k`-tree with `n` nodes
+        sage: G = graphs.RandomPartialKTree(50, 0, 0)
+        sage: G.treewidth()
+        0
+        sage: G = graphs.RandomPartialKTree(5, 2, 7)
+        sage: G.treewidth()
+        0
+        sage: G.size()
+        0
+
+    EXAMPLES::
+
+        sage: G = graphs.RandomPartialKTree(50,5,2)
+        sage: G.treewidth()
+        5
+        sage: G.show()  # not tested
+    """
+    if n < 0:
+        raise ValueError("n must not be negative")
+
+    if k < 0:
+        raise ValueError("k must not be negative")
+
+    # A graph with treewidth 0 has no edges
+    if k == 0:
+        g = Graph(n, name=f"Random partial 0-tree")
+        return g
+
+    if n < k + 1:
+        raise ValueError("n must be greater than k")
+
+    if seed is not None:
+        set_random_seed(seed)
+
+    # This formula calculates how many edges are in a `k`-tree with `n` nodes
+    edgesInKTree = (k ^ 2 + k) / 2 + (n - k - 1) * k
+
+    # Check that x doesn't delete too many edges
+    if x > edgesInKTree:
+        raise ValueError("x must be less than the number of edges in the `k`-tree with `n` nodes")
+
+    # The graph will have no edges
+    if x == edgesInKTree:
+        g = Graph(n, name=f"Random partial {k}-tree")
+        return g
+
+    g = RandomKTree(n, k, seed)
+
+    from sage.misc.prandom import shuffle
+
+    edges = list(g.edges())
+    # Deletes x random edges from the graph
+    shuffle(edges)
+    g.delete_edges(edges[:x])
+
+    g.name(f"Random partial {k}-tree")
+    return g
+
+
 def RandomRegular(d, n, seed=None):
     r"""
     Return a random `d`-regular graph on `n` vertices, or ``False`` on failure.
@@ -1545,16 +1733,19 @@ def RandomToleranceGraph(n, seed=None):
     Return a random tolerance graph.
 
     The random tolerance graph is built from a random tolerance representation
-    by using the function `ToleranceGraph`. This representation is a list
-    `((l_0,r_0,t_0), (l_1,r_1,t_1), ..., (l_k,r_k,t_k))` where `k = n-1` and
-    `I_i = (l_i,r_i)` denotes a random interval and `t_i` a random positive
-    value. The width of the representation is limited to `n^2 * 2^n`.
+    by using the function
+    :meth:`~sage.graphs.generators.intersection.ToleranceGraph`. This
+    representation is a list `((l_0,r_0,t_0), (l_1,r_1,t_1), ...,
+    (l_k,r_k,t_k))` where `k = n-1` and `I_i = (l_i,r_i)` denotes a random
+    interval and `t_i` a random positive value. The width of the representation
+    is limited to `n^2 * 2^n`.
 
     .. NOTE::
 
-        The vertices are named 0, 1, ..., n-1. The tolerance representation used
-        to create the graph is saved with the graph and can be recovered using
-        ``get_vertex()`` or ``get_vertices()``.
+        The vertices are named `0, 1, \cdots, n-1`. The tolerance representation
+        used to create the graph is saved with the graph and can be recovered
+        using :meth:`~sage.graphs.generic_graph.GenericGraph.get_vertex` or
+        :meth:`~sage.graphs.generic_graph.GenericGraph.get_vertices`.
 
     INPUT:
 
@@ -1957,7 +2148,7 @@ def RandomTriangulation(n, set_position=False, k=3, seed=None):
         word2 = rotate_word_to_next_occurrence(word)
         if len(word2) >= 5:
             word = [word2[0]] + word2[4:]
-            in1, in2, in3 = [u[1] for u in word2[:3]]
+            in1, in2, in3 = (u[1] for u in word2[:3])
             edges.append([in1, in3])  # edge 'in1,in3'
             idx = embedding[in1].index(in2)
             embedding[in1].insert(idx, in3)
@@ -2164,17 +2355,17 @@ def RandomBicubicPlanar(n, seed=None):
     Z3 = Zmod(3)
     colour = Z3.zero()
     not_touched = [i for i, v in enumerate(w) if v[0] in ['x', 'xb']]
-    for i, v in enumerate(w):
+    for i, wi in enumerate(w):
         # internal edges
-        if v[0] == 'i':
+        if wi[0] == 'i':
             colour += 1
             if w[i + 1][0] == 'n':
-                G.add_edge((w[i], w[i + 1], colour))
-        elif v[0] == 'n':
+                G.add_edge((wi, w[i + 1], colour))
+        elif wi[0] == 'n':
             colour += 2
-        elif v[0] == 'x':
+        elif wi[0] == 'x':
             pile.append(i)
-        elif v[0] == 'xb' and i in not_touched:
+        elif wi[0] == 'xb' and i in not_touched:
             if pile:
                 j = pile.pop()
                 G.add_edge((w[i + 1], w[j - 1], colour))
