@@ -32,7 +32,7 @@ Functions and methods
 """
 
 
-class HypergraphGenerators():
+class HypergraphGenerators:
     r"""
     A class consisting of constructors for common hypergraphs.
     """
@@ -211,7 +211,7 @@ class HypergraphGenerators():
 
         INPUT:
 
-        - ``k,n`` -- nonnegative integers with `k\leq n`
+        - ``k``, ``n`` -- nonnegative integers with `k\leq n`
 
         EXAMPLES::
 
@@ -257,7 +257,7 @@ class HypergraphGenerators():
             Traceback (most recent call last):
             ...
             ValueError: the uniformity should be non-negative
-            sage: hypergraphs.UniformRandomUniform(52, I, 17)
+            sage: hypergraphs.UniformRandomUniform(52, I, 17)                           # needs sage.symbolic
             Traceback (most recent call last):
             ...
             ValueError: the uniformity should be an integer
