@@ -92,9 +92,7 @@ class AbelianGroupElement_gap(ElementLibGAP):
         r"""
         Implement pickling.
 
-        OUTPUT:
-
-        - a tuple ``f`` such that this element is ``f[0](*f[1])``
+        OUTPUT: tuple ``f`` such that this element is ``f[0](*f[1])``
 
         EXAMPLES::
 
@@ -112,9 +110,7 @@ class AbelianGroupElement_gap(ElementLibGAP):
         r"""
         Return the tuple of exponents of this element.
 
-        OUTPUT:
-
-        - a tuple of integers
+        OUTPUT: tuple of integers
 
         EXAMPLES::
 
@@ -172,9 +168,7 @@ class AbelianGroupElement_gap(ElementLibGAP):
         r"""
         Return the order of this element.
 
-        OUTPUT:
-
-        - an integer or infinity
+        OUTPUT: integer or infinity
 
         EXAMPLES::
 
@@ -204,9 +198,7 @@ class AbelianGroupElement_polycyclic(AbelianGroupElement_gap):
         r"""
         Return the tuple of exponents of ``self``.
 
-        OUTPUT:
-
-        - a tuple of integers
+        OUTPUT: tuple of integers
 
         EXAMPLES::
 
@@ -272,9 +264,7 @@ class AbelianGroup_gap(UniqueRepresentation, GroupMixinLibGAP, ParentLibGAP, Abe
 
         - ``S`` -- anything
 
-        OUTPUT:
-
-        Boolean.
+        OUTPUT: boolean
 
         EXAMPLES::
 
@@ -293,7 +283,7 @@ class AbelianGroup_gap(UniqueRepresentation, GroupMixinLibGAP, ParentLibGAP, Abe
 
     def _element_constructor_(self, x, check=True):
         r"""
-        Defines coercions and conversions.
+        Define coercions and conversions.
 
         INPUT:
 
@@ -331,7 +321,7 @@ class AbelianGroup_gap(UniqueRepresentation, GroupMixinLibGAP, ParentLibGAP, Abe
 
         TESTS:
 
-        Document that :trac:`31428` is fixed::
+        Document that :issue:`31428` is fixed::
 
             sage: A = AbelianGroupGap([])
             sage: A([]) == A.one()
@@ -492,9 +482,7 @@ class AbelianGroup_gap(UniqueRepresentation, GroupMixinLibGAP, ParentLibGAP, Abe
         Use :meth:`elementary_divisors` if you are looking for an
         invariant of the group.
 
-        OUTPUT:
-
-        - a tuple of integers
+        OUTPUT: tuple of integers
 
         EXAMPLES::
 
@@ -598,9 +586,7 @@ class AbelianGroup_gap(UniqueRepresentation, GroupMixinLibGAP, ParentLibGAP, Abe
 
         - ``gens`` -- a list of elements coercible into this group
 
-        OUTPUT:
-
-        - a subgroup
+        OUTPUT: a subgroup
 
         EXAMPLES::
 
@@ -643,9 +629,7 @@ class AbelianGroupGap(AbelianGroup_gap):
     - ``generator_orders`` -- a list of nonnegative integers where `0`
       gives a factor isomorphic to `\ZZ`
 
-    OUTPUT:
-
-    - an abelian group
+    OUTPUT: an abelian group
 
     EXAMPLES::
 
@@ -731,7 +715,7 @@ class AbelianGroupGap(AbelianGroup_gap):
 
     def __reduce__(self):
         r"""
-        Implements pickling.
+        Implement pickling.
 
         We have to work around the fact that gap does not provide pickling.
 
@@ -816,11 +800,11 @@ class AbelianGroupSubgroup_gap(AbelianGroup_gap):
             Subgroup of Abelian group with gap, generator orders (2, 3, 4, 5)
              generated by (f1, f2)
         """
-        return "Subgroup of %s generated by %s"%(self.ambient(),self.gens())
+        return "Subgroup of %s generated by %s" % (self.ambient(),self.gens())
 
     def __reduce__(self):
         r"""
-        Implements pickling.
+        Implement pickling.
 
         We have to work around the fact that gap does not provide pickling.
 
@@ -850,9 +834,7 @@ class AbelianGroupSubgroup_gap(AbelianGroup_gap):
 
         - ``x`` -- an element of this subgroup
 
-        OUTPUT:
-
-        The corresponding element of the ambient group
+        OUTPUT: the corresponding element of the ambient group
 
         EXAMPLES::
 
@@ -881,9 +863,7 @@ class AbelianGroupSubgroup_gap(AbelianGroup_gap):
 
         - ``x`` -- an element of the ambient group that actually lies in this subgroup.
 
-        OUTPUT:
-
-        The corresponding element of this subgroup
+        OUTPUT: the corresponding element of this subgroup
 
         EXAMPLES::
 
@@ -955,7 +935,7 @@ class AbelianGroupQuotient_gap(AbelianGroup_gap):
 
     def __reduce__(self):
         r"""
-        Implements pickling.
+        Implement pickling.
 
         We have to work around the fact that gap does not provide pickling.
 
@@ -980,9 +960,7 @@ class AbelianGroupQuotient_gap(AbelianGroup_gap):
 
         - ``S`` -- anything
 
-        OUTPUT:
-
-        Boolean.
+        OUTPUT: boolean
 
         EXAMPLES::
 
