@@ -1,13 +1,16 @@
+# sage.doctest: needs sage.rings.number_field
 r"""
 Class functions of groups.
 
 This module implements a wrapper of GAP's ClassFunction function.
 
-NOTE: The ordering of the columns of the character table of a group
-corresponds to the ordering of the list. However, in general there is
-no way to canonically list (or index) the conjugacy classes of a group.
-Therefore the ordering of  the columns of the character table of
-a group is somewhat random.
+.. NOTE:
+
+    The ordering of the columns of the character table of a group
+    corresponds to the ordering of the list. However, in general there is
+    no way to canonically list (or index) the conjugacy classes of a group.
+    Therefore the ordering of  the columns of the character table of
+    a group is somewhat random.
 
 AUTHORS:
 
@@ -16,21 +19,23 @@ AUTHORS:
 - Volker Braun (October 2010): Bugfixes, exterior and symmetric power.
 """
 
-#*****************************************************************************
+# ****************************************************************************
 #       Copyright (C) 2008 Franco Saliola <saliola@gmail.com>
 #
 #  Distributed under the terms of the GNU General Public License (GPL)
 #                  https://www.gnu.org/licenses/
-#*****************************************************************************
+# ****************************************************************************
 
 from sage.structure.sage_object import SageObject
 from sage.structure.richcmp import richcmp, richcmp_method
 from sage.interfaces.gap import gap
 from sage.rings.integer import Integer
-from sage.rings.number_field.number_field import CyclotomicField
 from sage.libs.gap.element import GapElement
 from sage.libs.gap.libgap import libgap
 from sage.libs.gap.element import GapElement as LibGapElement
+from sage.misc.lazy_import import lazy_import
+
+lazy_import('sage.rings.number_field.number_field', 'CyclotomicField')
 
 # TODO:
 #
@@ -45,11 +50,10 @@ def ClassFunction(group, values):
 
     INPUT:
 
-    - ``group`` -- a group.
-
-    - ``values`` -- list/tuple/iterable of numbers. The values of the
-      class function on the conjugacy classes, in that order.
+    - ``group`` -- a group
 
+    - ``values`` -- list/tuple/iterable of numbers; the values of the
+      class function on the conjugacy classes, in that order
 
     EXAMPLES::
 
@@ -63,24 +67,26 @@ def ClassFunction(group, values):
         sage: chi = ClassFunction(G, values); chi
         Character of Cyclic group of order 4 as a permutation group
     """
+    from sage.misc.superseded import deprecation
     try:
         return group.class_function(values)
     except AttributeError:
         pass
 
-    if isinstance(values, LibGapElement):
+    if isinstance(values, (LibGapElement, tuple, list)):
         return ClassFunction_libgap(group, values)
 
+    # deprecation(36889, "please use libgap class functions instead")
     return ClassFunction_gap(group, values)
 
 
 #####################################################################
-###
-### GAP Interface-based Class Function
-###
-### This is old code that should be deleted once we have transitioned
-### everything to using the library interface to GAP.
-###
+#
+#   GAP Interface-based Class Function
+#
+#   This is old code that should be deleted once we have transitioned
+#   everything to using the library interface to GAP.
+#
 #####################################################################
 
 @richcmp_method
@@ -127,13 +133,13 @@ class ClassFunction_gap(SageObject):
 
     def _gap_init_(self):
         r"""
-        Returns a string showing how to declare / initialize self in Gap.
+        Return a string showing how to declare / initialize ``self`` in Gap.
         Stored in the \code{self._gap_string} attribute.
 
         EXAMPLES::
 
             sage: G = CyclicPermutationGroup(4)
-            sage: values  = [1, -1, 1, -1]
+            sage: values  = gap([1, -1, 1, -1])
             sage: ClassFunction(G, values)._gap_init_()
             'ClassFunction( CharacterTable( Group( [ (1,2,3,4) ] ) ), [ 1, -1, 1, -1 ] )'
         """
@@ -141,12 +147,12 @@ class ClassFunction_gap(SageObject):
 
     def _gap_(self, *args):
         r"""
-        Coerce self into a GAP element.
+        Coerce ``self`` into a GAP element.
 
         EXAMPLES::
 
             sage: G = CyclicPermutationGroup(4)
-            sage: values  = [1, -1, 1, -1]
+            sage: values  = gap([1, -1, 1, -1])
             sage: chi = ClassFunction(G, values);  chi
             Character of Cyclic group of order 4 as a permutation group
             sage: type(_)
@@ -162,27 +168,23 @@ class ClassFunction_gap(SageObject):
         r"""
         Return a string representation.
 
-        OUTPUT:
-
-        A string.
-
         EXAMPLES::
 
             sage: G = SymmetricGroup(4)
             sage: values  = [1, -1, 1, 1, -1]
-            sage: ClassFunction(G, values)
+            sage: ClassFunction(G, gap(values))
             Character of Symmetric group of order 4! as a permutation group
         """
         return "Character of %s" % repr(self._group)
 
     def __iter__(self):
         r"""
-        Iterate through the values of self evaluated on the conjugacy
+        Iterate through the values of ``self`` evaluated on the conjugacy
         classes.
 
         EXAMPLES::
 
-            sage: xi = ClassFunction(SymmetricGroup(4), [1, -1, 1, 1, -1])
+            sage: xi = ClassFunction(SymmetricGroup(4), gap([1, -1, 1, 1, -1]))
             sage: list(xi)
             [1, -1, 1, 1, -1]
         """
@@ -236,7 +238,7 @@ class ClassFunction_gap(SageObject):
         EXAMPLES::
 
             sage: G = PermutationGroup([[(1,2,3),(4,5)],[(3,4)]])
-            sage: chi = ClassFunction(G, [1, 1, 1, 1, 1, 1, 1])
+            sage: chi = ClassFunction(G, gap([1, 1, 1, 1, 1, 1, 1]))
             sage: type(chi)
             <class 'sage.groups.class_function.ClassFunction_gap'>
             sage: loads(dumps(chi)) == chi
@@ -246,7 +248,7 @@ class ClassFunction_gap(SageObject):
 
     def domain(self):
         r"""
-        Returns the domain of the self.
+        Return the domain of the ``self``.
 
         OUTPUT:
 
@@ -291,20 +293,17 @@ class ClassFunction_gap(SageObject):
 
     def __add__(self, other):
         r"""
-        Returns the sum of the characters self and other.
+        Return the sum of the characters of ``self`` and other.
 
         INPUT:
 
-        - ``other`` -- a :class:`ClassFunction` of the same group as
-          ``self``.
+        - ``other`` -- a :class:`ClassFunction` of the same group as ``self``
 
-        OUTPUT:
-
-        A :class:`ClassFunction`
+        OUTPUT: a :class:`ClassFunction`
 
         EXAMPLES::
 
-            sage: chi = ClassFunction(SymmetricGroup(4), [3, 1, -1, 0, -1])
+            sage: chi = ClassFunction(SymmetricGroup(4), gap([3, 1, -1, 0, -1]))
             sage: s = chi+chi
             sage: s
             Character of Symmetric group of order 4! as a permutation group
@@ -318,16 +317,14 @@ class ClassFunction_gap(SageObject):
 
     def __sub__(self, other):
         r"""
-        Returns the difference of the characters ``self`` and ``other``.
+        Return the difference of the characters ``self`` and ``other``.
 
         INPUT:
 
         - ``other`` -- a :class:`ClassFunction` of the same group as
-          ``self``.
+          ``self``
 
-        OUTPUT:
-
-        A :class:`ClassFunction`
+        OUTPUT: a :class:`ClassFunction`
 
         EXAMPLES::
 
@@ -352,18 +349,16 @@ class ClassFunction_gap(SageObject):
         INPUT:
 
         - ``other`` -- either a number or a :class:`ClassFunction` of
-          the same group as ``self``. A number can be anything that
+          the same group as ``self``; a number can be anything that
           can be converted into GAP: integers, rational, and elements
-          of certain number fields.
+          of certain number fields
 
-        OUTPUT:
-
-        A :class:`ClassFunction`
+        OUTPUT: a :class:`ClassFunction`
 
         EXAMPLES::
 
             sage: G = SymmetricGroup(4)
-            sage: chi1 = ClassFunction(G, [3, 1, -1, 0, -1])
+            sage: chi1 = ClassFunction(G, gap([3, 1, -1, 0, -1]))
             sage: 3*chi1
             Character of Symmetric group of order 4! as a permutation group
             sage: 3*chi1 == chi1+chi1+chi1
@@ -371,7 +366,6 @@ class ClassFunction_gap(SageObject):
             sage: (3*chi1).values()
             [9, 3, -3, 0, -3]
 
-
             sage: (1/2*chi1).values()
             [3/2, 1/2, -1/2, 0, -1/2]
 
@@ -381,7 +375,7 @@ class ClassFunction_gap(SageObject):
             sage: (zeta3 * chi1).values()
             [3*zeta3, zeta3, -zeta3, 0, -zeta3]
 
-            sage: chi2 = ClassFunction(G, [1, -1, 1, 1, -1])
+            sage: chi2 = ClassFunction(G, gap([1, -1, 1, 1, -1]))
             sage: p = chi1*chi2
             sage: p
             Character of Symmetric group of order 4! as a permutation group
@@ -415,9 +409,7 @@ class ClassFunction_gap(SageObject):
         r"""
         Return ``self``.
 
-        OUTPUT:
-
-        A :class:`ClassFunction`
+        OUTPUT: a :class:`ClassFunction`
 
         EXAMPLES::
 
@@ -435,9 +427,7 @@ class ClassFunction_gap(SageObject):
         r"""
         Return the additive inverse of ``self``.
 
-        OUTPUT:
-
-        A :class:`ClassFunction`
+        OUTPUT: a :class:`ClassFunction`
 
         EXAMPLES::
 
@@ -453,7 +443,7 @@ class ClassFunction_gap(SageObject):
 
     def __pow__(self, other):
         r"""
-        Returns the product of self with itself other times.
+        Return the product of ``self`` with itself other times.
 
         EXAMPLES::
 
@@ -464,26 +454,23 @@ class ClassFunction_gap(SageObject):
             sage: p.values()
             [27, 1, -1, 0, -1]
         """
-        if not isinstance(other, (int,Integer)):
+        if not isinstance(other, (int, Integer)):
             raise NotImplementedError
         return ClassFunction(self._group, self._gap_classfunction ** other)
 
     def symmetric_power(self, n):
         r"""
-        Returns the symmetrized product of self with itself ``n`` times.
+        Return the symmetrized product of ``self`` with itself ``n`` times.
 
         INPUT:
 
-        - ``n`` -- a positive integer.
+        - ``n`` -- positive integer
 
-        OUTPUT:
-
-        The ``n``-th symmetrized power of ``self`` as a
-        :class:`ClassFunction`.
+        OUTPUT: the ``n``-th symmetrized power of ``self`` as a :class:`ClassFunction`
 
         EXAMPLES::
 
-            sage: chi = ClassFunction(SymmetricGroup(4), [3, 1, -1, 0, -1])
+            sage: chi = ClassFunction(SymmetricGroup(4), gap([3, 1, -1, 0, -1]))
             sage: p = chi.symmetric_power(3)
             sage: p
             Character of Symmetric group of order 4! as a permutation group
@@ -492,25 +479,23 @@ class ClassFunction_gap(SageObject):
         """
         n = Integer(n)
         tbl = gap.UnderlyingCharacterTable(self)
-        return ClassFunction(self._group, gap.SymmetricParts(tbl,[self],n)[1])
+        return ClassFunction(self._group, gap.SymmetricParts(tbl, [self], n)[1])
 
     def exterior_power(self, n):
         r"""
-        Returns the anti-symmetrized product of self with itself ``n`` times.
+        Return the antisymmetrized product of ``self`` with itself ``n``
+        times.
 
         INPUT:
 
-        - ``n`` -- a positive integer.
+        - ``n`` -- positive integer.
 
-        OUTPUT:
-
-        The ``n``-th anti-symmetrized power of ``self`` as a
-        :class:`ClassFunction`.
+        OUTPUT: the ``n``-th antisymmetrized power of ``self`` as a :class:`ClassFunction`
 
         EXAMPLES::
 
-            sage: chi = ClassFunction(SymmetricGroup(4), [3, 1, -1, 0, -1])
-            sage: p = chi.exterior_power(3)   # the highest anti-symmetric power for a 3-d character
+            sage: chi = ClassFunction(SymmetricGroup(4), gap([3, 1, -1, 0, -1]))
+            sage: p = chi.exterior_power(3)   # the highest antisymmetric power for a 3-d character
             sage: p
             Character of Symmetric group of order 4! as a permutation group
             sage: p.values()
@@ -520,11 +505,11 @@ class ClassFunction_gap(SageObject):
         """
         n = Integer(n)
         tbl = gap.UnderlyingCharacterTable(self)
-        return ClassFunction(self._group, gap.AntiSymmetricParts(tbl,[self],n)[1])
+        return ClassFunction(self._group, gap.AntiSymmetricParts(tbl, [self], n)[1])
 
     def scalar_product(self, other):
         r"""
-        Returns the scalar product of self with other.
+        Return the scalar product of ``self`` with other.
 
         EXAMPLES::
 
@@ -541,8 +526,8 @@ class ClassFunction_gap(SageObject):
 
     def is_irreducible(self):
         r"""
-        Returns True if self cannot be written as the sum of two nonzero
-        characters of self.
+        Return ``True`` if ``self`` cannot be written as the sum of two nonzero
+        characters of ``self``.
 
         EXAMPLES::
 
@@ -555,7 +540,7 @@ class ClassFunction_gap(SageObject):
 
     def degree(self):
         r"""
-        Returns the degree of the character self.
+        Return the degree of the character self.
 
         EXAMPLES::
 
@@ -568,7 +553,7 @@ class ClassFunction_gap(SageObject):
 
     def irreducible_constituents(self):
         r"""
-        Returns a list of the characters that appear in the decomposition
+        Return a list of the characters that appear in the decomposition
         of chi.
 
         EXAMPLES::
@@ -600,10 +585,9 @@ class ClassFunction_gap(SageObject):
         L = self._gap_classfunction.ConstituentsOfCharacter()
         return tuple(ClassFunction(self._group, list(l)) for l in L)
 
-    def decompose(self):
+    def decompose(self) -> tuple:
         r"""
-        Returns a list of the characters that appear in the decomposition
-        of chi.
+        Return a list of the characters appearing the decomposition of ``self``.
 
         EXAMPLES::
 
@@ -613,14 +597,13 @@ class ClassFunction_gap(SageObject):
             ((3, Character of Symmetric group of order 5! as a permutation group),
              (2, Character of Symmetric group of order 5! as a permutation group))
         """
-        L = []
-        for irr in self.irreducible_constituents():
-            L.append((self.scalar_product(irr), irr))
+        L = [(self.scalar_product(irr), irr)
+             for irr in self.irreducible_constituents()]
         return tuple(L)
 
     def norm(self):
         r"""
-        Returns the norm of self.
+        Return the norm of ``self``.
 
         EXAMPLES::
 
@@ -630,9 +613,9 @@ class ClassFunction_gap(SageObject):
         """
         return self._gap_classfunction.Norm()
 
-    def values(self):
+    def values(self) -> list:
         r"""
-        Return the list of values of self on the conjugacy classes.
+        Return the list of values of ``self`` on the conjugacy classes.
 
         EXAMPLES::
 
@@ -660,7 +643,7 @@ class ClassFunction_gap(SageObject):
 
     def central_character(self):
         r"""
-        Returns the central character of self.
+        Return the central character of ``self``.
 
         EXAMPLES::
 
@@ -672,7 +655,7 @@ class ClassFunction_gap(SageObject):
 
     def determinant_character(self):
         r"""
-        Returns the determinant character of self.
+        Return the determinant character of ``self``.
 
         EXAMPLES::
 
@@ -691,7 +674,7 @@ class ClassFunction_gap(SageObject):
             sage: chi1.tensor_product(chi3).values()
             [1, -1, 1]
         """
-        return ClassFunction(self._group, gap.Tensored([self],[other])[1])
+        return ClassFunction(self._group, gap.Tensored([self], [other])[1])
 
     def restrict(self, H):
         r"""
@@ -699,11 +682,9 @@ class ClassFunction_gap(SageObject):
 
         INPUT:
 
-        - ``H`` -- a subgroup of the underlying group of ``self``.
+        - ``H`` -- a subgroup of the underlying group of ``self``
 
-        OUTPUT:
-
-        A :class:`ClassFunction` of ``H`` defined by restriction.
+        OUTPUT: a :class:`ClassFunction` of ``H`` defined by restriction
 
         EXAMPLES::
 
@@ -712,7 +693,8 @@ class ClassFunction_gap(SageObject):
             Character of Symmetric group of order 5! as a permutation group
             sage: H = G.subgroup([(1,2,3), (1,2), (4,5)])
             sage: chi.restrict(H)
-            Character of Subgroup generated by [(4,5), (1,2), (1,2,3)] of (Symmetric group of order 5! as a permutation group)
+            Character of Subgroup generated by [(1,2,3), (1,2), (4,5)] of
+             (Symmetric group of order 5! as a permutation group)
             sage: chi.restrict(H).values()
             [3, -3, -3, -1, 0, 0]
         """
@@ -725,7 +707,7 @@ class ClassFunction_gap(SageObject):
 
         INPUT:
 
-        - ``G`` -- A supergroup of the underlying group of ``self``.
+        - ``G`` -- a supergroup of the underlying group of ``self``
 
         OUTPUT:
 
@@ -738,7 +720,8 @@ class ClassFunction_gap(SageObject):
             sage: G = SymmetricGroup(5)
             sage: H = G.subgroup([(1,2,3), (1,2), (4,5)])
             sage: xi = H.trivial_character(); xi
-            Character of Subgroup generated by [(4,5), (1,2), (1,2,3)] of (Symmetric group of order 5! as a permutation group)
+            Character of Subgroup generated by [(1,2,3), (1,2), (4,5)] of
+             (Symmetric group of order 5! as a permutation group)
             sage: xi.induct(G)
             Character of Symmetric group of order 5! as a permutation group
             sage: xi.induct(G).values()
@@ -786,9 +769,9 @@ class ClassFunction_gap(SageObject):
 
 
 #####################################################################
-###
-### Class function using the GAP library
-###
+#
+#   Class function using the GAP library
+#
 #####################################################################
 
 
@@ -829,12 +812,11 @@ class ClassFunction_libgap(SageObject):
         if isinstance(values, LibGapElement) and values.IsClassFunction():
             self._gap_classfunction = values
         else:
-            self._gap_classfunction = libgap.ClassFunction(G._libgap_(),
-                                                           list(values))
+            self._gap_classfunction = libgap.ClassFunction(G, list(values))
         e = self._gap_classfunction.Conductor().sage()
         self._base_ring = CyclotomicField(e)
 
-    def gap(self):
+    def _libgap_(self):
         r"""
         Return the underlying LibGAP element.
 
@@ -845,24 +827,20 @@ class ClassFunction_libgap(SageObject):
             sage: chi = ClassFunction(G, values);  chi
             Character of Cyclic group of order 4 as a permutation group
             sage: type(chi)
-            <class 'sage.groups.class_function.ClassFunction_gap'>
-            sage: gap(chi)
-            ClassFunction( CharacterTable( Group( [ (1,2,3,4) ] ) ), [ 1, -1, 1, -1 ] )
+            <class 'sage.groups.class_function.ClassFunction_libgap'>
+            sage: libgap(chi)
+            ClassFunction( CharacterTable( Group([ (1,2,3,4) ]) ), [ 1, -1, 1, -1 ] )
             sage: type(_)
-            <class 'sage.interfaces.gap.GapElement'>
+            <class 'sage.libs.gap.element.GapElement_List'>
         """
         return self._gap_classfunction
 
-    _libgap_ = _gap_ = gap
+    gap = _gap_ = _libgap_
 
     def _repr_(self):
         r"""
         Return a string representation.
 
-        OUTPUT:
-
-        A string.
-
         EXAMPLES::
 
             sage: G = SymmetricGroup(4)
@@ -872,6 +850,16 @@ class ClassFunction_libgap(SageObject):
         """
         return "Character of %s" % repr(self._group)
 
+    def __hash__(self):
+        r"""
+        TESTS::
+
+            sage: G = SymmetricGroup(5)
+            sage: chi1 = ClassFunction(G,[1,1,1,1,1,1,1])
+            sage: d = {chi1:'trivial'}
+        """
+        return hash((self._group, tuple(self)))
+
     def __iter__(self):
         r"""
         Iterate through the values.
@@ -939,9 +927,7 @@ class ClassFunction_libgap(SageObject):
         r"""
         Return the domain of ``self``.
 
-        OUTPUT:
-
-        The underlying group of the class function.
+        OUTPUT: the underlying group of the class function
 
         EXAMPLES::
 
@@ -988,12 +974,9 @@ class ClassFunction_libgap(SageObject):
 
         INPUT:
 
-        - ``other`` -- a :class:`ClassFunction` of the same group as
-          ``self``.
+        - ``other`` -- a :class:`ClassFunction` of the same group as ``self``
 
-        OUTPUT:
-
-        A :class:`ClassFunction`
+        OUTPUT: a :class:`ClassFunction`
 
         EXAMPLES::
 
@@ -1015,12 +998,9 @@ class ClassFunction_libgap(SageObject):
 
         INPUT:
 
-        - ``other`` -- a :class:`ClassFunction` of the same group as
-          ``self``.
+        - ``other`` -- a :class:`ClassFunction` of the same group as ``self``
 
-        OUTPUT:
-
-        A :class:`ClassFunction`
+        OUTPUT: a :class:`ClassFunction`
 
         EXAMPLES::
 
@@ -1049,9 +1029,7 @@ class ClassFunction_libgap(SageObject):
           can be converted into GAP: integers, rational, and elements
           of certain number fields.
 
-        OUTPUT:
-
-        A :class:`ClassFunction`
+        OUTPUT: a :class:`ClassFunction`
 
         EXAMPLES::
 
@@ -1064,7 +1042,6 @@ class ClassFunction_libgap(SageObject):
             sage: (3*chi1).values()
             [9, 3, -3, 0, -3]
 
-
             sage: (1/2*chi1).values()
             [3/2, 1/2, -1/2, 0, -1/2]
 
@@ -1108,9 +1085,7 @@ class ClassFunction_libgap(SageObject):
         r"""
         Return ``self``.
 
-        OUTPUT:
-
-        A :class:`ClassFunction`
+        OUTPUT: a :class:`ClassFunction`
 
         EXAMPLES::
 
@@ -1128,9 +1103,7 @@ class ClassFunction_libgap(SageObject):
         r"""
         Return the additive inverse of ``self``.
 
-        OUTPUT:
-
-        A :class:`ClassFunction`
+        OUTPUT: a :class:`ClassFunction`
 
         EXAMPLES::
 
@@ -1157,7 +1130,7 @@ class ClassFunction_libgap(SageObject):
             sage: p.values()
             [27, 1, -1, 0, -1]
         """
-        if not isinstance(other, (int,Integer)):
+        if not isinstance(other, (int, Integer)):
             raise NotImplementedError
         return ClassFunction(self._group, self._gap_classfunction ** other)
 
@@ -1167,12 +1140,9 @@ class ClassFunction_libgap(SageObject):
 
         INPUT:
 
-        - ``n`` -- a positive integer
+        - ``n`` -- positive integer
 
-        OUTPUT:
-
-        The ``n``-th symmetrized power of ``self`` as a
-        :class:`ClassFunction`.
+        OUTPUT: the ``n``-th symmetrized power of ``self`` as a :class:`ClassFunction`
 
         EXAMPLES::
 
@@ -1184,26 +1154,23 @@ class ClassFunction_libgap(SageObject):
             [10, 2, -2, 1, 0]
         """
         n = Integer(n)
-        tbl = self._gap_classfunction.UnderlyingCharacterTable(self)
-        return ClassFunction(self._group, tbl.SymmetricParts([self],n)[1])
+        tbl = self._gap_classfunction.UnderlyingCharacterTable()
+        return ClassFunction(self._group, tbl.SymmetricParts([self], n)[0])
 
     def exterior_power(self, n):
         r"""
-        Return the anti-symmetrized product of ``self`` with itself ``n`` times.
+        Return the antisymmetrized product of ``self`` with itself ``n`` times.
 
         INPUT:
 
-        - ``n`` -- a positive integer
+        - ``n`` -- positive integer
 
-        OUTPUT:
-
-        The ``n``-th anti-symmetrized power of ``self`` as a
-        :class:`ClassFunction`.
+        OUTPUT: the ``n``-th antisymmetrized power of ``self`` as a :class:`ClassFunction`
 
         EXAMPLES::
 
             sage: chi = ClassFunction(SymmetricGroup(4), [3, 1, -1, 0, -1])
-            sage: p = chi.exterior_power(3)   # the highest anti-symmetric power for a 3-d character
+            sage: p = chi.exterior_power(3)   # the highest antisymmetric power for a 3-d character
             sage: p
             Character of Symmetric group of order 4! as a permutation group
             sage: p.values()
@@ -1212,8 +1179,8 @@ class ClassFunction_libgap(SageObject):
             True
         """
         n = Integer(n)
-        tbl = self._gap_classfunction.UnderlyingCharacterTable(self)
-        return ClassFunction(self._group, tbl.AntiSymmetricParts([self],n)[1])
+        tbl = self._gap_classfunction.UnderlyingCharacterTable()
+        return ClassFunction(self._group, tbl.AntiSymmetricParts([self], n)[0])
 
     def scalar_product(self, other):
         r"""
@@ -1294,10 +1261,9 @@ class ClassFunction_libgap(SageObject):
         L = self._gap_classfunction.ConstituentsOfCharacter()
         return tuple(ClassFunction_libgap(self._group, l) for l in L)
 
-    def decompose(self):
+    def decompose(self) -> tuple:
         r"""
-        Return a list of the characters that appear in the decomposition
-        of ``self``.
+        Return a list of the characters appearing the decomposition of ``self``.
 
         EXAMPLES::
 
@@ -1307,9 +1273,8 @@ class ClassFunction_libgap(SageObject):
             ((3, Character of Symmetric group of order 5! as a permutation group),
              (2, Character of Symmetric group of order 5! as a permutation group))
         """
-        L = []
-        for irr in self.irreducible_constituents():
-            L.append((self.scalar_product(irr), irr))
+        L = [(self.scalar_product(irr), irr)
+             for irr in self.irreducible_constituents()]
         return tuple(L)
 
     def norm(self):
@@ -1326,12 +1291,12 @@ class ClassFunction_libgap(SageObject):
 
     def values(self):
         r"""
-        Return the list of values of self on the conjugacy classes.
+        Return the list of values of ``self`` on the conjugacy classes.
 
         EXAMPLES::
 
             sage: G = GL(2,3)
-            sage: [x.values() for x in G.irreducible_characters()] #random
+            sage: [x.values() for x in G.irreducible_characters()]  # random
             [[1, 1, 1, 1, 1, 1, 1, 1],
              [1, 1, 1, 1, 1, -1, -1, -1],
              [2, -1, 2, -1, 2, 0, 0, 0],
@@ -1396,11 +1361,9 @@ class ClassFunction_libgap(SageObject):
 
         INPUT:
 
-        - ``H`` -- a subgroup of the underlying group of ``self``.
+        - ``H`` -- a subgroup of the underlying group of ``self``
 
-        OUTPUT:
-
-        A :class:`ClassFunction` of ``H`` defined by restriction.
+        OUTPUT: a :class:`ClassFunction` of ``H`` defined by restriction
 
         EXAMPLES::
 
@@ -1409,7 +1372,8 @@ class ClassFunction_libgap(SageObject):
             Character of Symmetric group of order 5! as a permutation group
             sage: H = G.subgroup([(1,2,3), (1,2), (4,5)])
             sage: chi.restrict(H)
-            Character of Subgroup generated by [(4,5), (1,2), (1,2,3)] of (Symmetric group of order 5! as a permutation group)
+            Character of Subgroup generated by [(1,2,3), (1,2), (4,5)] of
+             (Symmetric group of order 5! as a permutation group)
             sage: chi.restrict(H).values()
             [3, -3, -3, -1, 0, 0]
         """
@@ -1427,7 +1391,7 @@ class ClassFunction_libgap(SageObject):
 
         INPUT:
 
-        - ``G`` -- A supergroup of the underlying group of ``self``.
+        - ``G`` -- a supergroup of the underlying group of ``self``
 
         OUTPUT:
 
@@ -1440,7 +1404,8 @@ class ClassFunction_libgap(SageObject):
             sage: G = SymmetricGroup(5)
             sage: H = G.subgroup([(1,2,3), (1,2), (4,5)])
             sage: xi = H.trivial_character(); xi
-            Character of Subgroup generated by [(4,5), (1,2), (1,2,3)] of (Symmetric group of order 5! as a permutation group)
+            Character of Subgroup generated by [(1,2,3), (1,2), (4,5)] of
+             (Symmetric group of order 5! as a permutation group)
             sage: xi.induct(G)
             Character of Symmetric group of order 5! as a permutation group
             sage: xi.induct(G).values()
