@@ -1,3 +1,4 @@
+# sage.doctest: needs sage.modules
 """
 Mix-in Class for GAP-based Groups
 
@@ -8,7 +9,7 @@ the parent/element.
 If your group implementation uses libgap, then you should add
 :class:`GroupMixinLibGAP` as the first class that you are deriving
 from. This ensures that it properly overrides any default methods that
-just raise ``NotImplementedError``.
+just raise :class:`NotImplementedError`.
 """
 
 from sage.libs.gap.libgap import libgap
@@ -18,7 +19,8 @@ from sage.misc.cachefunc import cached_method
 from sage.groups.class_function import ClassFunction_libgap
 from sage.groups.libgap_wrapper import ElementLibGAP
 
-class GroupMixinLibGAP():
+
+class GroupMixinLibGAP:
     def __contains__(self, elt):
         r"""
         TESTS::
@@ -54,10 +56,8 @@ class GroupMixinLibGAP():
         r"""
         Return whether the group is Abelian.
 
-        OUTPUT:
-
-        Boolean. ``True`` if this group is an Abelian group and ``False``
-        otherwise.
+        OUTPUT: boolean; ``True`` if this group is an Abelian group and
+        ``False`` otherwise
 
         EXAMPLES::
 
@@ -182,9 +182,7 @@ class GroupMixinLibGAP():
         """
         Test whether the matrix group is finite.
 
-        OUTPUT:
-
-        Boolean.
+        OUTPUT: boolean
 
         EXAMPLES::
 
@@ -198,7 +196,7 @@ class GroupMixinLibGAP():
 
     def cardinality(self):
         """
-        Implements :meth:`EnumeratedSets.ParentMethods.cardinality`.
+        Implement :meth:`EnumeratedSets.ParentMethods.cardinality`.
 
         EXAMPLES::
 
@@ -250,8 +248,8 @@ class GroupMixinLibGAP():
 
         EXAMPLES::
 
-            sage: G = SU(3,GF(2))
-            sage: len(G.conjugacy_classes_representatives())
+            sage: G = SU(3,GF(2))                                                       # needs sage.rings.finite_rings
+            sage: len(G.conjugacy_classes_representatives())                            # needs sage.rings.finite_rings
             16
 
             sage: G = GL(2,GF(3))
@@ -261,7 +259,7 @@ class GroupMixinLibGAP():
             [0 1], [1 1], [0 2], [1 2], [1 0], [1 2], [1 1], [0 1]
             )
 
-            sage: len(GU(2,GF(5)).conjugacy_classes_representatives())
+            sage: len(GU(2,GF(5)).conjugacy_classes_representatives())                  # needs sage.rings.finite_rings
             36
 
         ::
@@ -270,12 +268,11 @@ class GroupMixinLibGAP():
             Traceback (most recent call last):
             ...
             NotImplementedError: only implemented for finite groups
-
         """
         if not self.is_finite():
             raise NotImplementedError("only implemented for finite groups")
         G = self.gap()
-        reps = [ cc.Representative() for cc in G.ConjugacyClasses() ]
+        reps = [cc.Representative() for cc in G.ConjugacyClasses()]
         return tuple(self(g) for g in reps)
 
     def conjugacy_classes(self):
@@ -332,14 +329,14 @@ class GroupMixinLibGAP():
 
         INPUT:
 
-        - ``values`` -- list/tuple/iterable of numbers. The values of the
-          class function on the conjugacy classes, in that order.
+        - ``values`` -- list/tuple/iterable of numbers; the values of the
+          class function on the conjugacy classes, in that order
 
         EXAMPLES::
 
             sage: G = GL(2,GF(3))
-            sage: chi = G.class_function(range(8))
-            sage: list(chi)
+            sage: chi = G.class_function(range(8))                                      # needs sage.rings.number_field
+            sage: list(chi)                                                             # needs sage.rings.number_field
             [0, 1, 2, 3, 4, 5, 6, 7]
         """
         from sage.groups.class_function import ClassFunction_libgap
@@ -350,14 +347,12 @@ class GroupMixinLibGAP():
         """
         Return the center of this group as a subgroup.
 
-        OUTPUT:
-
-        The center as a subgroup.
+        OUTPUT: the center as a subgroup
 
         EXAMPLES::
 
-            sage: G = SU(3, GF(2))
-            sage: G.center()
+            sage: G = SU(3, GF(2))                                                      # needs sage.rings.finite_rings
+            sage: G.center()                                                            # needs sage.rings.finite_rings
             Subgroup with 1 generators (
             [a 0 0]
             [0 a 0]
@@ -374,7 +369,7 @@ class GroupMixinLibGAP():
             [0 2 0]
             [0 0 2]
             ) of General Linear Group of degree 3 over Finite Field of size 3
-            sage: GU(3, GF(2)).center()
+            sage: GU(3, GF(2)).center()                                                 # needs sage.rings.finite_rings
             Subgroup with 1 generators (
             [a + 1     0     0]
             [    0 a + 1     0]
@@ -477,7 +472,8 @@ class GroupMixinLibGAP():
 
             sage: G = groups.matrix.GL(2, 2)
             sage: G.subgroups()
-            [Subgroup with 0 generators () of General Linear Group of degree 2 over Finite Field of size 2,
+            [Subgroup with 0 generators ()
+               of General Linear Group of degree 2 over Finite Field of size 2,
              Subgroup with 1 generators (
              [0 1]
              [1 0]
@@ -522,7 +518,8 @@ class GroupMixinLibGAP():
 
             sage: G = groups.matrix.GL(2,2)
             sage: G.conjugacy_classes_subgroups()
-            [Subgroup with 0 generators () of General Linear Group of degree 2 over Finite Field of size 2,
+            [Subgroup with 0 generators ()
+               of General Linear Group of degree 2 over Finite Field of size 2,
              Subgroup with 1 generators (
              [1 1]
              [0 1]
@@ -622,10 +619,10 @@ class GroupMixinLibGAP():
             [-2 -1  2]
             [ 0  0  1]
             ) of Matrix group over Rational Field with 2 generators (
-            [  0 1/2   0]  [  0 1/2   0]
-            [  2   0   0]  [ -2  -1   2]
-            [  0   0   1], [  0   0   1]
-            )
+              [  0 1/2   0]  [  0 1/2   0]
+              [  2   0   0]  [ -2  -1   2]
+              [  0   0   1], [  0   0   1]
+              )
             sage: GL(3,ZZ).intersection(G)
             Subgroup with 1 generators (
             [ 1  0  0]
@@ -633,11 +630,12 @@ class GroupMixinLibGAP():
             [ 0  0  1]
             ) of General Linear Group of degree 3 over Integer Ring
             sage: G.intersection(SL(3,ZZ))
-            Subgroup with 0 generators () of Matrix group over Rational Field with 2 generators (
-            [  0 1/2   0]  [  0 1/2   0]
-            [  2   0   0]  [ -2  -1   2]
-            [  0   0   1], [  0   0   1]
-            )
+            Subgroup with 0 generators ()
+              of Matrix group over Rational Field with 2 generators (
+              [  0 1/2   0]  [  0 1/2   0]
+              [  2   0   0]  [ -2  -1   2]
+              [  0   0   1], [  0   0   1]
+              )
         """
         G = self.gap()
         H = other.gap()
@@ -649,14 +647,12 @@ class GroupMixinLibGAP():
         """
         Return the irreducible characters of the group.
 
-        OUTPUT:
-
-        A tuple containing all irreducible characters.
+        OUTPUT: tuple containing all irreducible characters
 
         EXAMPLES::
 
             sage: G = GL(2,2)
-            sage: G.irreducible_characters()
+            sage: G.irreducible_characters()                                            # needs sage.rings.number_field
             (Character of General Linear Group of degree 2 over Finite Field of size 2,
              Character of General Linear Group of degree 2 over Finite Field of size 2,
              Character of General Linear Group of degree 2 over Finite Field of size 2)
@@ -671,9 +667,7 @@ class GroupMixinLibGAP():
         if not self.is_finite():
             raise NotImplementedError("only implemented for finite groups")
         Irr = self.gap().Irr()
-        L = []
-        for irr in Irr:
-            L.append(ClassFunction_libgap(self, irr))
+        L = [ClassFunction_libgap(self, irr) for irr in Irr]
         return tuple(L)
 
     def character(self, values):
@@ -691,7 +685,7 @@ class GroupMixinLibGAP():
         EXAMPLES::
 
             sage: G = MatrixGroup(AlternatingGroup(4))
-            sage: G.character([1]*len(G.conjugacy_classes_representatives()))
+            sage: G.character([1]*len(G.conjugacy_classes_representatives()))           # needs sage.rings.number_field
             Character of Matrix group over Integer Ring with 12 generators
 
         ::
@@ -714,7 +708,7 @@ class GroupMixinLibGAP():
 
         EXAMPLES::
 
-            sage: MatrixGroup(SymmetricGroup(3)).trivial_character()
+            sage: MatrixGroup(SymmetricGroup(3)).trivial_character()                    # needs sage.rings.number_field
             Character of Matrix group over Integer Ring with 6 generators
 
         ::
@@ -726,7 +720,7 @@ class GroupMixinLibGAP():
         """
         if not self.is_finite():
             raise NotImplementedError("only implemented for finite groups")
-        values = [1]*self._gap_().NrConjugacyClasses().sage()
+        values = [1] * self._gap_().NrConjugacyClasses().sage()
         return self.character(values)
 
     def character_table(self):
@@ -742,10 +736,10 @@ class GroupMixinLibGAP():
 
         EXAMPLES::
 
-            sage: MatrixGroup(SymmetricGroup(2)).character_table()
+            sage: MatrixGroup(SymmetricGroup(2)).character_table()                      # needs sage.rings.number_field
             [ 1 -1]
             [ 1  1]
-            sage: MatrixGroup(SymmetricGroup(3)).character_table()
+            sage: MatrixGroup(SymmetricGroup(3)).character_table()                      # needs sage.rings.number_field
             [ 1  1 -1]
             [ 2 -1  0]
             [ 1  1  1]
@@ -758,14 +752,14 @@ class GroupMixinLibGAP():
             [ 4  0 -1 -1  2  1  0]
             [ 1  1  1  1  1  1  1]
         """
-        #code from function in permgroup.py, but modified for
-        #how gap handles these groups.
-        G    = self._gap_()
-        cl   = self.conjugacy_classes()
+        # code from function in permgroup.py, but modified for
+        # how gap handles these groups.
+        G = self._gap_()
+        cl = self.conjugacy_classes()
         from sage.rings.integer import Integer
-        n    = Integer(len(cl))
+        n = Integer(len(cl))
         irrG = G.Irr()
-        ct   = [[irrG[i][j] for j in range(n)] for i in range(n)]
+        ct = [[irrG[i][j] for j in range(n)] for i in range(n)]
 
         from sage.rings.number_field.number_field import CyclotomicField
         e = irrG.Flat().Conductor()
@@ -781,9 +775,7 @@ class GroupMixinLibGAP():
         """
         Return a random element of this group.
 
-        OUTPUT:
-
-        A group element.
+        OUTPUT: a group element
 
         EXAMPLES::
 
@@ -797,7 +789,7 @@ class GroupMixinLibGAP():
             True
 
             sage: F = GF(5); MS = MatrixSpace(F,2,2)
-            sage: gens = [MS([[1,2],[-1,1]]),MS([[1,1],[0,1]])]
+            sage: gens = [MS([[1,2],[-1,1]]), MS([[1,1],[0,1]])]
             sage: G = MatrixGroup(gens)
             sage: G.random_element()  # random
             [1 3]
@@ -861,10 +853,8 @@ class GroupMixinLibGAP():
         """
         List all elements of this group.
 
-        OUTPUT:
-
-        A tuple containing all group elements in a random but fixed
-        order.
+        OUTPUT: tuple containing all group elements in a random but fixed
+        order
 
         EXAMPLES::
 
@@ -885,7 +875,7 @@ class GroupMixinLibGAP():
             sage: all(g in G for g in G.list())
             True
 
-        An example over a ring (see :trac:`5241`)::
+        An example over a ring (see :issue:`5241`)::
 
             sage: M1 = matrix(ZZ,2,[[-1,0],[0,1]])
             sage: M2 = matrix(ZZ,2,[[1,0],[0,-1]])
@@ -905,7 +895,7 @@ class GroupMixinLibGAP():
             [ 0  1], [ 0 -1], [ 0 -1]
             )
 
-        An example over a field (see :trac:`10515`)::
+        An example over a field (see :issue:`10515`)::
 
             sage: gens = [matrix(QQ,2,[1,0,0,1])]
             sage: MatrixGroup(gens).list()
@@ -914,7 +904,7 @@ class GroupMixinLibGAP():
             [0 1]
             )
 
-        Another example over a ring (see :trac:`9437`)::
+        Another example over a ring (see :issue:`9437`)::
 
             sage: len(SL(2, Zmod(4)).list())
             48
@@ -936,11 +926,9 @@ class GroupMixinLibGAP():
 
         INPUT:
 
-        - ``H`` -- a group.
+        - ``H`` -- a group
 
-        OUTPUT:
-
-        Boolean.
+        OUTPUT: boolean
 
         EXAMPLES::
 
