@@ -6,10 +6,10 @@ finite set of generating matrices.
 
 EXAMPLES::
 
-    sage: F = GF(3)                                                                     # optional - sage.rings.finite_rings
-    sage: gens = [matrix(F, 2, [1,0, -1,1]), matrix(F, 2, [1,1,0,1])]                   # optional - sage.rings.finite_rings
-    sage: G = MatrixGroup(gens)                                                         # optional - sage.rings.finite_rings
-    sage: G.conjugacy_classes_representatives()                                         # optional - sage.rings.finite_rings
+    sage: F = GF(3)
+    sage: gens = [matrix(F, 2, [1,0, -1,1]), matrix(F, 2, [1,1,0,1])]
+    sage: G = MatrixGroup(gens)
+    sage: G.conjugacy_classes_representatives()                                         # needs sage.libs.gap
     (
     [1 0]  [0 2]  [0 1]  [2 0]  [0 2]  [0 1]  [0 2]
     [0 1], [1 1], [2 1], [0 2], [1 2], [2 2], [1 0]
@@ -48,7 +48,7 @@ AUTHORS:
 - Volker Braun (2013-1) port to new Parent, libGAP.
 
 - Sebastian Oehms (2018-07): Added _permutation_group_element_ (Issue #25706)
-- Sebastian Oehms (2019-01): Revision of :trac:`25706` (:trac:`26903` and :trac:`27143`).
+- Sebastian Oehms (2019-01): Revision of :issue:`25706` (:issue:`26903` and :issue:`27143`).
 """
 
 # #############################################################################
@@ -72,10 +72,10 @@ AUTHORS:
 from sage.groups.matrix_gps.group_element import is_MatrixGroupElement
 from sage.groups.matrix_gps.matrix_group import MatrixGroup_generic
 from sage.matrix.constructor import matrix
-from sage.matrix.matrix_space import is_MatrixSpace
+from sage.matrix.matrix_space import MatrixSpace
 from sage.misc.cachefunc import cached_method
 from sage.rings.integer_ring import ZZ
-from sage.structure.element import is_Matrix
+from sage.structure.element import Matrix
 from sage.structure.sequence import Sequence
 
 
@@ -83,9 +83,7 @@ def normalize_square_matrices(matrices):
     """
     Find a common space for all matrices.
 
-    OUTPUT:
-
-    A list of matrices, all elements of the same matrix space.
+    OUTPUT: a list of matrices, all elements of the same matrix space
 
     EXAMPLES::
 
@@ -107,7 +105,7 @@ def normalize_square_matrices(matrices):
             deg.append(m.parent().degree())
             gens.append(m.matrix())
             continue
-        if is_Matrix(m):
+        if isinstance(m, Matrix):
             if not m.is_square():
                 raise TypeError('matrix must be square')
             deg.append(m.ncols())
@@ -132,7 +130,7 @@ def normalize_square_matrices(matrices):
         raise ValueError('not all matrices have the same size')
     gens = Sequence(gens, immutable=True)
     MS = gens.universe()
-    if not is_MatrixSpace(MS):
+    if not isinstance(MS, MatrixSpace):
         raise TypeError('all generators must be matrices')
     if MS.nrows() != MS.ncols():
         raise ValueError('matrices must be square')
@@ -151,7 +149,8 @@ def QuaternionMatrixGroupGF3():
     is not isomorphic to the group of symmetries of a square
     (the dihedral group `D_4`).
 
-    .. note::
+    .. NOTE::
+
         This group is most easily available via ``groups.matrix.QuaternionGF3()``.
 
     EXAMPLES:
@@ -161,37 +160,40 @@ def QuaternionMatrixGroupGF3():
     is the product of `I` and `J`. ::
 
         sage: from sage.groups.matrix_gps.finitely_generated import QuaternionMatrixGroupGF3
-        sage: Q = QuaternionMatrixGroupGF3()                                            # optional - sage.rings.finite_rings
-        sage: Q.order()                                                                 # optional - sage.rings.finite_rings
+
+        sage: # needs sage.libs.gap
+        sage: Q = QuaternionMatrixGroupGF3()
+        sage: Q.order()
         8
-        sage: aye = Q.gens()[0]; aye                                                    # optional - sage.rings.finite_rings
+        sage: aye = Q.gens()[0]; aye
         [1 1]
         [1 2]
-        sage: jay = Q.gens()[1]; jay                                                    # optional - sage.rings.finite_rings
+        sage: jay = Q.gens()[1]; jay
         [2 1]
         [1 1]
-        sage: kay = aye*jay; kay                                                        # optional - sage.rings.finite_rings
+        sage: kay = aye*jay; kay
         [0 2]
         [1 0]
 
     TESTS::
 
-        sage: groups.matrix.QuaternionGF3()                                             # optional - sage.rings.finite_rings
+        sage: groups.matrix.QuaternionGF3()
         Matrix group over Finite Field of size 3 with 2 generators (
         [1 1]  [2 1]
         [1 2], [1 1]
         )
 
-        sage: Q = QuaternionMatrixGroupGF3()                                            # optional - sage.rings.finite_rings
-        sage: QP = Q.as_permutation_group()                                             # optional - sage.rings.finite_rings
-        sage: QP.is_isomorphic(QuaternionGroup())                                       # optional - sage.rings.finite_rings
+        sage: # needs sage.groups
+        sage: Q = QuaternionMatrixGroupGF3()
+        sage: QP = Q.as_permutation_group()
+        sage: QP.is_isomorphic(QuaternionGroup())
         True
-        sage: H = DihedralGroup(4)                                                      # optional - sage.groups sage.rings.finite_rings
-        sage: H.order()                                                                 # optional - sage.groups sage.rings.finite_rings
+        sage: H = DihedralGroup(4)
+        sage: H.order()
         8
-        sage: QP.is_abelian(), H.is_abelian()                                           # optional - sage.groups sage.rings.finite_rings
+        sage: QP.is_abelian(), H.is_abelian()
         (False, False)
-        sage: QP.is_isomorphic(H)                                                       # optional - sage.groups sage.rings.finite_rings
+        sage: QP.is_isomorphic(H)
         False
     """
     from sage.rings.finite_rings.finite_field_constructor import FiniteField
@@ -209,16 +211,16 @@ def MatrixGroup(*gens, **kwds):
     INPUT:
 
     - ``*gens`` -- matrices, or a single list/tuple/iterable of
-      matrices, or a matrix group.
+      matrices, or a matrix group
 
-    - ``check`` -- boolean keyword argument (optional, default:
-      ``True``). Whether to check that each matrix is invertible.
+    - ``check`` -- boolean keyword argument (default: ``True``);
+      whether to check that each matrix is invertible
 
     EXAMPLES::
 
-        sage: F = GF(5)                                                                 # optional - sage.rings.finite_rings
-        sage: gens = [matrix(F, 2, [1,2, -1,1]), matrix(F,2, [1,1, 0,1])]               # optional - sage.rings.finite_rings
-        sage: G = MatrixGroup(gens); G                                                  # optional - sage.rings.finite_rings
+        sage: F = GF(5)
+        sage: gens = [matrix(F, 2, [1,2, -1,1]), matrix(F,2, [1,1, 0,1])]
+        sage: G = MatrixGroup(gens); G
         Matrix group over Finite Field of size 5 with 2 generators (
         [1 2]  [1 1]
         [4 1], [0 1]
@@ -230,8 +232,8 @@ def MatrixGroup(*gens, **kwds):
     matrices over the finite field, so creates that matrix group
     there::
 
-        sage: gens = [matrix(2, [1,2, -1,1]), matrix(GF(7), 2, [1,1, 0,1]), 2]          # optional - sage.rings.finite_rings
-        sage: G = MatrixGroup(gens); G                                                  # optional - sage.rings.finite_rings
+        sage: gens = [matrix(2, [1,2, -1,1]), matrix(GF(7), 2, [1,1, 0,1]), 2]
+        sage: G = MatrixGroup(gens); G
         Matrix group over Finite Field of size 7 with 3 generators (
         [1 2]  [1 1]  [2 0]
         [6 1], [0 1], [0 2]
@@ -244,12 +246,12 @@ def MatrixGroup(*gens, **kwds):
         ...
         ValueError: each generator must be an invertible matrix
 
-        sage: F = GF(5); MS = MatrixSpace(F, 2, 2)                                      # optional - sage.rings.finite_rings
-        sage: MatrixGroup([MS.0])                                                       # optional - sage.rings.finite_rings
+        sage: F = GF(5); MS = MatrixSpace(F, 2, 2)
+        sage: MatrixGroup([MS.0])
         Traceback (most recent call last):
         ...
         ValueError: each generator must be an invertible matrix
-        sage: MatrixGroup([MS.0], check=False)  # works formally but is mathematical nonsense   # optional - sage.rings.finite_rings
+        sage: MatrixGroup([MS.0], check=False)  # works formally but is mathematical nonsense
         Matrix group over Finite Field of size 5 with 1 generators (
         [1 0]
         [0 0]
@@ -268,7 +270,7 @@ def MatrixGroup(*gens, **kwds):
         sage: SL2C.gens()
         Traceback (most recent call last):
         ...
-        AttributeError: 'LinearMatrixGroup_generic_with_category' object has no attribute 'gens'
+        AttributeError: 'LinearMatrixGroup_generic_with_category' object has no attribute 'gens'...
     """
     if isinstance(gens[-1], dict):   # hack for unpickling
         kwds.update(gens[-1])
@@ -319,15 +321,16 @@ class FinitelyGeneratedMatrixGroup_generic(MatrixGroup_generic):
     """
     TESTS::
 
-        sage: m1 = matrix(SR, [[1,2], [3,4]])                                           # optional - sage.symbolic
-        sage: m2 = matrix(SR, [[1,3], [-1,0]])                                          # optional - sage.symbolic
-        sage: MatrixGroup(m1) == MatrixGroup(m1)                                        # optional - sage.symbolic
+        sage: # needs sage.symbolic
+        sage: m1 = matrix(SR, [[1,2], [3,4]])
+        sage: m2 = matrix(SR, [[1,3], [-1,0]])
+        sage: MatrixGroup(m1) == MatrixGroup(m1)
         True
-        sage: MatrixGroup(m1) == MatrixGroup(m1.change_ring(QQ))                        # optional - sage.symbolic
+        sage: MatrixGroup(m1) == MatrixGroup(m1.change_ring(QQ))
         False
-        sage: MatrixGroup(m1) == MatrixGroup(m2)                                        # optional - sage.symbolic
+        sage: MatrixGroup(m1) == MatrixGroup(m2)
         False
-        sage: MatrixGroup(m1, m2) == MatrixGroup(m2, m1)                                # optional - sage.symbolic
+        sage: MatrixGroup(m1, m2) == MatrixGroup(m2, m1)
         False
 
         sage: m1 = matrix(QQ, [[1,2], [3,4]])
@@ -339,9 +342,10 @@ class FinitelyGeneratedMatrixGroup_generic(MatrixGroup_generic):
         sage: MatrixGroup(m1, m2) == MatrixGroup(m2, m1)
         False
 
-        sage: G = GL(2, GF(3))                                                          # optional - sage.rings.finite_rings
-        sage: H = G.as_matrix_group()                                                   # optional - sage.rings.finite_rings
-        sage: H == G, G == H                                                            # optional - sage.rings.finite_rings
+        sage: # needs sage.libs.gap
+        sage: G = GL(2, GF(3))
+        sage: H = G.as_matrix_group()
+        sage: H == G, G == H
         (True, True)
     """
 
@@ -351,11 +355,12 @@ class FinitelyGeneratedMatrixGroup_generic(MatrixGroup_generic):
 
         EXAMPLES::
 
-            sage: m1 = matrix(SR, [[1,2], [3,4]])                                       # optional - sage.symbolic
-            sage: m2 = matrix(SR, [[1,3], [-1,0]])                                      # optional - sage.symbolic
-            sage: G = MatrixGroup(m1, m2)                                               # optional - sage.symbolic
-            sage: TestSuite(G).run()                                                    # optional - sage.symbolic
-            sage: type(G)                                                               # optional - sage.symbolic
+            sage: # needs sage.symbolic
+            sage: m1 = matrix(SR, [[1,2], [3,4]])
+            sage: m2 = matrix(SR, [[1,3], [-1,0]])
+            sage: G = MatrixGroup(m1, m2)
+            sage: TestSuite(G).run()
+            sage: type(G)
             <class 'sage.groups.matrix_gps.finitely_generated.FinitelyGeneratedMatrixGroup_generic_with_category'>
 
             sage: from sage.groups.matrix_gps.finitely_generated import \
@@ -371,30 +376,30 @@ class FinitelyGeneratedMatrixGroup_generic(MatrixGroup_generic):
         MatrixGroup_generic.__init__(self, degree, base_ring, category=category)
 
     @cached_method
-    def gens(self):
+    def gens(self) -> tuple:
         """
         Return the generators of the matrix group.
 
         EXAMPLES::
 
-            sage: F = GF(3); MS = MatrixSpace(F, 2, 2)                                  # optional - sage.rings.finite_rings
-            sage: gens = [MS([[1,0], [0,1]]), MS([[1,1], [0,1]])]                       # optional - sage.rings.finite_rings
-            sage: G = MatrixGroup(gens)                                                 # optional - sage.rings.finite_rings
-            sage: gens[0] in G                                                          # optional - sage.rings.finite_rings
+            sage: F = GF(3); MS = MatrixSpace(F, 2, 2)
+            sage: gens = [MS([[1,0], [0,1]]), MS([[1,1], [0,1]])]
+            sage: G = MatrixGroup(gens)
+            sage: gens[0] in G
             True
-            sage: gens = G.gens()                                                       # optional - sage.rings.finite_rings
-            sage: gens[0] in G                                                          # optional - sage.rings.finite_rings
+            sage: gens = G.gens()
+            sage: gens[0] in G
             True
-            sage: gens = [MS([[1,0], [0,1]]), MS([[1,1], [0,1]])]                       # optional - sage.rings.finite_rings
+            sage: gens = [MS([[1,0], [0,1]]), MS([[1,1], [0,1]])]
 
-            sage: F = GF(5); MS = MatrixSpace(F, 2, 2)                                  # optional - sage.rings.finite_rings
-            sage: G = MatrixGroup([MS(1), MS([1,2, 3,4])])                              # optional - sage.rings.finite_rings
-            sage: G                                                                     # optional - sage.rings.finite_rings
+            sage: F = GF(5); MS = MatrixSpace(F, 2, 2)
+            sage: G = MatrixGroup([MS(1), MS([1,2, 3,4])])
+            sage: G
             Matrix group over Finite Field of size 5 with 2 generators (
             [1 0]  [1 2]
             [0 1], [3 4]
             )
-            sage: G.gens()                                                              # optional - sage.rings.finite_rings
+            sage: G.gens()
             (
             [1 0]  [1 2]
             [0 1], [3 4]
@@ -405,39 +410,37 @@ class FinitelyGeneratedMatrixGroup_generic(MatrixGroup_generic):
 
     def gen(self, i):
         """
-        Return the `i`-th generator
+        Return the `i`-th generator.
 
-        OUTPUT:
-
-        The `i`-th generator of the group.
+        OUTPUT: the `i`-th generator of the group
 
         EXAMPLES::
 
-            sage: H = GL(2, GF(3))                                                      # optional - sage.rings.finite_rings
-            sage: h1, h2 = H([[1,0], [2,1]]), H([[1,1], [0,1]])                         # optional - sage.rings.finite_rings
-            sage: G = H.subgroup([h1, h2])                                              # optional - sage.rings.finite_rings
-            sage: G.gen(0)                                                              # optional - sage.rings.finite_rings
+            sage: # needs sage.libs.gap
+            sage: H = GL(2, GF(3))
+            sage: h1, h2 = H([[1,0], [2,1]]), H([[1,1], [0,1]])
+            sage: G = H.subgroup([h1, h2])
+            sage: G.gen(0)
             [1 0]
             [2 1]
-            sage: G.gen(0).matrix() == h1.matrix()                                      # optional - sage.rings.finite_rings
+            sage: G.gen(0).matrix() == h1.matrix()
             True
         """
         return self.gens()[i]
 
     def ngens(self):
         """
-        Return the number of generators
+        Return the number of generators.
 
-        OUTPUT:
-
-        An integer. The number of generators.
+        OUTPUT: integer; the number of generators
 
         EXAMPLES::
 
-            sage: H = GL(2, GF(3))                                                      # optional - sage.rings.finite_rings
-            sage: h1, h2 = H([[1,0], [2,1]]), H([[1,1], [0,1]])                         # optional - sage.rings.finite_rings
-            sage: G = H.subgroup([h1, h2])                                              # optional - sage.rings.finite_rings
-            sage: G.ngens()                                                             # optional - sage.rings.finite_rings
+            sage: # needs sage.libs.gap
+            sage: H = GL(2, GF(3))
+            sage: h1, h2 = H([[1,0], [2,1]]), H([[1,1], [0,1]])
+            sage: G = H.subgroup([h1, h2])
+            sage: G.ngens()
             2
         """
         return len(self._gens_matrix)
@@ -453,12 +456,13 @@ class FinitelyGeneratedMatrixGroup_generic(MatrixGroup_generic):
             sage: loads(dumps(G)) == G
             True
 
-        Check that :trac:`22128` is fixed::
+        Check that :issue:`22128` is fixed::
 
-            sage: R = MatrixSpace(SR, 2)                                                # optional - sage.symbolic
-            sage: G = MatrixGroup([R([[1, 1], [0, 1]])])                                # optional - sage.symbolic
-            sage: G.register_embedding(R)                                               # optional - sage.symbolic
-            sage: loads(dumps(G))                                                       # optional - sage.symbolic
+            sage: # needs sage.symbolic
+            sage: R = MatrixSpace(SR, 2)
+            sage: G = MatrixGroup([R([[1, 1], [0, 1]])])
+            sage: G.register_embedding(R)
+            sage: loads(dumps(G))
             Matrix group over Symbolic Ring with 1 generators (
             [1 1]
             [0 1]
@@ -470,10 +474,11 @@ class FinitelyGeneratedMatrixGroup_generic(MatrixGroup_generic):
         """
         EXAMPLES::
 
-            sage: m1 = matrix(SR, [[1,2], [3,4]])                                       # optional - sage.symbolic
-            sage: m2 = matrix(SR, [[1,3], [-1,0]])                                      # optional - sage.symbolic
-            sage: G = MatrixGroup(m1, m2)                                               # optional - sage.symbolic
-            sage: G._test_matrix_generators()                                           # optional - sage.symbolic
+            sage: # needs sage.symbolic
+            sage: m1 = matrix(SR, [[1,2], [3,4]])
+            sage: m2 = matrix(SR, [[1,3], [-1,0]])
+            sage: G = MatrixGroup(m1, m2)
+            sage: G._test_matrix_generators()
         """
         tester = self._tester(**options)
         for g,h in zip(self.gens(), MatrixGroup(self.gens()).gens()):
