@@ -20,7 +20,7 @@ To access the LiE interpreter directly, run lie_console().
 
 EXAMPLES::
 
-    sage: a4 = lie('A4')  # optional - lie
+    sage: a4 = lie('A4')             # optional - lie
     sage: lie.diagram('A4')          # optional - lie
     O---O---O---O
     1   2   3   4
@@ -53,37 +53,38 @@ The following examples are taken from Section 2.1 of the LiE manual.
 
 You can perform basic arithmetic operations in LiE. ::
 
-    sage: lie.eval('19+68') # optional - lie
+    sage: # optional - lie
+    sage: lie.eval('19+68')
     '87'
-    sage: a = lie('1111111111*1111111111') # optional - lie
-    sage: a # optional - lie
+    sage: a = lie('1111111111*1111111111')
+    sage: a
     1234567900987654321
-    sage: a/1111111111 # optional - lie
+    sage: a/1111111111
     1111111111
-    sage: a = lie('345') # optional - lie
-    sage: a^2+3*a-5 # optional - lie
+    sage: a = lie('345')
+    sage: a^2+3*a-5
     120055
-    sage: _ / 7*a # optional - lie
+    sage: _ / 7*a
     5916750
 
 Vectors in LiE are created using square brackets.  Notice that
-the indexing in LiE is 1-based, unlike Python/Sage which is
-0-based. ::
+the indexing in LiE is 1-based, unlike Python/Sage which is 0-based. ::
 
-    sage: v = lie('[3,2,6873,-38]') # optional - lie
-    sage: v # optional - lie
+    sage: # optional - lie
+    sage: v = lie('[3,2,6873,-38]')
+    sage: v
     [3,2,6873,-38]
-    sage: v[3] # optional - lie
+    sage: v[3]
     6873
-    sage: v+v # optional - lie
+    sage: v+v
     [6,4,13746,-76]
-    sage: v*v # optional - lie
+    sage: v*v
     47239586
-    sage: v+234786 # optional - lie
+    sage: v+234786
     [3,2,6873,-38,234786]
-    sage: v-3 # optional - lie
+    sage: v-3
     [3,2,-38]
-    sage: v^v # optional - lie
+    sage: v^v
     [3,2,6873,-38,3,2,6873,-38]
 
 You can also work with matrices in LiE. ::
@@ -102,19 +103,20 @@ You can also work with matrices in LiE. ::
          ,[3, 7, 0, 9]
          ]
 
-    sage: m^3 # optional - lie
+    sage: # optional - lie
+    sage: m^3
          [[ 220,   87, 81, 375]
          ,[-168,-1089, 13,1013]
          ,[1550,  357,-55,1593]
          ,[-854, -652, 98,-170]
          ]
-    sage: v*m # optional - lie
+    sage: v*m
     [-6960,62055,55061,-319]
-    sage: m*v # optional - lie
+    sage: m*v
     [20508,-27714,54999,-14089]
-    sage: v*m*v # optional - lie
+    sage: v*m*v
     378549605
-    sage: m+v # optional - lie
+    sage: m+v
          [[ 1, 0,   3,  3]
          ,[12, 4,  -4,  7]
          ,[-1, 9,   8,  0]
@@ -131,17 +133,18 @@ You can also work with matrices in LiE. ::
 
 LiE handles multivariate (Laurent) polynomials. ::
 
-    sage: lie('X[1,2]') # optional - lie
+    sage: # optional - lie
+    sage: lie('X[1,2]')
     1X[1,2]
-    sage: -3*_ # optional - lie
+    sage: -3*_
     -3X[1,2]
-    sage: _ + lie('4X[-1,4]') # optional - lie
+    sage: _ + lie('4X[-1,4]')
     4X[-1,4] - 3X[ 1,2]
-    sage: _^2 # optional - lie
+    sage: _^2
     16X[-2,8] - 24X[ 0,6] +  9X[ 2,4]
-    sage: lie('(4X[-1,4]-3X[1,2])*(X[2,0]-X[0,-4])') # optional - lie
+    sage: lie('(4X[-1,4]-3X[1,2])*(X[2,0]-X[0,-4])')
     -4X[-1, 0] + 3X[ 1,-2] + 4X[ 1, 4] - 3X[ 3, 2]
-    sage: _ - _ # optional - lie
+    sage: _ - _
     0X[0,0]
 
 
@@ -173,19 +176,19 @@ You can define your own functions in LiE using lie.eval .  Once you've defined
 a function (say f), you can call it using lie.f ; however, user-defined functions
 do not show up when using tab-completion. ::
 
-    sage: lie.eval('f(int x) = 2*x') # optional - lie
+    sage: # optional - lie
+    sage: lie.eval('f(int x) = 2*x')
     ''
-    sage: lie.f(984) # optional - lie
+    sage: lie.f(984)
     1968
-    sage: lie.eval('f(int n) = a=3*n-7; if a < 0 then a = -a fi; 7^a+a^3-4*a-57') # optional - lie
+    sage: lie.eval('f(int n) = a=3*n-7; if a < 0 then a = -a fi; 7^a+a^3-4*a-57')
     ''
-    sage: lie.f(2) # optional - lie
+    sage: lie.f(2)
     -53
-    sage: lie.f(5) # optional - lie
+    sage: lie.f(5)
     5765224
 
 
-
 LiE's help can be accessed through lie.help('functionname') where
 functionname is the function you want to receive help for. ::
 
@@ -200,7 +203,6 @@ functionname is the function you want to receive help for. ::
 This can also be accessed with lie.functionname? .
 
 
-
 With the exception of groups, all LiE data types can be converted into
 native Sage data types by calling the .sage() method.
 
@@ -210,7 +212,7 @@ Integers::
     sage: b = a.sage(); b # optional - lie
     1234
     sage: type(b) # optional - lie
-    <type 'sage.rings.integer.Integer'>
+    <class 'sage.rings.integer.Integer'>
 
 Vectors::
 
@@ -227,7 +229,7 @@ Matrices::
     [1 2]
     [3 4]
     sage: type(b) # optional - lie
-    <type 'sage.matrix.matrix_integer_dense.Matrix_integer_dense'>
+    <class 'sage.matrix.matrix_integer_dense.Matrix_integer_dense'>
 
 Polynomials::
 
@@ -235,7 +237,7 @@ Polynomials::
     sage: b = a.sage(); b              # optional - lie
     -2*x0^2*x1 + x0*x1^2
     sage: type(b)                      # optional - lie
-    <type 'sage.rings.polynomial.multi_polynomial_libsingular.MPolynomial_libsingular'>
+    <class 'sage.rings.polynomial.multi_polynomial_libsingular.MPolynomial_libsingular'>
 
 Text::
 
@@ -251,7 +253,8 @@ of the manual gives an example of a function written in LiE's language
 which evaluates a polynomial at a point.  Below is a (roughly) direct
 translation of that program into Python / Sage. ::
 
-    sage: def eval_pol(p, pt): # optional - lie
+    sage: # optional - lie
+    sage: def eval_pol(p, pt):
     ....:     s = 0
     ....:     for i in range(1,p.length().sage()+1):
     ....:         m = 1
@@ -259,16 +262,14 @@ translation of that program into Python / Sage. ::
     ....:             m *= pt[j]^p.expon(i)[j]
     ....:         s += p.coef(i)*m
     ....:     return s
-    sage: a = lie('X[1,2]') # optional - lie
-    sage: b1 = lie('[1,2]') # optional - lie
-    sage: b2 = lie('[2,3]') # optional - lie
-    sage: eval_pol(a, b1) # optional - lie
+    sage: a = lie('X[1,2]')
+    sage: b1 = lie('[1,2]')
+    sage: b2 = lie('[2,3]')
+    sage: eval_pol(a, b1)
     4
-    sage: eval_pol(a, b2) # optional - lie
+    sage: eval_pol(a, b2)
     18
 
-
-
 AUTHORS:
 
 - Mike Hansen 2007-08-27
@@ -282,7 +283,7 @@ AUTHORS:
 #
 #  Distributed under the terms of the GNU General Public License (GPL)
 #
-#                  http://www.gnu.org/licenses/
+#                  https://www.gnu.org/licenses/
 #
 ##########################################################################
 
@@ -290,8 +291,9 @@ from .expect import Expect, ExpectElement, ExpectFunction, FunctionElement
 from sage.interfaces.interface import AsciiArtString
 from sage.misc.misc_c import prod
 from sage.env import DOT_SAGE, LIE_INFO_DIR
+from sage.misc.sage_eval import sage_eval
 from sage.interfaces.tab_completion import ExtraTabCompletion
-from sage.docs.instancedoc import instancedoc
+from sage.misc.instancedoc import instancedoc
 import os
 
 
@@ -308,8 +310,8 @@ class LiE(ExtraTabCompletion, Expect):
     help about a given function.  Type ``lie(...)`` to create
     a new LiE object, and ``lie.eval(...)`` to run a string
     using LiE (and get the result back as a string).
-
     """
+
     def __init__(self,
                  maxread=None, script_subdirectory=None,
                  logfile=None,
@@ -323,27 +325,27 @@ class LiE(ExtraTabCompletion, Expect):
         Expect.__init__(self,
 
                         # The capitalized version of this is used for printing.
-                        name = 'LiE',
+                        name='LiE',
 
                         # This is regexp of the input prompt.  If you can change
                         # it to be very obfuscated that would be better.   Even
                         # better is to use sequence numbers.
-                        prompt = '> ',
+                        prompt='> ',
 
                         # This is the command that starts up your program
-                        command = "bash lie",
+                        command="bash lie",
 
                         server=server,
-                        script_subdirectory = script_subdirectory,
+                        script_subdirectory=script_subdirectory,
 
                         # If this is true, then whenever the user presses Control-C to
                         # interrupt a calculation, the whole interface is restarted.
-                        restart_on_ctrlc = False,
+                        restart_on_ctrlc=False,
 
                         # If true, print out a message when starting
                         # up the command when you first send a command
                         # to this interface.
-                        verbose_start = False,
+                        verbose_start=False,
 
                         logfile=logfile,
 
@@ -389,85 +391,79 @@ class LiE(ExtraTabCompletion, Expect):
                 self._tab_completion_dict = trait_dict
                 self._help_dict = help_dict
                 return
-            except IOError:
+            except OSError:
                 pass
 
-
-        #Go through INFO.3 and get the necessary information
+        # Go through INFO.3 and get the necessary information
         filenames = ['INFO.3', 'INFO.0']
         commands = {}
         commands['vid'] = []
         help = {}
 
-
         for f in filenames:
             info = open(os.path.join(LIE_INFO_DIR, f))
             prev_command = ""
             help_text = ""
             for line in info:
-                #If the line doesn't start with an "@", then
-                #it is part of the help text for the previous
-                #command
+                # If the line doesn't start with an "@", then
+                # it is part of the help text for the previous
+                # command
                 if len(line) == 0 or line[0] != "@":
                     if prev_command != "":
                         help_text += line
                     continue
 
-
-                #Do not add not completions that do not start with an
-                #alphabetical character or that contain 'silence'
+                # Do not add not completions that do not start with an
+                # alphabetical character or that contain 'silence'
                 if len(line) > 1 and (not line[1].isalpha() or line.find('silence') != -1):
                     help[prev_command] = help.get(prev_command, "") + help_text
                     help_text = ""
                     prev_command = ""
                     continue
 
+                # At this point we should be at the start of a new
+                # command definition
 
-                #At this point we should be at the start of a new
-                #command definition
-
-
-                #Get the type of the first argument of the command
+                # Get the type of the first argument of the command
                 i = line.find('(')
-                if line[i+1] == ")":
+                if line[i + 1] == ")":
                     t = 'vid'
                 else:
-                    t = line[i+1:i+4]
+                    t = line[i + 1:i + 4]
 
-                #Save the help text for the command
+                # Save the help text for the command
                 help[prev_command] = help.get(prev_command, "") + help_text
                 help_text = ""
                 prev_command = line[1:i]
 
-                #Add the command
+                # Add the command
                 if t in commands:
                     commands[t].append(line[1:i])
                 else:
-                    commands[t] = [ line[1:i] ]
+                    commands[t] = [line[1:i]]
 
-            #Take care of the last help text which doesn't get processed
-            #since there's no following @ symbol
+            # Take care of the last help text which doesn't get processed
+            # since there's no following @ symbol
             help[prev_command] = help.get(prev_command, "") + help_text
 
         info.close()
 
-
-        #Build the list of all possible command completions
+        # Build the list of all possible command completions
         l = []
         for key in commands:
             l += commands[key]
 
-        #Save the data
+        # Save the data
         self._tab_completion_dict = commands
         self._tab_completion_list = sorted(l)
         self._help_dict = help
 
-        #Write them to file
+        # Write them to file
         if use_disk_cache:
             sage.misc.persist.save(commands, COMMANDS_CACHE)
             sage.misc.persist.save(help, HELP_CACHE)
 
-    def _repr_(self):
+    def _repr_(self) -> str:
         """
         EXAMPLES::
 
@@ -480,9 +476,8 @@ class LiE(ExtraTabCompletion, Expect):
         """
         EXAMPLES::
 
-            sage: lie.__reduce__()
+            sage: LiE().__reduce__()
             (<function reduce_load_lie at 0x...>, ())
-
         """
         return reduce_load_lie, tuple([])
 
@@ -495,7 +490,7 @@ class LiE(ExtraTabCompletion, Expect):
         """
         return LiEFunction
 
-    def _quit_string(self):
+    def _quit_string(self) -> str:
         """
         EXAMPLES::
 
@@ -515,7 +510,6 @@ class LiE(ExtraTabCompletion, Expect):
         """
         raise NotImplementedError
 
-
     def _tab_completion(self, type=None, verbose=False, use_disk_cache=True):
         """
         EXAMPLES::
@@ -538,11 +532,11 @@ class LiE(ExtraTabCompletion, Expect):
         else:
             return self._tab_completion_list
 
-    def _an_element_impl(self):
+    def _an_element_(self):
         """
         EXAMPLES::
 
-            sage: lie._an_element_impl() # optional - lie
+            sage: lie._an_element_() # optional - lie
             0
         """
         return self(0)
@@ -552,16 +546,15 @@ class LiE(ExtraTabCompletion, Expect):
         EXAMPLES::
 
             sage: filename = tmp_filename()
-            sage: f = open(filename, 'w')
-            sage: _ = f.write('x = 2\n')
-            sage: f.close()
+            sage: with open(filename, 'w') as f:
+            ....:     _ = f.write('x = 2\n')
             sage: lie.read(filename)  # optional - lie
             sage: lie.get('x')        # optional - lie
             '2'
             sage: import os
             sage: os.unlink(filename)
         """
-        self.eval('read %s'%filename)
+        self.eval('read %s' % filename)
 
     def console(self):
         """
@@ -574,16 +567,15 @@ class LiE(ExtraTabCompletion, Expect):
             Authors: Arjeh M. Cohen, Marc van Leeuwen, Bert Lisser.
             Free source code distribution
             ...
-
         """
         lie_console()
 
-    def version(self):
+    def version(self) -> str:
         """
         EXAMPLES::
 
             sage: lie.version() # optional - lie
-            '2.1'
+            '2.2'
         """
         return lie_version()
 
@@ -593,11 +585,10 @@ class LiE(ExtraTabCompletion, Expect):
 
             sage: lie._object_class()
             <class 'sage.interfaces.lie.LiEElement'>
-
         """
         return LiEElement
 
-    def _true_symbol(self):
+    def _true_symbol(self) -> str:
         """
         EXAMPLES::
 
@@ -606,7 +597,7 @@ class LiE(ExtraTabCompletion, Expect):
         """
         return '1'
 
-    def _false_symbol(self):
+    def _false_symbol(self) -> str:
         """
         EXAMPLES::
 
@@ -615,7 +606,7 @@ class LiE(ExtraTabCompletion, Expect):
         """
         return '0'
 
-    def _equality_symbol(self):
+    def _equality_symbol(self) -> str:
         """
         EXAMPLES::
 
@@ -626,7 +617,7 @@ class LiE(ExtraTabCompletion, Expect):
 
     def help(self, command):
         """
-        Returns a string of the LiE help for command.
+        Return a string of the LiE help for command.
 
         EXAMPLES::
 
@@ -653,16 +644,14 @@ class LiE(ExtraTabCompletion, Expect):
             RuntimeError: An error occurred running a LiE command:
             Argument types do not match in call. Types are: diagram(bin).
             Valid argument types are for instance: diagram(grp).
-
         """
         out = Expect._eval_line(self, line, allow_use_file=allow_use_file, wait_for_prompt=wait_for_prompt)
-        #Check to see if an error has occurred
-        err = max( out.find("\n(in"), out.find('not defined'), out.find('Argument types')  )
+        # Check to see if an error has occurred
+        err = max(out.find("\n(in"), out.find('not defined'), out.find('Argument types'))
         if err != -1:
-            raise RuntimeError("An error occurred running a LiE command:\n%s"%(out.replace('\r\n','\n')))
+            raise RuntimeError("An error occurred running a LiE command:\n%s" % (out.replace('\r\n', '\n')))
         return out
 
-
     def eval(self, code, strip=True, **kwds):
         """
         EXAMPLES::
@@ -670,8 +659,8 @@ class LiE(ExtraTabCompletion, Expect):
             sage: lie.eval('2+2')  # optional - lie
             '4'
         """
-        s = Expect.eval(self,code, strip=True, **kwds)
-        #return s.strip()
+        s = Expect.eval(self, code, strip=True, **kwds)
+        # return s.strip()
         if len(s) > 0 and s.find("\n") != -1:
             return s
         else:
@@ -687,9 +676,9 @@ class LiE(ExtraTabCompletion, Expect):
             sage: lie.get('x')       # optional - lie
             '2'
         """
-        cmd = '%s=%s' % (var,value)
+        cmd = '%s=%s' % (var, value)
         out = self.eval(cmd)
-        i = min( out.find('not defined'), out.find(r'\(in'), out.find('Argument types') )
+        i = min(out.find('not defined'), out.find(r'\(in'), out.find('Argument types'))
         if i != -1:
             raise RuntimeError(out)
 
@@ -702,10 +691,8 @@ class LiE(ExtraTabCompletion, Expect):
             sage: lie.set('x', '2')  # optional - lie
             sage: lie.get('x')       # optional - lie
             '2'
-
         """
-        s = self.eval('%s' % var)
-        return s
+        return self.eval('%s' % var)
 
     def get_using_file(self, var):
         """
@@ -727,12 +714,12 @@ class LiE(ExtraTabCompletion, Expect):
             1   2   3   4
             A4
         """
-        #If function just prints something on the screen rather than
-        #returning an object, then we return an AsciiArtString rather
-        #than a LiEElement
+        # If function just prints something on the screen rather than
+        # returning an object, then we return an AsciiArtString rather
+        # than a LiEElement
         if function in ['diagram', 'setdefault', 'print_tab', 'type', 'factor', 'void', 'gcol']:
             args, kwds = self._convert_args_kwds(args, kwds)
-            cmd = "%s(%s)"%(function, ",".join([s.name() for s in args]))
+            cmd = "%s(%s)" % (function, ",".join(s.name() for s in args))
             return AsciiArtString(self.eval(cmd))
 
         return Expect.function_call(self, function, args, kwds)
@@ -746,12 +733,12 @@ class LiE(ExtraTabCompletion, Expect):
         """
         return LiEFunctionElement
 
-    
+
 @instancedoc
 class LiEElement(ExtraTabCompletion, ExpectElement):
     def _tab_completion(self):
         """
-        Returns the possible tab completions for self.
+        Return the possible tab completions for ``self``.
 
         EXAMPLES::
 
@@ -777,9 +764,9 @@ class LiEElement(ExtraTabCompletion, ExpectElement):
             sage: m.type() # optional - lie
             'mat'
         """
-        t = self.parent().eval('type(%s)'%self._name)
+        t = self.parent().eval('type(%s)' % self._name)
         i = t.find(':')
-        return t[i+1:].strip()
+        return t[i + 1:].strip()
 
     def _matrix_(self, R=None):
         """
@@ -816,6 +803,8 @@ class LiEElement(ExtraTabCompletion, ExpectElement):
             [12  4 -4  7]
             [-1  9  8  0]
             [ 3 -5 -2  9]
+            sage: lie('-1X[1,1]').sage() # optional - lie
+            -x0*x1
 
         """
         t = self.type()
@@ -823,38 +812,39 @@ class LiEElement(ExtraTabCompletion, ExpectElement):
             raise ValueError("cannot convert Lie groups to native Sage objects")
         elif t == 'mat':
             import sage.matrix.constructor
-            return  sage.matrix.constructor.matrix( eval( str(self).replace('\n','').strip())  )
+            data = sage_eval(str(self).replace('\n', '').strip())
+            return sage.matrix.constructor.matrix(data)
         elif t == 'pol':
-            from sage.rings.all import PolynomialRing, QQ
+            from sage.rings.polynomial.polynomial_ring_constructor import PolynomialRing
+            from sage.rings.rational_field import QQ
 
-            #Figure out the number of variables
+            # Figure out the number of variables
             s = str(self)
             open_bracket = s.find('[')
             close_bracket = s.find(']')
             nvars = len(s[open_bracket:close_bracket].split(','))
 
-            #create the polynomial ring
+            # create the polynomial ring
             R = PolynomialRing(QQ, nvars, 'x')
             x = R.gens()
-            pol = R(0)
+            pol = R.zero()
 
-            #Split up the polynomials into terms
+            # Split up the polynomials into terms
             terms = []
             for termgrp in s.split(' - '):
-                #The first entry in termgrp has
-                #a negative coefficient
-                termgrp = "-"+termgrp.strip()
+                # The first entry in termgrp has
+                # a negative coefficient
+                termgrp = "-" + termgrp.strip()
                 terms += termgrp.split('+')
-            #Make sure we don't accidentally add a negative
-            #sign to the first monomial
-            if s[0] != "-":
-                terms[0] = terms[0][1:]
+            # Make sure we don't accidentally add a negative
+            # sign to the first monomial
+            terms[0] = terms[0][1:]
 
-            #go through all the terms in s
+            # go through all the terms in s
             for term in terms:
                 xpos = term.find('X')
                 coef = eval(term[:xpos].strip())
-                exps = eval(term[xpos+1:].strip())
+                exps = eval(term[xpos + 1:].strip())
                 monomial = prod([x[i]**exps[i] for i in range(nvars)])
                 pol += coef * monomial
 
@@ -885,7 +875,7 @@ class LiEFunctionElement(FunctionElement):
 class LiEFunction(ExpectFunction):
     def _instancedoc_(self):
         """
-        Returns the help for self.
+        Return the help for ``self``.
 
         EXAMPLES::
 
@@ -896,23 +886,29 @@ class LiEFunction(ExpectFunction):
         return M.help(self._name)
 
 
-
-def is_LiEElement(x):
+def is_LiEElement(x) -> bool:
     """
     EXAMPLES::
 
         sage: from sage.interfaces.lie import is_LiEElement
+        sage: is_LiEElement(2)
+        doctest:...: DeprecationWarning: the function is_LiEElement is deprecated; use isinstance(x, sage.interfaces.abc.LiEElement) instead
+        See https://github.com/sagemath/sage/issues/34804 for details.
+        False
         sage: l = lie(2) # optional - lie
         sage: is_LiEElement(l) # optional - lie
         True
-        sage: is_LiEElement(2)
-        False
     """
+    from sage.misc.superseded import deprecation
+    deprecation(34804, "the function is_LiEElement is deprecated; use isinstance(x, sage.interfaces.abc.LiEElement) instead")
+
     return isinstance(x, LiEElement)
 
+
 # An instance
 lie = LiE()
 
+
 def reduce_load_lie():
     """
     EXAMPLES::
@@ -936,7 +932,6 @@ def lie_console():
         Authors: Arjeh M. Cohen, Marc van Leeuwen, Bert Lisser.
         Free source code distribution
         ...
-
     """
     from sage.repl.rich_output.display_manager import get_display_manager
     if not get_display_manager().is_in_terminal():
@@ -950,11 +945,9 @@ def lie_version():
 
         sage: from sage.interfaces.lie import lie_version
         sage: lie_version() # optional - lie
-        '2.1'
+        '2.2'
     """
-    f = open(os.path.join(LIE_INFO_DIR, 'INFO.0'))
-    lines = f.readlines()
-    f.close()
+    with open(os.path.join(LIE_INFO_DIR, 'INFO.0')) as f:
+        lines = f.readlines()
     i = lines.index('@version()\n')
-    return lines[i+1].split()[1]
-
+    return lines[i + 1].split()[1]
