@@ -35,7 +35,7 @@ This is the interface used by the maxima object::
     <class 'sage.interfaces.maxima.Maxima'>
 
 If the string "error" (case insensitive) occurs in the output of
-anything from Maxima, a RuntimeError exception is raised.
+anything from Maxima, a :class:`RuntimeError` exception is raised.
 
 EXAMPLES: We evaluate a very simple expression in Maxima.
 
@@ -448,14 +448,14 @@ A long complicated input expression::
     sage: maxima._eval_line('((((((((((0) + ((1) / ((n0) ^ (0)))) + ((1) / ((n1) ^ (1)))) + ((1) / ((n2) ^ (2)))) + ((1) / ((n3) ^ (3)))) + ((1) / ((n4) ^ (4)))) + ((1) / ((n5) ^ (5)))) + ((1) / ((n6) ^ (6)))) + ((1) / ((n7) ^ (7)))) + ((1) / ((n8) ^ (8)))) + ((1) / ((n9) ^ (9)));')
     '1/n9^9+1/n8^8+1/n7^7+1/n6^6+1/n5^5+1/n4^4+1/n3^3+1/n2^2+1/n1+1'
 
-Test that Maxima gracefully handles this syntax error (:trac:`17667`)::
+Test that Maxima gracefully handles this syntax error (:issue:`17667`)::
 
     sage: maxima.eval("1 == 1;")
     Traceback (most recent call last):
     ...
     TypeError: ...incorrect syntax: = is not a prefix operator...
 
-Test that conversion of symbolic functions with latex names works (:trac:`31047`)::
+Test that conversion of symbolic functions with latex names works (:issue:`31047`)::
 
     sage: var('phi')
     phi
@@ -467,7 +467,7 @@ Test that conversion of symbolic functions with latex names works (:trac:`31047`
     sage: test.operator()._latex_() == 'C_+'
     True
 
-Test that the output is parseable (:trac:`31796`)::
+Test that the output is parseable (:issue:`31796`)::
 
     sage: foo = maxima('a and (b or c)') ; foo
     a and (b or c)
@@ -475,11 +475,9 @@ Test that the output is parseable (:trac:`31796`)::
     a and (b or c)
     sage: bar == foo
     True
-
-
 """
 
-#*****************************************************************************
+# ****************************************************************************
 #       Copyright (C) 2005 William Stein <wstein@gmail.com>
 #
 #  Distributed under the terms of the GNU General Public License (GPL)
@@ -491,8 +489,8 @@ Test that the output is parseable (:trac:`31796`)::
 #
 #  The full text of the GPL is available at:
 #
-#                  http://www.gnu.org/licenses/
-#*****************************************************************************
+#                  https://www.gnu.org/licenses/
+# ****************************************************************************
 
 import os
 import re
@@ -542,7 +540,7 @@ class Maxima(MaximaAbstract, Expect):
             sage: maxima == loads(dumps(m))
             True
 
-        We make sure labels are turned off (see :trac:`6816`)::
+        We make sure labels are turned off (see :issue:`6816`)::
 
             sage: 'nolabels : true' in maxima._Expect__init_code
             True
@@ -556,7 +554,7 @@ class Maxima(MaximaAbstract, Expect):
         if not os.path.exists(STARTUP):
             raise RuntimeError('You must get the file sage-maxima.lisp')
 
-        #self.__init_code = init_code
+        # self.__init_code = init_code
         if init_code is None:
             # display2d -- no ascii art output
             # keepfloat -- don't automatically convert floats to rationals
@@ -570,7 +568,7 @@ class Maxima(MaximaAbstract, Expect):
         # See trac # 6818.
         init_code.append('nolabels : true')
 
-        MaximaAbstract.__init__(self,"maxima")
+        MaximaAbstract.__init__(self, "maxima")
         Expect.__init__(self,
                         name='maxima',
                         prompt=r'\(\%i[0-9]+\) ',
@@ -649,7 +647,7 @@ class Maxima(MaximaAbstract, Expect):
             sage: maxima.__reduce__()
             (<function reduce_load_Maxima at 0x...>, ())
         """
-        return reduce_load_Maxima, tuple([]) #(self.__init_code,)
+        return reduce_load_Maxima, tuple()  # (self.__init_code,)
 
     def _sendline(self, string):
         """
@@ -728,8 +726,8 @@ class Maxima(MaximaAbstract, Expect):
             if i > 0:
                 v = self._before()
 
-                #We check to see if there is a "serious" error in Maxima.
-                #Note that this depends on the order of self._prompt_wait
+                # We check to see if there is a "serious" error in Maxima.
+                # Note that this depends on the order of self._prompt_wait
                 if expr is self._prompt_wait and i > len(self._ask):
                     self.quit()
                     raise ValueError(
@@ -887,23 +885,22 @@ class Maxima(MaximaAbstract, Expect):
             sage: maxima._batch('10003;',batchload=False)
             '...batch...10003...'
         """
-        filename = '%s-%s'%(self._local_tmpfile(),randrange(2147483647))
-        F = open(filename, 'w')
-        F.write(s)
-        F.close()
+        filename = '%s-%s' % (self._local_tmpfile(), randrange(2147483647))
+        with open(filename, 'w') as F:
+            F.write(s)
         if self.is_remote():
             self._send_tmpfile_to_server(local_file=filename)
             tmp_to_use = self._remote_tmpfile()
         tmp_to_use = filename
 
         if batchload:
-            cmd = 'batchload("%s");'%tmp_to_use
+            cmd = 'batchload("%s");' % tmp_to_use
         else:
-            cmd = 'batch("%s");'%tmp_to_use
+            cmd = 'batch("%s");' % tmp_to_use
 
         r = randrange(2147483647)
         s = str(r+1)
-        cmd = "%s1+%s;\n"%(cmd,r)
+        cmd = "%s1+%s;\n" % (cmd, r)
 
         self._sendline(cmd)
         self._expect_expr(s)
@@ -969,7 +966,7 @@ class Maxima(MaximaAbstract, Expect):
             Maxima ERROR:
                 Principal Value
         """
-        raise TypeError("Error executing code in Maxima\nCODE:\n\t%s\nMaxima ERROR:\n\t%s"%(cmd, out.replace('-- an error.  To debug this try debugmode(true);','')))
+        raise TypeError("Error executing code in Maxima\nCODE:\n\t%s\nMaxima ERROR:\n\t%s" % (cmd, out.replace('-- an error.  To debug this try debugmode(true);', '')))
 
     ###########################################
     # Direct access to underlying lisp interpreter.
@@ -989,7 +986,7 @@ class Maxima(MaximaAbstract, Expect):
             19
             (
         """
-        self._eval_line(':lisp %s\n""'%cmd, allow_use_file=False,
+        self._eval_line(':lisp %s\n""' % cmd, allow_use_file=False,
                wait_for_prompt=False, reformat=False, error_check=False)
         self._expect_expr('(%i)')
         return self._before()
@@ -1004,9 +1001,9 @@ class Maxima(MaximaAbstract, Expect):
 
         INPUT:
 
-        - ``var`` - string
+        - ``var`` -- string
 
-        - ``value`` - string
+        - ``value`` -- string
 
         EXAMPLES::
 
@@ -1016,15 +1013,15 @@ class Maxima(MaximaAbstract, Expect):
         """
         if not isinstance(value, str):
             raise TypeError
-        cmd = '%s : %s$'%(var, value.rstrip(';'))
+        cmd = '%s : %s$' % (var, value.rstrip(';'))
         if len(cmd) > self.__eval_using_file_cutoff:
             self._batch(cmd, batchload=True)
         else:
             self._eval_line(cmd)
-            #self._sendline(cmd)
-            #self._expect_expr()
-            #out = self._before()
-            #self._error_check(cmd, out)
+            # self._sendline(cmd)
+            # self._expect_expr()
+            # out = self._before()
+            # self._error_check(cmd, out)
 
     def clear(self, var):
         """
@@ -1100,30 +1097,30 @@ class Maxima(MaximaAbstract, Expect):
         """
         return MaximaElementFunction
 
-    ## some old helper functions to wrap the calculus use
-    ## of the Maxima interface. these routines expect arguments
-    ## living in the symbolic ring and return something
-    ## that is hopefully coercible into the symbolic ring again.
-##
-##    def sr_integral(self,*args):
-##        return args[0]._maxima_().integrate(*args[1:])
-##
-##    def sr_sum(self,expression,v,a,b):
-##        sum  = "'sum(%s, %s, %s, %s)" % tuple([repr(expr._maxima_()) for expr in (expression, v, a, b)])
-##        result = self.simplify_sum(sum)
-##        result = result.ratsimp()
-##        return expression.parent()(result)
-##
-##    def sr_limit(self,ex,*args):
-##        return ex._maxima_().limit(*args)
-##
-##    def sr_tlimit(self,ex,*args):
-##        return ex._maxima_().tlimit(*args)
-##
+    # some old helper functions to wrap the calculus use
+    # of the Maxima interface. these routines expect arguments
+    # living in the symbolic ring and return something
+    # that is hopefully coercible into the symbolic ring again.
+
+#    def sr_integral(self,*args):
+#        return args[0]._maxima_().integrate(*args[1:])
+
+#    def sr_sum(self,expression,v,a,b):
+#        sum  = "'sum(%s, %s, %s, %s)" % tuple([repr(expr._maxima_()) for expr in (expression, v, a, b)])
+#        result = self.simplify_sum(sum)
+#        result = result.ratsimp()
+#        return expression.parent()(result)
+
+#    def sr_limit(self,ex,*args):
+#        return ex._maxima_().limit(*args)
+
+#    def sr_tlimit(self,ex,*args):
+#        return ex._maxima_().tlimit(*args)
+
 
 def is_MaximaElement(x):
     """
-    Returns True if ``x`` is of type :class:`MaximaElement`.
+    Return True if ``x`` is of type :class:`MaximaElement`.
 
     EXAMPLES::
 
@@ -1196,7 +1193,7 @@ class MaximaElement(MaximaAbstractElement, ExpectElement):
         P = self.parent()
         with gc_disabled():
             P._eval_line('display2d : true$')
-            s = P._eval_line('disp(%s)$'%self.name(), reformat=False)
+            s = P._eval_line('disp(%s)$' % self.name(), reformat=False)
             P._eval_line('display2d : false$')
         s = s.strip('\r\n')
 
@@ -1261,7 +1258,7 @@ maxima = Maxima(init_code=['display2d : false',
                 script_subdirectory=None)
 
 
-def reduce_load_Maxima(): #(init_code=None):
+def reduce_load_Maxima():  # (init_code=None):
     """
     Unpickle a Maxima Pexpect interface.
 
@@ -1271,7 +1268,8 @@ def reduce_load_Maxima(): #(init_code=None):
         sage: reduce_load_Maxima()
         Maxima
     """
-    return maxima #Maxima(init_code=init_code)
+    return maxima  # Maxima(init_code=init_code)
+
 
 # This is defined for compatibility with the old Maxima interface.
 def reduce_load_Maxima_function(parent, defn, args, latex):
@@ -1289,6 +1287,7 @@ def reduce_load_Maxima_function(parent, defn, args, latex):
     """
     return parent.function(args, defn, defn, latex)
 
+
 def __doctest_cleanup():
     """
     Kill all Pexpect interfaces.
