@@ -74,14 +74,14 @@ Camera projection modes
 The ``PROJECTION`` keyword must be followed by one of the supported
 camera projection mode identifiers ``PERSPECTIVE``, ``PERSPECTIVE_DOF``,
 ``ORTHOGRAPHIC``, or ``FISHEYE``. The ``FISHEYE`` projection mode
-requires two extra parameters ``FOCALDIST`` and ``APERTURE`` which
+requires two extra parameters ``FOCALLENGTH`` and ``APERTURE`` which
 precede the regular camera options.
 
 ::
 
    Camera
      projection perspective_dof
-     FOCALDIST 0.75
+     focallength 0.75
      aperture 0.02
      Zoom 0.666667
      Aspectratio 1.000000
@@ -673,22 +673,24 @@ parameters so that you can position the image map on the object
 properly.
 """
 
-#*****************************************************************************
+# ****************************************************************************
 #       Copyright (C) 2006 John E. Stone
 #
 #  Distributed under the terms of the GNU General Public License (GPL)
 #  as published by the Free Software Foundation; either version 2 of
 #  the License, or (at your option) any later version.
-#                  http://www.gnu.org/licenses/
-#*****************************************************************************
+#                  https://www.gnu.org/licenses/
+# ****************************************************************************
 
 import os
+import re
 
 from sage.cpython.string import bytes_to_str
 from sage.misc.pager import pager
 from sage.misc.superseded import deprecation
 from sage.misc.temporary_file import tmp_filename
 from sage.structure.sage_object import SageObject
+from sage.misc.cachefunc import cached_method
 
 
 class TachyonRT(SageObject):
@@ -700,36 +702,36 @@ class TachyonRT(SageObject):
 
     INPUT:
 
-    -  ``model`` - a string that describes a 3d model in
+    -  ``model`` -- a string that describes a 3d model in
        the Tachyon modeling format. Type ``sage.interfaces.tachyon?`` for a
        description of this format.
 
-    -  ``outfile`` - (default: 'sage.png') output filename;
+    -  ``outfile`` -- (default: 'sage.png') output filename;
        the extension of the filename determines the type. Supported types
        include:
 
-       -  ``tga`` - 24-bit (uncompressed)
+       -  ``tga`` -- 24-bit (uncompressed)
 
-       -  ``bmp`` - 24-bit Windows BMP (uncompressed)
+       -  ``bmp`` -- 24-bit Windows BMP (uncompressed)
 
-       -  ``ppm`` - 24-bit PPM (uncompressed)
+       -  ``ppm`` -- 24-bit PPM (uncompressed)
 
-       -  ``rgb`` - 24-bit SGI RGB (uncompressed)
+       -  ``rgb`` -- 24-bit SGI RGB (uncompressed)
 
-       -  ``png`` - 24-bit PNG (compressed, lossless)
+       -  ``png`` -- 24-bit PNG (compressed, lossless)
 
-    -  ``verbose`` - integer; (default: 1)
+    -  ``verbose`` -- integer; (default: 1)
 
-       -  ``0`` - silent
+       -  ``0`` -- silent
 
-       -  ``1`` - some output
+       -  ``1`` -- some output
 
-       -  ``2`` - very verbose output
+       -  ``2`` -- very verbose output
 
-    -  ``block`` - bool (default: True); if False, run the
+    -  ``block`` -- bool (default: ``True``); if False, run the
        rendering command in the background.
 
-    -  ``extra_opts`` - passed directly to tachyon command
+    -  ``extra_opts`` -- passed directly to tachyon command
        line. Use tachyon_rt.usage() to see some of the possibilities.
 
     OUTPUT:
@@ -799,6 +801,11 @@ class TachyonRT(SageObject):
             Parser failed due to an input file syntax error.
             Aborting render.
         """
+        if self.version() >= '0.99.2':
+            # this keyword was changed in 0.99.2
+            model = model.replace(
+                "              focallength ",
+                "              focaldist ")
         modelfile = tmp_filename(ext='.dat')
         with open(modelfile, 'w') as file:
             file.write(model)
@@ -851,6 +858,25 @@ class TachyonRT(SageObject):
         else:
             print(r)
 
+    @cached_method
+    def version(self):
+        """
+        Returns the version of the Tachyon raytracer being used.
+
+        TESTS::
+
+            sage: tachyon_rt.version()  # random
+            0.98.9
+            sage: tachyon_rt.version() >= '0.98.9'
+            True
+        """
+        with os.popen('tachyon') as f:
+            r = f.readline()
+        res = re.search(r"Version ([\d.]*)", r)
+        # debian patches tachyon so it won't report the version
+        # we hardcode '0.99' since that's indeed the version they ship
+        return res[1] if res else '0.99'
+
     def help(self, use_pager=True):
         """
         Deprecated: type 'sage.interfaces.tachyon?' for help
@@ -861,8 +887,9 @@ class TachyonRT(SageObject):
             sage: t = TachyonRT()
             sage: t.help(use_pager=False)
             doctest:...: DeprecationWarning: type 'sage.interfaces.tachyon?' for help
-            See https://trac.sagemath.org/34066 for details.
+            See https://github.com/sagemath/sage/issues/34066 for details.
         """
         deprecation(34066, "type 'sage.interfaces.tachyon?' for help")
 
+
 tachyon_rt = TachyonRT()
