@@ -1,7 +1,7 @@
 r"""
 Tests for the Sage <-> PARI interface
 
-The default precision is 64 bits, see :trac:`21425`::
+The default precision is 64 bits, see :issue:`21425`::
 
     sage: pari("bitprecision(Pi)")
     64
@@ -10,30 +10,30 @@ Sage-specific API checks:
 
 Creating PARI objects::
 
-    sage: pari(Matrix(2,2,range(4)))
+    sage: pari(Matrix(2,2,range(4)))                                                    # needs sage.modules
     [0, 1; 2, 3]
-    sage: pari(x^2-3)
+    sage: pari(x^2-3)                                                                   # needs sage.symbolic
     x^2 - 3
 
 The following example caused Sage to crash before
-:trac:`20630`::
+:issue:`20630`::
 
     sage: R.<theta> = QQ[]
-    sage: K.<a> = NumberField(theta^2 + 1)
-    sage: K.absolute_polynomial().galois_group(pari_group=True)
+    sage: K.<a> = NumberField(theta^2 + 1)                                              # needs sage.rings.number_field
+    sage: K.absolute_polynomial().galois_group(pari_group=True)                         # needs sage.groups sage.rings.number_field
     PARI group [2, -1, 1, "S2"] of degree 2
 
-Before :trac:`15654`, this used to take a very long time.
+Before :issue:`15654`, this used to take a very long time.
 Now it takes much less than a second::
 
     sage: pari.allocatemem(200000)
     PARI stack size set to 200000 bytes, maximum size set to ...
-    sage: x = polygen(ZpFM(3,10))
-    sage: pol = ((x-1)^50 + x)
-    sage: pari(pol).poldisc()
+    sage: x = polygen(ZpFM(3,10))                                                       # needs sage.rings.padics
+    sage: pol = ((x-1)^50 + x)                                                          # needs sage.rings.padics
+    sage: pari(pol).poldisc()                                                           # needs sage.rings.padics
     2*3 + 3^4 + 2*3^6 + 3^7 + 2*3^8 + 2*3^9 + O(3^10)
 
-This used to give the wrong answer before :trac:`23259`::
+This used to give the wrong answer before :issue:`23259`::
 
     sage: R.<x> = QQ[]
     sage: f = pari(x^12 + x^7 - 1/5*x^6 - 3*x^5 + 13/5*x^4 + 11/5*x^3 + 2/5*x^2 + 2/5*x + 1/5)
@@ -59,21 +59,22 @@ from the lowest degree term.  This includes trailing zeros::
 
 Number fields::
 
+    sage: # needs sage.rings.number_field
     sage: x = polygen(QQ)
     sage: K.<a> = NumberField(x^4 - 4*x^2 + 1)
     sage: pari(K).nf_get_pol()
     y^4 - 4*y^2 + 1
     sage: L.<b> = K.extension(x^2 - 5)
-    sage: pari(L).nf_get_pol()        # Absolute
+    sage: pari(L).nf_get_pol()              # Absolute
     y^8 - 28*y^6 + 208*y^4 - 408*y^2 + 36
-    sage: L.pari_rnf().nf_get_pol()   # Relative
+    sage: L.pari_rnf().nf_get_pol()         # Relative
     x^2 - 5
-
     sage: K.pari_nf().nf_get_pol()
     y^4 - 4*y^2 + 1
     sage: K.pari_bnf().nf_get_pol()
     y^4 - 4*y^2 + 1
 
+    sage: # needs sage.rings.number_field
     sage: K.<a> = QuadraticField(-65)
     sage: G = K.pari_bnf().bnf_get_gen(); G
     [[3, 2; 0, 1], [2, 1; 0, 1]]
@@ -82,23 +83,23 @@ Number fields::
 
 Conversions::
 
+    sage: # needs sage.rings.number_field
     sage: K.<i> = QuadraticField(-1)
     sage: F = pari(K).idealfactor(K.ideal(5)); F
     [[5, [-2, 1]~, 1, 1, [2, -1; 1, 2]], 1; [5, [2, 1]~, 1, 1, [-2, -1; 1, -2]], 1]
     sage: F[0,0].pr_get_p()
     5
-
-    sage: K.<i> = QuadraticField(-1)
     sage: J = pari(K).idealstar(K.ideal(4*i + 2))
     sage: J.bid_get_cyc()
     [4, 2]
 
-    sage: int(pari(RealField(63)(2^63-1)))
+    sage: int(pari(RealField(63)(2^63 - 1)))                                            # needs sage.rings.real_mpfr
     9223372036854775807   # 32-bit
     9223372036854775807   # 64-bit
-    sage: int(pari(RealField(63)(2^63+2)))
+    sage: int(pari(RealField(63)(2^63 + 2)))                                            # needs sage.rings.real_mpfr
     9223372036854775810
 
+    sage: # needs sage.rings.padics
     sage: K = Qp(11,5)
     sage: x = K(11^-10 + 5*11^-7 + 11^-6)
     sage: y = pari(x)
@@ -107,8 +108,9 @@ Conversions::
     sage: y.padicprime().type()
     't_INT'
 
+    sage: # needs sage.rings.finite_rings
     sage: x = polygen(GF(3))
-    sage: k.<a> = GF(9, modulus=x^2+1)
+    sage: k.<a> = GF(9, modulus=x^2 + 1)
     sage: b = pari(a).ffprimroot()
     sage: b  # random
     a + 1
@@ -125,20 +127,21 @@ Conversions::
 
 Conversion from matrices and vectors is supported::
 
-    sage: a = pari(matrix(2,3,[1,2,3,4,5,6])); a, a.type()
+    sage: a = pari(matrix(2,3,[1,2,3,4,5,6])); a, a.type()                              # needs sage.modules
     ([1, 2, 3; 4, 5, 6], 't_MAT')
-    sage: v = vector([1.2, 3.4, 5.6])
-    sage: pari(v)
+    sage: v = vector([1.2, 3.4, 5.6])                                                   # needs sage.modules
+    sage: pari(v)                                                                       # needs sage.modules
     [1.20000000000000, 3.40000000000000, 5.60000000000000]
 
 Some more exotic examples::
 
+    sage: # needs sage.rings.number_field
     sage: K.<a> = NumberField(polygen(QQ)^3 - 2)
     sage: pari(K)
     [y^3 - 2, [1, 1], -108, 1, [[1, 1.25992104989487, 1.58740105196820; 1, -0.629960524947437 + 1.09112363597172*I, -0.793700525984100 - 1.37472963699860*I], [1, 1.25992104989487, 1.58740105196820; 1, 0.461163111024285, -2.16843016298270; 1, -1.72108416091916, 0.581029111014503], [16, 20, 25; 16, 7, -35; 16, -28, 9], [3, 0, 0; 0, 0, 6; 0, 6, 0], [6, 0, 0; 0, 6, 0; 0, 0, 3], [2, 0, 0; 0, 0, 1; 0, 1, 0], [2, [0, 0, 2; 1, 0, 0; 0, 1, 0]], [2, 3]], [1.25992104989487, -0.629960524947437 + 1.09112363597172*I], [1, y, y^2], [1, 0, 0; 0, 1, 0; 0, 0, 1], [1, 0, 0, 0, 0, 2, 0, 2, 0; 0, 1, 0, 1, 0, 0, 0, 0, 2; 0, 0, 1, 0, 1, 0, 1, 0, 0]]
 
-    sage: E = EllipticCurve('37a1')
-    sage: pari(E)
+    sage: E = EllipticCurve('37a1')                                                     # needs sage.schemes
+    sage: pari(E)                                                                       # needs sage.schemes
     [0, 0, 1, -1, 0, 0, -2, 1, -1, 48, -216, 37, 110592/37, Vecsmall([1]), [Vecsmall([64, 1])], [0, 0, 0, 0, 0, 0, 0, 0]]
 
 Deprecation checks::
@@ -405,6 +408,8 @@ Basic functions::
     -1
     sage: pari(3/4).ceil()
     1
+
+    sage: # needs sage.symbolic
     sage: x = SR.symbol('x')
     sage: pari(x).ceil()
     x
@@ -493,6 +498,8 @@ Basic functions::
     [1, 2, 4]
     sage: pari([[1.1,2.2],[3.3,4.4]]).floor()
     [[1, 2], [3, 4]]
+
+    sage: # needs sage.symbolic
     sage: x = SR.symbol('x')
     sage: pari(x).floor()
     x
@@ -500,6 +507,7 @@ Basic functions::
     x + 1
     sage: pari(x^2+5*x+2.5).floor()
     x^2 + 5*x + 2.50000000000000
+
     sage: pari('"hello world"').floor()
     Traceback (most recent call last):
     ...
@@ -507,7 +515,7 @@ Basic functions::
 
     sage: pari(1.75).frac()
     0.750000000000000
-    sage: pari(sqrt(2)).frac()
+    sage: pari(sqrt(2)).frac()                                                          # needs sage.symbolic
     0.414213562373095
     sage: pari('sqrt(-2)').frac()
     Traceback (most recent call last):
@@ -516,7 +524,7 @@ Basic functions::
 
     sage: pari('1+2*I').imag()
     2
-    sage: pari(sqrt(-2)).imag()
+    sage: pari(sqrt(-2)).imag()                                                         # needs sage.symbolic
     1.41421356237310
     sage: pari('x+I').imag()
     1
@@ -536,13 +544,13 @@ Basic functions::
     sage: b.lift()
     -17*x^2 - 3*x
 
-    sage: pari(pi).sign()
+    sage: pari(pi).sign()                                                               # needs sage.symbolic
     1
     sage: pari(0).sign()
     0
     sage: pari(-1/2).sign()
     -1
-    sage: pari(SR(I)).sign()
+    sage: pari(SR(I)).sign()                                                            # needs sage.symbolic
     Traceback (most recent call last):
     ...
     PariError: incorrect type in gsigne (t_COMPLEX)
@@ -705,16 +713,16 @@ Transcendental functions::
     1.04719755119660
     sage: pari(1.1).acos()
     0.443568254385115*I
-    sage: C.<i> = ComplexField()
-    sage: pari(1.1+i).acos()
+    sage: C.<i> = ComplexField()                                                        # needs sage.rings.real_mpfr
+    sage: pari(1.1+i).acos()                                                            # needs sage.rings.real_mpfr
     0.849343054245252 - 1.09770986682533*I
 
     sage: pari(2).acosh()
     1.31695789692482
     sage: pari(0).acosh()
     1.57079632679490*I
-    sage: C.<i> = ComplexField()
-    sage: pari(i).acosh()
+    sage: C.<i> = ComplexField()                                                        # needs sage.rings.real_mpfr
+    sage: pari(i).acosh()                                                               # needs sage.rings.real_mpfr
     0.881373587019543 + 1.57079632679490*I
 
     sage: pari(2).agm(2)
@@ -723,12 +731,12 @@ Transcendental functions::
     0
     sage: pari(1).agm(2)
     1.45679103104691
-    sage: C.<i> = ComplexField()
-    sage: pari(1+i).agm(-3)
+    sage: C.<i> = ComplexField()                                                        # needs sage.rings.real_mpfr
+    sage: pari(1+i).agm(-3)                                                             # needs sage.rings.real_mpfr
     -0.964731722290876 + 1.15700282952632*I
 
-    sage: C.<i> = ComplexField()
-    sage: pari(2+i).arg()
+    sage: C.<i> = ComplexField()                                                        # needs sage.rings.real_mpfr
+    sage: pari(2+i).arg()                                                               # needs sage.rings.real_mpfr
     0.463647609000806
 
     sage: pari(pari(0.5).sin()).asin()
@@ -738,14 +746,14 @@ Transcendental functions::
 
     sage: pari(2).asinh()
     1.44363547517881
-    sage: C.<i> = ComplexField()
-    sage: pari(2+i).asinh()
+    sage: C.<i> = ComplexField()                                                        # needs sage.rings.real_mpfr
+    sage: pari(2+i).asinh()                                                             # needs sage.rings.real_mpfr
     1.52857091948100 + 0.427078586392476*I
 
     sage: pari(1).atan()
     0.785398163397448
-    sage: C.<i> = ComplexField()
-    sage: pari(1.5+i).atan()
+    sage: C.<i> = ComplexField()                                                        # needs sage.rings.real_mpfr
+    sage: pari(1.5+i).atan()                                                            # needs sage.rings.real_mpfr
     1.10714871779409 + 0.255412811882995*I
 
     sage: pari(0).atanh()
@@ -763,6 +771,8 @@ Transcendental functions::
     0.412710032209716
     sage: pari(2).besseli(3)
     2.24521244092995
+
+    sage: # needs sage.rings.real_mpfr
     sage: C.<i> = ComplexField()
     sage: pari(2).besseli(3+i)
     1.12539407613913 + 2.08313822670661*I
@@ -772,37 +782,37 @@ Transcendental functions::
 
     sage: pari(1.5).cos()
     0.0707372016677029
-    sage: C.<i> = ComplexField()
-    sage: pari(1+i).cos()
+    sage: C.<i> = ComplexField()                                                        # needs sage.rings.real_mpfr
+    sage: pari(1+i).cos()                                                               # needs sage.rings.real_mpfr
     0.833730025131149 - 0.988897705762865*I
     sage: pari('x+O(x^8)').cos()
     1 - 1/2*x^2 + 1/24*x^4 - 1/720*x^6 + 1/40320*x^8 + O(x^9)
 
     sage: pari(1.5).cosh()
     2.35240961524325
-    sage: C.<i> = ComplexField()
-    sage: pari(1+i).cosh()
+    sage: C.<i> = ComplexField()                                                        # needs sage.rings.real_mpfr
+    sage: pari(1+i).cosh()                                                              # needs sage.rings.real_mpfr
     0.833730025131149 + 0.988897705762865*I
     sage: pari('x+O(x^8)').cosh()
     1 + 1/2*x^2 + 1/24*x^4 + 1/720*x^6 + ...O(...)
 
     sage: pari(5).cotan()
     -0.295812915532746
-    sage: x = RR(pi)
+    sage: x = RR(pi)                                                                    # needs sage.symbolic
     sage: pari(x).cotan()  # random
     -8.17674825 E15
 
     sage: pari(1).dilog()
     1.64493406684823
-    sage: C.<i> = ComplexField()
-    sage: pari(1+i).dilog()
+    sage: C.<i> = ComplexField()                                                        # needs sage.rings.real_mpfr
+    sage: pari(1+i).dilog()                                                             # needs sage.rings.real_mpfr
     0.616850275068085 + 1.46036211675312*I
 
     sage: pari(1).erfc()
     0.157299207050285
 
-    sage: C.<i> = ComplexField()
-    sage: pari(i).eta()
+    sage: C.<i> = ComplexField()                                                        # needs sage.rings.real_mpfr
+    sage: pari(i).eta()                                                                 # needs sage.rings.real_mpfr
     0.998129069925959
 
     sage: pari(0).exp()
@@ -816,8 +826,8 @@ Transcendental functions::
     1.00000000000000
     sage: pari(5).gamma()
     24.0000000000000
-    sage: C.<i> = ComplexField()
-    sage: pari(1+i).gamma()
+    sage: C.<i> = ComplexField()                                                        # needs sage.rings.real_mpfr
+    sage: pari(1+i).gamma()                                                             # needs sage.rings.real_mpfr
     0.498015668118356 - 0.154949828301811*I
     sage: pari(-1).gamma()
     Traceback (most recent call last):
@@ -828,23 +838,23 @@ Transcendental functions::
     1.32934038817914
     sage: pari(5).gammah()
     52.3427777845535
-    sage: C.<i> = ComplexField()
-    sage: pari(1+i).gammah()
+    sage: C.<i> = ComplexField()                                                        # needs sage.rings.real_mpfr
+    sage: pari(1+i).gammah()                                                            # needs sage.rings.real_mpfr
     0.575315188063452 + 0.0882106775440939*I
 
     sage: pari(1).hyperu(2,3)
     0.333333333333333
 
-    sage: C.<i> = ComplexField()
-    sage: pari(1+i).incgam(3-i)
+    sage: C.<i> = ComplexField()                                                        # needs sage.rings.real_mpfr
+    sage: pari(1+i).incgam(3-i)                                                         # needs sage.rings.real_mpfr
     -0.0458297859919946 + 0.0433696818726677*I
     sage: pari(1).incgamc(2)
     0.864664716763387
 
     sage: pari(5).log()
     1.60943791243410
-    sage: C.<i> = ComplexField()
-    sage: pari(i).log()
+    sage: C.<i> = ComplexField()                                                        # needs sage.rings.real_mpfr
+    sage: pari(i).log()                                                                 # needs sage.rings.real_mpfr
     0.E-19 + 1.57079632679490*I
 
     sage: pari(100).lngamma()
@@ -857,14 +867,14 @@ Transcendental functions::
 
     sage: pari(1).sin()
     0.841470984807897
-    sage: C.<i> = ComplexField()
-    sage: pari(1+i).sin()
+    sage: C.<i> = ComplexField()                                                        # needs sage.rings.real_mpfr
+    sage: pari(1+i).sin()                                                               # needs sage.rings.real_mpfr
     1.29845758141598 + 0.634963914784736*I
 
     sage: pari(0).sinh()
     0.E-19
-    sage: C.<i> = ComplexField()
-    sage: pari(1+i).sinh()
+    sage: C.<i> = ComplexField()                                                        # needs sage.rings.real_mpfr
+    sage: pari(1+i).sinh()                                                              # needs sage.rings.real_mpfr
     0.634963914784736 + 1.29845758141598*I
 
     sage: pari(2).sqrt()
@@ -877,14 +887,14 @@ Transcendental functions::
 
     sage: pari(2).tan()
     -2.18503986326152
-    sage: C.<i> = ComplexField()
-    sage: pari(i).tan()
+    sage: C.<i> = ComplexField()                                                        # needs sage.rings.real_mpfr
+    sage: pari(i).tan()                                                                 # needs sage.rings.real_mpfr
     0.761594155955765*I
 
     sage: pari(1).tanh()
     0.761594155955765
-    sage: C.<i> = ComplexField()
-    sage: z = pari(i); z
+    sage: C.<i> = ComplexField()                                                        # needs sage.rings.real_mpfr
+    sage: z = pari(i); z                                                                # needs sage.rings.real_mpfr
     1.00000000000000*I
     sage: result = z.tanh()
     sage: result.real() <= 1e-18
@@ -901,6 +911,7 @@ Transcendental functions::
     sage: pari(0.5).thetanullk(1)
     0.548978532560341
 
+    sage: # needs sage.rings.real_mpfr
     sage: C.<i> = ComplexField()
     sage: pari(i).weber()
     1.18920711500272
@@ -911,8 +922,8 @@ Transcendental functions::
 
     sage: pari(2).zeta()
     1.64493406684823
-    sage: x = RR(pi)^2/6
-    sage: pari(x)
+    sage: x = RR(pi)^2/6                                                                # needs sage.symbolic
+    sage: pari(x)                                                                       # needs sage.symbolic
     1.64493406684823
     sage: pari(3).zeta()
     1.20205690315959
@@ -966,6 +977,7 @@ Linear algebra::
     sage: pari('[1,2,3; 4,5,6;  7,8,9]').mathnf()
     [6, 1; 3, 1; 0, 1]
 
+    sage: # needs sage.modules
     sage: M = matrix([[1,2,3],[4,5,6],[7,8,11]])
     sage: d = M.det()
     sage: pari(M).mathnfmod(d)
@@ -976,6 +988,7 @@ Linear algebra::
     sage: pari(M).mathnfmod(12)
     [1, 0, 0; 0, 2, 0; 0, 0, 6]
 
+    sage: # needs sage.modules
     sage: M = matrix([[1,0,0],[0,2,0],[0,0,6]])
     sage: pari(M).mathnfmodid(6)
     [1, 0, 0; 0, 2, 0; 0, 0, 6]
@@ -1007,6 +1020,7 @@ Linear algebra::
 
 Quadratic forms::
 
+    sage: # needs sage.modules
     sage: A = Matrix(3,3,[1,2,3,2,5,5,3,5,11])
     sage: A.is_positive_definite()
     True
@@ -1029,6 +1043,7 @@ Quadratic forms::
     10, 5.00000000000000000, [  1   2   0   1  -1]
     ]
 
+    sage: # needs sage.modules
     sage: M = diagonal_matrix([1,1,-1])
     sage: P = M.__pari__().qfparam([0,1,-1]); P
     [0, -2, 0; 1, 0, -1; -1, 0, -1]
@@ -1042,6 +1057,7 @@ Quadratic forms::
     sage: 48^2 + 55^2 == 73^2
     True
 
+    sage: # needs sage.modules
     sage: M = diagonal_matrix([1,2,3,4,-5])
     sage: M.__pari__().qfsolve()
     [0, 1, -1, 0, -1]~
@@ -1087,6 +1103,7 @@ Number-theoretical functions::
     sage: pari(10).eulerphi()
     4
 
+    sage: # needs sage.symbolic
     sage: x = SR.symbol('x')
     sage: pari(10).gcd(15)
     5
@@ -1153,6 +1170,7 @@ Finite fields::
     sage: pari(2003).ffinit(3)
     Mod(1, 2003)*x^3 + Mod(1, 2003)*x^2 + Mod(1993, 2003)*x + Mod(1995, 2003)
 
+    sage: # needs sage.rings.finite_rings
     sage: k.<a> = GF(2^12)
     sage: g = pari(a).ffprimroot()
     sage: (g^1234).fflog(g)
@@ -1167,6 +1185,7 @@ Finite fields::
     sage: (b^555).fflog(b, (ord, ord.factor()) )
     555
 
+    sage: # needs sage.rings.finite_rings
     sage: k.<a> = GF(5^80)
     sage: g = pari(a).ffprimroot()
     sage: g.fforder()
@@ -1178,6 +1197,7 @@ Finite fields::
 
 p-adic functions::
 
+    sage: # needs sage.rings.padics
     sage: K = Qp(11,5)
     sage: x = K(11^-10 + 5*11^-7 + 11^-6)
     sage: y = pari(x)
@@ -1201,10 +1221,10 @@ Elliptic curves::
     [0, 1/2, 0, -3/4, 0, 2, -3/2, 0, -9/16, 40, -116, 117/4, 256000/117, Vecsmall([1]), [Vecsmall([64, 1])], [0, 0, 0, 0, 0, 0, 0, 0]]
     sage: pari([0,0.5,0,-0.75,0]).ellinit()
     [0, 0.500000000000000, 0, -0.750000000000000, 0, 2.00000000000000, -1.50000000000000, 0, -0.562500000000000, 40.0000000000000, -116.000000000000, 29.2500000000000, 2188.03418803419, Vecsmall([0]), [Vecsmall([64, 1])], [0, 0, 0, 0]]
-    sage: pari([0,SR(I),0,1,0]).ellinit()
+    sage: pari([0,SR(I),0,1,0]).ellinit()                                               # needs sage.symbolic
     [0, I, 0, 1, 0, 4*I, 2, 0, -1, -64, 352*I, -80, 16384/5, Vecsmall([0]), [Vecsmall([64, 0])], [0, 0, 0, 0]]
-    sage: x = SR.symbol('x')
-    sage: pari([0,x,0,2*x,1]).ellinit()
+    sage: x = SR.symbol('x')                                                            # needs sage.symbolic
+    sage: pari([0,x,0,2*x,1]).ellinit()                                                 # needs sage.symbolic
     [0, x, 0, 2*x, 1, 4*x, 4*x, 4, -4*x^2 + 4*x, 16*x^2 - 96*x, -64*x^3 + 576*x^2 - 864, 64*x^4 - 576*x^3 + 576*x^2 - 432, (256*x^6 - 4608*x^5 + 27648*x^4 - 55296*x^3)/(4*x^4 - 36*x^3 + 36*x^2 - 27), Vecsmall([0]), [Vecsmall([64, 0])], [0, 0, 0, 0]]
 
     sage: e = pari([0,1,1,-2,0]).ellinit()
@@ -1233,6 +1253,8 @@ Elliptic curves::
     sage: e = pari([0, 5, 2, -1, 1]).ellinit()
     sage: e.ellglobalred()
     [20144, [1, -2, 0, -1], 1, [2, 4; 1259, 1], [[4, 2, 0, 1], [1, 5, 0, 1]]]
+
+    sage: # needs sage.schemes
     sage: e = pari(EllipticCurve('17a').a_invariants()).ellinit()
     sage: e.ellglobalred()
     [17, [1, 0, 0, 0], 4, Mat([17, 1]), [[1, 8, 0, 4]]]
@@ -1251,8 +1273,9 @@ Elliptic curves::
     sage: e.ellak(0)
     0
 
+    sage: # needs sage.schemes
     sage: E = EllipticCurve('389a1')
-    sage: pari(E).ellanalyticrank()
+    sage: pari(E).ellanalyticrank()                                                     # needs sage.rings.number_field
     [2, 1.51863300057685]
 
     sage: e = pari([0, -1, 1, -10, -20]).ellinit()
@@ -1291,6 +1314,7 @@ Elliptic curves::
     sage: om.elleisnum(100)
     2.15314248576078 E50
 
+    sage: # needs sage.schemes
     sage: e = pari([0,0,0,0,1]).ellinit()
     sage: e.elllocalred(7)
     [0, 1, [1, 0, 0, 0], 1]
@@ -1331,6 +1355,7 @@ Elliptic curves::
     sage: e.elllocalred(3)
     [2, -10, [1, 0, 0, 0], 4]
 
+    sage: # needs sage.schemes
     sage: e = pari(EllipticCurve('65a1').a_invariants()).ellinit()
     sage: e.ellorder([0,0])
     2
@@ -1340,11 +1365,11 @@ Elliptic curves::
     sage: e = pari([0,1,1,-2,0]).ellinit()
     sage: e.ellordinate(0)
     [0, -1]
-    sage: e.ellordinate(SR(I))
+    sage: e.ellordinate(SR(I))                                                          # needs sage.symbolic
     [0.582203589721741 - 1.38606082464177*I, -1.58220358972174 + 1.38606082464177*I]
-    sage: e.ellordinate(SR(I), precision=128)[0].sage()
+    sage: e.ellordinate(SR(I), precision=128)[0].sage()                                 # needs sage.symbolic
     0.58220358972174117723338947874993600727 - 1.3860608246417697185311834209833653345*I
-    sage: e.ellordinate(1+3*5^1+O(5^3))
+    sage: e.ellordinate(1+3*5^1+O(5^3))                                                 # needs sage.rings.padics
     [4*5 + 5^2 + O(5^3), 4 + 3*5^2 + O(5^3)]
     sage: e.ellordinate('z+2*z^2+O(z^4)')
     [-2*z - 7*z^2 - 23*z^3 + O(z^4), -1 + 2*z + 7*z^2 + 23*z^3 + O(z^4)]
@@ -1365,9 +1390,9 @@ Elliptic curves::
     [0]
     sage: e.ellmul(p, 2)
     [1/4, -7/8]
-    sage: q = e.ellmul(p, SR(1+I)); q
+    sage: q = e.ellmul(p, SR(1+I)); q                                                   # needs sage.symbolic
     [-2*I, 1 + I]
-    sage: e.ellmul(q, SR(1-I))
+    sage: e.ellmul(q, SR(1-I))                                                          # needs sage.symbolic
     [1/4, -7/8]
     sage: for D in [-7, -8, -11, -12, -16, -19, -27, -28]:  # long time (1s)
     ....:     hcpol = hilbert_class_polynomial(D)
@@ -1397,6 +1422,7 @@ Elliptic curves::
     sage: e.ellrootno(1009)
     1
 
+    sage: # needs sage.rings.real_mpfr
     sage: e = pari([0,0,0,1,0]).ellinit()
     sage: C.<i> = ComplexField()
     sage: e.ellsigma(2+i)
@@ -1409,26 +1435,26 @@ Elliptic curves::
     sage: e = pari([0,0,0,1,0]).ellinit()
     sage: e.ellzeta(1)
     1.06479841295883
-    sage: C.<i> = ComplexField()
-    sage: e.ellzeta(i-1)
+    sage: C.<i> = ComplexField()                                                        # needs sage.rings.real_mpfr
+    sage: e.ellzeta(i-1)                                                                # needs sage.rings.real_mpfr
     -0.350122658523049 - 0.350122658523049*I
 
     sage: e = pari([0,0,0,1,0]).ellinit()
-    sage: C.<i> = ComplexField()
-    sage: e.ellztopoint(1+i)
+    sage: C.<i> = ComplexField()                                                        # needs sage.rings.real_mpfr
+    sage: e.ellztopoint(1+i)                                                            # needs sage.rings.real_mpfr
     [0.E-... - 1.02152286795670*I, -0.149072813701096 - 0.149072813701096*I]
     sage: e.ellztopoint(0)
     [0]
 
-    sage: pari(SR(I)).ellj()
+    sage: pari(SR(I)).ellj()                                                            # needs sage.symbolic
     1728.00000000000
-    sage: pari(SR(3*I)).ellj()
+    sage: pari(SR(3*I)).ellj()                                                          # needs sage.symbolic
     153553679.396729
     sage: pari('quadgen(-3)').ellj()
     0.E-54
     sage: pari('quadgen(-7)').ellj(precision=256).sage()
     -3375.000000000000000000000000000000000000000000000000000000000000000000000000
-    sage: pari(SR(-I)).ellj()
+    sage: pari(SR(-I)).ellj()                                                           # needs sage.symbolic
     Traceback (most recent call last):
     ...
     PariError: domain error in modular function: Im(argument) <= 0
@@ -1497,16 +1523,17 @@ Quadratic class numbers::
 General number fields::
 
     sage: x = polygen(QQ)
-    sage: K.<a> = NumberField(x^2 - 1/8)
-    sage: pari(x^2 - 2).factornf(K.pari_polynomial("a"))
+    sage: K.<a> = NumberField(x^2 - 1/8)                                                # needs sage.rings.number_field
+    sage: pari(x^2 - 2).factornf(K.pari_polynomial("a"))                                # needs sage.rings.number_field
     doctest:...: DeprecationWarning: the PARI/GP function factornf is obsolete (2016-08-08)
     [x + Mod(-a, a^2 - 2), 1; x + Mod(a, a^2 - 2), 1]
 
-    sage: K.<z> = QuadraticField(-23)
-    sage: p = K.primes_above(3)[0]
-    sage: K.pari_bnf().bnrclassno(p._pari_bid_())
+    sage: K.<z> = QuadraticField(-23)                                                   # needs sage.rings.number_field
+    sage: p = K.primes_above(3)[0]                                                      # needs sage.rings.number_field
+    sage: K.pari_bnf().bnrclassno(p._pari_bid_())                                       # needs sage.rings.number_field
     3
 
+    sage: # needs sage.symbolic
     sage: x = SR.symbol('x')
     sage: P = pari(x^6 + 108)
     sage: G = P.galoisinit()
@@ -1515,6 +1542,7 @@ General number fields::
     sage: len(G[5]) == prod(G[7])
     True
 
+    sage: # needs sage.symbolic
     sage: G = pari(x^6 + 108).galoisinit()
     sage: G.galoispermtopol(G[5])
     [x, 1/12*x^4 - 1/2*x, -1/12*x^4 - 1/2*x, 1/12*x^4 + 1/2*x, -1/12*x^4 + 1/2*x, -x]
@@ -1523,6 +1551,7 @@ General number fields::
     sage: G.galoispermtopol(G[5][1:4])
     [1/12*x^4 - 1/2*x, -1/12*x^4 - 1/2*x, 1/12*x^4 + 1/2*x]
 
+    sage: # needs sage.symbolic
     sage: G = pari(x^4 + 1).galoisinit()
     sage: G.galoisfixedfield(G[5][1], flag=2)
     [y^2 - 2, Mod(-x^3 + x, x^4 + 1), [x^2 - y*x + 1, x^2 + y*x + 1]]
@@ -1537,6 +1566,7 @@ General number fields::
     sage: list(L[0][1])
     [3, 2]
 
+    sage: # needs sage.symbolic
     sage: G = pari(x^6 + 108).galoisinit()
     sage: G.galoisisabelian()
     0
@@ -1546,6 +1576,7 @@ General number fields::
     sage: H.galoisisabelian(flag=1)
     1
 
+    sage: # needs sage.symbolic
     sage: G = pari(x^6 + 108).galoisinit()
     sage: L = G.galoissubgroups()
     sage: G.galoisisnormal(L[0])
@@ -1553,18 +1584,20 @@ General number fields::
     sage: G.galoisisnormal(L[2])
     0
 
+    sage: # needs sage.rings.number_field
     sage: F = QuadraticField(5, 'alpha')
     sage: nf = F.__pari__()
     sage: P = F.ideal(F.gen())
     sage: Q = F.ideal(2)
-    sage: moduli = pari.matrix(2,2,[P.pari_prime(),4,Q.pari_prime(),4])
+    sage: moduli = pari.matrix(2,2,[P.pari_prime(),4,Q.pari_prime(),4])                 # needs sage.symbolic
     sage: residues = pari.vector(2,[0,1])
-    sage: b = F(nf.idealchinese(moduli,residues))
-    sage: b.valuation(P) >= 4
+    sage: b = F(nf.idealchinese(moduli,residues))                                       # needs sage.symbolic
+    sage: b.valuation(P) >= 4                                                           # needs sage.symbolic
     True
     sage: (b-1).valuation(Q) >= 2
     True
 
+    sage: # needs sage.symbolic
     sage: F = NumberField(x^3-2, 'alpha')
     sage: nf = F.__pari__()
     sage: x = pari('[1, -1, 2]~')
@@ -1573,17 +1606,19 @@ General number fields::
     1
 
     sage: y = pari('[2, -2, 4]~')
-    sage: nf.idealcoprime(x, y)
+    sage: nf.idealcoprime(x, y)                                                         # needs sage.rings.number_field
     [5/43, 9/43, -1/43]~
 
+    sage: # needs sage.rings.number_field
     sage: R.<x> = PolynomialRing(QQ)
     sage: K.<a> = NumberField(x^2 + 1)
     sage: L = K.pari_nf().ideallist(100)
-    sage: L[0]   # One ideal of norm 1.
+    sage: L[0]   # One ideal of norm 1.                                                 # needs sage.symbolic
     [[1, 0; 0, 1]]
-    sage: L[64]  # 4 ideals of norm 65.
+    sage: L[64]  # 4 ideals of norm 65.                                                 # needs sage.symbolic
     [[65, 8; 0, 1], [65, 47; 0, 1], [65, 18; 0, 1], [65, 57; 0, 1]]
 
+    sage: # needs sage.rings.number_field
     sage: F = NumberField(x^3-2, 'alpha')
     sage: nf = F.__pari__()
     sage: I = pari('[1, -1, 2]~')
@@ -1591,12 +1626,14 @@ General number fields::
     sage: nf.ideallog(5, bid)
     [25]~
 
+    sage: # needs sage.rings.number_field
     sage: K.<i> = QuadraticField(-1)
     sage: F = pari(K).idealprimedec(5); F
     [[5, [-2, 1]~, 1, 1, [2, -1; 1, 2]], [5, [2, 1]~, 1, 1, [-2, -1; 1, -2]]]
     sage: F[0].pr_get_p()
     5
 
+    sage: # needs sage.rings.number_field
     sage: x = polygen(ZZ)
     sage: F = NumberField(x^3 - 2, 'alpha')
     sage: nf = F.__pari__()
@@ -1604,6 +1641,7 @@ General number fields::
     sage: nf.idealstar(I)
     [[[43, 9, 5; 0, 1, 0; 0, 0, 1], [0]], [42, [42]], [Mat([[43, [9, 1, 0]~, 1, 1, [-5, 2, -18; -9, -5, 2; 1, -9, -5]], 1]), Mat([[43, [9, 1, 0]~, 1, 1, [-5, 2, -18; -9, -5, 2; 1, -9, -5]], 1])], [[[[42], [3], [43, 9, 5; 0, 1, 0; 0, 0, 1], [[[-14, -8, 20]~, [1, 34, 38], [43, [9, 1, 0]~, 1, 1, [-5, 2, -18; -9, -5, 2; 1, -9, -5]]]~, 3, [42, [2, 1; 3, 1; 7, 1]]]]], [[], Vecsmall([])]], [Mat(1)]]
 
+    sage: # needs sage.rings.number_field
     sage: x = polygen(QQ)
     sage: K.<a> = NumberField(x^3 - 17)
     sage: Kpari = K.pari_nf()
@@ -1616,12 +1654,14 @@ General number fields::
     sage: Kpari.getattr('zk') * pari("[3/2, -5, 0]~")
     -5/3*y^2 + 5/3*y - 1/6
 
+    sage: # needs sage.rings.number_field
     sage: k.<a> = NumberField(x^2 + 5)
     sage: x = 10
     sage: y = a + 1
     sage: pari(k).nfeltdiveuc(x, y)
     [2, -2]~
 
+    sage: # needs sage.rings.number_field
     sage: x = polygen(ZZ)
     sage: k.<a> = NumberField(x^2 + 5)
     sage: I = k.ideal(a)
@@ -1641,6 +1681,7 @@ General number fields::
     sage: nf.nfgaloisconj()
     [-x, x]~
 
+    sage: # needs sage.rings.number_field
     sage: x = polygen(QQ)
     sage: K.<t> = NumberField(x^3 - x + 1)
     sage: pari(K).nfhilbert(t, t + 2)
@@ -1652,6 +1693,7 @@ General number fields::
     sage: pari(K).nfhilbert(t, t + 2, P.pari_prime())
     1
 
+    sage: # needs sage.rings.number_field
     sage: F.<a> = NumberField(x^2-x-1)
     sage: Fp = pari(F)
     sage: A = matrix(F,[[1,2,a,3],[3,0,a+2,0],[0,0,a,2],[3+a,a,0,1]])
@@ -1684,6 +1726,7 @@ General number fields::
     ...
     PariError: incorrect type in checknf [please apply nfinit()] (t_REAL)
 
+    sage: # needs sage.rings.number_field
     sage: F = NumberField(x^3-2,'alpha')
     sage: G = NumberField(x^3-2,'beta')
     sage: F.__pari__().nfisisom(G.__pari__())
@@ -1743,6 +1786,7 @@ General number fields::
     ...
     PariError: domain error in quadray: isfundamental(D) = 0
 
+    sage: # needs sage.rings.number_field sage.symbolic
     sage: x = SR.symbol('x')
     sage: F = NumberField(x^3-2,'alpha')
     sage: F.__pari__()[0].nfdisc()
@@ -1767,10 +1811,11 @@ library::
     sage: eta1 = e.elleta(precision=150)[0]
     sage: eta1.sage()
     3.605463601432652085915820564207726774810268996598024745444380641429820491740 # 64-bit
-    3.60546360143265208591582056420772677481026899659802474544                    # 32-bit 
+    3.60546360143265208591582056420772677481026899659802474544                    # 32-bit
     sage: from cypari2 import Pari
     sage: pari = Pari()
 
+    sage: # needs sage.symbolic
     sage: f = pari('(2/3)*x^3 + x - 5/7 + y'); f
     2/3*x^3 + x + (y - 5/7)
     sage: var('x,y')
