@@ -256,7 +256,6 @@ REFERENCES:
 
 - \B. O'Neill : *Semi-Riemannian Geometry* [ONe1983]_
 - \J. M. Lee : *Riemannian Manifolds* [Lee1997]_
-
 """
 
 #*****************************************************************************
@@ -297,8 +296,8 @@ class PseudoRiemannianManifold(DifferentiableManifold):
 
     - ``n`` -- positive integer; dimension of the manifold
     - ``name`` -- string; name (symbol) given to the manifold
-    - ``metric_name`` -- (default: ``'g'``) string; name (symbol) given to the
-      metric
+    - ``metric_name`` -- (default: ``None``) string; name (symbol) given to the
+      metric; if ``None``, ``'g'`` is used
     - ``signature`` -- (default: ``None``) signature `S` of the metric as a
       single integer: `S = n_+ - n_-`, where `n_+` (resp. `n_-`) is the
       number of positive terms (resp. number of negative terms) in any
@@ -412,8 +411,8 @@ class PseudoRiemannianManifold(DifferentiableManifold):
         -2
 
     """
-    def __init__(self, n, name, metric_name='g', signature=None, base_manifold=None,
-                 diff_degree=infinity, latex_name=None,
+    def __init__(self, n, name, metric_name=None, signature=None,
+                 base_manifold=None, diff_degree=infinity, latex_name=None,
                  metric_latex_name=None, start_index=0, category=None,
                  unique_tag=None):
         r"""
@@ -450,7 +449,9 @@ class PseudoRiemannianManifold(DifferentiableManifold):
                                         category=category)
         self._metric = None # to be initialized by metric()
         self._metric_signature = signature
-        if not isinstance(metric_name, str):
+        if metric_name is None:
+            metric_name = 'g'
+        elif not isinstance(metric_name, str):
             raise TypeError("{} is not a string".format(metric_name))
         self._metric_name = metric_name
         if metric_latex_name is None:
