@@ -288,7 +288,6 @@ as follows::
     3
     sage: t[1,2,2,1] # check of the antisymmetry with respect to the last 2 indices
     -3
-
 """
 
 # *****************************************************************************
@@ -355,8 +354,8 @@ class TensorFieldParal(FreeModuleTensor, TensorField):
 
     .. MATH::
 
-        t(p):\ \underbrace{T_q^*M\times\cdots\times T_q^*M}_{k\ \; \mbox{times}}
-        \times \underbrace{T_q M\times\cdots\times T_q M}_{l\ \; \mbox{times}}
+        t(p):\ \underbrace{T_q^*M\times\cdots\times T_q^*M}_{k\ \; \text{times}}
+        \times \underbrace{T_q M\times\cdots\times T_q M}_{l\ \; \text{times}}
         \longrightarrow K,
 
     where `T_q^* M` is the dual vector space to `T_q M` and `K` is the
@@ -657,7 +656,6 @@ class TensorFieldParal(FreeModuleTensor, TensorField):
         # Initialization of derived quantities:
         self._init_derived()
 
-
     def _repr_(self):
         r"""
         String representation of ``self``.
@@ -769,7 +767,6 @@ class TensorFieldParal(FreeModuleTensor, TensorField):
             basis = basis.frame()
         return (basis, format_spec)
 
-
     def _set_comp_unsafe(self, basis=None):
         r"""
         Return the components of the tensor field in a given vector frame
@@ -1511,7 +1508,6 @@ class TensorFieldParal(FreeModuleTensor, TensorField):
                                     vc[[i]].coord_function(chart).diff(ind[k])
                     resc[[ind]] = rsum.scalar_field()
 
-
             #
             # 3/ Final result (the tensor)
             res = vf_module.tensor_from_comp(self._tensor_type, resc)
@@ -1590,8 +1586,9 @@ class TensorFieldParal(FreeModuleTensor, TensorField):
             return self
         if subdomain not in self._restrictions:
             if not subdomain.is_subset(self._domain):
-                raise ValueError("the provided domain is not a subset of " +
-                                 "the field's domain")
+                raise ValueError(
+                    f"the provided domain {subdomain} is not a subset of the field's domain {self._domain}"
+                )
             if dest_map is None:
                 dest_map = self._fmodule._dest_map.restrict(subdomain)
             elif not dest_map._codomain.is_subset(self._ambient_domain):
