@@ -159,23 +159,23 @@ Let us check the components of `f` with respect to the frame `e`::
     [1, 0, 0]
     sage: f[3].comp(e)[:]
     [0, 1, 0]
-
 """
 
-#******************************************************************************
+# *****************************************************************************
 #       Copyright (C) 2013-2018 Eric Gourgoulhon <eric.gourgoulhon@obspm.fr>
 #       Copyright (C) 2019 Michael Jung <micjung@uni-potsdam.de>
 #
 #  Distributed under the terms of the GNU General Public License (GPL)
 #  as published by the Free Software Foundation; either version 2 of
 #  the License, or (at your option) any later version.
-#                  http://www.gnu.org/licenses/
-#******************************************************************************
+#                  https://www.gnu.org/licenses/
+# *****************************************************************************
 
 from sage.tensor.modules.free_module_basis import (FreeModuleBasis,
                                                    FreeModuleCoBasis)
 from sage.tensor.modules.finite_rank_free_module import FiniteRankFreeModule
 
+
 class LocalCoFrame(FreeModuleCoBasis):
     r"""
     Local coframe on a vector bundle.
@@ -398,10 +398,10 @@ class LocalCoFrame(FreeModuleCoBasis):
             \left(E|_{M}, \left(e^{\xi},e^{\zeta}\right)\right)
 
         """
-        super(LocalCoFrame, self).set_name(symbol, latex_symbol=latex_symbol,
-                                      indices=indices,
-                                      latex_indices=latex_indices,
-                                      index_position=index_position)
+        super().set_name(symbol, latex_symbol=latex_symbol,
+                         indices=indices,
+                         latex_indices=latex_indices,
+                         index_position=index_position)
         if include_domain:
             # Redefinition of the name and the LaTeX name to include the domain
             self._name = "({}|_{}, {})".format(self._vbundle._name,
@@ -597,12 +597,12 @@ class LocalFrame(FreeModuleBasis):
             symbol_dual = tuple(symbol_dual)
         if isinstance(latex_symbol_dual, list):
             latex_symbol_dual = tuple(latex_symbol_dual)
-        return super(LocalFrame, cls).__classcall__(cls, section_module,
-                                        symbol, latex_symbol=latex_symbol,
-                                        indices=indices,
-                                        latex_indices=latex_indices,
-                                        symbol_dual=symbol_dual,
-                                        latex_symbol_dual=latex_symbol_dual)
+        return super().__classcall__(cls, section_module,
+                                     symbol, latex_symbol=latex_symbol,
+                                     indices=indices,
+                                     latex_indices=latex_indices,
+                                     symbol_dual=symbol_dual,
+                                     latex_symbol_dual=latex_symbol_dual)
 
     def __init__(self, section_module, symbol, latex_symbol=None, indices=None,
                  latex_indices=None, symbol_dual=None, latex_symbol_dual=None):
@@ -1239,10 +1239,10 @@ class LocalFrame(FreeModuleBasis):
             \left(E|_{M}, \left(E_{\alpha},E_{\beta}\right)\right)
 
         """
-        super(LocalFrame, self).set_name(symbol, latex_symbol=latex_symbol,
-                                          indices=indices,
-                                          latex_indices=latex_indices,
-                                          index_position=index_position)
+        super().set_name(symbol, latex_symbol=latex_symbol,
+                         indices=indices,
+                         latex_indices=latex_indices,
+                         index_position=index_position)
         if include_domain:
             # Redefinition of the name and the LaTeX name to include the domain
             self._name = "({}|_{}, {})".format(self._vbundle._name,
