@@ -1,3 +1,4 @@
+# sage.doctest: needs sage.libs.flint sage.libs.pari
 """
 Torsion subgroups of modular abelian varieties
 
@@ -91,7 +92,7 @@ TESTS::
 from sage.arith.misc import divisors, gcd
 from sage.misc.misc_c import prod
 from sage.modular.abvar.torsion_point import TorsionPoint
-from sage.modular.arithgroup.all import is_Gamma0, is_Gamma1
+from sage.modular.arithgroup.all import Gamma0_class, Gamma1_class
 from sage.modular.dirichlet import DirichletGroup
 from sage.modules.module import Module
 from sage.rings.fast_arith import prime_range
@@ -115,7 +116,7 @@ class RationalTorsionSubgroup(FiniteSubgroup):
         INPUT:
 
 
-        -  ``abvar`` - a modular abelian variety
+        -  ``abvar`` -- a modular abelian variety
 
 
         EXAMPLES::
@@ -176,11 +177,11 @@ class RationalTorsionSubgroup(FiniteSubgroup):
         subgroup.
 
         The computation of the rational torsion order of J1(p) is conjectural
-        and will only be used if proof=False. See Section 6.2.3 of [CES2003]_.
+        and will only be used if ``proof=False``. See Section 6.2.3 of [CES2003]_.
 
         INPUT:
 
-        - ``proof`` -- a boolean (default: True)
+        - ``proof`` -- a boolean (default: ``True``)
 
         OUTPUT:
 
@@ -202,13 +203,14 @@ class RationalTorsionSubgroup(FiniteSubgroup):
             sage: J.rational_torsion_subgroup().order()
             19
 
-        Sometimes the order can only be computed with proof=False. ::
+        Sometimes the order can only be computed with ``proof=False``. ::
 
             sage: J = J1(23)
             sage: J.rational_torsion_subgroup().order()
             Traceback (most recent call last):
             ...
-            RuntimeError: Unable to compute order of torsion subgroup (it is in [408991, 9406793])
+            RuntimeError: Unable to compute order of torsion subgroup
+            (it is in [408991, 9406793])
 
             sage: J.rational_torsion_subgroup().order(proof=False)
             408991
@@ -219,7 +221,7 @@ class RationalTorsionSubgroup(FiniteSubgroup):
             n = O[0]
             self._order = n
             return n
-        raise RuntimeError("Unable to compute order of torsion subgroup (it is in %s)"%O)
+        raise RuntimeError("Unable to compute order of torsion subgroup (it is in %s)" % O)
 
     def lattice(self):
         """
@@ -249,7 +251,8 @@ class RationalTorsionSubgroup(FiniteSubgroup):
             sage: T.lattice()
             Traceback (most recent call last):
             ...
-            NotImplementedError: unable to compute the rational torsion subgroup in this case (there is no known general algorithm yet)
+            NotImplementedError: unable to compute the rational torsion subgroup
+            in this case (there is no known general algorithm yet)
 
         The problem is that the multiple of the order obtained by counting
         points over finite fields is twice the divisor of the order got
@@ -278,14 +281,14 @@ class RationalTorsionSubgroup(FiniteSubgroup):
 
         INPUT:
 
-        - ``proof`` -- a boolean (default: True)
+        - ``proof`` -- a boolean (default: ``True``)
 
         OUTPUT:
 
         - an array of positive integers
 
         The computation of the rational torsion order of J1(p) is conjectural
-        and will only be used if proof=False. See Section 6.2.3 of [CES2003]_.
+        and will only be used if ``proof=False``. See Section 6.2.3 of [CES2003]_.
 
         EXAMPLES::
 
@@ -397,7 +400,7 @@ class RationalTorsionSubgroup(FiniteSubgroup):
             return self._divisor_of_order
 
         # The Gamma0 case
-        if all(is_Gamma0(G) for G in A.groups()):
+        if all(isinstance(G, Gamma0_class) for G in A.groups()):
             self._divisor_of_order = A.rational_cuspidal_subgroup().order()
             return self._divisor_of_order
 
@@ -411,7 +414,7 @@ class RationalTorsionSubgroup(FiniteSubgroup):
 
         INPUT:
 
-        - ``proof`` -- a boolean (default: True)
+        - ``proof`` -- a boolean (default: ``True``)
 
         The computation of the rational torsion order of J1(p) is conjectural
         and will only be used if proof=False. See Section 6.2.3 of [CES2003]_.
@@ -431,7 +434,7 @@ class RationalTorsionSubgroup(FiniteSubgroup):
         performance. ::
 
             sage: J = J1(23)
-            sage: J.rational_torsion_subgroup().multiple_of_order() # long time (2s)
+            sage: J.rational_torsion_subgroup().multiple_of_order()  # long time (2s)
             9406793
             sage: J.rational_torsion_subgroup().multiple_of_order(proof=False)
             408991
@@ -474,7 +477,7 @@ class RationalTorsionSubgroup(FiniteSubgroup):
             return self._multiple_of_order_proof_false
 
         # The Gamma0 and Gamma1 case
-        if all((is_Gamma0(G) or is_Gamma1(G) for G in A.groups())):
+        if all((isinstance(G, Gamma0_class) or isinstance(G, Gamma1_class) for G in A.groups())):
             self._multiple_of_order = self.multiple_of_order_using_frobp()
             return self._multiple_of_order
 
@@ -494,7 +497,7 @@ class RationalTorsionSubgroup(FiniteSubgroup):
         INPUT:
 
 
-        -  ``maxp`` - (default: None) If maxp is None (the
+        -  ``maxp`` -- (default: None) If maxp is None (the
            default), return gcd of best bound computed so far with bound
            obtained by computing GCD's of orders modulo p until this gcd
            stabilizes for 3 successive primes. If maxp is given, just use all
@@ -577,7 +580,7 @@ class RationalTorsionSubgroup(FiniteSubgroup):
             T = ZZ(1)
             self.__multiple_of_order_using_frobp = T
             return T
-        if not all((is_Gamma0(G) or is_Gamma1(G) for G in A.groups())):
+        if not all((isinstance(G, Gamma0_class) or isinstance(G, Gamma1_class) for G in A.groups())):
             raise NotImplementedError("torsion multiple only implemented for Gamma0 and Gamma1")
 
         bnd = ZZ(0)
@@ -591,7 +594,7 @@ class RationalTorsionSubgroup(FiniteSubgroup):
             if (2*N) % p == 0:
                 continue
 
-            if (len(A.groups()) == 1 and is_Gamma0(A.groups()[0])):
+            if (len(A.groups()) == 1 and isinstance(A.groups()[0], Gamma0_class)):
                 f = A.hecke_polynomial(p)
                 b = ZZ(f(p+1))
             else:
@@ -601,7 +604,7 @@ class RationalTorsionSubgroup(FiniteSubgroup):
                 b = 1
                 for simple in D:
                     G = simple.newform_level()[1]
-                    if is_Gamma0(G):
+                    if isinstance(G, Gamma0_class):
                         f = simple.hecke_polynomial(p)
                         b *= ZZ(f(p+1))
                     else:
@@ -674,13 +677,13 @@ class QQbarTorsionSubgroup(Module):
         INPUT:
 
 
-        -  ``abvar`` - an abelian variety
+        -  ``abvar`` -- an abelian variety
 
 
         EXAMPLES::
 
             sage: A = J0(23)
-            sage: A.qbar_torsion_subgroup()
+            sage: A.qbar_torsion_subgroup()                                             # needs sage.rings.number_field
             Group of all torsion points in QQbar on Abelian variety J0(23) of dimension 2
         """
         self.__abvar = abvar
@@ -694,10 +697,10 @@ class QQbarTorsionSubgroup(Module):
 
         EXAMPLES::
 
-            sage: J0(23).qbar_torsion_subgroup()._repr_()
+            sage: J0(23).qbar_torsion_subgroup()._repr_()                               # needs sage.rings.number_field
             'Group of all torsion points in QQbar on Abelian variety J0(23) of dimension 2'
         """
-        return 'Group of all torsion points in QQbar on %s'%self.__abvar
+        return 'Group of all torsion points in QQbar on %s' % self.__abvar
 
     def field_of_definition(self):
         """
@@ -709,7 +712,7 @@ class QQbarTorsionSubgroup(Module):
 
         EXAMPLES::
 
-            sage: J0(23).qbar_torsion_subgroup().field_of_definition()
+            sage: J0(23).qbar_torsion_subgroup().field_of_definition()                  # needs sage.rings.number_field
             Rational Field
         """
         return self.__abvar.base_field()
@@ -726,9 +729,9 @@ class QQbarTorsionSubgroup(Module):
 
         EXAMPLES::
 
-            sage: P = J0(23).qbar_torsion_subgroup()([1,1/2,3/4,2]); P
+            sage: P = J0(23).qbar_torsion_subgroup()([1,1/2,3/4,2]); P                  # needs sage.rings.number_field
             [(1, 1/2, 3/4, 2)]
-            sage: P.order()
+            sage: P.order()                                                             # needs sage.rings.number_field
             4
         """
         v = self.__abvar.vector_space()(x)
@@ -743,7 +746,7 @@ class QQbarTorsionSubgroup(Module):
 
         EXAMPLES::
 
-            sage: J0(23).qbar_torsion_subgroup().abelian_variety()
+            sage: J0(23).qbar_torsion_subgroup().abelian_variety()                      # needs sage.rings.number_field
             Abelian variety J0(23) of dimension 2
         """
         return self.__abvar
