@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Manin symbol lists
 
@@ -14,7 +13,6 @@ different types.  The hierarchy is as follows:
     - :class:`ManinSymbolList_gamma_h`
 
   - :class:`ManinSymbolList_character`
-
 """
 # ****************************************************************************
 #       Sage: Open Source Mathematical Software
@@ -520,7 +518,7 @@ class ManinSymbolList_group(ManinSymbolList):
 
         INPUT:
 
-        - ``j`` - (int) a symbol index
+        - ``j`` -- (int) a symbol index
 
         OUTPUT:
 
@@ -559,7 +557,7 @@ class ManinSymbolList_group(ManinSymbolList):
 
         INPUT:
 
-        - ``j`` - (int) a symbol index
+        - ``j`` -- (int) a symbol index
 
         OUTPUT: see documentation for apply()
 
@@ -602,7 +600,7 @@ class ManinSymbolList_group(ManinSymbolList):
 
         INPUT:
 
-        - ``j`` - (int) a symbol index
+        - ``j`` -- (int) a symbol index
 
         OUTPUT: see documentation for apply()
 
@@ -645,7 +643,7 @@ class ManinSymbolList_group(ManinSymbolList):
 
         INPUT:
 
-        - ``j`` - (int) a symbol index
+        - ``j`` -- (int) a symbol index
 
         - ``m = [a, b, c, d]`` a list of 4 integers, which defines a 2x2 matrix
 
@@ -716,9 +714,9 @@ class ManinSymbolList_gamma0(ManinSymbolList_group):
 
     INPUT:
 
-    - ``level`` - (integer): the level.
+    - ``level`` -- (integer): the level.
 
-    - ``weight`` - (integer): the weight.
+    - ``weight`` -- (integer): the weight.
 
     EXAMPLES::
 
@@ -768,9 +766,9 @@ class ManinSymbolList_gamma1(ManinSymbolList_group):
 
     INPUT:
 
-    - ``level`` - (integer): the level.
+    - ``level`` -- (integer): the level.
 
-    - ``weight`` - (integer): the weight.
+    - ``weight`` -- (integer): the weight.
 
     EXAMPLES::
 
@@ -825,9 +823,9 @@ class ManinSymbolList_gamma_h(ManinSymbolList_group):
 
     INPUT:
 
-    - ``group`` - (integer): the congruence subgroup.
+    - ``group`` -- (integer): the congruence subgroup.
 
-    - ``weight`` - (integer): the weight.
+    - ``weight`` -- (integer): the weight.
 
     EXAMPLES::
 
@@ -861,7 +859,7 @@ class ManinSymbolList_gamma_h(ManinSymbolList_group):
             sage: G = GammaH(117, [4])
             sage: m = ManinSymbolList_gamma_h(G,2); m
             Manin Symbol List of weight 2 for Congruence Subgroup Gamma_H(117) with H generated by [4]
-            """
+        """
         self.__group = group
         ManinSymbolList_group.__init__(self, group.level(), weight, ghlist.GHlist(group))
 
@@ -901,6 +899,7 @@ class ManinSymbolList_character(ManinSymbolList):
 
     EXAMPLES::
 
+        sage: # needs sage.rings.number_field
         sage: eps = DirichletGroup(4).gen(0)
         sage: from sage.modular.modsym.manin_symbol_list import ManinSymbolList_character
         sage: m = ManinSymbolList_character(eps,2); m
@@ -916,12 +915,13 @@ class ManinSymbolList_character(ManinSymbolList):
 
         INPUT:
 
-        -  ``character`` - (DirichletCharacter) the Dirichlet character
+        -  ``character`` -- (DirichletCharacter) the Dirichlet character
 
-        -  ``weight`` - (integer) the weight
+        -  ``weight`` -- (integer) the weight
 
         EXAMPLES::
 
+            sage: # needs sage.rings.number_field
             sage: eps = DirichletGroup(4).gen(0)
             sage: from sage.modular.modsym.manin_symbol_list import ManinSymbolList_character
             sage: m = ManinSymbolList_character(eps,2); m
@@ -955,6 +955,7 @@ class ManinSymbolList_character(ManinSymbolList):
 
         EXAMPLES::
 
+            sage: # needs sage.rings.number_field
             sage: eps = DirichletGroup(4).gen(0)
             sage: from sage.modular.modsym.manin_symbol_list import ManinSymbolList_character
             sage: m = ManinSymbolList_character(eps,2); m
@@ -971,10 +972,11 @@ class ManinSymbolList_character(ManinSymbolList):
 
         OUTPUT:
 
-        ``integer`` - the level of the symbols in this list.
+        ``integer`` -- the level of the symbols in this list.
 
         EXAMPLES::
 
+            sage: # needs sage.rings.number_field
             sage: eps = DirichletGroup(4).gen(0)
             sage: from sage.modular.modsym.manin_symbol_list import ManinSymbolList_character
             sage: ManinSymbolList_character(eps,4).level()
@@ -1005,6 +1007,7 @@ class ManinSymbolList_character(ManinSymbolList):
 
         EXAMPLES::
 
+            sage: # needs sage.rings.number_field
             sage: eps = DirichletGroup(4).gen(0)
             sage: from sage.modular.modsym.manin_symbol_list import ManinSymbolList_character
             sage: m = ManinSymbolList_character(eps,4)
@@ -1031,7 +1034,7 @@ class ManinSymbolList_character(ManinSymbolList):
 
         INPUT:
 
-        - ``j`` - (integer) a symbol index.
+        - ``j`` -- (integer) a symbol index.
 
         OUTPUT:
 
@@ -1041,6 +1044,7 @@ class ManinSymbolList_character(ManinSymbolList):
 
         EXAMPLES::
 
+            sage: # needs sage.rings.number_field
             sage: eps = DirichletGroup(4).gen(0)
             sage: from sage.modular.modsym.manin_symbol_list import ManinSymbolList_character
             sage: m = ManinSymbolList_character(eps,2); m
@@ -1065,6 +1069,7 @@ class ManinSymbolList_character(ManinSymbolList):
 
         EXAMPLES::
 
+            sage: # needs sage.rings.number_field
             sage: eps = DirichletGroup(4).gen(0)
             sage: from sage.modular.modsym.manin_symbol_list import ManinSymbolList_character
             sage: ManinSymbolList_character(eps,2)._apply_S_only_0pm1()
@@ -1080,7 +1085,7 @@ class ManinSymbolList_character(ManinSymbolList):
 
         INPUT:
 
-        - ``j`` - (integer) a symbol index
+        - ``j`` -- (integer) a symbol index
 
         OUTPUT:
 
@@ -1090,6 +1095,7 @@ class ManinSymbolList_character(ManinSymbolList):
 
         EXAMPLES::
 
+            sage: # needs sage.rings.number_field
             sage: eps = DirichletGroup(4).gen(0)
             sage: from sage.modular.modsym.manin_symbol_list import ManinSymbolList_character
             sage: m = ManinSymbolList_character(eps,2); m
@@ -1112,7 +1118,7 @@ class ManinSymbolList_character(ManinSymbolList):
 
         INPUT:
 
-        - ``j`` - (integer) a symbol index.
+        - ``j`` -- (integer) a symbol index.
 
         OUTPUT:
 
@@ -1123,6 +1129,7 @@ class ManinSymbolList_character(ManinSymbolList):
 
         EXAMPLES::
 
+            sage: # needs sage.rings.number_field
             sage: eps = DirichletGroup(4).gen(0)
             sage: from sage.modular.modsym.manin_symbol_list import ManinSymbolList_character
             sage: m = ManinSymbolList_character(eps,2); m
@@ -1154,7 +1161,7 @@ class ManinSymbolList_character(ManinSymbolList):
 
         INPUT:
 
-        - ``j`` - (integer) a symbol index
+        - ``j`` -- (integer) a symbol index
 
         OUTPUT:
 
@@ -1165,6 +1172,7 @@ class ManinSymbolList_character(ManinSymbolList):
 
         EXAMPLES::
 
+            sage: # needs sage.rings.number_field
             sage: eps = DirichletGroup(4).gen(0)
             sage: from sage.modular.modsym.manin_symbol_list import ManinSymbolList_character
             sage: m = ManinSymbolList_character(eps,2); m
@@ -1200,6 +1208,7 @@ class ManinSymbolList_character(ManinSymbolList):
 
         EXAMPLES::
 
+            sage: # needs sage.rings.number_field
             sage: eps = DirichletGroup(4).gen(0)
             sage: from sage.modular.modsym.manin_symbol_list import ManinSymbolList_character
             sage: m = ManinSymbolList_character(eps,2); m
@@ -1229,6 +1238,7 @@ class ManinSymbolList_character(ManinSymbolList):
 
         EXAMPLES::
 
+            sage: # needs sage.rings.number_field
             sage: eps = DirichletGroup(4).gen(0)
             sage: from sage.modular.modsym.manin_symbol_list import ManinSymbolList_character
             sage: m = ManinSymbolList_character(eps,4); m
@@ -1257,7 +1267,7 @@ class ManinSymbolList_character(ManinSymbolList):
 
         INPUT:
 
-        - ``x`` - 3-tuple of integers ``(i,u,v)``, defining an element of this
+        - ``x`` -- 3-tuple of integers ``(i,u,v)``, defining an element of this
           list of Manin symbols, which need not be normalized.
 
         OUTPUT:
@@ -1267,6 +1277,7 @@ class ManinSymbolList_character(ManinSymbolList):
 
         EXAMPLES::
 
+            sage: # needs sage.rings.number_field
             sage: eps = DirichletGroup(4).gen(0)
             sage: from sage.modular.modsym.manin_symbol_list import ManinSymbolList_character
             sage: m = ManinSymbolList_character(eps,4); m
