@@ -1,3 +1,4 @@
+# sage.doctest: needs sage.combinat
 r"""
 Finitely presented graded modules
 
@@ -1154,9 +1155,9 @@ class FPModule(UniqueRepresentation, IndexedGenerators, Module):
 
         INPUT:
 
-        - ``k`` -- an non-negative integer
+        - ``k`` -- a non-negative integer
         - ``top_dim`` -- stop the computation at this degree
-          (optional, default ``None``, but required if the algebra is
+          (default: ``None``, but required if the algebra is
           not finite-dimensional)
         - ``verbose`` -- (default: ``False``) a boolean to control if
           log messages should be emitted
