@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Discrete subgroups of `\\ZZ^n`
 
@@ -14,7 +13,6 @@ TESTS::
     sage: from sage.modules.free_module_integer import IntegerLattice
     sage: L = IntegerLattice(random_matrix(ZZ, 10, 10))
     sage: TestSuite(L).run()
-
 """
 
 ##############################################################################
@@ -38,7 +36,11 @@ from sage.matrix.constructor import matrix
 from sage.misc.cachefunc import cached_method
 from sage.modules.free_module import FreeModule_submodule_with_basis_pid, FreeModule_ambient_pid
 from sage.modules.free_module_element import vector
-from sage.rings.number_field.number_field_element import OrderElement_absolute
+
+try:
+    from sage.rings.number_field.number_field_element import OrderElement_absolute
+except ImportError:
+    OrderElement_absolute = ()
 
 
 def IntegerLattice(basis, lll_reduce=True):
@@ -107,9 +109,11 @@ def IntegerLattice(basis, lll_reduce=True):
 
     We construct an ideal lattice from an element of an absolute order::
 
+        sage: # needs sage.rings.number_field
         sage: K.<a>  = CyclotomicField(17)
         sage: O = K.ring_of_integers()
-        sage: f = O(-a^15 + a^13 + 4*a^12 - 12*a^11 - 256*a^10 + a^9 - a^7 - 4*a^6 + a^5 + 210*a^4 + 2*a^3 - 2*a^2 + 2*a - 2)
+        sage: f = O(-a^15 + a^13 + 4*a^12 - 12*a^11 - 256*a^10 + a^9 - a^7
+        ....:       - 4*a^6 + a^5 + 210*a^4 + 2*a^3 - 2*a^2 + 2*a - 2)
         sage: from sage.modules.free_module_integer import IntegerLattice
         sage: IntegerLattice(f)
         Free module of degree 16 and rank 16 over Integer Ring
@@ -151,6 +155,7 @@ def IntegerLattice(basis, lll_reduce=True):
 
     Sage also interfaces with fpylll's lattice generator::
 
+        sage: # needs fpylll
         sage: from sage.modules.free_module_integer import IntegerLattice
         sage: from fpylll import IntegerMatrix
         sage: A = IntegerMatrix.random(8, "simdioph", bits=20, bits2=10)
@@ -197,7 +202,8 @@ class FreeModule_submodule_with_basis_integer(FreeModule_submodule_with_basis_pi
     EXAMPLES::
 
         sage: from sage.modules.free_module_integer import IntegerLattice
-        sage: L = IntegerLattice(sage.crypto.gen_lattice(type='modular', m=10, seed=1337, dual=True)); L
+        sage: L = IntegerLattice(sage.crypto.gen_lattice(type='modular', m=10,
+        ....:                                            seed=1337, dual=True)); L
         Free module of degree 10 and rank 10 over Integer Ring
         User basis matrix:
         [-1  1  2 -2  0  1  0 -1  2  1]
@@ -259,11 +265,12 @@ class FreeModule_submodule_with_basis_integer(FreeModule_submodule_with_basis_pi
             sage: M.row_space() == L.matrix().row_space()
             True
 
+            sage: # needs sage.rings.number_field
             sage: x = polygen(ZZ, 'x')
-            sage: K.<a> = NumberField(x^8 + 1)                                          # optional - sage.rings.number_field
-            sage: O = K.ring_of_integers()                                              # optional - sage.rings.number_field
-            sage: f = O(a^7 - a^6 + 4*a^5 - a^4 + a^3 + 1)                              # optional - sage.rings.number_field
-            sage: IntegerLattice(f)                                                     # optional - sage.rings.number_field
+            sage: K.<a> = NumberField(x^8 + 1)
+            sage: O = K.ring_of_integers()
+            sage: f = O(a^7 - a^6 + 4*a^5 - a^4 + a^3 + 1)
+            sage: IntegerLattice(f)
             Free module of degree 8 and rank 8 over Integer Ring
             User basis matrix:
             [ 0  1  0  1  0  3  3  0]
@@ -324,7 +331,7 @@ class FreeModule_submodule_with_basis_integer(FreeModule_submodule_with_basis_pi
         A lattice basis `(b_1, b_2, ..., b_d)` is `(\delta, \eta)`-LLL-reduced
         if the two following conditions hold:
 
-        -  For any `i > j`, we have `\lvert \mu_{i, j} \rvert \leq η`.
+        -  For any `i > j`, we have `\lvert \mu_{i, j} \rvert \leq \eta`.
 
         -  For any `i < d`, we have
            `\delta \lvert b_i^* \rvert^2 \leq \lvert b_{i+1}^* +
@@ -334,12 +341,13 @@ class FreeModule_submodule_with_basis_integer(FreeModule_submodule_with_basis_pi
         \rangle` and `b_i^*` is the `i`-th vector of the Gram-Schmidt
         orthogonalisation of `(b_1, b_2, \ldots, b_d)`.
 
-        The default reduction parameters are `\delta = 3/4` and
+        The default reduction parameters are `\delta = 0.99` and
         `\eta = 0.501`.
 
         The parameters `\delta` and `\eta` must satisfy:
         `0.25 < \delta \leq 1.0` and `0.5 \leq \eta < \sqrt{\delta}`.
         Polynomial time complexity is only guaranteed for `\delta < 1`.
+        Not every algorithm admits the case `\delta = 1`.
 
         INPUT:
 
@@ -365,10 +373,10 @@ class FreeModule_submodule_with_basis_integer(FreeModule_submodule_with_basis_pi
             ...
             sage: L.reduced_basis == A
             True
-            sage: old = L.reduced_basis[0].norm().n()
+            sage: old = L.reduced_basis[0].norm().n()                                   # needs sage.symbolic
             sage: _ = L.LLL()
-            sage: new = L.reduced_basis[0].norm().n()
-            sage: new <= old
+            sage: new = L.reduced_basis[0].norm().n()                                   # needs sage.symbolic
+            sage: new <= old                                                            # needs sage.symbolic
             True
         """
         basis = self.reduced_basis
@@ -398,21 +406,18 @@ class FreeModule_submodule_with_basis_integer(FreeModule_submodule_with_basis_pi
 
         EXAMPLES::
 
+            sage: # needs sage.libs.linbox (o/w timeout)
             sage: from sage.modules.free_module_integer import IntegerLattice
             sage: A = sage.crypto.gen_lattice(type='random', n=1, m=60, q=2^60, seed=42)
             sage: L = IntegerLattice(A, lll_reduce=False)
             sage: min(v.norm().n() for v in L.reduced_basis)
             4.17330740711759e15
-
             sage: L.LLL()
             60 x 60 dense matrix over Integer Ring (use the '.str()' method to see the entries)
-
             sage: min(v.norm().n() for v in L.reduced_basis)
             5.19615242270663
-
             sage: L.BKZ(block_size=10)
             60 x 60 dense matrix over Integer Ring (use the '.str()' method to see the entries)
-
             sage: min(v.norm().n() for v in L.reduced_basis)
             4.12310562561766
 
@@ -558,21 +563,21 @@ class FreeModule_submodule_with_basis_integer(FreeModule_submodule_with_basis_pi
             sage: from sage.modules.free_module_integer import IntegerLattice
             sage: A = sage.crypto.gen_lattice(type='random', n=1, m=30, q=2^40, seed=42)
             sage: L = IntegerLattice(A, lll_reduce=False)
-            sage: min(v.norm().n() for v in L.reduced_basis)
+            sage: min(v.norm().n() for v in L.reduced_basis)                            # needs sage.symbolic
             6.03890756700000e10
 
-            sage: L.shortest_vector().norm().n()
+            sage: L.shortest_vector().norm().n()                                        # needs sage.symbolic
             3.74165738677394
 
             sage: L = IntegerLattice(A, lll_reduce=False)
-            sage: min(v.norm().n() for v in L.reduced_basis)
+            sage: min(v.norm().n() for v in L.reduced_basis)                            # needs sage.symbolic
             6.03890756700000e10
 
-            sage: L.shortest_vector(algorithm="pari").norm().n()
+            sage: L.shortest_vector(algorithm="pari").norm().n()                        # needs sage.symbolic
             3.74165738677394
 
             sage: L = IntegerLattice(A, lll_reduce=True)
-            sage: L.shortest_vector(algorithm="pari").norm().n()
+            sage: L.shortest_vector(algorithm="pari").norm().n()                        # needs sage.symbolic
             3.74165738677394
         """
         if algorithm == "pari":
@@ -649,20 +654,24 @@ class FreeModule_submodule_with_basis_integer(FreeModule_submodule_with_basis_pi
             sage: L = IntegerLattice([[1, 0], [0, 1]])
             sage: V = L.voronoi_cell()
             sage: V.Vrepresentation()
-            (A vertex at (1/2, -1/2), A vertex at (1/2, 1/2), A vertex at (-1/2, 1/2), A vertex at (-1/2, -1/2))
+            (A vertex at (1/2, -1/2),
+             A vertex at (1/2, 1/2),
+             A vertex at (-1/2, 1/2),
+             A vertex at (-1/2, -1/2))
 
         The volume of the Voronoi cell is the square root of the
         discriminant of the lattice::
 
-            sage: L = IntegerLattice(Matrix(ZZ, 4, 4, [[0,0,1,-1],[1,-1,2,1],[-6,0,3,3,],[-6,-24,-6,-5]])); L
+            sage: L = IntegerLattice(Matrix(ZZ, 4, 4, [[0,0,1,-1], [1,-1,2,1],
+            ....:                                      [-6,0,3,3,], [-6,-24,-6,-5]])); L
             Free module of degree 4 and rank 4 over Integer Ring
             User basis matrix:
             [  0   0   1  -1]
             [  1  -1   2   1]
             [ -6   0   3   3]
             [ -6 -24  -6  -5]
-            sage: V = L.voronoi_cell() # long time
-            sage: V.volume()           # long time
+            sage: V = L.voronoi_cell()  # long time
+            sage: V.volume()            # long time
             678
             sage: sqrt(L.discriminant())
             678
@@ -672,7 +681,10 @@ class FreeModule_submodule_with_basis_integer(FreeModule_submodule_with_basis_pi
             sage: L = IntegerLattice([[2, 0, 0], [0, 2, 0]])
             sage: V = L.voronoi_cell()
             sage: V.Hrepresentation()
-            (An inequality (-1, 0, 0) x + 1 >= 0, An inequality (0, -1, 0) x + 1 >= 0, An inequality (1, 0, 0) x + 1 >= 0, An inequality (0, 1, 0) x + 1 >= 0)
+            (An inequality (-1, 0, 0) x + 1 >= 0,
+             An inequality (0, -1, 0) x + 1 >= 0,
+             An inequality (1, 0, 0) x + 1 >= 0,
+             An inequality (0, 1, 0) x + 1 >= 0)
 
         ALGORITHM:
 
@@ -749,7 +761,7 @@ class FreeModule_submodule_with_basis_integer(FreeModule_submodule_with_basis_pi
 
         TESTS:
 
-        Check that the example from :trac:`29866` works::
+        Check that the example from :issue:`29866` works::
 
             sage: from sage.modules.free_module_integer import IntegerLattice
             sage: M = matrix(ZZ, [[20957228, -4966110], [9411844, 19625639]])
@@ -758,7 +770,7 @@ class FreeModule_submodule_with_basis_integer(FreeModule_submodule_with_basis_pi
             sage: L.closest_vector(u) in L
             True
 
-        Check that the example, of non-maximal rank, from :trac:`32486` works::
+        Check that the example, of non-maximal rank, from :issue:`32486` works::
 
             from sage.modules.free_module_integer import IntegerLattice
             L = IntegerLattice([[-1,  0,  1],[1,0,2]])
@@ -777,7 +789,7 @@ class FreeModule_submodule_with_basis_integer(FreeModule_submodule_with_basis_pi
         def CVPP_2V(t, V, voronoi_cell):
             t_new = t
             while not voronoi_cell.contains(t_new.list()):
-                v = max(V, key=lambda v: t_new * v / v.norm() ** 2)
+                v = max(V, key=lambda v: t_new * v / v.dot_product(v))
                 t_new = t_new - v
             return t - t_new
 
@@ -793,3 +805,74 @@ class FreeModule_submodule_with_basis_integer(FreeModule_submodule_with_basis_pi
             t_new = t_new - CVPP_2V(t_new, V_scaled, ZZ(2 ** (i - 1)) * voronoi_cell)
             i -= 1
         return t - t_new
+
+    def approximate_closest_vector(self, t, delta=None, *args, **kwargs):
+        r"""
+        Compute a vector `w` such that
+
+        .. MATH::
+
+            |t-w|<(\frac{1}{\delta-\frac{1}{4}})^{d/2}|t-u|
+
+        where `u` is the closest lattice point to `t`, `\delta` is the LLL
+        reduction parameter, and `d` is the dimension of the lattice.
+
+        This will check whether the basis is already `\delta`-LLL-reduced
+        and otherwise it will run LLL to make sure that it is. For more
+        information about ``delta`` see :meth:`LLL`.
+
+        INPUT:
+
+        - ``t`` -- the target vector to compute a close vector to
+
+        - ``delta`` -- (default: ``0.99``) the LLL reduction parameter
+
+        - ``*args`` -- passed through to :meth:`LLL`
+
+        - ``**kwds`` -- passed through to :meth:`LLL`
+
+        OUTPUT:
+
+        The vector `w` described above.
+
+        EXAMPLES::
+
+            sage: from sage.modules.free_module_integer import IntegerLattice
+            sage: L = IntegerLattice([[1, 0], [0, 1]])
+            sage: L.approximate_closest_vector((-6, 5/3))
+            (-6, 2)
+
+        The quality of the approximation depends on ``delta``::
+
+            sage: from sage.modules.free_module_integer import IntegerLattice
+            sage: L = IntegerLattice([[101, 0, 0, 0], [0, 101, 0, 0],
+            ....:                     [0, 0, 101, 0], [-28, 39, 45, 1]], lll_reduce=False)
+            sage: t = vector([1337]*4)
+            sage: L.approximate_closest_vector(t, delta=0.26)
+            (1348, 1340, 1383, 1337)
+            sage: L.approximate_closest_vector(t, delta=0.99)
+            (1326, 1349, 1339, 1345)
+            sage: L.closest_vector(t)
+            (1326, 1349, 1339, 1345)
+
+        ALGORITHM:
+
+        Uses the algorithm from [Bab86]_.
+        """
+        if delta is None:
+            delta = ZZ(99)/ZZ(100)
+
+        # bound checks on delta are performed in is_LLL_reduced
+        if not self._reduced_basis.is_LLL_reduced(delta=delta):
+            self.LLL(*args, delta=delta, **kwargs)
+
+        B = self._reduced_basis
+        G = B.gram_schmidt()[0]
+        t = vector(t)
+
+        b = t
+        for i in reversed(range(G.nrows())):
+            b -= B[i] * ((b * G[i]) / (G[i] * G[i])).round("even")
+        return (t - b).change_ring(ZZ)
+
+    babai = approximate_closest_vector
\ No newline at end of file
