@@ -1,10 +1,12 @@
+# sage.doctest: needs sage.groups
 r"""
 Invariant modules
 """
 
 # ****************************************************************************
 #       Copyright (C) 2021 Trevor K. Karn <karnx018 at umn.edu>
-#                          Travis Scrimshaw
+#                     2021 Travis Scrimshaw
+#                     2022 Matthias Koeppe
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -20,6 +22,8 @@ from sage.categories.finitely_generated_semigroups import FinitelyGeneratedSemig
 from sage.categories.finite_dimensional_modules_with_basis import FiniteDimensionalModulesWithBasis
 from sage.sets.family import Family
 from sage.matrix.constructor import Matrix
+from sage.libs.gap.libgap import libgap
+
 
 class FiniteDimensionalInvariantModule(SubmoduleWithBasis):
     r"""
@@ -64,7 +68,7 @@ class FiniteDimensionalInvariantModule(SubmoduleWithBasis):
 
         sage: [I.lift(b) for b in I.basis()]
         [M[1] + M[2] + M[3]]
-    
+
     The we could also have the action be a right-action, instead of the
     default left-action::
 
@@ -262,9 +266,29 @@ class FiniteDimensionalInvariantModule(SubmoduleWithBasis):
                          category=category,
                          *args, **kwargs)
 
+    def construction(self):
+        r"""
+        Return the functorial construction of ``self``.
+
+        EXAMPLES::
+
+            sage: G = CyclicPermutationGroup(3)
+            sage: R = G.regular_representation(); R
+            Left Regular Representation of Cyclic group of order 3 as a permutation group over Integer Ring
+            sage: I = R.invariant_module()
+            sage: I.construction()
+            (EquivariantSubobjectConstructionFunctor,
+            Left Regular Representation of Cyclic group of order 3 as a permutation group over Integer Ring)
+        """
+        from sage.categories.pushout import EquivariantSubobjectConstructionFunctor
+        return (EquivariantSubobjectConstructionFunctor(self._semigroup,
+                                                        self._action,
+                                                        self._side),
+                self.ambient())
+
     def _repr_(self):
         r"""
-        Return a string representaion of ``self``.
+        Return a string representation of ``self``.
 
         EXAMPLES::
 
@@ -776,27 +800,24 @@ class FiniteDimensionalTwistedInvariantModule(SubmoduleWithBasis):
             sage: type(T)
             <class 'sage.modules.with_basis.invariant.FiniteDimensionalInvariantModule_with_category'>
 
-        Check the ``ValueError``::
+        Check the :class:`ValueError`::
 
-            sage: from sage.groups.class_function import ClassFunction_libgap
-            sage: chi = ClassFunction_libgap(G, chi)
-            sage: T = M.twisted_invariant_module(G, chi, action_on_basis=action)
+            sage: T = M.twisted_invariant_module(G, "ichigo", action_on_basis=action)
             Traceback (most recent call last):
             ...
             ValueError: chi must be a list/tuple or a class function of the group G
         """
+        from sage.groups.class_function import ClassFunction, ClassFunction_libgap
 
-        from sage.groups.class_function import ClassFunction, ClassFunction_gap
-
-        if isinstance(chi,(list,tuple)):
-            chi = ClassFunction(G, chi)
-        elif not isinstance(chi, ClassFunction_gap):
+        if isinstance(chi, (list, tuple)):
+            chi = ClassFunction(G, libgap(chi))
+        elif not isinstance(chi, ClassFunction_libgap):
             raise ValueError("chi must be a list/tuple or a class function of the group G")
 
         try:
-            is_trivial = all(chi(conj.an_element()) == 1 for conj in G.conjugacy_classes())
-        except AttributeError: # to handle ReflectionGroups
-            is_trivial = all(chi(G(list(conj)[0])) == 1 for conj in G.conjugacy_classes().values())
+            is_trivial = all(chi(next(iter(conj))) == 1 for conj in G.conjugacy_classes())
+        except AttributeError:  # to handle ReflectionGroups
+            is_trivial = all(chi(G(next(iter(conj)))) == 1 for conj in G.conjugacy_classes())
 
         if is_trivial:
             action_on_basis = kwargs.pop('action_on_basis', None)
@@ -862,11 +883,11 @@ class FiniteDimensionalTwistedInvariantModule(SubmoduleWithBasis):
         else:
             raise ValueError("side must either be 'left' or 'right'")
 
-        proj_matrix = Matrix(M.dimension()) #initialize the zero-matrix
+        proj_matrix = Matrix(M.dimension())  # initialize the zero-matrix
         for g in self._group:
-            proj_matrix += self._chi(g)*Matrix((self.__sided_action__(g,b)).to_vector() for b in M.basis())
+            proj_matrix += self._chi(g)*Matrix((self.__sided_action__(g, b)).to_vector() for b in M.basis())
 
-        n = self._chi(self._group.identity()) # chi(1) is the dimension
+        n = self._chi(self._group.identity())  # chi(1) is the dimension
         g = self._group.order()
 
         self._projection_matrix = (n/g)*proj_matrix
@@ -939,7 +960,7 @@ class FiniteDimensionalTwistedInvariantModule(SubmoduleWithBasis):
         """
         return self.retract(self.project_ambient(x))
 
-    def project_ambient(self,x):
+    def project_ambient(self, x):
         r"""
         Project ``x`` in the ambient representation onto the submodule of the
         ambient representation to which ``self`` is isomorphic as a module.
@@ -984,7 +1005,7 @@ class FiniteDimensionalTwistedInvariantModule(SubmoduleWithBasis):
             sage: G.rename(); M.rename()  # reset names
         """
         if (isinstance(self._ambient, Representation)
-            and x.parent() is self._ambient._module):
+                and x.parent() is self._ambient._module):
             x = self._ambient._element_constructor_(x)
         return self._project_ambient(x)
 
