@@ -53,6 +53,9 @@ class CurveArrow(GraphicPrimitive):
 
         EXAMPLES::
 
+            sage: import numpy  # to ensure numpy 2.0 compatibility
+            sage: if int(numpy.version.short_version[0]) > 1:
+            ....:     numpy.set_printoptions(legacy="1.25")
             sage: from sage.plot.arrow import CurveArrow
             sage: b = CurveArrow(path=[[(0,0),(.5,.5),(1,0)],[(.5,1),(0,0)]],
             ....:                options={})
@@ -114,7 +117,7 @@ class CurveArrow(GraphicPrimitive):
             sage: CurveArrow(path=[[(0,0),(1,4),(2,3)]],options={})._repr_()
             'CurveArrow from (0, 0) to (2, 3)'
         """
-        return "CurveArrow from %s to %s" % (self.path[0][0], self.path[-1][-1])
+        return f"CurveArrow from {self.path[0][0]} to {self.path[-1][-1]}"
 
     def _render_on_subplot(self, subplot):
         """
@@ -152,7 +155,7 @@ class CurveArrow(GraphicPrimitive):
         from matplotlib.path import Path
         bpath = Path(self.vertices, self.codes)
         p = FancyArrowPatch(path=bpath,
-                            lw=width, arrowstyle='%s,head_width=%s,head_length=%s' % (style, head_width, head_length),
+                            lw=width, arrowstyle='{},head_width={},head_length={}'.format(style, head_width, head_length),
                             fc=color, ec=color,
                             linestyle=get_matplotlib_linestyle(options['linestyle'], return_type='long'))
         p.set_zorder(options['zorder'])
@@ -319,7 +322,7 @@ class Arrow(GraphicPrimitive):
             sage: Arrow(0,0,2,3,{})._repr_()
             'Arrow from (0.0,0.0) to (2.0,3.0)'
         """
-        return "Arrow from (%s,%s) to (%s,%s)" % (self.xtail, self.ytail, self.xhead, self.yhead)
+        return f"Arrow from ({self.xtail},{self.ytail}) to ({self.xhead},{self.yhead})"
 
     def _render_on_subplot(self, subplot):
         r"""
@@ -339,7 +342,7 @@ class Arrow(GraphicPrimitive):
 
         The length of the ends (shrinkA and shrinkB) should not depend
         on the width of the arrow, because Matplotlib already takes
-        this into account. See :trac:`12836`::
+        this into account. See :issue:`12836`::
 
             sage: fig = Graphics().matplotlib()
             sage: sp = fig.add_subplot(1,1,1, label='axis1')
@@ -352,7 +355,7 @@ class Arrow(GraphicPrimitive):
             sage: p1.shrinkB == p2.shrinkB
             True
 
-        Dashed arrows should have solid arrowheads, :trac:`12852`. We tried to
+        Dashed arrows should have solid arrowheads, :issue:`12852`. We tried to
         make up a test for this, which turned out to be fragile and hence was
         removed. In general, robust testing of graphics seems basically need a
         human eye or AI.
@@ -378,7 +381,7 @@ class Arrow(GraphicPrimitive):
         from matplotlib.patches import FancyArrowPatch
         p = FancyArrowPatch((self.xtail, self.ytail), (self.xhead, self.yhead),
                             lw=width,
-                            arrowstyle='%s,head_width=%s,head_length=%s' % (style, head_width, head_length),
+                            arrowstyle='{},head_width={},head_length={}'.format(style, head_width, head_length),
                             shrinkA=arrowshorten_end, shrinkB=arrowshorten_end,
                             fc=color, ec=color,
                             linestyle=get_matplotlib_linestyle(options['linestyle'], return_type='long'))
@@ -395,10 +398,10 @@ class Arrow(GraphicPrimitive):
 
             import matplotlib.patheffects as pe
 
-            class CheckNthSubPath():
+            class CheckNthSubPath:
                 def __init__(self, patch, n):
                     """
-                    creates an callable object that returns True if the
+                    creates a callable object that returns True if the
                     provided path is the n-th path from the patch.
                     """
                     self._patch = patch
@@ -475,7 +478,7 @@ def arrow(tailpoint=None, headpoint=None, **kwds):
 
     TESTS:
 
-    Check that :trac:`35031` is fixed::
+    Check that :issue:`35031` is fixed::
 
         sage: arrow((0,0), (0,0), linestyle='dashed')
         Graphics object consisting of 1 graphics primitive
@@ -489,7 +492,8 @@ def arrow(tailpoint=None, headpoint=None, **kwds):
 
 
 @rename_keyword(color='rgbcolor')
-@options(width=2, rgbcolor=(0,0,1), zorder=2, head=1, linestyle='solid', legend_label=None)
+@options(width=2, rgbcolor=(0,0,1), zorder=2, head=1, linestyle='solid',
+         legend_label=None, legend_color=None)
 def arrow2d(tailpoint=None, headpoint=None, path=None, **options):
     """
     If ``tailpoint`` and ``headpoint`` are provided, returns an arrow from
@@ -499,38 +503,38 @@ def arrow2d(tailpoint=None, headpoint=None, path=None, **options):
 
     INPUT:
 
-    - ``tailpoint`` - the starting point of the arrow
+    - ``tailpoint`` -- the starting point of the arrow
 
-    - ``headpoint`` - where the arrow is pointing to
+    - ``headpoint`` -- where the arrow is pointing to
 
-    - ``path`` - the list of points and control points (see bezier_path for
+    - ``path`` -- the list of points and control points (see bezier_path for
       detail) that the arrow will follow from source to destination
 
-    - ``head`` - 0, 1 or 2, whether to draw the head at the start (0), end (1)
+    - ``head`` -- 0, 1 or 2, whether to draw the head at the start (0), end (1)
       or both (2) of the path (using 0 will swap headpoint and tailpoint).
       This is ignored in 3D plotting.
 
-    - ``linestyle`` - (default: ``'solid'``) The style of the line, which is
+    - ``linestyle`` -- (default: ``'solid'``) The style of the line, which is
       one of ``'dashed'``, ``'dotted'``, ``'solid'``, ``'dashdot'``,
       or ``'--'``, ``':'``, ``'-'``, ``'-.'``, respectively.
 
-    - ``width`` - (default: 2) the width of the arrow shaft, in points
+    - ``width`` -- (default: 2) the width of the arrow shaft, in points
 
-    - ``color`` - (default: (0,0,1)) the color of the arrow (as an RGB tuple or
+    - ``color`` -- (default: (0,0,1)) the color of the arrow (as an RGB tuple or
       a string)
 
-    - ``hue`` - the color of the arrow (as a number)
+    - ``hue`` -- the color of the arrow (as a number)
 
-    - ``arrowsize`` - the size of the arrowhead
+    - ``arrowsize`` -- the size of the arrowhead
 
-    - ``arrowshorten`` - the length in points to shorten the arrow (ignored if
+    - ``arrowshorten`` -- the length in points to shorten the arrow (ignored if
       using path parameter)
 
-    - ``legend_label`` - the label for this item in the legend
+    - ``legend_label`` -- the label for this item in the legend
 
-    - ``legend_color`` - the color for the legend label
+    - ``legend_color`` -- the color for the legend label
 
-    - ``zorder`` - the layer level to draw the arrow-- note that this is
+    - ``zorder`` -- the layer level to draw the arrow-- note that this is
       ignored in 3D plotting.
 
     EXAMPLES:
@@ -640,6 +644,12 @@ def arrow2d(tailpoint=None, headpoint=None, path=None, **options):
     ::
 
         sage: arrow2d((-2,2), (7,1)).show(frame=True)
+
+    TESTS:
+
+    Verify that :issue:`36153` is fixed::
+
+        sage: A = arrow2d((-1,-1), (2,3), legend_label="test")
     """
     from sage.plot.all import Graphics
     g = Graphics()
