@@ -199,7 +199,7 @@ def mod_one(x):
 
     INPUT:
 
-    - ``x`` - an instance of Integer, int, RealNumber, etc.; the
+    - ``x`` -- an instance of Integer, int, RealNumber, etc.; the
       number to reduce
 
     OUTPUT:
@@ -215,7 +215,7 @@ def mod_one(x):
         0.0
         sage: mod_one(-11/7)
         0.4285714285714286
-        sage: mod_one(pi) + mod_one(-pi)
+        sage: mod_one(pi) + mod_one(-pi)                                                # needs sage.symbolic
         1.0
     """
     x = float(x)
@@ -232,7 +232,7 @@ def html_to_float(c):
 
     INPUT:
 
-    - ``c`` - a string; a valid HTML hex color
+    - ``c`` -- a string; a valid HTML hex color
 
     OUTPUT:
 
@@ -254,7 +254,7 @@ def html_to_float(c):
         raise ValueError("'%s' must be a valid HTML hex color (e.g., '#f07' or '#d6e7da')" % c)
     h = c[1:]
     if len(h) == 3:
-        h = '%s%s%s%s%s%s' % (h[0], h[0], h[1], h[1], h[2], h[2])
+        h = f'{h[0]}{h[0]}{h[1]}{h[1]}{h[2]}{h[2]}'
     elif len(h) != 6:
         raise ValueError("color hex string (= '%s') must have length 3 or 6" % h)
     return tuple([int(h[i:i + 2], base=16) / 255 for i in [0, 2, 4]])
@@ -268,10 +268,10 @@ def rgbcolor(c, space='rgb'):
 
     INPUT:
 
-    - ``c`` - a :class:`Color` instance, string (name or HTML hex),
+    - ``c`` -- a :class:`Color` instance, string (name or HTML hex),
       3-tuple, or 3-list; the color to convert
 
-    - ``space`` - a string (default: 'rgb'); the color space
+    - ``space`` -- a string (default: 'rgb'); the color space
       coordinate system (other choices are 'hsl', 'hls', and 'hsv') in
       which to interpret a 3-tuple or 3-list
 
@@ -338,8 +338,8 @@ def rgbcolor(c, space='rgb'):
 
     elif isinstance(c, (list, tuple)):
         if len(c) != 3:
-            raise ValueError("color list or tuple '%s' must have 3 entries, one for each RGB, HSV, HLS, or HSL channel" % (c, ))
-        c = [mod_one(_) for _ in list(c)]
+            raise ValueError(f"color list or tuple '{c}' must have 3 entries, one for each RGB, HSV, HLS, or HSL channel")
+        c = [mod_one(comp) for comp in c]
         if space == 'rgb':
             return tuple(c)
         elif space == 'hsv':
@@ -358,10 +358,10 @@ def rgbcolor(c, space='rgb'):
 to_mpl_color = rgbcolor
 
 
-class Color():
+class Color:
     def __init__(self, r='#0000ff', g=None, b=None, space='rgb'):
         """
-        An Red-Green-Blue (RGB) color model color object.  For most
+        A Red-Green-Blue (RGB) color model color object.  For most
         consumer-grade devices (e.g., CRTs, LCDs, and printers), as
         well as internet applications, this is a point in the sRGB
         absolute color space.  The Hue-Saturation-Lightness (HSL),
@@ -376,10 +376,10 @@ class Color():
 
         INPUT:
 
-        -  ``r,g,b`` - either a triple of floats between 0 and 1,
+        -  ``r,g,b`` -- either a triple of floats between 0 and 1,
            OR ``r`` - a color name string or HTML color hex string
 
-        - ``space`` - a string (default: 'rgb'); the coordinate system
+        - ``space`` -- a string (default: 'rgb'); the coordinate system
           (other choices are 'hsl', 'hls', and 'hsv') in which to
           interpret a triple of floats
 
@@ -421,7 +421,7 @@ class Color():
             sage: Color(1, 0.5, 1/16, space='hsl').__repr__()
             'RGB color (0.09375, 0.03125, 0.03125)'
         """
-        return "RGB color %s" % (self._rgb, )
+        return f"RGB color {self._rgb}"
 
     def __lt__(self, right):
         """
@@ -431,7 +431,7 @@ class Color():
 
         INPUT:
 
-        - ``right`` - an object
+        - ``right`` -- an object
 
         OUTPUT:
 
@@ -457,7 +457,7 @@ class Color():
 
         INPUT:
 
-        - ``right`` - an object
+        - ``right`` -- an object
 
         OUTPUT:
 
@@ -481,7 +481,7 @@ class Color():
 
         INPUT:
 
-        - ``right`` - a :class:`Color` instance
+        - ``right`` -- a :class:`Color` instance
 
         OUTPUT:
 
@@ -509,7 +509,7 @@ class Color():
 
         INPUT:
 
-        - ``right`` - a :class:`Color` instance
+        - ``right`` -- a :class:`Color` instance
 
         OUTPUT:
 
@@ -537,7 +537,7 @@ class Color():
 
         INPUT:
 
-        - ``right`` - an object
+        - ``right`` -- an object
 
         OUTPUT:
 
@@ -563,7 +563,7 @@ class Color():
 
         INPUT:
 
-        - ``right`` - an object
+        - ``right`` -- an object
 
         OUTPUT:
 
@@ -606,10 +606,10 @@ class Color():
 
         INPUT:
 
-        - ``color`` - a :class:`Color` instance or float-convertible
+        - ``color`` -- a :class:`Color` instance or float-convertible
           3-tuple/list; the color with which to blend this color
 
-        - ``fraction`` - a float-convertible number; the fraction of
+        - ``fraction`` -- a float-convertible number; the fraction of
           ``color`` to blend with this color
 
         OUTPUT:
@@ -645,7 +645,7 @@ class Color():
             color = [float(_) for _ in color]
             return Color(rgbcolor([(1 - fraction) * a + fraction * b
                                    for a, b in zip(self._rgb, color)]))
-        raise TypeError("%s must be a Color or float-convertible 3-tuple/list" % (color, ))
+        raise TypeError(f"{color} must be a Color or float-convertible 3-tuple/list")
 
     def __add__(self, right):
         """
@@ -654,7 +654,7 @@ class Color():
 
         INPUT:
 
-        - ``right`` - a :class:`Color` instance or float-convertible
+        - ``right`` -- a :class:`Color` instance or float-convertible
           3-tuple/list
 
         OUTPUT:
@@ -690,7 +690,7 @@ class Color():
 
         INPUT:
 
-        - ``left`` - a :class:`Color` instance or float-convertible
+        - ``left`` -- a :class:`Color` instance or float-convertible
           3-tuple/list
 
         OUTPUT:
@@ -721,7 +721,7 @@ class Color():
 
         INPUT:
 
-        - ``right`` - a float-convertible number
+        - ``right`` -- a float-convertible number
 
         OUTPUT:
 
@@ -749,7 +749,7 @@ class Color():
 
         INPUT:
 
-        - ``left`` - a float-convertible number
+        - ``left`` -- a float-convertible number
 
         OUTPUT:
 
@@ -854,7 +854,7 @@ class Color():
 
         INPUT:
 
-        - ``i`` - an integer; the 0-based coordinate to retrieve
+        - ``i`` -- an integer; the 0-based coordinate to retrieve
 
         OUTPUT:
 
@@ -997,7 +997,7 @@ class Color():
 
         INPUT:
 
-        - ``fraction`` - a float (default: 1/3); blending fraction
+        - ``fraction`` -- a float (default: 1/3); blending fraction
           to apply
 
         OUTPUT:
@@ -1025,7 +1025,7 @@ class Color():
 
         INPUT:
 
-        - ``fraction`` - a float (default: 1/3); blending fraction
+        - ``fraction`` -- a float (default: 1/3); blending fraction
           to apply
 
         OUTPUT:
@@ -1080,7 +1080,7 @@ class ColorsDict(dict):
 
         INPUT:
 
-        - ``name`` - a string; the name of the color to return
+        - ``name`` -- a string; the name of the color to return
 
         OUTPUT:
 
@@ -1099,12 +1099,12 @@ class ColorsDict(dict):
             sage: cols.punk
             Traceback (most recent call last):
             ...
-            AttributeError: 'ColorsDict' has no attribute or colormap punk
+            AttributeError: 'ColorsDict' has no attribute or colormap punk...
         """
         try:
             return self[name]
         except KeyError:
-            raise AttributeError("'%s' has no attribute or colormap %s" % (type(self).__name__, name))
+            raise AttributeError("'{}' has no attribute or colormap {}".format(type(self).__name__, name))
 
     def __dir__(self):
         """
@@ -1146,19 +1146,20 @@ def hue(h, s=1, v=1):
     This function makes it easy to sample a broad range of colors for
     graphics::
 
+        sage: # needs sage.symbolic
         sage: p = Graphics()
         sage: for phi in xsrange(0, 2 * pi, 1 / pi):
-        ....:     p += plot(sin(x + phi), (x, -7, 7), rgbcolor = hue(phi))
+        ....:     p += plot(sin(x + phi), (x, -7, 7), rgbcolor=hue(phi))
         sage: p
         Graphics object consisting of 20 graphics primitives
 
     INPUT:
 
-    - ``h`` - a number; the color's hue
+    - ``h`` -- a number; the color's hue
 
-    - ``s`` - a number (default: 1); the color's saturation
+    - ``s`` -- a number (default: 1); the color's saturation
 
-    - ``v`` - a number (default: 1); the color's value
+    - ``v`` -- a number (default: 1); the color's value
 
     OUTPUT:
 
@@ -1280,9 +1281,9 @@ def rainbow(n, format='hex'):
 
     INPUT:
 
-    - ``n`` - a number; the length of the list
+    - ``n`` -- a number; the length of the list
 
-    - ``format`` - a string (default: 'hex'); the output format for
+    - ``format`` -- a string (default: 'hex'); the output format for
       each color in the list; the other choice is 'rgbtuple'
 
     OUTPUT:
@@ -1306,10 +1307,7 @@ def rainbow(n, format='hex'):
 
     - Karl-Dieter Crisman (directly use :func:`hsv_to_rgb` for hues)
     """
-    R = []
-
-    for i in range(n):
-        R.append(tuple(map(float, hsv_to_rgb(i / n, 1, 1))))
+    R = [tuple(map(float, hsv_to_rgb(i / n, 1, 1))) for i in range(n)]
 
     if format == 'rgbtuple':
         return R
@@ -1334,7 +1332,7 @@ def get_cmap(cmap):
 
     INPUT:
 
-    - ``cmap`` - a string, list, tuple, or
+    - ``cmap`` -- a string, list, tuple, or
       :class:`matplotlib.colors.Colormap`; a string must be a valid
       color map name
 
@@ -1364,7 +1362,7 @@ def get_cmap(cmap):
 
     TESTS:
 
-    Check that :trac:`33491` is fixed::
+    Check that :issue:`33491` is fixed::
 
         sage: get_cmap('turbo')
         <matplotlib.colors.ListedColormap object at 0x...>
@@ -1528,7 +1526,7 @@ class Colormaps(MutableMapping):
 
         INPUT:
 
-        - ``name`` - a string; the name of the map to query
+        - ``name`` -- a string; the name of the map to query
 
         OUTPUT:
 
@@ -1552,7 +1550,7 @@ class Colormaps(MutableMapping):
 
         INPUT:
 
-        - ``name`` - a string; the name of the map return
+        - ``name`` -- a string; the name of the map return
 
         OUTPUT:
 
@@ -1584,7 +1582,7 @@ class Colormaps(MutableMapping):
 
         INPUT:
 
-        - ``name`` - a string; the name of the map to return
+        - ``name`` -- a string; the name of the map to return
 
         OUTPUT:
 
@@ -1599,7 +1597,7 @@ class Colormaps(MutableMapping):
             sage: maps.punk
             Traceback (most recent call last):
             ...
-            AttributeError: 'Colormaps' has no attribute or colormap punk
+            AttributeError: 'Colormaps' has no attribute or colormap punk...
             sage: maps['punk']
             Traceback (most recent call last):
             ...
@@ -1610,7 +1608,7 @@ class Colormaps(MutableMapping):
         try:
             return self[name]
         except KeyError:
-            raise AttributeError("'%s' has no attribute or colormap %s" % (type(self).__name__, name))
+            raise AttributeError("'{}' has no attribute or colormap {}".format(type(self).__name__, name))
 
     def __repr__(self):
         """
@@ -1638,9 +1636,9 @@ class Colormaps(MutableMapping):
 
         INPUT:
 
-        - ``name`` - a string; the name of the map to add
+        - ``name`` -- a string; the name of the map to add
 
-        - ``colormap`` - an instance of
+        - ``colormap`` -- an instance of
           :class:`matplotlib.colors.Colormap`; the color map to add
 
         EXAMPLES::
@@ -1664,7 +1662,7 @@ class Colormaps(MutableMapping):
 
         INPUT:
 
-        - ``name`` - a string; the name of the map to remove
+        - ``name`` -- a string; the name of the map to remove
 
         EXAMPLES::
 
