@@ -123,13 +123,13 @@ def plot_vector_field3d(functions, xrange, yrange, zrange,
 
     TESTS:
 
-    This tests that :trac:`2100` is fixed in a way compatible with this command::
+    This tests that :issue:`2100` is fixed in a way compatible with this command::
 
         sage: plot_vector_field3d((x*cos(z),-y*cos(z),sin(z)), (x,0,pi), (y,0,pi), (z,0,pi),center_arrows=True,aspect_ratio=(1,2,1))
         Graphics3d Object
     """
     (ff, gg, hh), ranges = setup_for_eval_on_grid(functions, [xrange, yrange, zrange], plot_points)
-    xpoints, ypoints, zpoints = [srange(*r, include_endpoint=True) for r in ranges]
+    xpoints, ypoints, zpoints = (srange(*r, include_endpoint=True) for r in ranges)
     points = [vector((i, j, k)) for i in xpoints for j in ypoints for k in zpoints]
     vectors = [vector((ff(*point), gg(*point), hh(*point))) for point in points]
 
