@@ -191,7 +191,7 @@ class Polygon(GraphicPrimitive_xydata):
 
         INPUT:
 
-        -  ``z`` - optional 3D height above `xy`-plane, or a list of
+        -  ``z`` -- optional 3D height above `xy`-plane, or a list of
            heights corresponding to the list of 2D polygon points.
 
         EXAMPLES:
@@ -524,10 +524,15 @@ def polygon2d(points, **options):
         sage: polygon2d([[1,2], [5,6], [5,0]]).aspect_ratio()
         1.0
 
+    TESTS:
+
+    Verify that :issue:`36153` does not arise::
+
+        sage: P = polygon2d([[1,2], [5,6], [5,0]], legend_label="test")
+
     AUTHORS:
 
     - David Joyner (2006-04-14): the long list of examples above.
-
     """
     from sage.plot.plot import xydata_from_point_list
     from sage.plot.all import Graphics
