@@ -1,13 +1,5 @@
 r"""
-Relative Number Field Ideals
-
-AUTHORS:
-
-- Steven Sivek (2005-05-16)
-
-- William Stein (2007-09-06)
-
-- Nick Alexander (2009-01)
+Ideals of relative number fields
 
 EXAMPLES::
 
@@ -22,6 +14,12 @@ EXAMPLES::
     Fractional ideal ((1/2*b + 2)*a - 1/2*b + 2)
     sage: K.fractional_ideal(G).absolute_norm().factor()
     7^2
+
+AUTHORS:
+
+- Steven Sivek (2005-05-16)
+- William Stein (2007-09-06)
+- Nick Alexander (2009-01)
 """
 
 #*****************************************************************************
@@ -272,7 +270,7 @@ class NumberFieldFractionalIdeal_rel(NumberFieldFractionalIdeal):
         TESTS:
 
         Number fields defined by non-monic and non-integral
-        polynomials are supported (:trac:`252`)::
+        polynomials are supported (:issue:`252`)::
 
             sage: K.<a> = NumberField(2*x^2 - 1/3)
             sage: L.<b> = K.extension(5*x^2 + 1)
@@ -405,7 +403,7 @@ class NumberFieldFractionalIdeal_rel(NumberFieldFractionalIdeal):
             815730721
 
         Number fields defined by non-monic and non-integral
-        polynomials are supported (:trac:`252`)::
+        polynomials are supported (:issue:`252`)::
 
             sage: K.<a> = NumberField(2*x^2 - 1/3)
             sage: L.<b> = K.extension(5*x^2 + 1)
@@ -524,7 +522,7 @@ class NumberFieldFractionalIdeal_rel(NumberFieldFractionalIdeal):
             True
 
         Number fields defined by non-monic and non-integral
-        polynomials are supported (:trac:`252`)::
+        polynomials are supported (:issue:`252`)::
 
             sage: K.<a> = NumberField(2*x^2 - 1/3)
             sage: L.<b> = K.extension(5*x^2 + 1)
@@ -687,7 +685,7 @@ class NumberFieldFractionalIdeal_rel(NumberFieldFractionalIdeal):
         """
         if self.is_prime():
             return self.absolute_ideal().ramification_index()
-        raise ValueError("the fractional ideal (= %s) is not prime"%self)
+        raise ValueError("the fractional ideal (= %s) is not prime" % self)
 
     def relative_ramification_index(self):
         """
@@ -722,7 +720,7 @@ class NumberFieldFractionalIdeal_rel(NumberFieldFractionalIdeal):
             abs_index = self.absolute_ramification_index()
             base_ideal = self.ideal_below()
             return ZZ(abs_index/base_ideal.absolute_ramification_index())
-        raise ValueError("the fractional ideal (= %s) is not prime"%self)
+        raise ValueError("the fractional ideal (= %s) is not prime" % self)
 
     def ramification_index(self):
         r"""
@@ -755,10 +753,10 @@ class NumberFieldFractionalIdeal_rel(NumberFieldFractionalIdeal):
             sage: K.<c> = F.extension(Y^2 - (1 + a)*(a + b)*a*b)
             sage: [I.residue_class_degree() for I in K.ideal(c).prime_factors()]
             [1, 2]
-         """
+        """
         if self.is_prime():
             return self.absolute_ideal().residue_class_degree()
-        raise ValueError("the ideal (= %s) is not prime"%self)
+        raise ValueError("the ideal (= %s) is not prime" % self)
 
     def residues(self):
         """
@@ -815,14 +813,14 @@ class NumberFieldFractionalIdeal_rel(NumberFieldFractionalIdeal):
         # Catch invalid inputs by making sure that we can make an ideal out of other.
         K = self.number_field()
         if not self.is_integral():
-            raise TypeError("%s is not an integral ideal"%self)
+            raise TypeError("%s is not an integral ideal" % self)
 
         other = K.ideal(other)
         if not other.is_integral():
-            raise TypeError("%s is not an integral ideal"%other)
+            raise TypeError("%s is not an integral ideal" % other)
 
         if not self.is_coprime(other):
-            raise TypeError("%s and %s are not coprime ideals"%(self, other))
+            raise TypeError("%s and %s are not coprime ideals" % (self, other))
 
         to_K = K.absolute_field('a').structure()[0]
         return to_K(self.absolute_ideal().element_1_mod(other.absolute_ideal()))
@@ -872,15 +870,15 @@ class NumberFieldFractionalIdeal_rel(NumberFieldFractionalIdeal):
             Traceback (most recent call last):
             ...
             ValueError: p (= Fractional ideal (5)) must be a prime
-         """
+        """
         if p == 0:
-            raise ValueError("p (= %s) must be nonzero"%p)
+            raise ValueError("p (= %s) must be nonzero" % p)
         if not isinstance(p, NumberFieldFractionalIdeal):
             p = self.number_field().ideal(p)
         if not p.is_prime():
-            raise ValueError("p (= %s) must be a prime"%p)
+            raise ValueError("p (= %s) must be a prime" % p)
         if p.ring() != self.number_field():
-            raise ValueError("p (= %s) must be an ideal in %s"%self.number_field())
+            raise ValueError("p (= %s) must be an ideal in %s" % self.number_field())
         return self.absolute_ideal().valuation(p.absolute_ideal())
 
 def is_NumberFieldFractionalIdeal_rel(x):
@@ -892,6 +890,10 @@ def is_NumberFieldFractionalIdeal_rel(x):
         sage: from sage.rings.number_field.number_field_ideal_rel import is_NumberFieldFractionalIdeal_rel
         sage: from sage.rings.number_field.number_field_ideal import is_NumberFieldFractionalIdeal
         sage: is_NumberFieldFractionalIdeal_rel(2/3)
+        doctest:warning...
+        DeprecationWarning: The function is_NumberFieldFractionalIdeal_rel is deprecated;
+        use 'isinstance(..., NumberFieldFractionalIdeal_rel' instead.
+        See https://github.com/sagemath/sage/issues/38124 for details.
         False
         sage: is_NumberFieldFractionalIdeal_rel(ideal(5))
         False
@@ -912,7 +914,9 @@ def is_NumberFieldFractionalIdeal_rel(x):
         Fractional ideal (-a)
         sage: is_NumberFieldFractionalIdeal_rel(N)
         False
-        sage: is_NumberFieldFractionalIdeal(N)
-        True
     """
+    from sage.misc.superseded import deprecation
+    deprecation(38124,
+                "The function is_NumberFieldFractionalIdeal_rel is deprecated; "
+                "use 'isinstance(..., NumberFieldFractionalIdeal_rel' instead.")
     return isinstance(x, NumberFieldFractionalIdeal_rel)
