@@ -1,3 +1,4 @@
+# sage.doctest: needs sage.libs.ntl
 """
 `p`-adic Extension Generic
 
@@ -19,10 +20,11 @@ AUTHORS:
 #                  http://www.gnu.org/licenses/
 #*****************************************************************************
 
+import sage.rings.abc
+
 from .padic_generic import pAdicGeneric, ResidueLiftingMap
 from .padic_base_generic import pAdicBaseGeneric
 from sage.rings.number_field.number_field_base import NumberField
-from sage.rings.number_field.order import Order
 from sage.rings.rational_field import QQ
 from sage.rings.infinity import Infinity
 from sage.structure.richcmp import op_EQ
@@ -49,7 +51,7 @@ class pAdicExtensionGeneric(pAdicGeneric):
             sage: R = Zp(5,5)
             sage: S.<x> = R[]
             sage: f = x^5 + 75*x^3 - 15*x^2 +125*x - 5
-            sage: W.<w> = R.ext(f) #indirect doctest
+            sage: W.<w> = R.ext(f)  # indirect doctest
         """
         #type checking done in factory
         self._given_poly = poly
@@ -72,7 +74,7 @@ class pAdicExtensionGeneric(pAdicGeneric):
 
             sage: R = Zp(5); S.<x> = ZZ[]; f = x^5 + 25*x - 5; W.<w> = R.ext(f)
             sage: L = W.fraction_field()
-            sage: w + L(w) #indirect doctest
+            sage: w + L(w)  # indirect doctest
             2*w + O(w^101)
             sage: w + R(5,2)
             w + w^5 + O(w^10)
@@ -141,7 +143,7 @@ class pAdicExtensionGeneric(pAdicGeneric):
             '\\Bold{Z}_{7^{3}}'
             sage: x = polygen(ZZ, 'x')
             sage: R2.<t> = R.ext(x^2 + 7)
-            sage: R2 #indirect doctest
+            sage: R2  # indirect doctest
             7-adic Eisenstein Extension Ring in t defined by x^2 + 7
             sage: R2._latex_()
             '\\Bold{Z}_{7}[t]'
@@ -155,7 +157,7 @@ class pAdicExtensionGeneric(pAdicGeneric):
             sage: K1._latex_()
             '\\Bold{Q}_{7^{3}}'
             sage: K2.<t> = K.ext(x^2+7)
-            sage: K2 #indirect doctest
+            sage: K2  # indirect doctest
             7-adic Eisenstein Extension Field in t defined by x^2 + 7
             sage: K2._latex_()
             '\\Bold{Q}_{7}[t]'
@@ -223,7 +225,7 @@ class pAdicExtensionGeneric(pAdicGeneric):
                 cat = R.category()
             else:
                 cat = EuclideanDomains() & MetricSpaces().Complete()
-        elif isinstance(R, Order) and R.number_field().defining_polynomial() == self.defining_polynomial():
+        elif isinstance(R, sage.rings.abc.Order) and R.number_field().defining_polynomial() == self.defining_polynomial():
             cat = IntegralDomains()
         elif isinstance(R, NumberField) and R.defining_polynomial() == self.defining_polynomial():
             if self.is_field():
@@ -375,7 +377,8 @@ class pAdicExtensionGeneric(pAdicGeneric):
         """
         Return the order with the same defining polynomial.
 
-        Will raise a ValueError if the coefficients of the defining polynomial are not integral.
+        Will raise a :class:`ValueError` if the coefficients of the defining
+        polynomial are not integral.
 
         EXAMPLES::
 
@@ -384,7 +387,7 @@ class pAdicExtensionGeneric(pAdicGeneric):
             sage: f = x^5 + 75*x^3 - 15*x^2 +125*x - 5
             sage: W.<w> = R.ext(f)
             sage: W.exact_ring()
-            Order in Number Field in w with defining polynomial x^5 + 75*x^3 - 15*x^2 + 125*x - 5
+            Order generated by w in Number Field in w with defining polynomial x^5 + 75*x^3 - 15*x^2 + 125*x - 5
 
             sage: T = Zp(5,5)
             sage: U.<z> = T[]
@@ -630,7 +633,7 @@ class pAdicExtensionGeneric(pAdicGeneric):
             from_V = MapFreeModuleToTwoStep
             to_V = MapTwoStepToFreeModule
         elif base is self:
-            return super(pAdicExtensionGeneric, self).free_module(base=base, basis=basis, map=map)
+            return super().free_module(base=base, basis=basis, map=map)
         else:
             raise NotImplementedError
         FromV = Hom(V, self)
@@ -734,7 +737,7 @@ class MapFreeModuleToOneStep(pAdicModuleIsomorphism):
 
         sage: K.<a> = Qq(125)
         sage: V, fr, to = K.free_module()
-        sage: TestSuite(fr).run(skip=['_test_nonzero_equal']) # skipped since Qq(125) doesn't have dimension()
+        sage: TestSuite(fr).run(skip=['_test_nonzero_equal'])  # skipped since Qq(125) doesn't have dimension()
     """
     def _call_(self, x):
         """
@@ -795,7 +798,7 @@ class MapFreeModuleToTwoStep(pAdicModuleIsomorphism):
         sage: R.<x> = ZZ[]
         sage: L.<b> = K.extension(x^2 - 5*x + 5)
         sage: V, fr, to = L.free_module(base=Qp(5))
-        sage: TestSuite(fr).run(skip=['_test_nonzero_equal']) # skipped since L doesn't have dimension()
+        sage: TestSuite(fr).run(skip=['_test_nonzero_equal'])  # skipped since L doesn't have dimension()
     """
     def _call_(self, x):
         """
@@ -900,7 +903,7 @@ class DefPolyConversion(Morphism):
 
         TESTS:
 
-        We check that :trac:`25990` has been resolved::
+        We check that :issue:`25990` has been resolved::
 
             sage: R.<a> = Zp(2).extension(x^3 - 2)
             sage: K = R.fraction_field()
@@ -939,7 +942,7 @@ class DefPolyConversion(Morphism):
             sage: S.<x> = ZZ[]
             sage: W.<w> = Zp(3).extension(x^4 + 9*x^2 + 3*x - 3)
             sage: z = W.random_element()
-            sage: r = repr(W.change(print_mode='digits')(z, absprec=8)) # indirect doctest
+            sage: r = repr(W.change(print_mode='digits')(z, absprec=8))  # indirect doctest
             sage: r[:3] == '...'
             True
             sage: all(l in ['0', '1', '2'] for l in r[3:])
