@@ -98,7 +98,7 @@ def LaurentPolynomialRing(base_ring, *args, **kwds):
     - ``name`` -- a string
     - ``names`` -- a list or tuple of names, or a comma separated string
     - ``n`` -- a positive integer
-    - ``sparse`` -- bool (default: False), whether or not elements are sparse
+    - ``sparse`` -- bool (default: ``False``), whether or not elements are sparse
     - ``order`` -- string or
       :class:`~sage.rings.polynomial.term_order.TermOrder`, e.g.,
 
@@ -436,14 +436,14 @@ class LaurentPolynomialRing_univariate(LaurentPolynomialRing_generic):
             sage: L = LaurentPolynomialRing(QQ,'x')
             sage: type(L)
             <class 'sage.rings.polynomial.laurent_polynomial_ring.LaurentPolynomialRing_univariate_with_category'>
-            sage: L == loads(dumps(L))
-            True
-
+            sage: TestSuite(L).run()
 
         TESTS::
 
+            sage: TestSuite(LaurentPolynomialRing(Zmod(2), 'y')).run()
             sage: TestSuite(LaurentPolynomialRing(Zmod(4), 'y')).run()
             sage: TestSuite(LaurentPolynomialRing(ZZ, 'u')).run()
+            sage: TestSuite(LaurentPolynomialRing(Zmod(2)['T'], 'u')).run()
             sage: TestSuite(LaurentPolynomialRing(Zmod(4)['T'], 'u')).run()
         """
         if R.ngens() != 1:
@@ -459,7 +459,7 @@ class LaurentPolynomialRing_univariate(LaurentPolynomialRing_generic):
             sage: LaurentPolynomialRing(QQ,'x')  # indirect doctest
             Univariate Laurent Polynomial Ring in x over Rational Field
         """
-        return "Univariate Laurent Polynomial Ring in %s over %s"%(self._R.variable_name(), self._R.base_ring())
+        return "Univariate Laurent Polynomial Ring in %s over %s" % (self._R.variable_name(), self._R.base_ring())
 
     def _element_constructor_(self, x):
         """
@@ -519,7 +519,7 @@ class LaurentPolynomialRing_univariate(LaurentPolynomialRing_generic):
 
         TESTS:
 
-        Check that conversion back from fraction field does work (:trac:`26425`)::
+        Check that conversion back from fraction field does work (:issue:`26425`)::
 
             sage: R.<t> = LaurentPolynomialRing(ZZ)
             sage: F = FractionField(R)
@@ -555,11 +555,11 @@ class LaurentPolynomialRing_univariate(LaurentPolynomialRing_generic):
         elif isinstance(x, FractionFieldElement):
             # since the field of fraction of self is defined corresponding to
             # the polynomial ring of self the conversion of its elements back
-            # must be treated separately (:trac:`26425`).
+            # must be treated separately (:issue:`26425`).
             return from_fraction_field(self, x)
 
         elif isinstance(x, LocalizationElement):
-            # see :trac:`33477`.
+            # see :issue:`33477`.
             F = self.fraction_field()
             return from_fraction_field(self, F(x))
 
@@ -607,7 +607,7 @@ class LaurentPolynomialRing_mpair(LaurentPolynomialRing_generic):
             sage: LaurentPolynomialRing(QQ,1,'x').__repr__()                            # needs sage.modules
             'Multivariate Laurent Polynomial Ring in x over Rational Field'
         """
-        return "Multivariate Laurent Polynomial Ring in %s over %s"%(", ".join(self._R.variable_names()), self._R.base_ring())
+        return "Multivariate Laurent Polynomial Ring in %s over %s" % (", ".join(self._R.variable_names()), self._R.base_ring())
 
     def monomial(self, *args):
         r"""
@@ -783,11 +783,11 @@ class LaurentPolynomialRing_mpair(LaurentPolynomialRing_generic):
         elif isinstance(x, FractionFieldElement):
             # since the field of fraction of self is defined corresponding to
             # the polynomial ring of self the conversion of its elements back
-            # must be treated separately (:trac:`33477`).
+            # must be treated separately (:issue:`33477`).
             return from_fraction_field(self, x)
 
         elif isinstance(x, LocalizationElement):
-            # see :trac:`33477`.
+            # see :issue:`33477`.
             F = self.fraction_field()
             return from_fraction_field(self, F(x))
 
