@@ -9,12 +9,12 @@ Affine `n` space over a ring
 #
 #                  https://www.gnu.org/licenses/
 # ****************************************************************************
+from itertools import product
 
-from sage.functions.orthogonal_polys import chebyshev_T, chebyshev_U
 from sage.rings.integer import Integer
 from sage.rings.integer_ring import ZZ
 from sage.rings.polynomial.polynomial_ring_constructor import PolynomialRing
-from sage.rings.rational_field import is_RationalField
+from sage.rings.rational_field import RationalField
 from sage.rings.polynomial.polynomial_ring import is_PolynomialRing
 from sage.rings.polynomial.multi_polynomial_ring import is_MPolynomialRing
 from sage.rings.finite_rings.finite_field_base import FiniteField
@@ -22,8 +22,6 @@ from sage.categories.map import Map
 from sage.categories.fields import Fields
 from sage.categories.number_fields import NumberFields
 from sage.misc.latex import latex
-from sage.misc.mrange import cartesian_product_iterator
-from sage.matrix.constructor import matrix
 from sage.structure.category_object import normalize_names
 from sage.schemes.generic.scheme import AffineScheme
 from sage.schemes.generic.ambient_space import AmbientSpace
@@ -48,12 +46,17 @@ def is_AffineSpace(x) -> bool:
 
         sage: from sage.schemes.affine.affine_space import is_AffineSpace
         sage: is_AffineSpace(AffineSpace(5, names='x'))
+        doctest:warning...
+        DeprecationWarning: The function is_AffineSpace is deprecated; use 'isinstance(..., AffineSpace_generic)' instead.
+        See https://github.com/sagemath/sage/issues/38022 for details.
         True
-        sage: is_AffineSpace(AffineSpace(5, GF(9, 'alpha'), names='x'))                 # optional - sage.rings.finite_rings
+        sage: is_AffineSpace(AffineSpace(5, GF(9, 'alpha'), names='x'))                 # needs sage.rings.finite_rings
         True
         sage: is_AffineSpace(Spec(ZZ))
         False
     """
+    from sage.misc.superseded import deprecation
+    deprecation(38022, "The function is_AffineSpace is deprecated; use 'isinstance(..., AffineSpace_generic)' instead.")
     return isinstance(x, AffineSpace_generic)
 
 
@@ -77,7 +80,7 @@ def AffineSpace(n, R=None, names=None, ambient_projective_space=None,
 
     Use the divide operator for base extension::
 
-        sage: AffineSpace(5, names='x')/GF(17)                                          # optional - sage.rings.finite_rings
+        sage: AffineSpace(5, names='x')/GF(17)
         Affine Space of dimension 5 over Finite Field of size 17
 
     The default base ring is `\ZZ`::
@@ -87,10 +90,10 @@ def AffineSpace(n, R=None, names=None, ambient_projective_space=None,
 
     There is also an affine space associated to each polynomial ring::
 
-        sage: R = GF(7)['x, y, z']                                                      # optional - sage.rings.finite_rings
-        sage: A = AffineSpace(R); A                                                     # optional - sage.rings.finite_rings
+        sage: R = GF(7)['x, y, z']
+        sage: A = AffineSpace(R); A
         Affine Space of dimension 3 over Finite Field of size 7
-        sage: A.coordinate_ring() is R                                                  # optional - sage.rings.finite_rings
+        sage: A.coordinate_ring() is R
         True
 
     TESTS::
@@ -170,10 +173,10 @@ class AffineSpace_generic(AmbientSpace, AffineScheme):
         sage: AffineSpace(5, PolynomialRing(QQ, 'z'), 'Z')
         Affine Space of dimension 5 over Univariate Polynomial Ring in z over Rational Field
 
-        sage: AffineSpace(RealField(), 3, 'Z')
+        sage: AffineSpace(RealField(), 3, 'Z')                                          # needs sage.rings.real_mpfr
         Affine Space of dimension 3 over Real Field with 53 bits of precision
 
-        sage: AffineSpace(Qp(7), 2, 'x')                                                # optional - sage.rings.padics
+        sage: AffineSpace(Qp(7), 2, 'x')                                                # needs sage.rings.padics
         Affine Space of dimension 2 over 7-adic Field with capped relative precision 20
 
     Even 0-dimensional affine spaces are supported::
@@ -185,7 +188,7 @@ class AffineSpace_generic(AmbientSpace, AffineScheme):
         """
         EXAMPLES::
 
-            sage: AffineSpace(3, Zp(5), 'y')                                            # optional - sage.rings.padics
+            sage: AffineSpace(3, Zp(5), 'y')                                            # needs sage.rings.padics
             Affine Space of dimension 3 over 5-adic Ring with capped relative precision 20
         """
         AmbientSpace.__init__(self, n, R)
@@ -205,15 +208,15 @@ class AffineSpace_generic(AmbientSpace, AffineScheme):
 
         EXAMPLES::
 
-            sage: FF = FiniteField(3)                                                   # optional - sage.rings.finite_rings
-            sage: AA = AffineSpace(FF, 0)                                               # optional - sage.rings.finite_rings
-            sage: [ x for x in AA ]                                                     # optional - sage.rings.finite_rings
+            sage: FF = FiniteField(3)
+            sage: AA = AffineSpace(FF, 0)
+            sage: [ x for x in AA ]
             [()]
-            sage: AA = AffineSpace(FF, 1, 'Z')                                          # optional - sage.rings.finite_rings
-            sage: [ x for x in AA ]                                                     # optional - sage.rings.finite_rings
+            sage: AA = AffineSpace(FF, 1, 'Z')
+            sage: [ x for x in AA ]
             [(0), (1), (2)]
-            sage: AA.<z,w> = AffineSpace(FF, 2)                                         # optional - sage.rings.finite_rings
-            sage: [ x for x in AA ]                                                     # optional - sage.rings.finite_rings
+            sage: AA.<z,w> = AffineSpace(FF, 2)
+            sage: [ x for x in AA ]
             [(0, 0), (0, 1), (0, 2), (1, 0), (1, 1), (1, 2), (2, 0), (2, 1), (2, 2)]
 
         AUTHOR:
@@ -225,7 +228,7 @@ class AffineSpace_generic(AmbientSpace, AffineScheme):
         AHom = self.point_homset()
         C = AHom.codomain()
 
-        for v in cartesian_product_iterator([R for _ in range(n)]):
+        for v in product(*[R for _ in range(n)]):
             yield C._point(AHom, v, check=False)
 
     def ngens(self):
@@ -249,13 +252,13 @@ class AffineSpace_generic(AmbientSpace, AffineScheme):
 
         EXAMPLES::
 
-            sage: A = AffineSpace(1, GF(3))                                             # optional - sage.rings.finite_rings
-            sage: A.rational_points()                                                   # optional - sage.rings.finite_rings
+            sage: A = AffineSpace(1, GF(3))
+            sage: A.rational_points()
             [(0), (1), (2)]
-            sage: A.rational_points(GF(3^2, 'b'))                                       # optional - sage.rings.finite_rings
+            sage: A.rational_points(GF(3^2, 'b'))                                       # needs sage.rings.finite_rings
             [(0), (b), (b + 1), (2*b + 1), (2), (2*b), (2*b + 2), (b + 2), (1)]
 
-            sage: AffineSpace(2, ZZ).rational_points(GF(2))                             # optional - sage.rings.finite_rings
+            sage: AffineSpace(2, ZZ).rational_points(GF(2))
             [(0, 0), (0, 1), (1, 0), (1, 1)]
 
         TESTS::
@@ -264,7 +267,7 @@ class AffineSpace_generic(AmbientSpace, AffineScheme):
             Traceback (most recent call last):
             ...
             TypeError: base ring (= Rational Field) must be a finite field
-            sage: AffineSpace(1, GF(3)).rational_points(ZZ)                             # optional - sage.rings.finite_rings
+            sage: AffineSpace(1, GF(3)).rational_points(ZZ)
             Traceback (most recent call last):
             ...
             TypeError: second argument (= Integer Ring) must be a finite field
@@ -272,10 +275,10 @@ class AffineSpace_generic(AmbientSpace, AffineScheme):
         if F is None:
             if not isinstance(self.base_ring(), FiniteField):
                 raise TypeError("base ring (= %s) must be a finite field" % self.base_ring())
-            return [P for P in self]
+            return list(self)
         elif not isinstance(F, FiniteField):
             raise TypeError("second argument (= %s) must be a finite field" % F)
-        return [P for P in self.base_extend(F)]
+        return list(self.base_extend(F))
 
     def __eq__(self, right):
         """
@@ -333,7 +336,7 @@ class AffineSpace_generic(AmbientSpace, AffineScheme):
 
         TESTS::
 
-            sage: AffineSpace(3, Zp(5), 'y')._latex_()                                  # optional - sage.rings.padics
+            sage: AffineSpace(3, Zp(5), 'y')._latex_()                                  # needs sage.rings.padics
             '\\mathbf{A}_{\\Bold{Z}_{5}}^3'
         """
         return "\\mathbf{A}_{%s}^%s" % (latex(self.base_ring()), self.dimension_relative())
@@ -434,7 +437,7 @@ class AffineSpace_generic(AmbientSpace, AffineScheme):
 
         TESTS::
 
-            sage: AffineSpace(3, Zp(5), 'y')._repr_()                                   # optional - sage.rings.padics
+            sage: AffineSpace(3, Zp(5), 'y')._repr_()                                   # needs sage.rings.padics
             'Affine Space of dimension 3 over 5-adic Ring with capped relative precision 20'
         """
         return "Affine Space of dimension %s over %s" % (self.dimension_relative(), self.base_ring())
@@ -481,8 +484,8 @@ class AffineSpace_generic(AmbientSpace, AffineScheme):
 
     def _check_satisfies_equations(self, v):
         """
-        Return True if ``v`` defines a point on the scheme self; raise a
-        TypeError otherwise.
+        Return ``True`` if ``v`` defines a point on the scheme ``self``; raise a
+        :class:`TypeError` otherwise.
 
         EXAMPLES::
 
@@ -556,7 +559,7 @@ class AffineSpace_generic(AmbientSpace, AffineScheme):
 
         INPUT:
 
-        - ``right`` - an affine space or subscheme.
+        - ``right`` -- an affine space or subscheme.
 
         OUTPUT: an affine space.= or subscheme.
 
@@ -633,14 +636,14 @@ class AffineSpace_generic(AmbientSpace, AffineScheme):
             sage: A.<x,y,z> = AffineSpace(3, ZZ)
             sage: AQ = A.change_ring(QQ); AQ
             Affine Space of dimension 3 over Rational Field
-            sage: AQ.change_ring(GF(5))                                                 # optional - sage.rings.finite_rings
+            sage: AQ.change_ring(GF(5))
             Affine Space of dimension 3 over Finite Field of size 5
 
         ::
 
-            sage: K.<w> = QuadraticField(5)                                             # optional - sage.rings.number_field
-            sage: A = AffineSpace(K, 2, 't')                                            # optional - sage.rings.number_field
-            sage: A.change_ring(K.embeddings(CC)[1])                                    # optional - sage.rings.number_field
+            sage: K.<w> = QuadraticField(5)                                             # needs sage.rings.number_field
+            sage: A = AffineSpace(K, 2, 't')                                            # needs sage.rings.number_field
+            sage: A.change_ring(K.embeddings(CC)[1])                                    # needs sage.rings.number_field
             Affine Space of dimension 2 over Complex Field with 53 bits of precision
         """
         if isinstance(R, Map):
@@ -654,9 +657,9 @@ class AffineSpace_generic(AmbientSpace, AffineScheme):
 
         EXAMPLES::
 
-            sage: R = AffineSpace(2, GF(9,'alpha'), 'z').coordinate_ring(); R           # optional - sage.rings.finite_rings
+            sage: R = AffineSpace(2, GF(9,'alpha'), 'z').coordinate_ring(); R           # needs sage.rings.finite_rings
             Multivariate Polynomial Ring in z0, z1 over Finite Field in alpha of size 3^2
-            sage: AffineSpace(3, R, 'x').coordinate_ring()                              # optional - sage.rings.finite_rings
+            sage: AffineSpace(3, R, 'x').coordinate_ring()                              # needs sage.rings.finite_rings
             Multivariate Polynomial Ring in x0, x1, x2 over Multivariate Polynomial Ring
             in z0, z1 over Finite Field in alpha of size 3^2
         """
@@ -742,7 +745,7 @@ class AffineSpace_generic(AmbientSpace, AffineScheme):
 
         TESTS:
 
-        Check that :trac:`25897` is fixed::
+        Check that :issue:`25897` is fixed::
 
             sage: A.<x,y> = AffineSpace(ZZ, 2)
             sage: A.projective_embedding(4)
@@ -797,7 +800,7 @@ class AffineSpace_generic(AmbientSpace, AffineScheme):
 
         INPUT:
 
-        -  ``X`` - a list or tuple of equations.
+        -  ``X`` -- a list or tuple of equations.
 
         EXAMPLES::
 
@@ -810,6 +813,7 @@ class AffineSpace_generic(AmbientSpace, AffineScheme):
 
         ::
 
+            sage: # needs sage.libs.singular
             sage: X.defining_polynomials ()
             (x, y^2, x*y^2)
             sage: I = X.defining_ideal(); I
@@ -851,7 +855,7 @@ class AffineSpace_generic(AmbientSpace, AffineScheme):
             sage: AffineSpace(ZZ, 2, 'x').an_element()
             (5, 4)
 
-            sage: AffineSpace(Qp(5), 2, 'x').an_element()                               # optional - sage.rings.padics
+            sage: AffineSpace(Qp(5), 2, 'x').an_element()                               # needs sage.rings.padics
             (5^2 + O(5^22), 4*5 + O(5^21))
         """
         n = self.dimension_relative()
@@ -883,21 +887,21 @@ class AffineSpace_generic(AmbientSpace, AffineScheme):
         EXAMPLES::
 
             sage: A.<x> = AffineSpace(QQ, 1)
-            sage: A.chebyshev_polynomial(5, 'first')
+            sage: A.chebyshev_polynomial(5, 'first')                                    # needs sage.schemes
             Dynamical System of Affine Space of dimension 1 over Rational Field
               Defn: Defined on coordinates by sending (x) to (16*x^5 - 20*x^3 + 5*x)
 
         ::
 
             sage: A.<x> = AffineSpace(QQ, 1)
-            sage: A.chebyshev_polynomial(3, 'second')
+            sage: A.chebyshev_polynomial(3, 'second')                                   # needs sage.schemes
             Dynamical System of Affine Space of dimension 1 over Rational Field
               Defn: Defined on coordinates by sending (x) to (8*x^3 - 4*x)
 
         ::
 
             sage: A.<x> = AffineSpace(QQ, 1)
-            sage: A.chebyshev_polynomial(3, 2)
+            sage: A.chebyshev_polynomial(3, 2)                                          # needs sage.schemes
             Traceback (most recent call last):
             ...
             ValueError: keyword 'kind' must have a value of either 'first' or 'second'
@@ -921,15 +925,15 @@ class AffineSpace_generic(AmbientSpace, AffineScheme):
         ::
 
             sage: A.<x> = AffineSpace(QQ, 1)
-            sage: A.chebyshev_polynomial(7, monic=True)
+            sage: A.chebyshev_polynomial(7, monic=True)                                 # needs sage.schemes
             Dynamical System of Affine Space of dimension 1 over Rational Field
               Defn: Defined on coordinates by sending (x) to (x^7 - 7*x^5 + 14*x^3 - 7*x)
 
         ::
 
             sage: F.<t> = FunctionField(QQ)
-            sage: A.<x> = AffineSpace(F,1)
-            sage: A.chebyshev_polynomial(4, monic=True)
+            sage: A.<x> = AffineSpace(F, 1)
+            sage: A.chebyshev_polynomial(4, monic=True)                                 # needs sage.schemes
             Dynamical System of Affine Space of dimension 1
             over Rational function field in t over Rational Field
               Defn: Defined on coordinates by sending (x) to (x^4 + (-4)*x^2 + 2)
@@ -937,9 +941,13 @@ class AffineSpace_generic(AmbientSpace, AffineScheme):
         if self.dimension_relative() != 1:
             raise TypeError("affine space must be of dimension 1")
         n = ZZ(n)
-        if (n < 0):
+        if n < 0:
             raise ValueError("first parameter 'n' must be a non-negative integer")
+
         from sage.dynamics.arithmetic_dynamics.affine_ds import DynamicalSystem_affine
+        from sage.functions.orthogonal_polys import chebyshev_T, chebyshev_U
+        from sage.matrix.constructor import matrix
+
         if kind == 'first':
             if monic and self.base().characteristic() != 2:
                 f = DynamicalSystem_affine([chebyshev_T(n, self.gen(0))], domain=self)
@@ -983,9 +991,9 @@ class AffineSpace_field(AffineSpace_generic):
 
         TESTS::
 
-            sage: P2.<x,y,z> = AffineSpace(3, GF(3))                                    # optional - sage.rings.finite_rings
-            sage: point_homset = P2._point_homset(Spec(GF(3)), P2)                      # optional - sage.rings.finite_rings
-            sage: P2._point(point_homset, [1, 2, 3])                                    # optional - sage.rings.finite_rings
+            sage: P2.<x,y,z> = AffineSpace(3, GF(3))
+            sage: point_homset = P2._point_homset(Spec(GF(3)), P2)
+            sage: P2._point(point_homset, [1, 2, 3])
             (1, 2, 0)
         """
         return SchemeMorphism_point_affine_field(*args, **kwds)
@@ -998,8 +1006,8 @@ class AffineSpace_field(AffineSpace_generic):
 
         TESTS::
 
-            sage: P2.<x,y,z> = AffineSpace(3, GF(3))                                    # optional - sage.rings.finite_rings
-            sage: P2._morphism(P2.Hom(P2), [x, y, z])                                   # optional - sage.rings.finite_rings
+            sage: P2.<x,y,z> = AffineSpace(3, GF(3))
+            sage: P2._morphism(P2.Hom(P2), [x, y, z])
             Scheme endomorphism of Affine Space of dimension 3 over Finite Field of size 3
               Defn: Defined on coordinates by sending (x, y, z) to
                     (x, y, z)
@@ -1026,11 +1034,11 @@ class AffineSpace_field(AffineSpace_generic):
 
         kwds:
 
-        - ``bound`` - a real number
+        - ``bound`` -- a real number
 
-        - ``tolerance`` - a rational number in (0,1] used in doyle-krumm algorithm-4
+        - ``tolerance`` -- a rational number in (0,1] used in doyle-krumm algorithm-4
 
-        - ``precision`` - the precision to use for computing the elements of bounded height of number fields
+        - ``precision`` -- the precision to use for computing the elements of bounded height of number fields
 
         OUTPUT:
 
@@ -1051,11 +1059,11 @@ class AffineSpace_field(AffineSpace_generic):
         ::
 
             sage: u = QQ['u'].0
-            sage: A.<x,y> = AffineSpace(NumberField(u^2 - 2, 'v'), 2)                   # optional - sage.rings.number_field
-            sage: len(list(A.points_of_bounded_height(bound=2, tolerance=0.1)))         # optional - sage.rings.number_field
+            sage: A.<x,y> = AffineSpace(NumberField(u^2 - 2, 'v'), 2)                   # needs sage.rings.number_field
+            sage: len(list(A.points_of_bounded_height(bound=2, tolerance=0.1)))         # needs sage.rings.number_field
             529
         """
-        if is_RationalField(self.base_ring()):
+        if isinstance(self.base_ring(), RationalField):
             ftype = False  # stores whether field is a number field or the rational field
         elif self.base_ring() in NumberFields():  # true for rational field as well, so check is_RationalField first
             ftype = True
@@ -1105,15 +1113,16 @@ class AffineSpace_field(AffineSpace_generic):
 
         EXAMPLES::
 
+            sage: # needs sage.rings.number_field
             sage: R.<x> = QQ[]
-            sage: K.<w> = NumberField(x^5 - 2)                                          # optional - sage.rings.number_field
-            sage: AK.<x,y> = AffineSpace(K, 2)                                          # optional - sage.rings.number_field
-            sage: AK.weil_restriction()                                                 # optional - sage.rings.number_field
+            sage: K.<w> = NumberField(x^5 - 2)
+            sage: AK.<x,y> = AffineSpace(K, 2)
+            sage: AK.weil_restriction()
             Affine Space of dimension 10 over Rational Field
-            sage: R.<x> = K[]                                                           # optional - sage.rings.number_field
-            sage: L.<v> = K.extension(x^2 + 1)                                          # optional - sage.rings.number_field
-            sage: AL.<x,y> = AffineSpace(L, 2)                                          # optional - sage.rings.number_field
-            sage: AL.weil_restriction()                                                 # optional - sage.rings.number_field
+            sage: R.<x> = K[]
+            sage: L.<v> = K.extension(x^2 + 1)
+            sage: AL.<x,y> = AffineSpace(L, 2)
+            sage: AL.weil_restriction()
             Affine Space of dimension 4 over Number Field in w
              with defining polynomial x^5 - 2
         """
@@ -1147,7 +1156,7 @@ class AffineSpace_field(AffineSpace_generic):
         EXAMPLES::
 
             sage: A.<x,y,z> = AffineSpace(QQ, 3)
-            sage: A.curve([y - x^4, z - y^5])
+            sage: A.curve([y - x^4, z - y^5])                                           # needs sage.schemes
             Affine Curve over Rational Field defined by -x^4 + y, -y^5 + z
         """
         from sage.schemes.curves.constructor import Curve
@@ -1163,13 +1172,13 @@ class AffineSpace_field(AffineSpace_generic):
 
         EXAMPLES::
 
+            sage: # needs sage.libs.singular sage.schemes
             sage: A3.<x,y,z> = AffineSpace(3, QQ)
             sage: p1 = A3(1, 2, 3)
             sage: p2 = A3(4, 5, 6)
-            sage: A3.line_through(p1, p2)
+            sage: L = A3.line_through(p1, p2); L
             Affine Curve over Rational Field defined by -1/6*x + 1/6*y - 1/6,
               -1/6*x + 1/6*z - 1/3, -1/6*y + 1/6*z - 1/6, -1/6*x + 1/3*y - 1/6*z
-            sage: L = _
             sage: L(p1)
             (1, 2, 3)
             sage: L(p2)
@@ -1222,7 +1231,7 @@ class AffineSpace_field(AffineSpace_generic):
         if q is not None:
             v = [cp - cq for cp, cq in zip(p, q)]
         else:
-            v = [cp for cp in p]
+            v = list(p)
 
         return self._morphism(self.Hom(self), [x - c for x, c in zip(gens, v)])
 
@@ -1236,9 +1245,9 @@ class AffineSpace_finite_field(AffineSpace_field):
 
         TESTS::
 
-            sage: P2.<x,y,z> = AffineSpace(3, GF(3))                                    # optional - sage.rings.finite_rings
-            sage: point_homset = P2._point_homset(Spec(GF(3)), P2)                      # optional - sage.rings.finite_rings
-            sage: P2._point(point_homset, [1, 2, 3])                                    # optional - sage.rings.finite_rings
+            sage: P2.<x,y,z> = AffineSpace(3, GF(3))
+            sage: point_homset = P2._point_homset(Spec(GF(3)), P2)
+            sage: P2._point(point_homset, [1, 2, 3])
             (1, 2, 0)
         """
         return SchemeMorphism_point_affine_finite_field(*args, **kwds)
@@ -1251,8 +1260,8 @@ class AffineSpace_finite_field(AffineSpace_field):
 
         TESTS::
 
-            sage: P2.<x,y,z> = AffineSpace(3, GF(3))                                    # optional - sage.rings.finite_rings
-            sage: P2._morphism(P2.Hom(P2), [x, y, z])                                   # optional - sage.rings.finite_rings
+            sage: P2.<x,y,z> = AffineSpace(3, GF(3))
+            sage: P2._morphism(P2.Hom(P2), [x, y, z])
             Scheme endomorphism of Affine Space of dimension 3 over Finite Field of size 3
               Defn: Defined on coordinates by sending (x, y, z) to
                     (x, y, z)
