@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 r"""
 Galois representations attached to elliptic curves
 
@@ -97,7 +96,6 @@ REFERENCES:
 AUTHORS:
 
 - chris wuthrich (02/10): moved from ell_rational_field.py.
-
 """
 
 ######################################################################
@@ -457,7 +455,7 @@ class GaloisRepresentation(SageObject):
             sage: rho._is_surjective(7,100)
             True
 
-        TEST for :trac:`8451`::
+        TEST for :issue:`8451`::
 
             sage: E = EllipticCurve('648a1')
             sage: rho = E.galois_representation()
@@ -760,12 +758,12 @@ class GaloisRepresentation(SageObject):
             sage: EllipticCurve([0,0,1,2580,549326]).galois_representation().image_type(7)
             'The image is contained in the normalizer of a split Cartan group.'
 
-        Test :trac:`14577`::
+        Test :issue:`14577`::
 
             sage: EllipticCurve([0, 1, 0, -4788, 109188]).galois_representation().image_type(13)
             'The image in PGL_2(F_13) is the exceptional group S_4.'
 
-        Test :trac:`14752`::
+        Test :issue:`14752`::
 
             sage: EllipticCurve([0, 0, 0, -1129345880,-86028258620304]).galois_representation().image_type(11)
             'The image is contained in the normalizer of a non-split Cartan group.'
@@ -1109,7 +1107,7 @@ class GaloisRepresentation(SageObject):
 
         - a prime ``p``
 
-        - a natural number ``bound`` (optional, default=10000)
+        - a natural number ``bound`` (default: 10000)
 
         OUTPUT:
 
