@@ -41,7 +41,6 @@ AUTHORS:
 - David Roe       <roed@math.harvard.edu>
 
 - John Cremona
-
 """
 
 # ****************************************************************************
@@ -98,7 +97,7 @@ class KodairaSymbol_class(SageObject):
             sage: KodairaSymbol_class('In')
             In
 
-        Check that :trac:`31147` is fixed::
+        Check that :issue:`31147` is fixed::
 
             sage: latex(KodairaSymbol_class(-14))
             I_{10}^{*}
