@@ -1,12 +1,11 @@
-# -*- coding: utf-8 -*-
 r"""
 Global and semi-global minimal models for elliptic curves over number fields
 
-When E is an elliptic curve defined over a number field K of class
+When `E` is an elliptic curve defined over a number field `K` of class
 number 1, then it has a global minimal model, and we have a method to
-compute it, namely E.global_minimal_model().  Until Sage-6.7 this was
+compute it, namely ``E.global_minimal_model()``.  Until Sage-6.7 this was
 done using Tate's algorithm to minimise one prime at a time without
-affecting the other primes.  When the class number is not 1 a
+affecting the other primes.  When the class number is not 1, a
 different approach is used.
 
 In the general case global minimal models may or may not exist. This
@@ -22,8 +21,8 @@ return such a model.
 
 The implementation of this functionality is based on work of Kraus
 [Kra1989]_ which gives a local condition for when a pair of number field
-elements \(c_4\), \(c_6\) belong to a Weierstrass model which is
-integral at a prime \(P\), together with a global version. Only primes
+elements `c_4`, `c_6` belong to a Weierstrass model which is
+integral at a prime `P`, together with a global version. Only primes
 dividing 2 or 3 are hard to deal with. In order to compute the
 corresponding integral model one then needs to combine together the
 local transformations implicit in [Kra1989]_ into a single global one.
@@ -57,7 +56,7 @@ from sage.schemes.elliptic_curves.constructor import EllipticCurve
 
 def c4c6_nonsingular(c4, c6):
     r"""
-    Check if c4, c6 are integral with valid associated discriminant.
+    Check if `c_4`, `c_6` are integral with valid associated discriminant.
 
     INPUT:
 
@@ -65,7 +64,7 @@ def c4c6_nonsingular(c4, c6):
 
     OUTPUT:
 
-    Boolean, True if c4, c6 are both integral and c4^3-c6^2 is a
+    Boolean, ``True`` if `c_4`, `c_6` are both integral and `c_4^3-c_6^2` is a
     nonzero multiple of 1728.
 
     EXAMPLES:
@@ -86,11 +85,12 @@ def c4c6_nonsingular(c4, c6):
 
     Over number fields::
 
+        sage: # needs sage.rings.number_field
         sage: x = polygen(ZZ, 'x')
         sage: K.<a> = NumberField(x^2 - 10)
         sage: c4c6_nonsingular(-217728*a - 679104, 141460992*a + 409826304)
         True
-        sage: K.<a> = NumberField(x^3-10)
+        sage: K.<a> = NumberField(x^3 - 10)
         sage: c4c6_nonsingular(-217728*a - 679104, 141460992*a + 409826304)
         True
     """
@@ -108,23 +108,24 @@ def c4c6_model(c4, c6, assume_nonsingular=False):
 
     - ``c4``, ``c6`` -- elements of a number field
 
-    - ``assume_nonsingular`` (boolean, default False) -- if True,
+    - ``assume_nonsingular`` (boolean, default ``False``) -- if ``True``,
       check for integrality and nosingularity.
 
     OUTPUT:
 
-    The elliptic curve with a-invariants [0,0,0,-c4/48,-c6/864], whose
-    c-invariants are the given c4, c6.  If the supplied invariants are
-    singular, returns None when ``assume_nonsingular`` is False and
-    raises an ArithmeticError otherwise.
+    The elliptic curve with a-invariants `[0,0,0,-c_4/48,-c_6/864]`, whose
+    c-invariants are the given `c_4`, `c_6`.  If the supplied invariants are
+    singular, returns ``None`` when ``assume_nonsingular`` is ``False`` and
+    raises an :class:`ArithmeticError` otherwise.
 
     EXAMPLES::
 
         sage: from sage.schemes.elliptic_curves.kraus import c4c6_model
         sage: x = polygen(ZZ, 'x')
-        sage: K.<a> = NumberField(x^3 - 10)
-        sage: c4c6_model(-217728*a - 679104, 141460992*a + 409826304)
-        Elliptic Curve defined by y^2 = x^3 + (4536*a+14148)*x + (-163728*a-474336) over Number Field in a with defining polynomial x^3 - 10
+        sage: K.<a> = NumberField(x^3 - 10)                                             # needs sage.rings.number_field
+        sage: c4c6_model(-217728*a - 679104, 141460992*a + 409826304)                   # needs sage.rings.number_field
+        Elliptic Curve defined by y^2 = x^3 + (4536*a+14148)*x + (-163728*a-474336)
+         over Number Field in a with defining polynomial x^3 - 10
 
         sage: c4, c6 = EllipticCurve('389a1').c_invariants()
         sage: c4c6_model(c4,c6)
@@ -140,11 +141,11 @@ def c4c6_model(c4, c6, assume_nonsingular=False):
 
 def make_integral(a, P, e):
     r"""
-    Returns b in O_K with P^e|(a-b), given a in O_{K,P}.
+    Return `b` in `O_K` with `P^e|(a-b)`, given `a` in `O_{K,P}`.
 
     INPUT:
 
-    - ``a`` -- a number field element integral at ``P``
+    - ``a`` -- a number field element integral at `P`
 
     - ``P`` -- a prime ideal of the number field
 
@@ -158,7 +159,7 @@ def make_integral(a, P, e):
     ALGORITHM:
 
     Totally naive, we simply test residues modulo `P^e` until one
-    works.  We will only use this when P is a prime dividing 2 and e
+    works.  We will only use this when `P` is a prime dividing 2 and `e`
     is the ramification degree, so the number of residues to check is
     at worst `2^d` where `d` is the degree of the field.
 
@@ -166,18 +167,18 @@ def make_integral(a, P, e):
 
         sage: from sage.schemes.elliptic_curves.kraus import make_integral
 
+        sage: # needs sage.rings.number_field
         sage: x = polygen(ZZ, 'x')
         sage: K.<a> = NumberField(x^2 - 10)
         sage: P = K.primes_above(2)[0]
         sage: e = P.ramification_index(); e
         2
         sage: x = 1/5
-        sage: b = make_integral(x,P,e)
-        sage: b
+        sage: b = make_integral(x, P, e); b
         1
         sage: (b-x).valuation(P) >= e
         True
-        sage: make_integral(1/a,P,e)
+        sage: make_integral(1/a, P, e)
         Traceback (most recent call last):
         ...
         ArithmeticError: Cannot lift 1/10*a to O_K mod (Fractional ideal (2, a))^2
@@ -190,7 +191,7 @@ def make_integral(a, P, e):
 
 def sqrt_mod_4(x, P):
     r"""
-    Returns a local square root mod 4, if it exists.
+    Return a local square root mod 4, if it exists.
 
     INPUT:
 
@@ -200,21 +201,22 @@ def sqrt_mod_4(x, P):
 
     OUTPUT:
 
-    A pair (True, r) where that `r^2-x` has valuation at least `2e`,
-    or (False, 0) if there is no such `r`.  Note that
+    A pair ``(True, r)`` where that `r^2-x` has valuation at least `2e`,
+    or ``(False, 0)`` if there is no such `r`.  Note that
     `r^2\mod{P^{2e}}` only depends on `r\mod{P^e}`.
 
     EXAMPLES::
 
+        sage: # needs sage.rings.number_field
         sage: from sage.schemes.elliptic_curves.kraus import sqrt_mod_4
         sage: x = polygen(ZZ, 'x')
         sage: K.<a> = NumberField(x^2 - 10)
         sage: P = K.primes_above(2)[0]
-        sage: sqrt_mod_4(1+2*a,P)
+        sage: sqrt_mod_4(1 + 2*a, P)
         (False, 0)
-        sage: sqrt_mod_4(-1+2*a,P)
+        sage: sqrt_mod_4(-1 + 2*a, P)
         (True, a + 1)
-        sage: (1+a)^2 - (-1+2*a)
+        sage: (1+a)^2 - (-1 + 2*a)
         12
         sage: e = P.ramification_index()
         sage: ((1+a)^2 - (-1+2*a)).mod(P**e)
@@ -232,7 +234,7 @@ def sqrt_mod_4(x, P):
 
 def test_b2_local(c4, c6, P, b2, debug=False):
     r"""
-    Test if b2 gives a valid model at a prime dividing 3.
+    Test if `b_2` gives a valid model at a prime dividing 3.
 
     INPUT:
 
@@ -244,11 +246,12 @@ def test_b2_local(c4, c6, P, b2, debug=False):
 
     OUTPUT:
 
-    The elliptic curve which is the (b2/12,0,0)-transform of
-    [0,0,0,-c4/48,-c6/864] if this is integral at P, else False.
+    The elliptic curve which is the `(b_2/12,0,0)`-transform of
+    `[0,0,0,-c_4/48,-c_6/864]` if this is integral at `P`, else ``False``.
 
     EXAMPLES::
 
+        sage: # needs sage.rings.number_field
         sage: x = polygen(ZZ, 'x')
         sage: K.<a> = NumberField(x^2 - 10)
         sage: c4 = -60544*a + 385796
@@ -256,31 +259,39 @@ def test_b2_local(c4, c6, P, b2, debug=False):
         sage: P3a, P3b = K.primes_above(3)
         sage: from sage.schemes.elliptic_curves.kraus import test_b2_local
 
-    b2=0 works at the first prime but not the second::
+    `b_2=0` works at the first prime but not the second::
 
         sage: b2 = 0
-        sage: test_b2_local(c4,c6,P3a,b2)
-        Elliptic Curve defined by y^2 = x^3 + (3784/3*a-96449/12)*x + (1743740/27*a-32765791/108) over Number Field in a with defining polynomial x^2 - 10
-        sage: test_b2_local(c4,c6,P3b,b2)
+        sage: test_b2_local(c4,c6,P3a,b2)                                               # needs sage.rings.number_field
+        Elliptic Curve defined by
+         y^2 = x^3 + (3784/3*a-96449/12)*x + (1743740/27*a-32765791/108)
+         over Number Field in a with defining polynomial x^2 - 10
+        sage: test_b2_local(c4,c6,P3b,b2)                                               # needs sage.rings.number_field
         False
 
-    b2=-a works at the second prime but not the first::
+    `b_2=-a` works at the second prime but not the first::
 
-        sage: b2 = -a
-        sage: test_b2_local(c4,c6,P3a,b2,debug=True)
+        sage: b2 = -a                                                                   # needs sage.rings.number_field
+        sage: test_b2_local(c4,c6,P3a,b2,debug=True)                                    # needs sage.rings.number_field
         test_b2_local: not integral at Fractional ideal (3, a + 1)
         False
-        sage: test_b2_local(c4,c6,P3b,b2)
-        Elliptic Curve defined by y^2 = x^3 + (-1/4*a)*x^2 + (3784/3*a-192893/24)*x + (56378369/864*a-32879311/108) over Number Field in a with defining polynomial x^2 - 10
+        sage: test_b2_local(c4,c6,P3b,b2)                                               # needs sage.rings.number_field
+        Elliptic Curve defined by
+         y^2 = x^3 + (-1/4*a)*x^2 + (3784/3*a-192893/24)*x + (56378369/864*a-32879311/108)
+         over Number Field in a with defining polynomial x^2 - 10
 
-    Using CRT we can do both with the same b2::
+    Using CRT we can do both with the same `b_2`::
 
-        sage: b2 = K.solve_CRT([0,-a],[P3a,P3b]); b2
+        sage: b2 = K.solve_CRT([0,-a],[P3a,P3b]); b2                                    # needs sage.rings.number_field
         a + 1
-        sage: test_b2_local(c4,c6,P3a,b2)
-        Elliptic Curve defined by y^2 = x^3 + (1/4*a+1/4)*x^2 + (10091/8*a-128595/16)*x + (4097171/64*a-19392359/64) over Number Field in a with defining polynomial x^2 - 10
-        sage: test_b2_local(c4,c6,P3b,b2)
-        Elliptic Curve defined by y^2 = x^3 + (1/4*a+1/4)*x^2 + (10091/8*a-128595/16)*x + (4097171/64*a-19392359/64) over Number Field in a with defining polynomial x^2 - 10
+        sage: test_b2_local(c4,c6,P3a,b2)                                               # needs sage.rings.number_field
+        Elliptic Curve defined by
+         y^2 = x^3 + (1/4*a+1/4)*x^2 + (10091/8*a-128595/16)*x + (4097171/64*a-19392359/64)
+         over Number Field in a with defining polynomial x^2 - 10
+        sage: test_b2_local(c4,c6,P3b,b2)                                               # needs sage.rings.number_field
+        Elliptic Curve defined
+         by y^2 = x^3 + (1/4*a+1/4)*x^2 + (10091/8*a-128595/16)*x + (4097171/64*a-19392359/64)
+         over Number Field in a with defining polynomial x^2 - 10
     """
     E = c4c6_model(c4,c6).rst_transform(b2/12,0,0)
     if not (c4,c6) == E.c_invariants():
@@ -296,7 +307,7 @@ def test_b2_local(c4, c6, P, b2, debug=False):
 
 def test_b2_global(c4, c6, b2, debug=False):
     r"""
-    Test if b2 gives a valid model at all primes dividing 3.
+    Test if `b_2` gives a valid model at all primes dividing 3.
 
     INPUT:
 
@@ -306,12 +317,13 @@ def test_b2_global(c4, c6, b2, debug=False):
 
     OUTPUT:
 
-    The elliptic curve which is the (b2/12,0,0)-transform of
-    [0,0,0,-c4/48,-c6/864] if this is integral at all primes P
-    dividing 3, else False.
+    The elliptic curve which is the `(b_2/12,0,0)`-transform of
+    `[0,0,0,-c_4/48,-c_6/864]` if this is integral at all primes `P`
+    dividing 3, else ``False``.
 
     EXAMPLES::
 
+        sage: # needs sage.rings.number_field
         sage: x = polygen(ZZ, 'x')
         sage: K.<a> = NumberField(x^2 - 10)
         sage: c4 = -60544*a + 385796
@@ -319,7 +331,9 @@ def test_b2_global(c4, c6, b2, debug=False):
         sage: b2 = a+1
         sage: from sage.schemes.elliptic_curves.kraus import test_b2_global
         sage: test_b2_global(c4,c6,b2)
-        Elliptic Curve defined by y^2 = x^3 + (1/4*a+1/4)*x^2 + (10091/8*a-128595/16)*x + (4097171/64*a-19392359/64) over Number Field in a with defining polynomial x^2 - 10
+        Elliptic Curve defined by
+         y^2 = x^3 + (1/4*a+1/4)*x^2 + (10091/8*a-128595/16)*x + (4097171/64*a-19392359/64)
+         over Number Field in a with defining polynomial x^2 - 10
         sage: test_b2_global(c4,c6,0,debug=True)
         test_b2_global: not integral at all primes dividing 3
         False
@@ -342,7 +356,7 @@ def test_b2_global(c4, c6, b2, debug=False):
 
 def check_Kraus_local_3(c4, c6, P, assume_nonsingular=False, debug=False):
     r"""
-    Test if c4,c6 satisfy Kraus's conditions at a prime P dividing 3.
+    Test if `c_4`, `c_6` satisfy Kraus's conditions at a prime `P` dividing 3.
 
     INPUT:
 
@@ -350,17 +364,18 @@ def check_Kraus_local_3(c4, c6, P, assume_nonsingular=False, debug=False):
 
     - ``P`` -- a prime ideal of the number field which divides 3
 
-    - ``assume_nonsingular`` (boolean, default False) -- if True,
+    - ``assume_nonsingular`` (boolean, default ``False``) -- if ``True``,
       check for integrality and nosingularity.
 
     OUTPUT:
 
-    Either (False, 0) if Kraus's conditions fail, or (True, b2) if
+    Either ``(False, 0)`` if Kraus's conditions fail, or ``(True, b2)`` if
     they pass, in which case the elliptic curve which is the
-    (b2/12,0,0)-transform of [0,0,0,-c4/48,-c6/864] is integral at P.
+    `(b_2/12,0,0)`-transform of `[0,0,0,-c_4/48,-c_6/864]` is integral at `P`.
 
     EXAMPLES::
 
+        sage: # needs sage.rings.number_field
         sage: from sage.schemes.elliptic_curves.kraus import check_Kraus_local_3
         sage: x = polygen(ZZ, 'x')
         sage: K.<a> = NumberField(x^2 - 10)
@@ -374,7 +389,8 @@ def check_Kraus_local_3(c4, c6, P, assume_nonsingular=False, debug=False):
 
     An example in a field where 3 is ramified::
 
-        sage: K.<a> = NumberField(x^2-15)
+        sage: # needs sage.rings.number_field
+        sage: K.<a> = NumberField(x^2 - 15)
         sage: c4 = -60504*a + 386001
         sage: c6 = -55346820*a + 261045153
         sage: P3 = K.primes_above(3)[0]
@@ -413,7 +429,7 @@ def check_Kraus_local_3(c4, c6, P, assume_nonsingular=False, debug=False):
 
 def test_a1a3_local(c4, c6, P, a1, a3, debug=False):
     r"""
-    Test if a1,a3 are valid at a prime P dividing 2.
+    Test if `a_1`, `a_3` are valid at a prime `P` dividing `2`.
 
     INPUT:
 
@@ -425,11 +441,12 @@ def test_a1a3_local(c4, c6, P, a1, a3, debug=False):
 
     OUTPUT:
 
-    The elliptic curve which is the (a1^2/12,a1/2,a3/2)-transform of
-    [0,0,0,-c4/48,-c6/864] if this is integral at P, else False.
+    The elliptic curve which is the `(a_1^2/12,a_1/2,a_3/2)`-transform of
+    `[0,0,0,-c_4/48,-c_6/864]` if this is integral at `P`, else ``False``.
 
     EXAMPLES::
 
+        sage: # needs sage.rings.number_field
         sage: from sage.schemes.elliptic_curves.kraus import test_a1a3_local
         sage: x = polygen(ZZ, 'x')
         sage: K.<a> = NumberField(x^2 - 10)
@@ -437,7 +454,9 @@ def test_a1a3_local(c4, c6, P, a1, a3, debug=False):
         sage: c6 = -55799680*a + 262126328
         sage: P = K.primes_above(2)[0]
         sage: test_a1a3_local(c4,c6,P,a,0)
-        Elliptic Curve defined by y^2 + a*x*y = x^3 + (3784/3*a-24106/3)*x + (1772120/27*a-2790758/9) over Number Field in a with defining polynomial x^2 - 10
+        Elliptic Curve defined by
+         y^2 + a*x*y = x^3 + (3784/3*a-24106/3)*x + (1772120/27*a-2790758/9)
+         over Number Field in a with defining polynomial x^2 - 10
         sage: test_a1a3_local(c4,c6,P,a,a,debug=True)
         test_a1a3_local: not integral at Fractional ideal (2, a)
         False
@@ -456,7 +475,7 @@ def test_a1a3_local(c4, c6, P, a1, a3, debug=False):
 
 def test_a1a3_global(c4, c6, a1, a3, debug=False):
     r"""
-    Test if a1,a3 are valid at all primes P dividing 2.
+    Test if `a_1`, `a_3` are valid at all primes `P` dividing 2.
 
     INPUT:
 
@@ -466,12 +485,13 @@ def test_a1a3_global(c4, c6, a1, a3, debug=False):
 
     OUTPUT:
 
-    The elliptic curve which is the (a1^2/12,a1/2,a3/2)-transform of
-    [0,0,0,-c4/48,-c6/864] if this is integral at all primes P
-    dividing 2, else False.
+    The elliptic curve which is the `(a_1^2/12,a_1/2,a_3/2)`-transform of
+    `[0,0,0,-c_4/48,-c_6/864]` if this is integral at all primes `P`
+    dividing 2, else ``False``.
 
     EXAMPLES::
 
+        sage: # needs sage.rings.number_field
         sage: from sage.schemes.elliptic_curves.kraus import test_a1a3_global
         sage: x = polygen(ZZ, 'x')
         sage: K.<a> = NumberField(x^2 - 10)
@@ -480,7 +500,9 @@ def test_a1a3_global(c4, c6, a1, a3, debug=False):
         sage: test_a1a3_global(c4,c6,a,a,debug=False)
         False
         sage: test_a1a3_global(c4,c6,a,0)
-        Elliptic Curve defined by y^2 + a*x*y = x^3 + (3784/3*a-24106/3)*x + (1772120/27*a-2790758/9) over Number Field in a with defining polynomial x^2 - 10
+        Elliptic Curve defined by
+         y^2 + a*x*y = x^3 + (3784/3*a-24106/3)*x + (1772120/27*a-2790758/9)
+         over Number Field in a with defining polynomial x^2 - 10
     """
     E = c4c6_model(c4,c6).rst_transform(a1**2/12,a1/2,a3/2)
     if not (c4, c6) == E.c_invariants():
@@ -497,7 +519,7 @@ def test_a1a3_global(c4, c6, a1, a3, debug=False):
 
 def test_rst_global(c4, c6, r, s, t, debug=False):
     r"""
-    Test if the (r,s,t)-transform of the standard c4,c6-model is integral.
+    Test if the `(r,s,t)`-transform of the standard `c_4,c_6`-model is integral.
 
     INPUT:
 
@@ -507,19 +529,22 @@ def test_rst_global(c4, c6, r, s, t, debug=False):
 
     OUTPUT:
 
-    The elliptic curve which is the (r,s,t)-transform of
-    [0,0,0,-c4/48,-c6/864] if this is integral at all primes P, else
-    False.
+    The elliptic curve which is the `(r,s,t)`-transform of
+    `[0,0,0,-c_4/48,-c_6/864]` if this is integral at all primes `P`, else
+    ``False``.
 
     EXAMPLES::
 
+        sage: # needs sage.rings.number_field
         sage: from sage.schemes.elliptic_curves.kraus import test_rst_global
         sage: x = polygen(ZZ, 'x')
         sage: K.<a> = NumberField(x^2-10)
         sage: c4 = -60544*a + 385796
         sage: c6 = -55799680*a + 262126328
         sage: test_rst_global(c4,c6,1/3*a - 133/6, 3/2*a, -89/2*a + 5)
-        Elliptic Curve defined by y^2 + 3*a*x*y + (-89*a+10)*y = x^3 + (a-89)*x^2 + (1202*a-5225)*x + (34881*a-151813) over Number Field in a with defining polynomial x^2 - 10
+        Elliptic Curve defined by
+         y^2 + 3*a*x*y + (-89*a+10)*y = x^3 + (a-89)*x^2 + (1202*a-5225)*x + (34881*a-151813)
+         over Number Field in a with defining polynomial x^2 - 10
         sage: test_rst_global(c4,c6,a, 3, -89*a, debug=False)
         False
     """
@@ -556,7 +581,7 @@ def test_rst_global(c4, c6, r, s, t, debug=False):
 
 def check_Kraus_local_2(c4, c6, P, a1=None, assume_nonsingular=False):
     r"""
-    Test if c4,c6 satisfy Kraus's conditions at a prime P dividing 2.
+    Test if `c_4`, `c_6` satisfy Kraus's conditions at a prime `P` dividing 2.
 
     INPUT:
 
@@ -564,21 +589,22 @@ def check_Kraus_local_2(c4, c6, P, a1=None, assume_nonsingular=False):
 
     - ``P`` -- a prime ideal of the number field which divides 2
 
-    - ``a1`` -- an integral elements of a number field, or None (default)
+    - ``a1`` -- an integral elements of a number field, or ``None`` (default)
 
-    - ``assume_nonsingular`` (boolean, default False) -- if True,
-      check for integrality and nosingularity.
+    - ``assume_nonsingular`` (boolean, default ``False``) -- if ``True``,
+      check for integrality and nonsingularity.
 
     OUTPUT:
 
-    Either (False, 0, 0) if Kraus's conditions fail, or (True, a1,
-    a3) if they pass, in which case the elliptic curve which is the
-    (a1**2/12,a1/2,a3/2)-transform of [0,0,0,-c4/48,-c6/864] is
-    integral at P.  If a1 is provided and valid then the output will
-    be (True, a1, a3) for suitable a3.
+    Either ``(False, 0, 0)`` if Kraus's conditions fail, or ``(True, a1,
+    a3)`` if they pass, in which case the elliptic curve which is the
+    `(a_1^2/12,a_1/2,a_3/2)`-transform of `[0,0,0,-c_4/48,-c_6/864]` is
+    integral at `P`.  If `a_1` is provided and valid then the output will
+    be ``(True, a1, a3)`` for suitable `a_3`.
 
     EXAMPLES::
 
+        sage: # needs sage.rings.number_field
         sage: from sage.schemes.elliptic_curves.kraus import check_Kraus_local_2
         sage: x = polygen(ZZ, 'x')
         sage: K.<a> = NumberField(x^2 - 10)
@@ -647,7 +673,7 @@ def check_Kraus_local_2(c4, c6, P, a1=None, assume_nonsingular=False):
 
 def check_Kraus_local(c4, c6, P, assume_nonsingular=False):
     r"""
-    Check Kraus's conditions locally at a prime P.
+    Check Kraus's conditions locally at a prime `P`.
 
     INPUT:
 
@@ -655,17 +681,18 @@ def check_Kraus_local(c4, c6, P, assume_nonsingular=False):
 
     - ``P`` -- a prime ideal of the number field
 
-    - ``assume_nonsingular`` (boolean, default False) -- if True,
-      check for integrality and nosingularity.
+    - ``assume_nonsingular`` (boolean, default ``False``) -- if ``True``,
+      check for integrality and nonsingularity.
 
     OUTPUT:
 
-    Tuple: either (True,E) if there is a Weierstrass model E integral
-    at P and with invariants c4, c6, or (False, None) if there is
+    Tuple: either ``(True, E)`` if there is a Weierstrass model `E` integral
+    at `P` and with invariants `c_4`, `c_6`, or ``(False, None)`` if there is
     none.
 
     EXAMPLES::
 
+        sage: # needs sage.rings.number_field
         sage: from sage.schemes.elliptic_curves.kraus import check_Kraus_local
         sage: x = polygen(ZZ, 'x')
         sage: K.<a> = NumberField(x^2 - 15)
@@ -687,6 +714,7 @@ def check_Kraus_local(c4, c6, P, assume_nonsingular=False):
         sage: E.is_local_integral_model(P5) and (c4,c6)==E.c_invariants()
         True
 
+        sage: # needs sage.rings.number_field
         sage: c4 = 123+456*a
         sage: c6 = 789+101112*a
         sage: check_Kraus_local(c4,c6,P2)
@@ -719,22 +747,23 @@ def check_Kraus_local(c4, c6, P, assume_nonsingular=False):
 
 def check_Kraus_global(c4, c6, assume_nonsingular=False, debug=False):
     r"""
-    Test if c4,c6 satisfy Kraus's conditions at all primes.
+    Test if `c_4`, `c_6` satisfy Kraus's conditions at all primes.
 
     INPUT:
 
     - ``c4``, ``c6`` -- elements of a number field
 
-    - ``assume_nonsingular`` (boolean, default False) -- if True,
-      check for integrality and nosingularity.
+    - ``assume_nonsingular`` (boolean, default ``False``) -- if ``True``,
+      check for integrality and nonsingularity.
 
     OUTPUT:
 
-    Either False if Kraus's conditions fail, or, if they pass, an
-    elliptic curve E which is integral and has c-invariants c4,c6.
+    Either ``False`` if Kraus's conditions fail, or, if they pass, an
+    elliptic curve `E` which is integral and has c-invariants `c_4`, `c_6`.
 
     EXAMPLES::
 
+        sage: # needs sage.rings.number_field
         sage: from sage.schemes.elliptic_curves.kraus import check_Kraus_global
         sage: x = polygen(ZZ, 'x')
         sage: K.<a> = NumberField(x^2 - 10)
@@ -750,26 +779,33 @@ def check_Kraus_global(c4, c6, assume_nonsingular=False, debug=False):
         (a1, b2, a3) = (3*a, a + 1, 0)
         Using (r, s, t)=(1/3*a - 133/6, 3/2*a, -89/2*a + 5) should give a global integral model...
         ...and it does!
-        Elliptic Curve defined by y^2 + 3*a*x*y + (-89*a+10)*y = x^3 + (a-89)*x^2 + (1202*a-5225)*x + (34881*a-151813) over Number Field in a with defining polynomial x^2 - 10
+        Elliptic Curve defined by
+         y^2 + 3*a*x*y + (-89*a+10)*y = x^3 + (a-89)*x^2 + (1202*a-5225)*x + (34881*a-151813)
+         over Number Field in a with defining polynomial x^2 - 10
 
-        sage: K.<a> = NumberField(x^2-15)
+        sage: # needs sage.rings.number_field
+        sage: K.<a> = NumberField(x^2 - 15)
         sage: E = EllipticCurve([0, 0, 0, 4536*a + 14148, -163728*a - 474336])
         sage: c4, c6 = E.c_invariants()
         sage: check_Kraus_global(c4,c6)
-        Elliptic Curve defined by y^2 = x^3 + (4536*a+14148)*x + (-163728*a-474336) over Number Field in a with defining polynomial x^2 - 15
+        Elliptic Curve defined by y^2 = x^3 + (4536*a+14148)*x + (-163728*a-474336)
+         over Number Field in a with defining polynomial x^2 - 15
 
-    TESTS (see :trac:`17295`)::
+    TESTS (see :issue:`17295`)::
 
-        sage: K.<a> =NumberField(x^3 - 7*x - 5)
+        sage: # needs sage.rings.number_field
+        sage: K.<a> = NumberField(x^3 - 7*x - 5)
         sage: E = EllipticCurve([a, 0, 1, 2*a^2 + 5*a + 3, -a^2 - 3*a - 2])
-        sage: assert E.conductor().norm() ==8
+        sage: assert E.conductor().norm() == 8
         sage: G = K.galois_group(names='b')
         sage: def conj_curve(E,sigma): return EllipticCurve([sigma(a) for a in E.ainvs()])
         sage: EL = conj_curve(E,G[0])
         sage: L = EL.base_field()
-        sage: assert L.class_number()== 2
-        sage: EL.isogeny_class() # long time (~10s)
-        Isogeny class of Elliptic Curve defined by y^2 + (-1/90*b^4+7/18*b^2-1/2*b-98/45)*x*y + y = x^3 + (1/45*b^5-1/18*b^4-7/9*b^3+41/18*b^2+167/90*b-29/9)*x + (-1/90*b^5+1/30*b^4+7/18*b^3-4/3*b^2-61/90*b+11/5) over Number Field in b with defining polynomial x^6 - 42*x^4 + 441*x^2 - 697
+        sage: assert L.class_number() == 2
+        sage: EL.isogeny_class()  # long time (~10s)
+        Isogeny class of Elliptic Curve defined by
+         y^2 + (-1/90*b^4+7/18*b^2-1/2*b-98/45)*x*y + y = x^3 + (1/45*b^5-1/18*b^4-7/9*b^3+41/18*b^2+167/90*b-29/9)*x + (-1/90*b^5+1/30*b^4+7/18*b^3-4/3*b^2-61/90*b+11/5)
+         over Number Field in b with defining polynomial x^6 - 42*x^4 + 441*x^2 - 697
     """
     if not assume_nonsingular:
         if not c4c6_nonsingular(c4,c6):
@@ -895,14 +931,14 @@ def semi_global_minimal_model(E, debug=False):
 
     OUTPUT:
 
-    A tuple (Emin,I) where Emin is an elliptic curve which is either a
-    global minimal model of E if one exists (i.e., an integral model
-    which is minimal at every prime), or a semin-global minimal model
+    A tuple ``(Emin, I)`` where ``Emin`` is an elliptic curve which is either a
+    global minimal model of `E` if one exists (i.e., an integral model
+    which is minimal at every prime), or a semi-global minimal model
     (i.e., an integral model which is minimal at every prime except
-    one).  I is the unit ideal of Emin is a global minimal model, else
-    is the unique prime at which Emin is not minimal.  Thus in all
+    one).  `I` is the unit ideal of ``Emin`` is a global minimal model, else
+    is the unique prime at which ``Emin`` is not minimal.  Thus in all
     cases,
-    Emin.minimal_discriminant_ideal() * I**12 == (E.discriminant()).
+    ``Emin.minimal_discriminant_ideal() * I**12 == (E.discriminant())``.
 
     .. NOTE::
 
@@ -913,6 +949,7 @@ def semi_global_minimal_model(E, debug=False):
 
     EXAMPLES::
 
+        sage: # needs sage.rings.number_field
         sage: x = polygen(ZZ, 'x')
         sage: K.<a> = NumberField(x^2 - 10)
         sage: K.class_number()
@@ -921,27 +958,31 @@ def semi_global_minimal_model(E, debug=False):
         sage: from sage.schemes.elliptic_curves.kraus import semi_global_minimal_model
         sage: Emin, P = semi_global_minimal_model(E)
         sage: Emin
-        Elliptic Curve defined by y^2 + 3*x*y + (2*a-11)*y = x^3 + (a-10)*x^2 + (-152*a-415)*x + (1911*a+5920) over Number Field in a with defining polynomial x^2 - 10
+        Elliptic Curve defined by
+         y^2 + 3*x*y + (2*a-11)*y = x^3 + (a-10)*x^2 + (-152*a-415)*x + (1911*a+5920)
+         over Number Field in a with defining polynomial x^2 - 10
         sage: E.minimal_discriminant_ideal()*P**12 == K.ideal(Emin.discriminant())
         True
 
     TESTS:
 
-    Consider (see :trac:`20737`) a curve with no global minimal model
+    Consider (see :issue:`20737`) a curve with no global minimal model
     whose non-minimality class has order 3 in the class group, which
     has order 3315. The smallest prime in that ideal class has norm
     23567::
 
-        sage: K.<a> = NumberField(x^2-x+31821453)
-        sage: ainvs = (0, 0, 0, -382586771000351226384*a - 2498023791133552294513515, 358777608829102441023422458989744*a + 1110881475104109582383304709231832166)
+        sage: # long time, needs sage.rings.number_field
+        sage: K.<a> = NumberField(x^2 - x + 31821453)
+        sage: ainvs = (0, 0, 0, -382586771000351226384*a - 2498023791133552294513515,
+        ....:          358777608829102441023422458989744*a + 1110881475104109582383304709231832166)
         sage: E = EllipticCurve(ainvs)
         sage: from sage.schemes.elliptic_curves.kraus import semi_global_minimal_model
-        sage: Emin, p = semi_global_minimal_model(E) # long time (25s)
-        sage: p                                      # long time
+        sage: Emin, p = semi_global_minimal_model(E)  # 25s
+        sage: p
         Fractional ideal (23567, a + 2270)
-        sage: p.norm()                               # long time
+        sage: p.norm()
         23567
-        sage: Emin.discriminant().norm().factor()    # long time
+        sage: Emin.discriminant().norm().factor()
         23567^12
     """
     c = E.global_minimality_class()
