@@ -1,4 +1,4 @@
-# -*- coding: utf-8 -*-
+# sage.doctest: needs sage.rings.padics
 #
 # All these methods are imported in EllipticCurve_rational_field,
 # so there is no reason to add this module to the documentation.
@@ -85,7 +85,7 @@ def _normalize_padic_lseries(self, p, normalize, implementation, precision):
         sage: v = _normalize_padic_lseries(None, 5, "L_ratio", 'sage', 10)
         sage: u == v
         True
-     """
+    """
     if implementation == 'eclib':
         if normalize is None:
             normalize = "L_ratio"
@@ -295,7 +295,7 @@ def padic_regulator(self, p, prec=20, height=None, check_hypotheses=True):
         ....:     assert E.padic_regulator(5, prec) == full
 
     A case where the generator belongs to the formal group already
-    (:trac:`3632`)::
+    (:issue:`3632`)::
 
         sage: E = EllipticCurve([37,0])
         sage: E.padic_regulator(5,10)
@@ -481,7 +481,7 @@ def _multiply_point(E, R, P, m):
         sage: -67387681.sqrt() % 625     # sign is flipped here too
         541
 
-    Trivial cases (:trac:`3632`)::
+    Trivial cases (:issue:`3632`)::
 
         sage: _multiply_point(E, R, P, 1)
         (0, 624, 1)
@@ -595,7 +595,7 @@ def _multiple_to_make_good_reduction(E):
 
     - a positive integer ``n2``
 
-    EXAMPLE (:trac:`34790`)::
+    EXAMPLE (:issue:`34790`)::
 
         sage: from sage.schemes.elliptic_curves.padics import _multiple_to_make_good_reduction
         sage: E = EllipticCurve([-1728,-100656])
@@ -643,7 +643,7 @@ def _multiple_to_make_good_reduction(E):
         li = []
         for p in ps:
             np = u.valuation(p)
-            if Emin.discriminant() %p != 0:
+            if Emin.discriminant() % p != 0:
                 li.append(Emin.Np(p) * p**(np-1))
             elif Emin.has_additive_reduction(p):
                 li.append(E.tamagawa_number(p) * p**np)
@@ -652,7 +652,7 @@ def _multiple_to_make_good_reduction(E):
             else: # non split
                 li.append(E.tamagawa_number(p) * (p+1) * p**(np-1))
         otherbad = Integer(Emin.discriminant()).prime_divisors()
-        otherbad = [p for p in otherbad if u%p != 0 ]
+        otherbad = [p for p in otherbad if u % p != 0 ]
         li += [E.tamagawa_number(p) for p in otherbad]
         n2 = LCM(li)
     return n2
@@ -775,7 +775,7 @@ def padic_height(self, p, prec=20, sigma=None, check_hypotheses=True):
 
     TESTS:
 
-    Check that issue :trac:`20798` is solved::
+    Check that issue :issue:`20798` is solved::
 
         sage: E = EllipticCurve("91b")
         sage: h = E.padic_height(7,10)
@@ -1107,12 +1107,13 @@ def padic_sigma(self, p, N=20, E2=None, check=False, check_hypotheses=True):
 
     Test that it returns consistent results over a range of precision::
 
-        sage: max_N = 30   # get up to at least p^2         # long time
-        sage: E = EllipticCurve([1, 1, 1, 1, 1])            # long time
-        sage: p = 5                                         # long time
-        sage: E2 = E.padic_E2(5, max_N)                     # long time
-        sage: max_sigma = E.padic_sigma(p, max_N, E2=E2)    # long time
-        sage: for N in range(3, max_N):                     # long time
+        sage: # long time
+        sage: max_N = 30   # get up to at least p^2
+        sage: E = EllipticCurve([1, 1, 1, 1, 1])
+        sage: p = 5
+        sage: E2 = E.padic_E2(5, max_N)
+        sage: max_sigma = E.padic_sigma(p, max_N, E2=E2)
+        sage: for N in range(3, max_N):
         ....:    sigma = E.padic_sigma(p, N, E2=E2)
         ....:    assert sigma == max_sigma
     """
@@ -1585,7 +1586,7 @@ def matrix_of_frobenius(self, p, prec=20, check=False, check_hypotheses=True, al
     - ``prec`` -- (relative) `p`-adic precision for
       result  (default 20)
 
-    - ``check`` -- boolean (default: False), whether to perform a
+    - ``check`` -- boolean (default: ``False``), whether to perform a
       consistency check. This will slow down the computation by a
       constant factor 2. (The consistency check is to verify
       that its trace is correct to the specified precision. Otherwise,
