@@ -22,18 +22,18 @@ EXAMPLES::
 
 ::
 
-    sage: F.<a> = GF(3)                                                                 # optional - sage.rings.finite_rings
-    sage: R.<x> = F[]                                                                   # optional - sage.rings.finite_rings
-    sage: f = x^5 - 1                                                                   # optional - sage.rings.finite_rings
-    sage: C = HyperellipticCurve(f)                                                     # optional - sage.rings.finite_rings
-    sage: J = C.jacobian()                                                              # optional - sage.rings.finite_rings
-    sage: X = J(F)                                                                      # optional - sage.rings.finite_rings
-    sage: a = x^2 - x + 1; b = -x + 1; c = x - 1; d = 0                                 # optional - sage.rings.finite_rings
-    sage: D1 = X([a,b]); D1                                                             # optional - sage.rings.finite_rings
+    sage: F.<a> = GF(3)
+    sage: R.<x> = F[]
+    sage: f = x^5 - 1
+    sage: C = HyperellipticCurve(f)
+    sage: J = C.jacobian()
+    sage: X = J(F)
+    sage: a = x^2 - x + 1; b = -x + 1; c = x - 1; d = 0
+    sage: D1 = X([a,b]); D1
     (x^2 + 2*x + 1, y + x + 2)
-    sage: D2 = X([c,d]); D2                                                             # optional - sage.rings.finite_rings
+    sage: D2 = X([c,d]); D2
     (x + 2, y)
-    sage: D1 + D2                                                                       # optional - sage.rings.finite_rings
+    sage: D1 + D2
     (x^2 + 2*x + 2, y + 2*x + 1)
 """
 # ****************************************************************************
@@ -44,7 +44,7 @@ EXAMPLES::
 
 from sage.rings.polynomial.polynomial_ring_constructor import PolynomialRing
 from sage.rings.integer_ring import ZZ
-from sage.rings.integer import is_Integer, Integer
+from sage.rings.integer import Integer
 from sage.rings.polynomial.polynomial_element import Polynomial
 
 from sage.schemes.generic.homset import SchemeHomset_points
@@ -98,18 +98,18 @@ class JacobianHomset_divisor_classes(SchemeHomset_points):
 
         ::
 
-            sage: F.<a> = GF(3)                                                         # optional - sage.rings.finite_rings
-            sage: R.<x> = F[]                                                           # optional - sage.rings.finite_rings
-            sage: f = x^5 - 1                                                           # optional - sage.rings.finite_rings
-            sage: C = HyperellipticCurve(f)                                             # optional - sage.rings.finite_rings
-            sage: J = C.jacobian()                                                      # optional - sage.rings.finite_rings
-            sage: X = J(F)                                                              # optional - sage.rings.finite_rings
-            sage: a = x^2 - x + 1; b = -x + 1; c = x - 1; d = 0                         # optional - sage.rings.finite_rings
-            sage: D1 = X([a,b]); D1                                                     # optional - sage.rings.finite_rings
+            sage: F.<a> = GF(3)
+            sage: R.<x> = F[]
+            sage: f = x^5 - 1
+            sage: C = HyperellipticCurve(f)
+            sage: J = C.jacobian()
+            sage: X = J(F)
+            sage: a = x^2 - x + 1; b = -x + 1; c = x - 1; d = 0
+            sage: D1 = X([a,b]); D1
             (x^2 + 2*x + 1, y + x + 2)
-            sage: D2 = X([c,d]); D2                                                     # optional - sage.rings.finite_rings
+            sage: D2 = X([c,d]); D2
             (x + 2, y)
-            sage: D1 + D2                                                               # optional - sage.rings.finite_rings
+            sage: D1 + D2
             (x^2 + 2*x + 2, y + 2*x + 1)
         """
         if isinstance(P, (Integer, int)) and P == 0:
@@ -124,16 +124,16 @@ class JacobianHomset_divisor_classes(SchemeHomset_points):
             elif len(P) == 2:
                 P1 = P[0]
                 P2 = P[1]
-                if is_Integer(P1) and is_Integer(P2):
+                if isinstance(P1, Integer) and isinstance(P2, Integer):
                     R = PolynomialRing(self.value_ring(), 'x')
                     P1 = R(P1)
                     P2 = R(P2)
                     return JacobianMorphism_divisor_class_field(self, (P1, P2))
-                if is_Integer(P1) and isinstance(P2, Polynomial):
+                if isinstance(P1, Integer) and isinstance(P2, Polynomial):
                     R = PolynomialRing(self.value_ring(), 'x')
                     P1 = R(P1)
                     return JacobianMorphism_divisor_class_field(self, (P1, P2))
-                if is_Integer(P2) and isinstance(P1, Polynomial):
+                if isinstance(P2, Integer) and isinstance(P1, Polynomial):
                     R = PolynomialRing(self.value_ring(), 'x')
                     P2 = R(P2)
                     return JacobianMorphism_divisor_class_field(self, (P1, P2))
@@ -161,9 +161,9 @@ class JacobianHomset_divisor_classes(SchemeHomset_points):
         """
         Return S for a homset X(T) where T = Spec(S).
         """
-        from sage.schemes.generic.scheme import is_AffineScheme
+        from sage.schemes.generic.scheme import AffineScheme
         T = self.domain()
-        if is_AffineScheme(T):
+        if isinstance(T, AffineScheme):
             return T.coordinate_ring()
         else:
             raise TypeError("domain of argument must be of the form Spec(S)")
