@@ -1,3 +1,4 @@
+# sage.doctest: needs sage.geometry.polyhedron sage.graphs
 r"""
 Weierstrass form of a toric elliptic curve
 
@@ -175,8 +176,8 @@ def Discriminant(polynomial, variables=None):
         sage: Discriminant([quadratic1, quadratic2])
         -1/16
     """
-    (f, g) = WeierstrassForm(polynomial, variables)
-    return 4*f**3+27*g**2
+    f, g = WeierstrassForm(polynomial, variables)
+    return 4*f**3 + 27*g**2
 
 
 ######################################################################
@@ -198,7 +199,7 @@ def j_invariant(polynomial, variables=None):
     * A nodal cubic: `j(-y^2 + x^2 + x^3) = \infty`
 
     * A cuspidal cubic `y^2=x^3` has undefined `j`-invariant. In this
-      case, a ``ValueError`` is raised.
+      case, a :class:`ValueError` is raised.
 
     EXAMPLES::
 
@@ -219,10 +220,10 @@ def j_invariant(polynomial, variables=None):
         ...
         ValueError: curve is singular and has no well-defined j-invariant
     """
-    (f, g) = WeierstrassForm(polynomial, variables)
-    disc = 4*f**3+27*g**2
+    f, g = WeierstrassForm(polynomial, variables)
+    disc = 4*f**3 + 27*g**2
     if disc != 0:
-        return 1728 * 4*f**3/disc
+        return 1728 * 4 * f**3 / disc
     if f != 0:
         return Infinity
     raise ValueError('curve is singular and has no well-defined j-invariant')
@@ -280,7 +281,7 @@ def Newton_polytope_vars_coeffs(polynomial, variables):
     """
     R = polynomial.parent()
     var_indices = [R.gens().index(x) for x in variables]
-    result = dict()
+    result = {}
     for c, m in polynomial:
         e = m.exponents()[0]
         v = tuple([e[i] for i in var_indices])
@@ -504,7 +505,7 @@ def WeierstrassForm(polynomial, variables=None, transformation=False):
 ######################################################################
 def _check_homogeneity(polynomial, variables, weights, total_weight=None):
     """
-    Raise ``ValueError`` if the polynomial is not weighted
+    Raise :class:`ValueError` if the polynomial is not weighted
     homogeneous.
 
     INPUT:
@@ -525,7 +526,7 @@ def _check_homogeneity(polynomial, variables, weights, total_weight=None):
     OUTPUT:
 
     This function returns nothing. If the polynomial is not weighted
-    homogeneous, a ``ValueError`` is raised.
+    homogeneous, a :class:`ValueError` is raised.
 
     EXAMPLES::
 
@@ -551,8 +552,8 @@ def _check_homogeneity(polynomial, variables, weights, total_weight=None):
             total_weight = weight_e
         else:
             if weight_e != total_weight:
-                raise ValueError('the polynomial is not homogeneous with '
-                                 'weights '+str(weights))
+                msg = f'the polynomial is not homogeneous with weights {weights}'
+                raise ValueError(msg)
 
 
 ######################################################################
@@ -595,14 +596,14 @@ def _extract_coefficients(polynomial, monomials, variables):
             return tuple(0 for i in indices)
         e = monomial.exponents()[0]
         return tuple(e[i] for i in indices)
-    coeffs = dict()
+    coeffs = {}
     for c, m in polynomial:
         i = index(m)
         coeffs[i] = c*m + coeffs.pop(i, R.zero())
     result = tuple(coeffs.pop(index(m), R.zero()) // m for m in monomials)
     if coeffs:
-        raise ValueError('the polynomial contains more monomials than '
-                         'given: ' + str(coeffs))
+        msg = f'the polynomial contains more monomials than given: {coeffs}'
+        raise ValueError(msg)
     return result
 
 
@@ -622,7 +623,7 @@ def _check_polynomial_P2(cubic, variables):
     OUTPUT:
 
     This functions returns ``variables``, potentially guessed from the
-    polynomial ring. A ``ValueError`` is raised if the polynomial is
+    polynomial ring. A :class:`ValueError` is raised if the polynomial is
     not homogeneous.
 
     EXAMPLES::
@@ -756,7 +757,7 @@ def WeierstrassForm_P2(polynomial, variables=None):
     F = polynomial.base_ring()
     S = cubic.S_invariant()
     T = cubic.T_invariant()
-    return (27*S, -27/F(4)*T)
+    return (27 * S, -27 / F(4) * T)
 
 
 ######################################################################
@@ -779,7 +780,7 @@ def _check_polynomial_P1xP1(biquadric, variables):
     OUTPUT:
 
     This functions returns ``variables``, potentially guessed from the
-    polynomial ring. A ``ValueError`` is raised if the polynomial is
+    polynomial ring. A :class:`ValueError` is raised if the polynomial is
     not homogeneous.
 
     EXAMPLES::
@@ -852,7 +853,7 @@ def _partial_discriminant(quadric, y0, y1=None):
         monomials = (quadric.parent().one(), y0, y0**2)
         variables = [y0]
     else:
-        monomials = (y1**2, y0*y1, y0**2)
+        monomials = (y1**2, y0 * y1, y0**2)
         variables = [y0, y1]
     c = _extract_coefficients(quadric, monomials, variables)
     return c[1]**2 - 4*c[0]*c[2]
@@ -940,7 +941,7 @@ def WeierstrassForm_P1xP1(biquadric, variables=None):
     Q = invariant_theory.binary_quartic(delta, x, y)
     g2 = Q.EisensteinD()
     g3 = -Q.EisensteinE()
-    return (-g2/4, -g3/4)
+    return (-g2 / 4, -g3 / 4)
 
 
 ######################################################################
@@ -963,7 +964,7 @@ def _check_polynomial_P2_112(polynomial, variables):
     OUTPUT:
 
     This functions returns ``variables``, potentially guessed from the
-    polynomial ring. A ``ValueError`` is raised if the polynomial is
+    polynomial ring. A :class:`ValueError` is raised if the polynomial is
     not homogeneous.
 
     EXAMPLES::
@@ -991,7 +992,7 @@ def _check_polynomial_P2_112(polynomial, variables):
         _check_homogeneity(polynomial, variables, (1, 0, 1, -2), 0)
         _check_homogeneity(polynomial, variables, (0, 1, 0, 1), 2)
     elif len(variables) == 2:
-        variables = tuple([variables[0], variables[1], None, None])
+        variables = (variables[0], variables[1], None, None)
     else:
         raise ValueError(f'need two or four variables, got {variables}')
     return variables
@@ -1075,4 +1076,4 @@ def WeierstrassForm_P2_112(polynomial, variables=None):
     Q = invariant_theory.binary_quartic(delta, x, z)
     g2 = Q.EisensteinD()
     g3 = -Q.EisensteinE()
-    return (-g2/4, -g3/4)
+    return (-g2 / 4, -g3 / 4)
