@@ -62,11 +62,12 @@ class ConditionSet(Set_generic, Set_base, Set_boolean_operators, Set_add_sub_ope
         sage: 7/2 in EvensAndOdds
         False
 
-        sage: var('y')
+        sage: var('y')                                                                  # needs sage.symbolic
         y
-        sage: SmallOdds = ConditionSet(ZZ, is_odd, abs(y) <= 11, vars=[y]); SmallOdds
+        sage: SmallOdds = ConditionSet(ZZ, is_odd, abs(y) <= 11, vars=[y]); SmallOdds   # needs sage.symbolic
         { y ∈ Integer Ring : abs(y) <= 11, <function is_odd at 0x...>(y) }
 
+        sage: # needs sage.geometry.polyhedron
         sage: P = polytopes.cube(); P
         A 3-dimensional polyhedron in ZZ^3 defined as the convex hull of 8 vertices
         sage: P.rename("P")
@@ -74,16 +75,17 @@ class ConditionSet(Set_generic, Set_base, Set_boolean_operators, Set_add_sub_ope
         { x ∈ P : <function <lambda> at 0x...>(x) }
         sage: vector([1, 0, 0]) in P_inter_B
         True
-        sage: vector([1, 1, 1]) in P_inter_B
+        sage: vector([1, 1, 1]) in P_inter_B                                            # needs sage.symbolic
         False
 
+        sage: # needs sage.symbolic
         sage: predicate(x, y, z) = sqrt(x^2 + y^2 + z^2) < 1.2; predicate
         (x, y, z) |--> sqrt(x^2 + y^2 + z^2) < 1.20000000000000
-        sage: P_inter_B_again = ConditionSet(P, predicate); P_inter_B_again
+        sage: P_inter_B_again = ConditionSet(P, predicate); P_inter_B_again             # needs sage.geometry.polyhedron
         { (x, y, z) ∈ P : sqrt(x^2 + y^2 + z^2) < 1.20000000000000 }
-        sage: vector([1, 0, 0]) in P_inter_B_again
+        sage: vector([1, 0, 0]) in P_inter_B_again                                      # needs sage.geometry.polyhedron
         True
-        sage: vector([1, 1, 1]) in P_inter_B_again
+        sage: vector([1, 1, 1]) in P_inter_B_again                                      # needs sage.geometry.polyhedron
         False
 
     Iterating over subsets determined by predicates::
@@ -104,24 +106,25 @@ class ConditionSet(Set_generic, Set_base, Set_boolean_operators, Set_add_sub_ope
     Using ``ConditionSet`` without predicates provides a way of attaching variable names
     to a set::
 
-        sage: Z3 = ConditionSet(ZZ^3, vars=['x', 'y', 'z']); Z3
-        { (x, y, z) ∈ Ambient free module of rank 3 over the principal ideal domain Integer Ring }
-        sage: Z3.variable_names()
+        sage: Z3 = ConditionSet(ZZ^3, vars=['x', 'y', 'z']); Z3                         # needs sage.modules
+        { (x, y, z) ∈ Ambient free module of rank 3
+                       over the principal ideal domain Integer Ring }
+        sage: Z3.variable_names()                                                       # needs sage.modules
         ('x', 'y', 'z')
-        sage: Z3.arguments()
+        sage: Z3.arguments()                                                            # needs sage.modules sage.symbolic
         (x, y, z)
 
-        sage: Q4.<a, b, c, d> = ConditionSet(QQ^4); Q4
+        sage: Q4.<a, b, c, d> = ConditionSet(QQ^4); Q4                                  # needs sage.modules sage.symbolic
         { (a, b, c, d) ∈ Vector space of dimension 4 over Rational Field }
-        sage: Q4.variable_names()
+        sage: Q4.variable_names()                                                       # needs sage.modules sage.symbolic
         ('a', 'b', 'c', 'd')
-        sage: Q4.arguments()
+        sage: Q4.arguments()                                                            # needs sage.modules sage.symbolic
         (a, b, c, d)
 
     TESTS::
 
-        sage: TestSuite(P_inter_B).run(skip='_test_pickling')  # cannot pickle lambdas
-        sage: TestSuite(P_inter_B_again).run()
+        sage: TestSuite(P_inter_B).run(skip='_test_pickling')  # cannot pickle lambdas  # needs sage.geometry.polyhedron
+        sage: TestSuite(P_inter_B_again).run()                                          # needs sage.geometry.polyhedron sage.symbolic
     """
     @staticmethod
     def __classcall_private__(cls, universe, *predicates, vars=None, names=None, category=None):
@@ -130,9 +133,9 @@ class ConditionSet(Set_generic, Set_base, Set_boolean_operators, Set_add_sub_ope
 
         TESTS::
 
-            sage: ConditionSet(ZZ, names=["x"]) is ConditionSet(ZZ, names=x)
+            sage: ConditionSet(ZZ, names=["x"]) is ConditionSet(ZZ, names=x)                        # needs sage.symbolic
             True
-            sage: ConditionSet(RR, x > 0, names=x) is ConditionSet(RR, (x > 0).function(x))
+            sage: ConditionSet(RR, x > 0, names=x) is ConditionSet(RR, (x > 0).function(x))         # needs sage.symbolic
             True
         """
         if category is None:
@@ -224,10 +227,10 @@ class ConditionSet(Set_generic, Set_base, Set_boolean_operators, Set_add_sub_ope
 
         EXAMPLES::
 
-            sage: var('t') # parameter
+            sage: var('t')  # parameter                                                 # needs sage.symbolic
             t
-            sage: ZeroDimButNotNullary = ConditionSet(ZZ^0, t > 0, vars=("q"))
-            sage: ZeroDimButNotNullary._repr_()
+            sage: ZeroDimButNotNullary = ConditionSet(ZZ^0, t > 0, vars=("q"))          # needs sage.symbolic
+            sage: ZeroDimButNotNullary._repr_()                                         # needs sage.symbolic
             '{ q ∈ Ambient free module of rank 0
                    over the principal ideal domain Integer Ring : t > 0 }'
         """
@@ -257,10 +260,12 @@ class ConditionSet(Set_generic, Set_base, Set_boolean_operators, Set_add_sub_ope
             sage: Evens = ConditionSet(ZZ, is_even)
             sage: Evens._repr_condition(is_even)
             '<function is_even at 0x...>(x)'
+
+            sage: # needs sage.symbolic
             sage: BigSin = ConditionSet(RR, sin(x) > 0.9, vars=[x])
             sage: BigSin._repr_condition(BigSin._predicates[0])
             'sin(x) > 0.900000000000000'
-            sage: var('t') # parameter
+            sage: var('t')  # parameter
             t
             sage: ZeroDimButNotNullary = ConditionSet(ZZ^0, t > 0, vars=("q"))
             sage: ZeroDimButNotNullary._repr_condition(ZeroDimButNotNullary._predicates[0])
@@ -285,9 +290,9 @@ class ConditionSet(Set_generic, Set_base, Set_boolean_operators, Set_add_sub_ope
 
             sage: Odds = ConditionSet(ZZ, is_odd); Odds
             { x ∈ Integer Ring : <function is_odd at 0x...>(x) }
-            sage: args = Odds.arguments(); args
+            sage: args = Odds.arguments(); args                                         # needs sage.symbolic
             (x,)
-            sage: args[0].parent()
+            sage: args[0].parent()                                                      # needs sage.symbolic
             Symbolic Ring
         """
         from sage.symbolic.ring import SR
@@ -339,6 +344,7 @@ class ConditionSet(Set_generic, Set_base, Set_boolean_operators, Set_add_sub_ope
 
         TESTS::
 
+            sage: # needs sage.modules sage.symbolic
             sage: TripleDigits = ZZ^3
             sage: predicate(x, y, z) = sqrt(x^2 + y^2 + z^2) < 12; predicate
             (x, y, z) |--> sqrt(x^2 + y^2 + z^2) < 12
@@ -350,6 +356,7 @@ class ConditionSet(Set_generic, Set_base, Set_boolean_operators, Set_add_sub_ope
             sage: SmallTriples._call_predicate(predicate, element)
             sqrt(14) < 12
 
+            sage: # needs sage.modules sage.symbolic
             sage: var('t')
             t
             sage: TinyUniverse = ZZ^0
@@ -368,10 +375,11 @@ class ConditionSet(Set_generic, Set_base, Set_boolean_operators, Set_add_sub_ope
         r"""
         Return an element of ``self``.
 
-        This may raise ``NotImplementedError``.
+        This may raise :class:`NotImplementedError`.
 
         TESTS::
 
+            sage: # needs sage.modules sage.symbolic
             sage: TripleDigits = ZZ^3
             sage: predicate(x, y, z) = sqrt(x^2 + y^2 + z^2) < 12; predicate
             (x, y, z) |--> sqrt(x^2 + y^2 + z^2) < 12
@@ -406,6 +414,7 @@ class ConditionSet(Set_generic, Set_base, Set_boolean_operators, Set_add_sub_ope
 
         EXAMPLES::
 
+            sage: # needs sympy sage.modules sage.symbolic
             sage: predicate(x, y, z) = sqrt(x^2 + y^2 + z^2) < 12; predicate
             (x, y, z) |--> sqrt(x^2 + y^2 + z^2) < 12
             sage: SmallTriples = ConditionSet(ZZ^3, predicate); SmallTriples
@@ -418,17 +427,17 @@ class ConditionSet(Set_generic, Set_base, Set_boolean_operators, Set_add_sub_ope
             True
             sage: (5, 7, 9) in ST
             False
-
             sage: Interval = ConditionSet(RR, x >= -7, x <= 4, vars=[x]); Interval
             { x ∈ Real Field with 53 bits of precision : x >= -7, x <= 4 }
             sage: Interval._sympy_()
-            ConditionSet(x, (x >= -7) & (x <= 4), SageSet(Real Field with 53 bits of precision))
+            ConditionSet(x, (x >= -7) & (x <= 4),
+                            SageSet(Real Field with 53 bits of precision))
 
         If a predicate is not symbolic, we fall back to creating a wrapper::
 
             sage: Evens = ConditionSet(ZZ, is_even); Evens
             { x ∈ Integer Ring : <function is_even at 0x...>(x) }
-            sage: Evens._sympy_()
+            sage: Evens._sympy_()                                                       # needs sympy sage.symbolic
             SageSet({ x ∈ Integer Ring : <function is_even at 0x...>(x) })
         """
         from sage.interfaces.sympy import sympy_init
@@ -463,10 +472,12 @@ class ConditionSet(Set_generic, Set_base, Set_boolean_operators, Set_add_sub_ope
 
         EXAMPLES::
 
+            sage: # needs sage.modules sage.symbolic
             sage: in_small_oblong(x, y) = x^2 + 3 * y^2 <= 42
             sage: SmallOblongUniverse = ConditionSet(QQ^2, in_small_oblong)
             sage: SmallOblongUniverse
-            { (x, y) ∈ Vector space of dimension 2 over Rational Field : x^2 + 3*y^2 <= 42 }
+            { (x, y) ∈ Vector space of dimension 2
+                                over Rational Field : x^2 + 3*y^2 <= 42 }
             sage: parity_check(x, y) = abs(sin(pi/2*(x + y))) < 1/1000
             sage: EvenUniverse = ConditionSet(ZZ^2, parity_check); EvenUniverse
             { (x, y) ∈ Ambient free module of rank 2 over the principal ideal
@@ -480,13 +491,18 @@ class ConditionSet(Set_generic, Set_base, Set_boolean_operators, Set_add_sub_ope
         Combining two ``ConditionSet``s with different formal variables works correctly.
         The formal variables of the intersection are taken from ``self``::
 
-            sage: SmallMirrorUniverse = ConditionSet(QQ^2, in_small_oblong, vars=(y, x))
+            sage: # needs sage.modules sage.symbolic
+            sage: SmallMirrorUniverse = ConditionSet(QQ^2, in_small_oblong,
+            ....:                                    vars=(y, x))
             sage: SmallMirrorUniverse
-            { (y, x) ∈ Vector space of dimension 2 over Rational Field : 3*x^2 + y^2 <= 42 }
+            { (y, x) ∈ Vector space of dimension 2
+                               over Rational Field : 3*x^2 + y^2 <= 42 }
             sage: SmallOblongUniverse & SmallMirrorUniverse
-            { (x, y) ∈ Vector space of dimension 2 over Rational Field : x^2 + 3*y^2 <= 42 }
+            { (x, y) ∈ Vector space of dimension 2
+                               over Rational Field : x^2 + 3*y^2 <= 42 }
             sage: SmallMirrorUniverse & SmallOblongUniverse
-            { (y, x) ∈ Vector space of dimension 2 over Rational Field : 3*x^2 + y^2 <= 42 }
+            { (y, x) ∈ Vector space of dimension 2
+                               over Rational Field : 3*x^2 + y^2 <= 42 }
         """
         if isinstance(X, ConditionSet):
             return ConditionSet(self.ambient().intersection(X.ambient()),
