@@ -90,10 +90,12 @@ class DisjointUnionEnumeratedSets(UniqueRepresentation, Parent):
 
     In general the input can be any family::
 
+        sage: # needs sage.combinat
         sage: U3 = DisjointUnionEnumeratedSets(
         ....:     Family([2,3,4], Permutations, lazy=True))
         sage: U3
-        Disjoint union of Lazy family (<class 'sage.combinat.permutation.Permutations'>(i))_{i in [2, 3, 4]}
+        Disjoint union of Lazy family
+         (<class 'sage.combinat.permutation.Permutations'>(i))_{i in [2, 3, 4]}
         sage: U3.cardinality()
         32
         sage: it = iter(U3)
@@ -104,10 +106,12 @@ class DisjointUnionEnumeratedSets(UniqueRepresentation, Parent):
 
     This allows for infinite unions::
 
+        sage: # needs sage.combinat
         sage: U4 = DisjointUnionEnumeratedSets(
         ....:     Family(NonNegativeIntegers(), Permutations))
         sage: U4
-        Disjoint union of Lazy family (<class 'sage.combinat.permutation.Permutations'>(i))_{i in Non negative integers}
+        Disjoint union of Lazy family
+         (<class 'sage.combinat.permutation.Permutations'>(i))_{i in Non negative integers}
         sage: U4.cardinality()
         +Infinity
         sage: it = iter(U4)
@@ -126,6 +130,7 @@ class DisjointUnionEnumeratedSets(UniqueRepresentation, Parent):
 
     We demonstrate the ``keepkey`` option::
 
+        sage: # needs sage.combinat
         sage: Ukeep = DisjointUnionEnumeratedSets(
         ....:            Family(list(range(4)), Permutations), keepkey=True)
         sage: it = iter(Ukeep)
@@ -136,6 +141,7 @@ class DisjointUnionEnumeratedSets(UniqueRepresentation, Parent):
 
     We now demonstrate the ``facade`` option::
 
+        sage: # needs sage.combinat
         sage: UNoFacade = DisjointUnionEnumeratedSets(
         ....:                Family(list(range(4)), Permutations), facade=False)
         sage: it = iter(UNoFacade)
@@ -155,12 +161,12 @@ class DisjointUnionEnumeratedSets(UniqueRepresentation, Parent):
     The elements ``el`` of the disjoint union are simple wrapped elements.
     So to access the methods, you need to do ``el.value``::
 
-        sage: el[0]
+        sage: el[0]                                                                     # needs sage.combinat
         Traceback (most recent call last):
         ...
         TypeError: 'sage.structure.element_wrapper.ElementWrapper' object is not subscriptable
 
-        sage: el.value[0]
+        sage: el.value[0]                                                               # needs sage.combinat
         2
 
     Possible extensions: the current enumeration order is not suitable
@@ -210,16 +216,18 @@ class DisjointUnionEnumeratedSets(UniqueRepresentation, Parent):
 
         sage: TestSuite(U1).run()
         sage: TestSuite(U2).run()
-        sage: TestSuite(U3).run()
-        sage: TestSuite(U4).run()
-        doctest:...: UserWarning: Disjoint union of Lazy family (<class 'sage.combinat.permutation.Permutations'>(i))_{i in Non negative integers} is an infinite union
+        sage: TestSuite(U3).run()                                                       # needs sage.combinat
+        sage: TestSuite(U4).run()                                                       # needs sage.combinat
+        doctest:...: UserWarning: Disjoint union of Lazy family
+        (<class 'sage.combinat.permutation.Permutations'>(i))_{i in Non negative integers}
+        is an infinite union
         The default implementation of __contains__ can loop forever. Please overload it.
-        sage: TestSuite(UNoFacade).run()
+        sage: TestSuite(UNoFacade).run()                                                # needs sage.combinat
 
     We skip ``_test_an_element`` because the coercion framework does not
     currently allow a tuple to be returned for facade parents::
 
-        sage: TestSuite(Ukeep).run(skip="_test_an_element")
+        sage: TestSuite(Ukeep).run(skip="_test_an_element")                             # needs sage.combinat
 
     The following three lines are required for the pickling tests,
     because the classes ``MyUnion`` and ``UnionOfSpecialSets`` have
@@ -273,8 +281,8 @@ class DisjointUnionEnumeratedSets(UniqueRepresentation, Parent):
             ....:                                  2: FiniteEnumeratedSet([4,5,6])})
             sage: TestSuite(U).run()
 
-            sage: X = DisjointUnionEnumeratedSets({i: Partitions(i) for i in range(5)})
-            sage: TestSuite(X).run()
+            sage: X = DisjointUnionEnumeratedSets({i: Partitions(i) for i in range(5)})             # needs sage.combinat sage.libs.flint
+            sage: TestSuite(X).run()                                                    # needs sage.combinat sage.libs.flint
         """
         self._family = family
         self._facade = facade
@@ -326,7 +334,9 @@ class DisjointUnionEnumeratedSets(UniqueRepresentation, Parent):
             sage: U4 = DisjointUnionEnumeratedSets(
             ....:          Family(NonNegativeIntegers(), Compositions))
             sage: U4._is_a(Composition([3,2,1,1]))
-            doctest:...: UserWarning: Disjoint union of Lazy family (<class 'sage.combinat.composition.Compositions'>(i))_{i in Non negative integers} is an infinite union
+            doctest:...: UserWarning: Disjoint union of Lazy family
+            (<class 'sage.combinat.composition.Compositions'>(i))_{i in Non negative integers}
+            is an infinite union
             The default implementation of __contains__ can loop forever. Please overload it.
             True
         """
@@ -352,17 +362,19 @@ class DisjointUnionEnumeratedSets(UniqueRepresentation, Parent):
 
         EXAMPLES::
 
-            sage: U4 = DisjointUnionEnumeratedSets(
+            sage: U4 = DisjointUnionEnumeratedSets(                                     # needs sage.combinat
             ....:          Family(NonNegativeIntegers(), Partitions))
-            sage: Partition([]) in U4
-            doctest:...: UserWarning: Disjoint union of Lazy family (<class 'sage.combinat.partition.Partitions'>(i))_{i in Non negative integers} is an infinite union
+            sage: Partition([]) in U4                                                   # needs sage.combinat
+            doctest:...: UserWarning: Disjoint union of Lazy family
+            (<class 'sage.combinat.partition.Partitions'>(i))_{i in Non negative integers}
+            is an infinite union
             The default implementation of __contains__ can loop forever. Please overload it.
             True
 
         Note: one has to use a different family from the previous one in this
         file otherwise the warning is not re-issued::
 
-            sage: Partition([3,2,1,1]) in U4
+            sage: Partition([3,2,1,1]) in U4                                            # needs sage.combinat
             True
 
         The following call will loop forever::
@@ -387,6 +399,7 @@ class DisjointUnionEnumeratedSets(UniqueRepresentation, Parent):
             sage: [next(it), next(it), next(it), next(it), next(it), next(it)]
             [[], [1], [1, 2], [2, 1], [1, 2, 3], [1, 3, 2]]
 
+            sage: # needs sage.combinat
             sage: U4 = DisjointUnionEnumeratedSets(
             ....:          Family(NonNegativeIntegers(), Permutations),
             ....:          keepkey=True, facade=False)
@@ -463,6 +476,7 @@ class DisjointUnionEnumeratedSets(UniqueRepresentation, Parent):
         """
         TESTS::
 
+            sage: # needs sage.combinat sage.libs.flint
             sage: U = DisjointUnionEnumeratedSets(
             ....:          Family([1,2,3], Partitions), facade=False)
             sage: U._element_constructor_
@@ -483,6 +497,7 @@ class DisjointUnionEnumeratedSets(UniqueRepresentation, Parent):
         r"""
         TESTS::
 
+            sage: # needs sage.combinat sage.libs.flint
             sage: U = DisjointUnionEnumeratedSets(
             ....:         Family([1,2,3], Partitions), facade=False)
             sage: U([1])       # indirect doctest
@@ -497,6 +512,7 @@ class DisjointUnionEnumeratedSets(UniqueRepresentation, Parent):
                  2: Partitions of the integer 2,
                  3: Partitions of the integer 3}
 
+            sage: # needs sage.combinat sage.libs.flint
             sage: U = DisjointUnionEnumeratedSets(
             ....:          Family([1,2,3], Partitions), keepkey=True, facade=False)
             sage: U((1, [1]))    # indirect doctest
@@ -522,7 +538,9 @@ class DisjointUnionEnumeratedSets(UniqueRepresentation, Parent):
         """
         TESTS::
 
-            sage: X = DisjointUnionEnumeratedSets({i: Partitions(i) for i in range(5)})
+            sage: # needs sage.combinat sage.libs.flint
+            sage: X = DisjointUnionEnumeratedSets({i: Partitions(i)
+            ....:                                  for i in range(5)})
             sage: X([1]).parent()
             Partitions of the integer 1
             sage: X([2,1,1]).parent()  # indirect doctest
@@ -536,15 +554,17 @@ class DisjointUnionEnumeratedSets(UniqueRepresentation, Parent):
         because this returns a `tuple`, where the coercion framework requires
         an :class:`Element` be returned.
 
-            sage: X = DisjointUnionEnumeratedSets({i: Partitions(i) for i in range(5)},
+            sage: X = DisjointUnionEnumeratedSets({i: Partitions(i)                     # needs sage.combinat sage.libs.flint
+            ....:                                  for i in range(5)},
             ....:                                 keepkey=True)
-            sage: p = X._element_constructor_((0, []))  # indirect doctest
-            sage: p[1].parent()
+            sage: p = X._element_constructor_((0, []))  # indirect doctest              # needs sage.combinat sage.libs.flint
+            sage: p[1].parent()                                                         # needs sage.combinat sage.libs.flint
             Partitions of the integer 0
 
         Test that facade parents can create and properly access elements
-        that are tuples (fixed by :trac:`22382`)::
+        that are tuples (fixed by :issue:`22382`)::
 
+            sage: # needs sage.combinat sage.libs.flint
             sage: f = lambda mu: cartesian_product([mu.standard_tableaux(),
             ....:                                   mu.standard_tableaux()])
             sage: tabs = DisjointUnionEnumeratedSets(Family(Partitions(4), f))
@@ -588,6 +608,7 @@ class DisjointUnionEnumeratedSets(UniqueRepresentation, Parent):
         """
         TESTS::
 
+            sage: # needs sage.combinat sage.libs.flint
             sage: U = DisjointUnionEnumeratedSets(
             ....:          Family([1,2,3], Partitions), facade=False)
             sage: U.Element
@@ -597,7 +618,8 @@ class DisjointUnionEnumeratedSets(UniqueRepresentation, Parent):
             sage: U.Element
             Traceback (most recent call last):
             ...
-            AttributeError: 'DisjointUnionEnumeratedSets_with_category' object has no attribute 'Element'
+            AttributeError: 'DisjointUnionEnumeratedSets_with_category' object
+            has no attribute 'Element'...
         """
         if not self._facade:
             return ElementWrapper
