@@ -1,3 +1,4 @@
+# sage_setup: distribution = sagemath-objects
 r"""
 Finite Homogeneous Sequences
 
@@ -45,8 +46,8 @@ is ``Objects()``, the elements are not guaranteed to have any
 special parent.  This is what should happen, e.g., with finite field
 elements of different characteristics::
 
-    sage: v = Sequence([GF(3)(1), GF(7)(1)])                                            # optional - sage.rings.finite_rings
-    sage: v.universe()                                                                  # optional - sage.rings.finite_rings
+    sage: v = Sequence([GF(3)(1), GF(7)(1)])
+    sage: v.universe()
     Category of objects
 
 You can make a list immutable with ``v.freeze()``.  Assignment is
@@ -84,26 +85,26 @@ def Sequence(x, universe=None, check=True, immutable=False, cr=False, cr_str=Non
 
     INPUT:
 
-    - ``x`` - a list or tuple instance
+    - ``x`` -- a list or tuple instance
 
-    - ``universe`` - (default: None) the universe of elements; if None
+    - ``universe`` -- (default: None) the universe of elements; if None
       determined using canonical coercions and the entire list of
       elements.  If list is empty, is category Objects() of all
       objects.
 
-    - ``check`` -- (default: True) whether to coerce the elements of x
+    - ``check`` -- (default: ``True``) whether to coerce the elements of x
       into the universe
 
-    - ``immutable`` - (default: True) whether or not this sequence is
+    - ``immutable`` -- (default: ``True``) whether or not this sequence is
       immutable
 
-    - ``cr`` - (default: False) if True, then print a carriage return
+    - ``cr`` -- (default: ``False``) if True, then print a carriage return
       after each comma when printing this sequence.
 
-    - ``cr_str`` - (default: False) if True, then print a carriage return
+    - ``cr_str`` -- (default: ``False``) if True, then print a carriage return
       after each comma when calling ``str()`` on this sequence.
 
-    - ``use_sage_types`` -- (default: False) if True, coerce the
+    - ``use_sage_types`` -- (default: ``False``) if True, coerce the
        built-in Python numerical types int, float, complex to the
        corresponding Sage types (this makes functions like vector()
        more flexible)
@@ -201,9 +202,9 @@ def Sequence(x, universe=None, check=True, immutable=False, cr=False, cr_str=Non
     This example illustrates how every element of a list is taken into account
     when constructing a sequence.::
 
-        sage: v = Sequence([1, 7, 6, GF(5)(3)]); v                                      # optional - sage.rings.finite_rings
+        sage: v = Sequence([1, 7, 6, GF(5)(3)]); v
         [1, 2, 1, 3]
-        sage: v.universe()                                                              # optional - sage.rings.finite_rings
+        sage: v.universe()
         Finite Field of size 5
 
     TESTS::
@@ -276,23 +277,23 @@ class Sequence_generic(sage.structure.sage_object.SageObject, list):
 
     INPUT:
 
-    - ``x`` - a list or tuple instance
+    - ``x`` -- a list or tuple instance
 
-    - ``universe`` - (default: None) the universe of elements; if None
+    - ``universe`` -- (default: None) the universe of elements; if None
       determined using canonical coercions and the entire list of
       elements.  If list is empty, is category Objects() of all
       objects.
 
-    - ``check`` -- (default: True) whether to coerce the elements of x
+    - ``check`` -- (default: ``True``) whether to coerce the elements of x
       into the universe
 
-    - ``immutable`` - (default: True) whether or not this sequence is
+    - ``immutable`` -- (default: ``True``) whether or not this sequence is
       immutable
 
-    - ``cr`` - (default: False) if True, then print a carriage return
+    - ``cr`` -- (default: ``False``) if True, then print a carriage return
       after each comma when printing this sequence.
 
-    - ``use_sage_types`` -- (default: False) if True, coerce the
+    - ``use_sage_types`` -- (default: ``False``) if True, coerce the
        built-in Python numerical types int, float, complex to the
        corresponding Sage types (this makes functions like vector()
        more flexible)
@@ -397,9 +398,9 @@ class Sequence_generic(sage.structure.sage_object.SageObject, list):
 
     ::
 
-        sage: v = Sequence([1, 7, 6, GF(5)(3)]); v                                      # optional - sage.rings.finite_rings
+        sage: v = Sequence([1, 7, 6, GF(5)(3)]); v
         [1, 2, 1, 3]
-        sage: v.universe()                                                              # optional - sage.rings.finite_rings
+        sage: v.universe()
         Finite Field of size 5
 
     """
@@ -500,7 +501,7 @@ class Sequence_generic(sage.structure.sage_object.SageObject, list):
         else:
             y = self.__universe(value)
         list.__setitem__(self, n, y)
-        self.__hash=None
+        self.__hash = None
 
     def __getitem__(self, n):
         """
@@ -616,9 +617,9 @@ class Sequence_generic(sage.structure.sage_object.SageObject, list):
 
         INPUT:
 
-        - ``key`` - see Python ``list sort``
+        - ``key`` -- see Python ``list sort``
 
-        - ``reverse`` - see Python ``list sort``
+        - ``reverse`` -- see Python ``list sort``
 
         EXAMPLES::
 
@@ -674,11 +675,11 @@ class Sequence_generic(sage.structure.sage_object.SageObject, list):
         r"""
         TESTS::
 
-            sage: t= Sequence([sqrt(x), exp(x), x^(x-1)], universe=SR); t               # optional - sage.symbolic
+            sage: t= Sequence([sqrt(x), exp(x), x^(x-1)], universe=SR); t               # needs sage.symbolic
             [sqrt(x), e^x, x^(x - 1)]
-            sage: t._latex_()                                                           # optional - sage.symbolic
+            sage: t._latex_()                                                           # needs sage.symbolic
             '\\left[\\sqrt{x}, e^{x}, x^{x - 1}\\right]'
-            sage: latex(t)                                                              # optional - sage.symbolic
+            sage: latex(t)                                                              # needs sage.symbolic
             \left[\sqrt{x}, e^{x}, x^{x - 1}\right]
         """
         from sage.misc.latex import list_function as list_latex_function
@@ -845,7 +846,7 @@ class Sequence_generic(sage.structure.sage_object.SageObject, list):
 
         INPUT:
 
-        - ``name`` - some string
+        - ``name`` -- some string
 
         TESTS::
 
@@ -854,12 +855,12 @@ class Sequence_generic(sage.structure.sage_object.SageObject, list):
             sage: S.universe()
             Traceback (most recent call last):
             ...
-            AttributeError: 'Sequence_generic' object has no attribute '_Sequence_generic__universe'
+            AttributeError: 'Sequence_generic' object has no attribute '_Sequence_generic__universe'...
             sage: S._Sequence__universe = 'foobar'
             sage: S.universe()
             'foobar'
 
-        We test that :trac:`13998` is fixed::
+        We test that :issue:`13998` is fixed::
 
             sage: S = Sequence([])
             sage: S.set_immutable()
@@ -867,7 +868,7 @@ class Sequence_generic(sage.structure.sage_object.SageObject, list):
             sage: hash(S)
             Traceback (most recent call last):
             ...
-            AttributeError: 'Sequence_generic' object has no attribute '_Sequence_generic__hash'
+            AttributeError: 'Sequence_generic' object has no attribute '_Sequence_generic__hash'...
             sage: S._Sequence__hash = int(34)
             sage: hash(S)
             34
@@ -888,7 +889,9 @@ class Sequence_generic(sage.structure.sage_object.SageObject, list):
             self.__hash = self._Sequence__hash
             return self.__hash
         else:
-            raise AttributeError("'Sequence_generic' object has no attribute '%s'"%name)
+            raise AttributeError("'Sequence_generic' object has no attribute '%s'" % name)
+
+
 seq = Sequence
 
 from sage.misc.persist import register_unpickle_override
