@@ -372,7 +372,7 @@ class GenericDeclaration(UniqueRepresentation):
             True
             sage: GenericDeclaration(x, 'rational').contradicts({z: pi, y: pi})
             False
-       """
+        """
         if isinstance(soln, dict):
             value = soln.get(self._var)
             if value is None:
@@ -595,7 +595,7 @@ def assume(*args):
     TESTS:
 
     Test that you can do two non-relational
-    declarations at once (fixing :trac:`7084`)::
+    declarations at once (fixing :issue:`7084`)::
 
         sage: var('m,n')
         (m, n)
@@ -610,7 +610,7 @@ def assume(*args):
         sage: sin(m*pi).simplify()
         sin(pi*m)
 
-    Check that positive integers can be created (:trac:`20132`)
+    Check that positive integers can be created (:issue:`20132`)
 
         sage: x = SR.var('x', domain='positive')
         sage: assume(x, 'integer')
@@ -636,7 +636,7 @@ def assume(*args):
         Traceback (most recent call last):
         ...
         AttributeError: 'sage.rings.integer.Integer' object has no
-        attribute 'assume'
+        attribute 'assume'...
 
     Ensure that we can combine the two types of assumptions, as documented::
 
@@ -662,7 +662,7 @@ def assume(*args):
         [0 < x]
         sage: forget()
 
-    Check that :trac:`28538` is fixed::
+    Check that :issue:`28538` is fixed::
 
         sage: x, y = SR.var('x, y')
         sage: assume(x > 0)
@@ -815,7 +815,7 @@ def _forget_all():
 
     TESTS:
 
-    Check that :trac:`7315` is fixed::
+    Check that :issue:`7315` is fixed::
 
         sage: var('m,n')
         (m, n)
