@@ -26,7 +26,6 @@ REFERENCES:
 
 - Chap. 23 of R. Godement : *Algebra* [God1968]_
 - Chap. 15 of S. Lang : *Algebra* [Lan2002]_
-
 """
 #******************************************************************************
 #       Copyright (C) 2017 Eric Gourgoulhon <eric.gourgoulhon@obspm.fr>
@@ -311,7 +310,6 @@ class AlternatingContrTensor(FreeModuleTensor):
         """
         return self._tensor_rank
 
-
     def display(self, basis=None, format_spec=None):
         r"""
         Display the alternating contravariant tensor ``self`` in terms
@@ -438,7 +436,7 @@ class AlternatingContrTensor(FreeModuleTensor):
                     if is_atomic(coef_latex):
                         terms_latex.append(coef_latex + basis_term_latex)
                     else:
-                        terms_latex.append(r'\left(' + coef_latex + \
+                        terms_latex.append(r'\left(' + coef_latex +
                                            r'\right)' + basis_term_latex)
         if not terms_txt:
             expansion_txt = '0'
@@ -470,7 +468,6 @@ class AlternatingContrTensor(FreeModuleTensor):
 
     disp = display
 
-
     def wedge(self, other):
         r"""
         Exterior product of ``self`` with the alternating contravariant
