@@ -49,8 +49,7 @@ test.spyx
 
 AUTHORS:
 
-- Jeroen Demeyer (2010-11-20): initial version (:trac:`10300`)
-
+- Jeroen Demeyer (2010-11-20): initial version (:issue:`10300`)
 """
 from subprocess import Popen, PIPE
 import os
@@ -72,7 +71,7 @@ def test_executable(args, input="", timeout=100.0, pydebug_ignore_warnings=False
       should end with a newline.
 
     - ``timeout`` -- if the program produces no output for ``timeout``
-      seconds, a RuntimeError is raised.
+      seconds, a :class:`RuntimeError` is raised.
 
     - ``pydebug_ignore_warnings`` -- boolean. Set the PYTHONWARNINGS environment variable to ignore
       Python warnings when on a Python debug build (`--with-pydebug`, e.g. from building with
@@ -110,62 +109,68 @@ def test_executable(args, input="", timeout=100.0, pydebug_ignore_warnings=False
 
     Run Sage itself with various options::
 
-        sage: (out, err, ret) = test_executable([           # long time
+        sage: # long time
+        sage: (out, err, ret) = test_executable([
         ....:     "sage"], pydebug_ignore_warnings=True)
-        sage: out.find(version()) >= 0                      # long time
+        sage: out.find(version()) >= 0
         True
-        sage: err                                           # long time
+        sage: err
         ''
-        sage: ret                                           # long time
+        sage: ret
         0
 
-        sage: (out, err, ret) = test_executable([           # long time
+        sage: # long time
+        sage: (out, err, ret) = test_executable([
         ....:     "sage"], "3^33\n", pydebug_ignore_warnings=True)
-        sage: out.find(version()) >= 0                      # long time
+        sage: out.find(version()) >= 0
         True
-        sage: out.find("5559060566555523") >= 0             # long time
+        sage: out.find("5559060566555523") >= 0
         True
-        sage: err                                           # long time
+        sage: err
         ''
-        sage: ret                                           # long time
+        sage: ret
         0
 
-        sage: (out, err, ret) = test_executable([           # long time
+        sage: # long time
+        sage: (out, err, ret) = test_executable([
         ....:     "sage", "-q"], "3^33\n", pydebug_ignore_warnings=True)
-        sage: out.find(version()) >= 0                      # long time
+        sage: out.find(version()) >= 0
         False
-        sage: out.find("5559060566555523") >= 0             # long time
+        sage: out.find("5559060566555523") >= 0
         True
-        sage: err                                           # long time
+        sage: err
         ''
-        sage: ret                                           # long time
+        sage: ret
         0
 
-        sage: (out, err, ret) = test_executable([           # long time
+        sage: # long time
+        sage: (out, err, ret) = test_executable([
         ....:     "sage", "-c", "print(3^33)"])
-        sage: print(out)                                    # long time
+        sage: print(out)
         5559060566555523
-        sage: err                                           # long time
+        sage: err
         ''
-        sage: ret                                           # long time
+        sage: ret
         0
 
-        sage: (out, err, ret) = test_executable([           # long time
+        sage: # long time
+        sage: (out, err, ret) = test_executable([
         ....:     "sage", "--min", "-c", "print(3^33)"])
-        sage: print(out)                                    # long time
+        sage: print(out)
         5559060566555523
-        sage: err                                           # long time
+        sage: err
         ''
-        sage: ret                                           # long time
+        sage: ret
         0
 
-        sage: (out, err, ret) = test_executable([           # long time
+        sage: # long time
+        sage: (out, err, ret) = test_executable([
         ....:     "sage", "--startuptime"])
-        sage: out.find("Slowest module import") >= 0        # long time
+        sage: out.find("Slowest module import") >= 0
         True
-        sage: err                                           # long time
+        sage: err
         ''
-        sage: ret                                           # long time
+        sage: ret
         0
 
     Test help::
@@ -208,98 +213,74 @@ def test_executable(args, input="", timeout=100.0, pydebug_ignore_warnings=False
         sage: ret
         0
 
-        sage: (out, err, ret) = test_executable(["sage", "--root"])  # optional - sage_spkg
-        sage: len(out) >= 2   # at least one character + newline; optional - sage_spkg
+        sage: # optional - sage_spkg
+        sage: (out, err, ret) = test_executable(["sage", "--root"])
+        sage: len(out) >= 2
         True
-        sage: err  # optional - sage_spkg
+        sage: err
         ''
-        sage: ret  # optional - sage_spkg
+        sage: ret
         0
 
     Test ``sage --info [packages]``::
 
-        sage: out, err, ret = test_executable(["sage", "--info", "sqlite"])  # optional - sage_spkg
-        sage: print(out)  # optional - sage_spkg
+        sage: # optional - sage_spkg
+        sage: out, err, ret = test_executable(["sage", "--info", "sqlite"])
+        sage: print(out)
         sqlite...
         SQLite is a software library that implements a self-contained,
         serverless, zero-configuration, transactional SQL database engine.
         ...
-        sage: err  # optional - sage_spkg
+        sage: err
         ''
-        sage: ret  # optional - sage_spkg
+        sage: ret
         0
 
     Test ``sage-run`` on a Python file, both with an absolute and with a relative path::
 
-        sage: dir = tmp_dir(); name = 'python_test_file.py'
-        sage: fullname = os.path.join(dir, name)
-        sage: F = open(fullname, 'w')
-        sage: _ = F.write("print(3^33)\n")
-        sage: F.close()
-        sage: (out, err, ret) = test_executable(["sage", fullname])
-        sage: print(out)
-        34
-        sage: err
-        ''
-        sage: ret
-        0
-        sage: (out, err, ret) = test_executable(["sage", name], cwd=dir)
-        sage: print(out)
-        34
-        sage: err
-        ''
-        sage: ret
-        0
+        sage: import tempfile
+        sage: with tempfile.TemporaryDirectory() as dir:
+        ....:     name = 'python_test_file.py'
+        ....:     fullname = os.path.join(dir, name)
+        ....:     with open(fullname, 'w') as F:
+        ....:         _ = F.write("print(3^33)\n")
+        ....:     test_executable(["sage", fullname])
+        ....:     test_executable(["sage", name], cwd=dir)
+        ('34\n', '', 0)
+        ('34\n', '', 0)
 
     The same as above, but now with a ``.sage`` file.  This indirectly
     also tests the preparser::
 
-        sage: dir = tmp_dir(); name = 'sage_test_file.sage'
-        sage: fullname = os.path.join(dir, name)
-        sage: F = open(fullname, 'w')
-        sage: _ = F.write("k.<a> = GF(5^3); print(a^124)\n")
-        sage: F.close()
-        sage: (out, err, ret) = test_executable([           # long time
-        ....:     "sage", fullname])
-        sage: print(out)                                    # long time
-        1
-        sage: err                                           # long time
-        ''
-        sage: ret                                           # long time
-        0
-        sage: (out, err, ret) = test_executable([           # long time
-        ....:     "sage", name], cwd=dir)
-        sage: print(out)                                    # long time
-        1
-        sage: err                                           # long time
-        ''
-        sage: ret                                           # long time
-        0
+        sage: import tempfile
+        sage: with tempfile.TemporaryDirectory() as dir:  # long time
+        ....:     name = 'sage_test_file.sage'
+        ....:     fullname = os.path.join(dir, name)
+        ....:     with open(fullname, 'w') as F:
+        ....:         _ = F.write("k.<a> = GF(5^3); print(a^124)\n")
+        ....:     test_executable(["sage", fullname])
+        ....:     test_executable(["sage", name], cwd=dir)
+        ('1\n', '', 0)
+        ('1\n', '', 0)
 
     Test running a ``.spyx`` file::
 
-        sage: dir = tmp_dir(); name = 'sage_test_file.spyx'
-        sage: fullname = os.path.join(dir, name)
-        sage: F = open(fullname, 'w')
-        sage: _ = F.write("from cysignals.signals cimport *\nfrom sage.rings.integer cimport Integer\ncdef long i, s = 0\nsig_on()\nfor i in range(1000): s += i\nsig_off()\nprint(Integer(s))")
-        sage: F.close()
-        sage: (out, err, ret) = test_executable([           # long time
-        ....:     "sage", fullname], pydebug_ignore_warnings=True)
-        sage: print(out)                                    # long time
-        499500
-        sage: import re                                     # long time
-        sage: bool(re.match('Compiling.*spyx.*', err))      # long time
-        True
-        sage: ret                                           # long time
-        0
-        sage: (out, err, ret) = test_executable([           # long time
-        ....:     "sage", name], cwd=dir, pydebug_ignore_warnings=True)
-        sage: print(out)                                    # long time
-        499500
-        sage: bool(re.match('Compiling.*spyx.*', err))      # long time
-        True
-        sage: ret                                           # long time
-        0
+        sage: import tempfile
+        sage: with tempfile.TemporaryDirectory() as dir:  # long time
+        ....:     name = 'sage_test_file.spyx'
+        ....:     fullname = os.path.join(dir, name)
+        ....:     with open(fullname, 'w') as F:
+        ....:         _ = F.write("from cysignals.signals cimport *\n")
+        ....:         _ = F.write("from sage.rings.integer cimport Integer\n")
+        ....:         _ = F.write("cdef long i, s = 0\n")
+        ....:         _ = F.write("sig_on()\n")
+        ....:         _ = F.write("for i in range(5): s += i\n")
+        ....:         _ = F.write("sig_off()\n")
+        ....:         _ = F.write("print(Integer(s))")
+        ....:     test_executable(["sage", fullname], pydebug_ignore_warnings=True)
+        ....:     test_executable(["sage", name], cwd=dir, pydebug_ignore_warnings=True)
+        ('10\n', 'Compiling .../sage_test_file.spyx...\n', 0)
+        ('10\n', 'Compiling sage_test_file.spyx...\n', 0)
 
     Testing ``sage --preparse FILE`` and ``sage -t FILE``.  First create
     a file and preparse it::
@@ -318,17 +299,18 @@ def test_executable(args, input="", timeout=100.0, pydebug_ignore_warnings=False
 
     Now test my_script.sage and the preparsed version my_script.sage.py::
 
-        sage: (out, err, ret) = test_executable([           # long time
+        sage: # long time
+        sage: (out, err, ret) = test_executable([
         ....:     "sage", "-t", "--optional=sage", script])
-        sage: ret                                           # long time
+        sage: ret
         0
-        sage: out.find("All tests passed!") >= 0            # long time
+        sage: out.find("All tests passed!") >= 0
         True
-        sage: (out, err, ret) = test_executable([           # long time
+        sage: (out, err, ret) = test_executable([
         ....:     "sage", "-t", "--optional=sage", script_py])
-        sage: ret                                           # long time
+        sage: ret
         0
-        sage: out.find("All tests passed!") >= 0            # long time
+        sage: out.find("All tests passed!") >= 0
         True
 
     Test that the coding line and doctest are preserved::
@@ -407,10 +389,10 @@ def test_executable(args, input="", timeout=100.0, pydebug_ignore_warnings=False
         1
 
     Now run a test for the fixdoctests script and, in particular, check that the
-    issues raised in :trac:`10589` are fixed. We have to go to slightly silly
+    issues raised in :issue:`10589` are fixed. We have to go to slightly silly
     lengths to doctest the output.::
 
-        sage: test='r\"\"\"Add a doc-test for the fixdoctest command line option and, in particular, check that\n:trac:`10589` is fixed.\n\nEXAMPLES::\n\n    sage: 1+1              # incorrect output\n    3\n    sage: m=matrix(ZZ,3)   # output when none is expected\n    [0 0 0]\n    [0 0 0]\n    [1 0 0]\n    sage: (2/3)*m          # no output when it is expected\n    sage: mu=PartitionTuple([[4,4],[3,3,2,1],[1,1]])   # output when none is expected\n    [4, 4, 3, 3, 2, 1, 1]\n    sage: mu.pp()          # uneven indentation\n    ****\n    ****\n    sage: PartitionTuples.options(convention="French")\n    sage: mu.pp()         # fix doctest with uneven indentation\n    sage: PartitionTuples.options._reset()\n\"\"\"\n'
+        sage: test='r\"\"\"Add a doc-test for the fixdoctest command line option and, in particular, check that\n:issue:`10589` is fixed.\n\nEXAMPLES::\n\n    sage: 1+1              # incorrect output\n    3\n    sage: m=matrix(ZZ,3)   # output when none is expected\n    [0 0 0]\n    [0 0 0]\n    [1 0 0]\n    sage: (2/3)*m          # no output when it is expected\n    sage: mu=PartitionTuple([[4,4],[3,3,2,1],[1,1]])   # output when none is expected\n    [4, 4, 3, 3, 2, 1, 1]\n    sage: mu.pp()          # uneven indentation\n    ****\n    ****\n    sage: PartitionTuples.options(convention="French")\n    sage: mu.pp()         # fix doctest with uneven indentation\n    sage: PartitionTuples.options._reset()\n\"\"\"\n'
         sage: test_file = os.path.join(tmp_dir(), 'test_file.py')
         sage: F = open(test_file, 'w')
         sage: _ = F.write(test)
@@ -464,13 +446,14 @@ def test_executable(args, input="", timeout=100.0, pydebug_ignore_warnings=False
         sage: ret
         42
 
-        sage: (out, err, ret) = test_executable([   # long time
+        sage: # long time
+        sage: (out, err, ret) = test_executable([
         ....:     "sage", "--ipython"], "\n3**33\n", pydebug_ignore_warnings=True)
-        sage: out.find("5559060566555523") >= 0     # long time
+        sage: out.find("5559060566555523") >= 0
         True
-        sage: err                                   # long time
+        sage: err
         ''
-        sage: ret                                   # long time
+        sage: ret
         0
 
         sage: (out, err, ret) = test_executable(["sage", "--python"], "print(3^33)\n")
@@ -491,9 +474,8 @@ def test_executable(args, input="", timeout=100.0, pydebug_ignore_warnings=False
 
         sage: (out, err, ret) = test_executable(["sage", "--cython"])
         sage: print(err)
-        Cython (http://cython.org) is a compiler for code written in the
-        Cython language.  Cython is based on Pyrex by Greg Ewing.
         ...
+        cython: error: cython: Need at least one source file
 
         sage: def has_tty():
         ....:     try:
@@ -521,13 +503,14 @@ def test_executable(args, input="", timeout=100.0, pydebug_ignore_warnings=False
         sage: ret
         0
 
-        sage: (out, err, ret) = test_executable([                   # long time
+        sage: # long time
+        sage: (out, err, ret) = test_executable([
         ....:     "sage", "--gap", "-q"], "Size(SymmetricGroup(5));\n")
-        sage: out                                                   # long time
+        sage: out
         '120\n'
-        sage: err.replace('gap: halving pool size.', '').strip()    # long time
+        sage: err.replace('gap: halving pool size.', '').strip()
         ''
-        sage: ret                                                   # long time
+        sage: ret
         0
 
         sage: (out, err, ret) = test_executable([                   # long time  # optional - gdb
@@ -578,12 +561,13 @@ def test_executable(args, input="", timeout=100.0, pydebug_ignore_warnings=False
         sage: ret
         0
 
-        sage: (out, err, ret) = test_executable(["sage", "--R", "--version"])  # optional - r
-        sage: out.find("R version ") >= 0                                      # optional - r
+        sage: # optional - r
+        sage: (out, err, ret) = test_executable(["sage", "--R", "--version"])
+        sage: out.find("R version ") >= 0
         True
-        sage: err                                                              # optional - r
+        sage: err
         ''
-        sage: ret                                                              # optional - r
+        sage: ret
         0
 
         sage: (out, err, ret) = test_executable(["sage", "--sqlite3", "--version"])
@@ -596,28 +580,31 @@ def test_executable(args, input="", timeout=100.0, pydebug_ignore_warnings=False
 
     Check some things requiring an internet connection::
 
-        sage: (out, err, ret) = test_executable(["sage", "--standard"])  # optional - internet
-        sage: out.find("cython") >= 0  # optional - internet
+        sage: # optional - internet
+        sage: (out, err, ret) = test_executable(["sage", "--standard"])
+        sage: out.find("cython") >= 0
         True
-        sage: err  # optional - internet
+        sage: err
         ''
-        sage: ret  # optional - internet
+        sage: ret
         0
 
-        sage: (out, err, ret) = test_executable(["sage", "--optional"])  # optional - internet
-        sage: out.find("database_cremona_ellcurve") >= 0  # optional - internet
+        sage: # optional - internet
+        sage: (out, err, ret) = test_executable(["sage", "--optional"])
+        sage: out.find("database_cremona_ellcurve") >= 0
         True
-        sage: err  # optional - internet
+        sage: err
         ''
-        sage: ret  # optional - internet
+        sage: ret
         0
 
-        sage: (out, err, ret) = test_executable(["sage", "--experimental"])  # optional - internet
-        sage: out.find("valgrind") >= 0  # optional - internet
+        sage: # optional - internet
+        sage: (out, err, ret) = test_executable(["sage", "--experimental"])
+        sage: out.find("valgrind") >= 0
         True
-        sage: err  # optional - internet
+        sage: err
         ''
-        sage: ret  # optional - internet
+        sage: ret
         0
 
     Check an illegal command line option.  This outputs an error to stdout,
