@@ -227,6 +227,8 @@ class GenericCellComplex(SageObject):
             sage: K = SimplicialComplex([[1,2,3], [2,3,4]])
             sage: Z._n_cells_sorted(2, subcomplex=K)
             [(1, 2, 4), (1, 3, 4)]
+
+            sage: # needs sage.symbolic
             sage: S = SimplicialComplex([[complex(i), complex(1)]])
             sage: S._n_cells_sorted(0)
             [((1+0j),), (1j,)]
@@ -398,7 +400,7 @@ class GenericCellComplex(SageObject):
     #
     #     INPUT:
     #
-    #     -  ``n`` - positive integer (optional, default 1): suspend this
+    #     -  ``n`` -- positive integer (default: 1): suspend this
     #        many times.
     #     """
     #     raise NotImplementedError
@@ -433,7 +435,7 @@ class GenericCellComplex(SageObject):
 
         Definitely implement the following:
 
-        -  ``base_ring`` -- commutative ring (optional, default ZZ)
+        -  ``base_ring`` -- commutative ring (default: ZZ)
         -  ``cochain`` -- a bool: whether to return the cochain complex
 
         EXAMPLES::
@@ -466,15 +468,15 @@ class GenericCellComplex(SageObject):
         :type subcomplex: optional, default empty
         :param generators: If ``True``, return generators for the homology
            groups along with the groups.
-        :type generators: boolean; optional, default False
+        :type generators: boolean; optional, default: ``False``
         :param cohomology: If True, compute cohomology rather than homology.
-        :type cohomology: boolean; optional, default False
+        :type cohomology: boolean; optional, default: ``False``
         :param algorithm: The options are 'auto', 'dhsw', or 'pari'.
            See below for a description of what they mean.
         :type algorithm: string; optional, default 'pari'
         :param verbose: If True, print some messages as the homology is
            computed.
-        :type verbose: boolean; optional, default False
+        :type verbose: boolean; optional, default: ``False``
         :param reduced: If ``True``, return the reduced homology.
         :type reduced: boolean; optional, default ``True``
 
@@ -759,8 +761,8 @@ class GenericCellComplex(SageObject):
         INPUT:
 
         - ``n`` -- integer
-        - ``base_ring`` -- ring (optional, default `\ZZ`)
-        - ``cochains`` -- boolean (optional, default ``False``); if
+        - ``base_ring`` -- ring (default: `\ZZ`)
+        - ``cochains`` -- boolean (default: ``False``); if
           ``True``, return cochains instead
 
         The only difference between chains and cochains is
@@ -823,9 +825,9 @@ class GenericCellComplex(SageObject):
 
         INPUT:
 
-        - ``base_ring`` -- coefficient ring (optional, default
+        - ``base_ring`` -- coefficient ring (default:
           ``QQ``); must be a field
-        - ``cohomology`` -- boolean (optional, default ``False``); if
+        - ``cohomology`` -- boolean (default: ``False``); if
           ``True``, return cohomology instead of homology
 
         Homology basis elements are named 'h_{dim,i}' where i ranges
@@ -836,8 +838,7 @@ class GenericCellComplex(SageObject):
         .. SEEALSO::
 
             If ``cohomology`` is ``True``, this returns the cohomology
-            as a graded module. For the ring structure, use
-            :meth:`cohomology_ring`.
+            as a ring: it calls :meth:`cohomology_ring`.
 
         EXAMPLES::
 
@@ -865,7 +866,14 @@ class GenericCellComplex(SageObject):
             sage: list(H.basis(3))                                                      # needs sage.modules
             [h^{3,0}]
         """
-        from sage.homology.homology_vector_space_with_basis import HomologyVectorSpaceWithBasis
+        from sage.homology.homology_vector_space_with_basis import \
+            HomologyVectorSpaceWithBasis, HomologyVectorSpaceWithBasis_mod2, \
+            is_GF2
+
+        if cohomology:
+            return self.cohomology_ring(base_ring)
+        if is_GF2(base_ring):
+            return HomologyVectorSpaceWithBasis_mod2(base_ring, self)
         return HomologyVectorSpaceWithBasis(base_ring, self, cohomology)
 
     def cohomology_ring(self, base_ring=QQ):
@@ -882,7 +890,7 @@ class GenericCellComplex(SageObject):
 
         INPUT:
 
-        - ``base_ring`` -- coefficient ring (optional, default
+        - ``base_ring`` -- coefficient ring (default:
           ``QQ``); must be a field
 
         The basis elements in dimension ``dim`` are named 'h^{dim,i}'
@@ -972,7 +980,11 @@ class GenericCellComplex(SageObject):
             Cohomology ring of Simplicial complex with 9 vertices and
              18 facets over Rational Field
         """
-        from sage.homology.homology_vector_space_with_basis import CohomologyRing
+        from sage.homology.homology_vector_space_with_basis import CohomologyRing, \
+            CohomologyRing_mod2, is_GF2
+
+        if is_GF2(base_ring):
+            return CohomologyRing_mod2(base_ring, self)
         return CohomologyRing(base_ring, self)
 
     @abstract_method
@@ -1185,7 +1197,7 @@ class GenericCellComplex(SageObject):
         for dim in self.cells():
             cells += len(self.cells()[dim])
         if cells != 1:
-            cells_string = " and %s %s" % (cells, cells_name)
+            cells_string = " and {} {}".format(cells, cells_name)
         else:
             cells_string = " and 1 %s" % cell_name
         return Name + " complex " + vertex_string + cells_string
